(* ::Package:: *)

(************************************************************************)
(* This file was generated automatically by the Mathematica front end.  *)
(* It contains Initialization cells from a Notebook file, which         *)
(* typically will have the same name as this file except ending in      *)
(* ".nb" instead of ".m".                                               *)
(*                                                                      *)
(* This file is intended to be loaded into the Mathematica kernel using *)
(* the package loading commands Get or Needs.  Doing so is equivalent   *)
(* to using the Evaluate Initialization Cells menu command in the front *)
(* end.                                                                 *)
(*                                                                      *)
(* DO NOT EDIT THIS FILE.  This entire file is regenerated              *)
(* automatically each time the parent Notebook file is saved in the     *)
(* Mathematica front end.  Any changes you make to this file will be    *)
(* overwritten.                                                         *)
(************************************************************************)



(* TimeSamp for Package Version Control *)

Unprotect[TimeStamp];

TimeStamp::usage="TimeStamp[context] should be set to a Date[]-List indicating the version of the corresponding package.";

TimeStamp["MathVisionTools`BSpline`"] = {2010,11,14,15,0,0};

Protect[TimeStamp];


(*:Name: MathVisionTools`BSpline` *)

(*:Author: Markus van Almsick *)

(*:Email address: m.v.almsick@tue.nl *)

(*:Context: MathVisionTools`BSpline` *)

(*:Package Version: 2.0 *)

(*:Mathematica Version: 5.1 *)

(*:Copyright: Copyright 2005-2010, Markus van Almsick *)

(*:Title: BSplineDistribution *)

(*:Summary: This package provides properties and functionals of the uniform
probability distribution and sums there of called B-splines. *)

(*:Keywords: continuous distribution, uniform distribution, B-spline *)

(*:Warning:This package extends the definition of several descriptive statistics functions and the definition of Random.If the original usage messages are reloaded this change will not be reflected in the usage message, although the extended functionality will remain. *)

(*:Requirements: None *)

(*:Source: None *)

(*:History: Version 1.0 by Markus van Almsick, Decemeber 2004 *)

(*:Limitations: Works only for Mathematica 6.0 or later. *)

(*:Discussion: *)

(*:To do: *)


BeginPackage[
"MathVisionTools`BSpline`"
]

Unprotect[BSplineDistribution];


BSplineDistribution::usage="BSplineDistribution[n] represents the cardinal n-th B-spline, which is the convolution of (n+1) uniform distributions that range from -1/2 to 1/2. The resulting B-spline distribution thus reaches from -n/2 to n/2. To obtain a B-spline distribution in the domain [min,max] use BSplineDistribution[n, min, max]. All of Mathematica's statistics functions like PDF, CDF, Mean, ... apply."


Begin["`Private`"]


(* B-Spline Distribution *)


BSplineDistribution/:DistributionParameterQ[BSplineDistribution[n_]]:= IntegerQ[n] && n>=0;


BSplineDistribution::order="The lower boundary `1` of the distribution must be smaller than the upper boundary `2`."


BSplineDistribution/:DistributionParameterQ[BSplineDistribution[n_,min_,max_]]:= 
If[min<=max,IntegerQ[n] && n>=0,Message[BSplineDistribution::order,min,max];False]


BSplineDistribution/:DistributionDomainQ[BSplineDistribution[n_],x_]:=FreeQ[N[x],Complex]&&TrueQ[-((n+1)/2)<= x<= (n+1)/2];


BSplineDistribution/:DistributionDomainQ[BSplineDistribution[n_],list_?VectorQ]:=FreeQ[N[list],Complex]&&TrueQ[And@@Thread[-((n+1)/2)<= list<= (n+1)/2]];


BSplineDistribution/:DistributionDomainQ[BSplineDistribution[n_,min_,max_],list_?VectorQ]:=FreeQ[N[list],Complex]&&TrueQ[And@@Thread[min<= list<= max]];


BSplineDistribution/:DistributionDomainQ[BSplineDistribution[n_,min_,max_],x_]:=FreeQ[N[x],Complex]&&TrueQ[min<=x<=max];


BSplineDistribution/:Domain[BSplineDistribution[n_]]:=Interval[{-((n+1)/2),(n+1)/2}] /;DistributionParameterQ[BSplineDistribution[n]]


BSplineDistribution/:Domain[BSplineDistribution[n_,min_,max_]]:=Interval[{min,max}]/;DistributionParameterQ[BSplineDistribution[n,min,max]]


BSplineDistribution/:PDF[BSplineDistribution[0],x_]=Piecewise[{{1/2,x==-1/2||x==1/2},{1,-1/2<x<1/2}},0];


BSplineDistribution/:PDF[BSplineDistribution[0,min_,max_],x_]=Piecewise[{{1/(2(max-min)),x==min||x==max},{1/(max-min),0<(x-min)/(max-min)<1}}];


BSplineDistribution/:PDF[BSplineDistribution[1,min_,max_],x_]=1/(max-min)^2* Piecewise[{{4*(x-min),-2<2*(2*x-max-min)/(max-min)<=0},{4*(max-x),0<2*(2*x-max-min)/(max-min)<2}},0];


BSplineDistribution/:PDF[BSplineDistribution[2],x_]=Piecewise[{{(3+2*x)^2/8,-3/2<x<=-1/2},{3/4-x^2,-1/2<x<=1/2},{(3-2*x)^2/8,1/2<x<3/2}},0];


BSplineDistribution/:PDF[BSplineDistribution[2,min_,max_],x_]=1/(2*(max-min)^3)*Piecewise[{{27*(min-x)^2,-3<3*(-max-min+2*x)/(max-min)<=-1},{-9*(max^2+4*max*min+min^2-6*(max+min)*x+6*x^2),-1<3*(-max-min+2*x)/(max-min)<=1},{27*(max-x)^2,1<3*(-max-min+2*x)/(max-min)<3}},0];


BSplineDistribution/:PDF[BSplineDistribution[3],x_]=
Piecewise[{
{(2+x)^3/6,-2<x<=-1},
{(4-3*x^2*(2+x))/6,-1<x<=0},
{(4+3*(-2+x)*x^2)/6,0<x<=1},
{-(-2+x)^3/6,1<x<2}},0
];


BSplineDistribution/:PDF[BSplineDistribution[3,min_,max_],x_]=
1/(3*(max-min)^4)*
Piecewise[{
{-128*(min-x)^3,-4<4*(-max-min+2*x)/(max-min)<=-2},
{8*(max^3+11*min^3+3*max^2*(3*min-4*x)+3*max*(3*min-4*x)^2-60*min^2*x+96*min*x^2-48*x^3),-2<4*(-max-min+2*x)/(max-min)<=0},
{-8*(11*max^3+27*max^2*min+9*max*min^2+min^3)+96*(max+min)*(5*max+min)*x-384*(2*max+min)*x^2+384*x^3,0<4*(-max-min+2*x)/(max-min)<=2},
{128*(max-x)^3,2<4*(-max-min+2*x)/(max-min)<4}},0
];


BSplineDistribution/:PDF[BSplineDistribution[n_],x_]:=1/(2 n!) \!\(
\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \(n + 1\)]\(Binomial[n + 1, k] 
\*SuperscriptBox[\((x + 
\*FractionBox[\(n + 1\), \(2\)] - k)\), \(n\)]\ 
\*SuperscriptBox[\((\(-1\))\), \(k\)]\ Sign[x + 
\*FractionBox[\(n + 1\), \(2\)] - k]\)\)/; NumberQ[x]


BSplineDistribution/:PDF[BSplineDistribution[n_],x_]:=Piecewise[Table[{
Simplify[1/(2 n!) \!\(
\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \(n + 1\)]\(Binomial[n + 1, k] 
\*SuperscriptBox[\((x + 
\*FractionBox[\(n + 1\), \(2\)] - k)\), \(n\)]\ 
\*SuperscriptBox[\((\(-1\))\), \(k\)]\ Sign[i + 
\*FractionBox[\(n + 1\), \(2\)] - k]\)\)],
Simplify[If[i<n/2,i-1/2<x<= i+1/2,i-1/2<x< i+1/2]]
},{i,-n/2,n/2}]]/;DistributionParameterQ[BSplineDistribution[n]]


BSplineDistribution/:PDF[BSplineDistribution[n_,min_,max_],x_]:=(n+1)/(max-min) PDF[BSplineDistribution[n],(n+1)((x-min)/(max-min)-1/2)]


BSplineDistribution/:CDF[BSplineDistribution[0],x_]=Piecewise[{{1/2+x,-(1/2)<x<=1/2},{1,1/2<x}},0];


BSplineDistribution/:CDF[BSplineDistribution[0,min_,max_],x_]=
Piecewise[{{(-min+x)/(max-min),-1<(2*x-max-min)/(max-min)<=1},{1,max<x}},0];


BSplineDistribution/:CDF[BSplineDistribution[1],x_]=Piecewise[{{1/2 (1+x)^2,-1 <x<=0},{1/2+x-x^2/2,0<x<=1},{1,1<x}},0];


BSplineDistribution/:CDF[BSplineDistribution[1,min_,max_],x_]=Piecewise[{{(2*(min-x)^2)/(max-min)^2,-1<(2*x-max-min)/(max-min)<=0},{(-max^2-2*max*min+min^2+4*max*x-2*x^2)/(max-min)^2,0<(2*x-max-min)/(max-min)<=1},{1,max<x}},0]


BSplineDistribution/:CDF[BSplineDistribution[2],x_]=Piecewise[{{1/48 (3+2 x)^3,-(3/2)<x<=-(1/2)},{1/12 (6+9 x-4 x^3),-(1/2)<x<=1/2},{1/48 (21+2 x (27+2 x (-9+2 x))),1/2<x<=3/2},{1,3/2<x}},0];


BSplineDistribution/:CDF[BSplineDistribution[2,min_,max_],x_]=Piecewise[{{(-9*(min-x)^3)/(2*(max-min)^3),-1<(2*x-max-min)/(max-min)<=-1/3},{(4+(36*(max+min-2*x)*(max-x)*(min-x))/(max-min)^3)/8,-1/3<(2*x-max-min)/(max-min)<=1/3},{(-7*max^3-2*min^3+9*x^3+3*max^2*(-2*min+9*x)+3*max*(2*min^2-9*x^2))/(2*(max-min)^3),1/3<(2*x-max-min)/(max-min)<=1},{1,max<x}},0]


BSplineDistribution/:CDF[BSplineDistribution[3],x_]=Piecewise[{{1/24 (2+x)^4,-2<x<=-1},{1/24 (2-x^2) (6+x (8+3 x)),-1<x<=0},{1/24 (12+16 x-8 x^3+3 x^4),0<x<=1},{1-1/24 (-2+x)^4,1<x<=2},{1,2<x}},0];


BSplineDistribution/:CDF[BSplineDistribution[3,min_,max_],x_]=Piecewise[{{(32*(min-x)^4)/(3*(max-min)^4),-1<(2*x-max-min)/(max-min)<=-1/2},{-((max^2+6*max*min+min^2-8*(max+min)*x+8*x^2)*(max^2+6*max*min+17*min^2-8*(max+5*min)*x+24*x^2))/(6*(max-min)^4),-1/2<(2*x-max-min)/(max-min)<=0},{(12-(32*(max+min-2*x))/(max-min)+(64*(max+min-2*x)^3)/(max-min)^3+(48*(max+min-2*x)^4)/(max-min)^4)/24,0<(2*x-max-min)/(max-min)<=1/2},{1-(32*(max-x)^4)/(3*(max-min)^4),1/2<(2*x-max-min)/(max-min)<=1},{1,max<x}},0]


BSplineDistribution/:CDF[BSplineDistribution[n_],x_]:=1/2+1/(2 n!) \!\(
\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \(n + 1\)]\(Binomial[n + 1, k] \((x + 
\*FractionBox[\(n + 1\), \(2\)] - k)\)^\((n + 1)\)*\((\(-1\))\)^k*Sign[x + 
\*FractionBox[\(n + 1\), \(2\)] - k]/\((n + 1)\)\)\)/; NumberQ[x]


BSplineDistribution/:CDF[BSplineDistribution[n_],x_]:=Piecewise[Append[Table[{
Simplify[1/2+1/(2 n!) \!\(
\*UnderoverscriptBox[\(\[Sum]\), \(k = 0\), \(n + 1\)]\(Binomial[n + 1, k] \((x + 
\*FractionBox[\(n + 1\), \(2\)] - k)\)^\((n + 1)\)*\((\(-1\))\)^k*Sign[i + 
\*FractionBox[\(n + 1\), \(2\)] - k]/\((n + 1)\)\)\)],
i-1/2<x<= i+1/2
},{i,-(n/2),n/2}],{1,(n+1)/2<x}]]/;DistributionParameterQ[BSplineDistribution[n]]


BSplineDistribution/:CDF[BSplineDistribution[n_,min_,max_],x_]:= CDF[BSplineDistribution[n],(n+1)((x-min)/(max-min)-1/2)]


BSplineDistribution/:Mean[BSplineDistribution[n_]]=0;


BSplineDistribution/:Mean[BSplineDistribution[n_,min_,max_]]=(max+min)/2


BSplineDistribution/:Variance[BSplineDistribution[n_]]=(n+1)/12;


BSplineDistribution/:Variance[BSplineDistribution[n_,min_,max_]]=1/12 (3 (max+min)^2+(max-min)^2/(1+n));


BSplineDistribution/:StandardDeviation[BSplineDistribution[n_]]=Sqrt[(n+1)/12];


BSplineDistribution/:StandardDeviation[BSplineDistribution[n_,min_,max_]]=Sqrt[1/12 (3 (max+min)^2+(max-min)^2/(1+n))];


BSplineDistribution/:Skewness[BSplineDistribution[n_]]=0;


BSplineDistribution/:Skewness[BSplineDistribution[n_,min_,max_]]=(3*Sqrt[3]*(max+min)*(2*(max^2+min^2)+(max+min)^2*n))/((1+n)*(3*(max+min)^2+(max-min)^2/(1+n))^(3/2));


BSplineDistribution/:Kurtosis[BSplineDistribution[n_]]=(9+15 n)/(5 (n+1));


BSplineDistribution/:Kurtosis[BSplineDistribution[n_,min_,max_]]=(5-6/(1+n)+(8*(max-min)^2*(max^2+7*max*min+min^2))/(4*(max^2+max*min+min^2)+3*(max+min)^2*n)^2+(38*max^2-4*max*min+38*min^2)/(4*(max^2+max*min+min^2)+3*(max+min)^2*n))/5;


BSplineDistribution/:KurtosisExcess[BSplineDistribution[n_]]=-(6/(5 (n+1)));


BSplineDistribution/:KurtosisExcess[BSplineDistribution[n_,min_,max_]]=(-10-6/(1+n)+(8*(max-min)^2*(max^2+7*max*min+min^2))/(4*(max^2+max*min+min^2)+3*(max+min)^2*n)^2+(38*max^2-4*max*min+38*min^2)/(4*(max^2+max*min+min^2)+3*(max+min)^2*n))/5;


BSplineDistribution/: CharacteristicFunction[BSplineDistribution[n_],t_] = ((2 Sin[t/2])/t)^(n+1);


BSplineDistribution/: CharacteristicFunction[BSplineDistribution[n_,min_,max_],t_] = ((n+1) (I (E^(I min/(n+1) t)-E^(I max/(n+1) t)))/((max-min) t))^(n+1);


BSplineDistribution/:Quantile[BSplineDistribution[0],x_]=Piecewise[{{-(1/2),x<0},{-(1/2)+x,0<=x<=1},{1/2,1<x}}];


BSplineDistribution/:Quantile[BSplineDistribution[0,min_,max_],x_]=Piecewise[{{min,x<0},{min+(max-min) x,0<=x<=1},{max,1<x}}];


BSplineDistribution/:Quantile[BSplineDistribution[1],x_]=Piecewise[{{-1,x<0},{-1+ Sqrt[2x],0<=x<=1/2},{1- Sqrt[2(1-x)],1/2<x<=1},{1,1<x}}];


BSplineDistribution/:Quantile[BSplineDistribution[1,min_,max_],x_]=Piecewise[{{min,x<0},{min+(max-min)/2 Sqrt[2x],0<=x<=1/2},{min+(max-min)/2 (2-Sqrt[2-2 x]),1/2<x<=1},{max,1<x}}];


BSplineDistribution/:Quantile[BSplineDistribution[2],x_]=Piecewise[{{-(3/2),x<0},{-(3/2)+(6 x)^(1/3),0<=x<=1/6},{((-3)^(2/3)-(-3)^(1/3) (2-4 x+Sqrt[1+16 (-1+x) x])^(2/3))/(2 (2-4 x+Sqrt[1+16 (-1+x) x])^(1/3)),1/6<x<=5/6},{3/2-(6-6 x)^(1/3),5/6<x<=1},{3/2,1<x}}];


BSplineDistribution/:Quantile[BSplineDistribution[2,min_,max_],x_]=Piecewise[{{min,x<0},{min+(max-min)/3 (6 x)^(1/3),0<=x<=1/6},{min+(max-min)/3 ( 3/2+((-3)^(2/3)-(-3)^(1/3) (2-4 x+Sqrt[1+16 (-1+x) x])^(2/3))/(2 (2-4 x+Sqrt[1+16 (-1+x) x])^(1/3))),1/6<x<=5/6},{min+ (max-min)/3 (3-(6-6 x)^(1/3)),5/6<x<=1},{max,1<x}}];


BSplineDistribution/:Quantile[BSplineDistribution[3],x_]=Piecewise[{{-2,x<0},{(24x)^(1/4)-2,0<=x<=1/24},{With[{sqrt$=(3 Sqrt[3-162 x+14580 x^2-17496 x^3]+324 x)^(1/3)},1/3 (-2+Sqrt[4+sqrt$+(54 x-3)/sqrt$]-1/2 Sqrt[32-4 sqrt$+(12-216 x)/sqrt$+80/Sqrt[4+sqrt$+(54 x-3)/sqrt$]])],1/24<x<=1/2},
{With[{sqrt$ = (3 Sqrt[-3075+23490 x-37908 x^2+17496 x^3]+324 (1-x))^(1/3)},1/3 (2+1/2 Sqrt[32-4 sqrt$+80/Sqrt[4+sqrt$+(51-54 x)/sqrt$]+(-204+216 x)/sqrt$]-Sqrt[4+sqrt$+(51-54 x)/sqrt$])],1/2<x<=23/24},{2-(24-24 x)^(1/4),23/24<x<=1},{2,1<x}}];


BSplineDistribution/:Quantile[BSplineDistribution[3,min_,max_],x_]=Piecewise[{{min,x<0},{min+(max-min)/4 (24 x)^(1/4),0<=x<=1/24},{With[{sqrt$=(3 Sqrt[3-162 x+14580 x^2-17496 x^3]+324 x)^(1/3)},min+(max-min)/12  (4+Sqrt[4+sqrt$+(54 x-3)/sqrt$]-1/2 Sqrt[32-4 sqrt$+(12-216 x)/sqrt$+80/Sqrt[4+sqrt$+(54 x-3)/sqrt$]])],1/24<x<=1/2},
{With[{sqrt$ = (324(1-x)-3 Sqrt[-3075+23490 x-37908 x^2+17496 x^3])^(1/3)},(min+max)/2+(max-min)/12 (2+1/2 Sqrt[32-4 sqrt$+80/Sqrt[4+sqrt$+(51-54 x)/sqrt$]+(-204+216 x)/sqrt$]-Sqrt[4+sqrt$+(51-54 x)/sqrt$])],1/2<x<=23/24},{min+(max-min)/4 (4-(24-24 x)^(1/4)),23/24<x<=1},{max,1<x}}];


BSplineDistribution/:ExpectedValue[f_Function,BSplineDistribution[n_],opts___?OptionQ]:= 
Module[
{x,integral,assmp=Flatten[{Assumptions/.{opts}/.Options[ExpectedValue]}]},
(integral)/;(integral=Integrate[f[x] PDF[BSplineDistribution[n],x],{x,-(n+1)/2,(n+1)/2},Assumptions->Join[{n>=0, n\[Element]Integers},assmp]];
FreeQ[integral,Integrate])
]


BSplineDistribution/:ExpectedValue[f_,BSplineDistribution[n_],x_Symbol,opts___?OptionQ]:= 
Module[
{integral,assmp=Flatten[{Assumptions/.{opts}/.Options[ExpectedValue]}]},
(integral)/;(integral=Integrate[f[x] PDF[BSplineDistribution[n],x],{x,-(n+1)/2,(n+1)/2},Assumptions->Join[{n>=0, n\[Element]Integers},assmp]];
FreeQ[integral,Integrate])
]


BSplineDistribution/:ExpectedValue[f_Function,BSplineDistribution[n_,min_,max_],opts___?OptionQ]:= 
Module[
{x,integral,assmp=Flatten[{Assumptions/.{opts}/.Options[ExpectedValue]}]},
(integral)/;(integral=Integrate[f[x] PDF[BSplineDistribution[n,min,max],x],{x,min,max},Assumptions->Join[{n>=0, n\[Element]Integers,min<max,min\[Element]Reals,max\[Element]Reals},assmp]];
FreeQ[integral,Integrate])
]


BSplineDistribution/:ExpectedValue[f_,BSplineDistribution[n_,min_,max_],x_Symbol,opts___?OptionQ]:= Module[
{integral,assmp=Flatten[{Assumptions/.{opts}/.Options[ExpectedValue]}]},
(integral)/;(integral=Integrate[f[x] PDF[BSplineDistribution[n,min,max],x],{x,min,max},Assumptions->Join[{n>=0, n\[Element]Integers,min<max,min\[Element]Reals,max\[Element]Reals},assmp]];
FreeQ[integral,Integrate])
]


BSplineDistribution/:RandomReal[BSplineDistribution[n_]]:=Total[RandomReal[{-1/2,1/2},n+1]]


BSplineDistribution/:RandomReal[BSplineDistribution[n_,min_,max_]]:=Total[RandomReal[{min/(n+1),max/(n+1)},n+1]]


BSplineDistribution/:RandomReal[BSplineDistribution[n_],dim_Integer?Positive]:= Map[Total,RandomReal[{-1/2,1/2},{dim,n+1}]]


BSplineDistribution/:RandomReal[BSplineDistribution[n_,min_,max_],dim_Integer?Positive]:=Map[Total,RandomReal[{min/(n+1),max/(n+1)},{dim,n+1}]]


BSplineDistribution/:RandomReal[BSplineDistribution[n_],dims:{__Integer?Positive}]:=Map[Total,RandomReal[{-1/2,1/2},Append[dims,n+1]], {Length[dims]}]


BSplineDistribution/:RandomReal[BSplineDistribution[n_,min_,max_],dims:{__Integer?Positive}]:=Map[Total,RandomReal[{min/(n+1),max/(n+1)},Append[dims,n+1]], {Length[dims]}]


End[]

SetAttributes[
{BSplineDistribution},
{Protected, ReadProtected}
];

EndPackage[]
