(* ::Package:: *)

(************************************************************************)
(* This file was generated automatically by the Mathematica front end.  *)
(* It contains Initialization cells from a Notebook file, which         *)
(* typically will have the same name as this file except ending in      *)
(* ".nb" instead of ".m".                                               *)
(*                                                                      *)
(* This file is intended to be loaded into the Mathematica kernel using *)
(* the package loading commands Get or Needs.  Doing so is equivalent   *)
(* to using the Evaluate Initialization Cells menu command in the front *)
(* end.                                                                 *)
(*                                                                      *)
(* DO NOT EDIT THIS FILE.  This entire file is regenerated              *)
(* automatically each time the parent Notebook file is saved in the     *)
(* Mathematica front end.  Any changes you make to this file will be    *)
(* overwritten.                                                         *)
(************************************************************************)



(* TimeSamp for Package Version Control *)

Unprotect[TimeStamp];

TimeStamp::usage="TimeStamp[context] should be set to a Date[]-List indicating the version of the corresponding package.";

TimeStamp["MathVisionTools`BilateralFilter7`"] = {2010,11,14,16,40,0};

Protect[TimeStamp];


(*:Name: MathVisionTools`BilateralFilter` *)

(*:Author: Markus van Almsick *)

(*:Email address: m.van.almsick@tue.nl*)

(*:Context: MathVisionTools`BilateralFilter7`*)

(*:Package Version: 1.0 *)

(*:Mathematica Version: 5.2 *)

(*:Copyright: Copyright 2007, Technische Universiteit Eindhoven*)

(*:Title: BilateralFilter *)

(*:Summary: This package implements bilateral filters *)

(*:Keywords: Geometry Driven, Diffusion, Tomasi, Manduchi *)

(*:Requirements: None *)

(*:Source: Bilateral Filtering for Gray and Color Images, C.Tomasi and R.Manduchi, Proceedings of the 1998 IEEE International
Conference on Computer Vision *)

(*:History: Version 1.0 by Markus van Almsick, July 2007 *)

(*:Limitations: *)

(*:Discussion: *)

(*:To do: *)


BeginPackage["MathVisionTools`BilateralFilter7`",
"MathVisionTools`Common`MathVisionToolsCommon`",
"MathVisionTools`ImageFrame`"]

Unprotect[
BilateralFilter,
BilateralColorFilter 
]


BilateralFilter::usage="BilateralFilter[\[Sigma],\[Mu],img] applies a bilateral filter on image img with a geometric spread \[Sigma] and a photometric spread \[Mu]. The image may have up to 4 dimensions, but must consist of scalar numbers. Default values are \[Sigma] = 1.6 and \[Mu] = StandardDeviation[img]/2.";

BilateralColorFilter::usage="BilateralFilter[\[Sigma],\[Mu],img] is not yet implemented.";

Options[BilateralFilter]={ImageBoundary->Constant};


Begin["`Private`"]


BilateralFilter::bigdim="Bilateral filters are only implemented for images of up to 4 dimensions.";


BilateralFilter[\[Sigma]_?NumericQ:1.6,img_?(ArrayQ[#,1|2|3|4,NumericQ]&),opts___Rule]:=
BilateralFilter[\[Sigma],1/2 Sqrt[Variance[Flatten[img]]],img,opts]


BilateralFilter[\[Sigma]_?NumericQ,\[Mu]_?NumericQ,img_?(ArrayQ[#,1,NumericQ]&),opts___Rule]:=
Module[
{\[Sigma]3 = Ceiling[3 \[Sigma]],framedImg,filterFunction,gaussian},
gaussian=Table[Exp[-(x^2/(2 \[Sigma]^2))],{x,-\[Sigma]3,\[Sigma]3}];
filterFunction = 
Compile[{{patch,_Real,1}},
Module[
{kern=Exp[-(1/(2\[Mu]^2)) (patch-patch[[\[Sigma]3+1]])^2]*gaussian},
Total[kern*patch]/Total[kern]
],
{{\[Sigma]3,_Integer},{gaussian,_Real,1},{Total[_],_Real}}
];
framedImg=ImageFrame[img,\[Sigma]3,ImageBoundary->(ImageBoundary/. {opts}/.Options[BilateralFilter])];
Array[
filterFunction[Take[framedImg,{#,#+2 \[Sigma]3}]]&, 
Dimensions[img]
]
]/;ArrayDepth[img]===1


BilateralFilter[\[Sigma]_?NumericQ,\[Mu]_?NumericQ,img_?(ArrayQ[#,2,NumericQ]&),opts___Rule]:=
Module[
{\[Sigma]3 = Ceiling[3 \[Sigma]],framedImg,filterFunction,gaussian},
gaussian=Table[Exp[-((x^2+y^2)/(2 \[Sigma]^2))],{x,-\[Sigma]3,\[Sigma]3},{y,-\[Sigma]3,\[Sigma]3}];
filterFunction = 
Compile[{{patch,_Real,2}},
Module[
{kern=Exp[-(1/(2\[Mu]^2)) (patch-patch[[\[Sigma]3+1,\[Sigma]3+1]])^2]*gaussian},
Total[kern*patch,2]/Total[kern,2]
],
{{\[Sigma]3,_Integer},{gaussian,_Real,2},{Total[_,2],_Real}}
];
framedImg=ImageFrame[img,\[Sigma]3,ImageBoundary->(ImageBoundary/. {opts}/.Options[BilateralFilter])];
Array[
filterFunction[Take[framedImg,{#1,#1+2 \[Sigma]3},{#2,#2+2 \[Sigma]3}]]&, 
Dimensions[img]
]
]/;ArrayDepth[img]===2


BilateralFilter[\[Sigma]_?NumericQ,\[Mu]_?NumericQ,img_?(ArrayQ[#,3,NumericQ]&),opts___Rule]:=
Module[
{\[Sigma]3 = Ceiling[3 \[Sigma]],framedImg,filterFunction,gaussian},
gaussian=Table[Exp[-((x^2+y^2+z^2)/(2 \[Sigma]^2))],{x,-\[Sigma]3,\[Sigma]3},{y,-\[Sigma]3,\[Sigma]3},{z,-\[Sigma]3,\[Sigma]3}];
filterFunction = 
Compile[{{patch,_Real,3}},
Module[
{kern=Exp[-(1/(2\[Mu]^2)) (patch-patch[[\[Sigma]3+1,\[Sigma]3+1,\[Sigma]3+1]])^2]*gaussian},
Total[kern*patch,3]/Total[kern,3]
],
{{\[Sigma]3,_Integer},{gaussian,_Real,3},{Total[_,3],_Real}}
];
framedImg=ImageFrame[img,\[Sigma]3,ImageBoundary->(ImageBoundary/. {opts}/.Options[BilateralFilter])];
Array[
filterFunction[Take[framedImg,{#1,#1+2 \[Sigma]3},{#2,#2+2 \[Sigma]3},{#3,#3+2 \[Sigma]3}]]&, 
Dimensions[img]
]
]/;ArrayDepth[img]===3


BilateralFilter[\[Sigma]_?NumericQ,\[Mu]_?NumericQ,img_?(ArrayQ[#,4,NumericQ]&),opts___Rule]:=
Module[
{\[Sigma]3 = Ceiling[3 \[Sigma]],framedImg,filterFunction,gaussian},
gaussian=Table[Exp[-((x^2+y^2+z^2+t^2)/(2 \[Sigma]^2))],{x,-\[Sigma]3,\[Sigma]3},{y,-\[Sigma]3,\[Sigma]3},{z,-\[Sigma]3,\[Sigma]3},{t,-\[Sigma]3,\[Sigma]3}];
filterFunction = 
Compile[{{patch,_Real,4}},
Module[
{kern=Exp[-(1/(2\[Mu]^2)) (patch-patch[[\[Sigma]3+1,\[Sigma]3+1,\[Sigma]3+1,\[Sigma]3+1]])^2]*gaussian},
Total[kern*patch,4]/Total[kern,4]
],
{{\[Sigma]3,_Integer},{gaussian,_Real,4},{Total[_,4],_Real}}
];
framedImg=ImageFrame[img,\[Sigma]3,ImageBoundary->(ImageBoundary/. {opts}/.Options[BilateralFilter])];
Array[
filterFunction[Take[framedImg,{#1,#1+2 \[Sigma]3},{#2,#2+2 \[Sigma]3},{#3,#3+2 \[Sigma]3},{#4,#4+2 \[Sigma]3}]]&, 
Dimensions[img]
]
]/;ArrayDepth[img]===4


End[]

SetAttributes[
{BilateralFilter,
BilateralColorFilter },
{Protected, ReadProtected}
];

EndPackage[]
