(* ::Package:: *)

(************************************************************************)
(* This file was generated automatically by the Mathematica front end.  *)
(* It contains Initialization cells from a Notebook file, which         *)
(* typically will have the same name as this file except ending in      *)
(* ".nb" instead of ".m".                                               *)
(*                                                                      *)
(* This file is intended to be loaded into the Mathematica kernel using *)
(* the package loading commands Get or Needs.  Doing so is equivalent   *)
(* to using the Evaluate Initialization Cells menu command in the front *)
(* end.                                                                 *)
(*                                                                      *)
(* DO NOT EDIT THIS FILE.  This entire file is regenerated              *)
(* automatically each time the parent Notebook file is saved in the     *)
(* Mathematica front end.  Any changes you make to this file will be    *)
(* overwritten.                                                         *)
(************************************************************************)



(* TimeSamp for Package Version Control *)

Unprotect[TimeStamp];

TimeStamp::usage="TimeStamp[context] should be set to a Date[]-List indicating the version of the corresponding package.";

TimeStamp["MathVisionTools`Converters`Dicom`"] = {2010,2,2,12,0,0};

Protect[TimeStamp];


(*:Name: MathVisionTools`Converters`Dicom` *)

(*:Author: Markus van Almsick*)

(*:Email address: M.v.Almsick@tue.nl*)

(*:Context: MathVisionTools`Converters`Dicom`*)

(*:Package Version: 1.2 *)

(*:Mathematica Version: 6.1 *)

(*:Copyright: Copyright 2010, Technische Universiteit Eindhoven*)

(*:Title: Dicom *)

(*:Summary: This package implements DICOM import/export routines. *)

(*:Keywords: Dicom, Import, Export, ANI, SPI *)

(*:Requirements: None *)

(*:Source: None *)

(*:History: Version 1.0 by Markus van Almsick, July 2003 *)
(*:History: Version 1.1 by Markus van Almsick & Edwin Bennink, June 2007 *)

(*:Limitations: Binaries for Windows, Linux, and MacOSX only*)

(*:Discussion: *)

(*:To do: *)


BeginPackage["MathVisionTools`Converters`Dicom`"]

Unprotect[
Dicom,
DicomImport,
DicomDicitionary
]


Dicom::usage="Dicom[{graphics}, {tags}] is a Mathematica expression to represent Dicom files. The first argument is a list of Graphics[] expressions containing the image(s) of the Dicom file. The second argument is a list of rules replacing DICOM tag names with their respective values."

DicomImport::usage="DicomImport[fname,n] loads the n-th frame of a DICOM file into Mathematica. The imported data is a Mathematica expression with the head Dicom. It's first argument is a list of Graphics[] with the images encoded as Raster[] expressions. The second argument is a list of rules replacing DICOM tag names with their respective values. Frame index n=All will load all image frames. The default frame index is All and may be omitted."

DicomExport::usage="DicomExport[fname, data] exports 2D or 3D arrays (grayscale or color) to the Dicom file fname. The precision will be lossless for up to 16 bit whenever the data consists of Integers, in other cases the default is 8 bit. Every slice of a 3D array will be saved to the files \"fnameNNN.dcm\", in which NNN represents the slice counter. Different kinds of attributes can be set via the DicomTags option"

DicomDictionary::usage="DicomDictionary[] renders all the tags and their names in the dicom dictionary."

DicomTag::usage="DicomTag[g, e] represents a DICOM tag. The first argument g is the group, the second argument e the element ID in hexadecimal base."

DicomTags::usage="DicomTags is an option of DicomImport and DicomExport. If set to True, DicomImport renders a Mathematica expression with head Dicom that contains as its first argument the List of DICOM graphics and as its second argument the List of DICOM tags encoded as Mathematica replacement rules. The default is False, so that DicomImport simply renders a List of graphics. For DicomExport DicomTags can be assigned to a List of Dicom tags specifications given as Rules that assigned a tag String to its value."

Dicom::file = "Cannot find DICOM file `1`"

Options[DicomImport]={Path:> $Path, DicomTags -> False};

Options[DicomExport]={DicomTags -> {"Patient's Name"->"Mathematica","Patient ID"->"1","Patient's Birth Date"->{1988,7,1},"Patient's Birth Time"->{12,0,0},"Patient's Sex"->"M","Other Patient Names"->"Wolfram Research Inc.","Patient's Birth Name"->"SMP5","Study Instance UID"->{1,2,840,100000,21603455436641132737,1,1,1},"Accession Number"->"","Study Description"->"Mathematca Image Export","Study ID"->"41132737","Study Date":> Take[Date[],3],"Study Time":> Take[Date[],{4,6}],"Modality"->"OT","Series Date":> Take[Date[],3],"Series Time":> Take[Date[],{4,6}],"Series Instance UID"->{1,2,840,100000,21603455436641132737,1,1,2},"Series Number"->1,"Image Position"->{0,0,0},"Image Position (Patient)"->{0,0,0},"Image Orientation"->{1,0,0,0,1,0},"Image Orientation (Patient)"->{1,0,0,0,1,0},"Institution Name"->"Eindhoven University of Technology","Pixel Spacing"->{1,1},"Slice Thickness"->1,"Instance Number"->1}};


Begin["`Private`"]


(* Connection MathLink Binary *)

MLBinaryName = Switch[$SystemID,
"Windows","Dicom.exe",
"Darwin","Dicom",
"MacOSX-x86","Dicom",
"MacOSX-x86-64","Dicom",
"Linux","Dicom",
"Linux-x86-64","Dicom",
_,"Dicom"];

MLBinaryPath=Map[ToFileName[{#,"MathVisionTools","Converters","Binaries",$SystemID},MLBinaryName]&,$Path];

MLBinaryFiles = FileNames[MLBinaryPath];

Dicom::linkc="The LinkObject to the DicomImport binary is dead; attempt to connect failed";

If[MLBinaryFiles==={},
MLBinaryLink=$Failed,
If[Links[First[MLBinaryFiles]]==={},
CurrentDirectory = Directory[];
SetDirectory[DirectoryName[First[MLBinaryFiles]]];
Off[LinkConnect::"linkc"];
MLBinaryLink = Install[First[MLBinaryFiles]];
On[LinkConnect::"linkc"];
SetDirectory[CurrentDirectory],
MLBinaryLink = First[Links[First[MLBinaryFiles]]]
]
];

If[Head[MLBinaryLink]===$Failed,Message[Dicom::linkc]];


(* Dicom Import *)

DicomImport[fname_String, frame_Integer:0,opts___Rule]:= 
Module[
{fnames},
If[
Length[fnames = FileNames[FileNameTake[fname],Prepend[(Path /. {opts} /. Options[DicomImport]),DirectoryName[fname]]]
]>0,
ReadDicom[
First[fnames],
frame , 
If[(DicomTags ||"DicomTags")/. {opts} /. Options[DicomImport], 1, 0,0]
],
Message[Dicom::file,fname];$Failed
]
]

DicomImport[fname_String, All,opts___Rule]:= 
DicomImport[fname, 0,opts]

DicomImport[fname_String, frames_List,opts___Rule]:= 
Map[DicomImport[fname, #,opts]&,frames]


If[
$VersionNumber < 5,
Experimental`RegisterConverter[Import,
"DICOM",
{"*.dcm","*.DCM","*.dicom","*.DICOM","*.ani","*.ANI","*.spi","*.SPI"},
None,
DicomImport[
#1,
"ImageIndex"/.(ConversionOptions/.Rest[{##}]/.ConversionOptions->{})/."ImageIndex"->All,
 Apply[Sequence,ConversionOptions/.Rest[{##}]/.ConversionOptions->{}]
]&,
"TextFormat"->False
]
]


(* Dicom Export *)

DicomExport[fname_String, dicomData_,(opts___)?OptionQ]:=Block[
{blockData=dicomData,dicomTags,dicomPositionStep,dicomName,dicomBits,dicomRescale,dicomColorFunction},{dicomTags,dicomPositionStep,dicomName,dicomBits,dicomRescale,dicomColorFunction}={dicomTags,dicomPositionStep,dicomName,dicomBits,dicomRescale,dicomColorFunction}/.{opts}/.Options[dicomExport];
dicomTags=(#1->(#1/.dicomTags/.$defaultDicomTags)&)/@Union[$defaultDicomTags[[All,1]],dicomTags[[All,1]]];
If[dicomBits===Automatic,dicomBits=If[Flatten[blockData]\[Element]Integers,Ceiling[Log[2,(Max[#1]-Min[#1]&)[Flatten[blockData]]]],8]];
If[dicomColorFunction===Automatic,dicomColorFunction=If[Dimensions[blockData][[-1]]==3,RGBColor,If[dicomBits<=16,GrayLevel,Hue]]];
If[dicomRescale===Automatic&&!(Flatten[blockData]\[Element]Integers&&Ceiling[Log[2,(Max[#1]-Min[#1]&)[Flatten[blockData]]]]==dicomBits)||dicomRescale===True,blockData=Round[((2^dicomBits-1)/(Max[#1]-Min[#1]&)[Flatten[blockData]])*blockData]];
If[ArrayDepth[blockData]==3&&dicomColorFunction===RGBColor||ArrayDepth[blockData]==2,image=(Join[{"Pixel Data"->Graphics[Raster[#1,{{0,0},Dimensions[#1][[{2,1}]]},{Min[Flatten[#1]],Max[Flatten[#1]]},ColorFunction->dicomColorFunction],ImageSize->Dimensions[#1][[{2,1}]],PlotRange->{{0,Dimensions[#1][[2]]-1},{1,Dimensions[#1][[1]]}},AspectRatio->Automatic]},dicomTags]&)[blockData];
Export[StringJoin[dicomName,".dcm"],image,"DICOM"],Do[dicomTags=dicomTags/.("Instance Number"->_):>"Instance Number"->n;image=(Join[{"Pixel Data"->Graphics[Raster[#1,{{0,0},Dimensions[#1][[{2,1}]]},{Min[Flatten[#1]],Max[Flatten[#1]]},ColorFunction->dicomColorFunction],ImageSize->Dimensions[#1][[{2,1}]],PlotRange->{{0,Dimensions[#1][[2]]-1},{1,Dimensions[#1][[1]]}},AspectRatio->Automatic]},dicomTags]&)[blockData[[n]]];
Export[StringJoin[dicomName,StringDrop[ToString[n+1000],1],".dcm"],image,"DICOM"];dicomTags=dicomTags/.("Image Position (Patient)"->x_):>"Image Position (Patient)"->x+dicomPositionStep;,{n,1,Length[blockData]}]
]
];


(* Dicom Dictionary as used by Mathematica 5.0 Export *)
(* the Dicom Dictionary for DicomImport is implemented in the MathLink program *)

DicomExportDictionary={"Meta Element Group Length","File Meta Information Version","Media Storage SOP Class UID","Media Storage SOP Instance UID","Transfer Syntax UID","Implementation Class UID","Implementation Version Name","Source Application Entity Title","Private Information Creator UID","Private Information","File-set Group Length","File-set ID","File-set Descriptor File ID","Specific Character Set of File-set Descriptor File","Offset of the First Directory Record of the Root Directory Entity","Offset of the Last Directory Record of the Root Directory Entity","File-set Consistency Flag","Directory Record Sequence","Offset of the Next Directory Record","Record In-use Flag","Offset of Referenced Lower-Level Directory Entity","Directory Record Type","Private Record UID","Referenced File ID","MRDR Directory Record Offset","Referenced SOP Class UID in File","Referenced SOP Instance UID in File","Referenced Transfer Syntax UID in File","Number of References","Identifying Group Length","Length to End","Specific Character Set","Image Type","Recognition Code","Instance Creation Date","Instance Creation Time","Instance Creator UID","SOP Class UID","SOP Instance UID","Study Date","Series Date","Acquisition Date","Content Date","Overlay Date","Curve Date","Acquisition Datetime","Study Time","Series Time","Acquisition Time","Content Time","Overlay Time","Curve Time","Data Set Type","Data Set Subtype","Nuclear Medicine Series Type","Accession Number","Query/Retrieve Level","Retrieve AE Title","Instance Availability","Failed SOP Instance UID List","Modality","Modalities in Study","Conversion Type","Presentation Intent Type","Manufacturer","Institution Name","Institution Address","Institution Code Sequence","Referring Physician's Name","Referring Physician's Address","Referring Physician's Telephone Numbers","Code Value","Coding Scheme Designator","Coding Scheme Version","Code Meaning","Mapping Resource","Context Group Version","Context Group Local Version","Code Set Extension Flag","Private Coding Scheme Creator UID","Code Set Extension Creator UID","Context Identifier","Timezone Offset From UTC","Network ID","Station Name","Study Description","Procedure Code Sequence","Series Description","Institutional Department Name","Physician(s) of Record","Performing Physician's Name","Name of Physician(s) Reading Study","Operators' Name","Admitting Diagnoses Description","Admitting Diagnosis Code Sequence","Manufacturer's Model Name","Referenced Results Sequence","Referenced Study Sequence","Referenced Study Component Sequence","Referenced Series Sequence","Referenced Patient Sequence","Referenced Visit Sequence","Referenced Overlay Sequence","Referenced Image Sequence","Referenced Curve Sequence","Referenced SOP Class UID","Referenced SOP Instance UID","SOP Classes Supported","Referenced Frame Number","Transaction UID","Failure Reason","Failed SOP Sequence","Referenced SOP Sequence","Lossy Image Compression","Derivation Description","Source Image Sequence","Stage Name","Stage Number","Number of Stages","View Number","Number of Event Timers","Number of Views in Stage","Event Elapsed Time(s)","Event Timer Name(s)","Start Trim","Stop Trim","Recommended Display Frame Rate","Transducer Position","Transducer Orientation","Anatomic Structure","Anatomic Region Sequence","Anatomic Region Modifier Sequence","Primary Anatomic Structure Sequence","Anatomic Structure, Space or Region Sequence","Primary Anatomic Structure Modifier Sequence","Transducer Position Sequence","Transducer Position Modifier Sequence","Transducer Orientation Sequence","Transducer Orientation Modifier Sequence","Comments","Patient Group Length","Patient's Name","Patient ID","Issuer of Patient ID","Patient's Birth Date","Patient's Birth Time","Patient's Sex","Patient's Insurance Plan Code Sequence","Other Patient IDs","Other Patient Names","Patient's Birth Name","Patient's Age","Patient's Size","Patient's Weight","Patient's Address","Insurance Plan Identification","Patient's Mother's Birth Name","Military Rank","Branch of Service","Medical Record Locator","Medical Alerts","Contrast Allergies","Country of Residence","Region of Residence","Patient's Telephone Numbers","Ethnic Group","Occupation","Smoking Status","Additional Patient History","Pregnancy Status","Last Menstrual Date","Patient's Religious Preference","Patient Comments","Acquisition Group Length","Contrast/Bolus Agent","Contrast/Bolus Agent Sequence","Contrast/Bolus Administration Route Sequence","Body Part Examined","Scanning Sequence","Sequence Variant","Scan Options","MR Acquisition Type","Sequence Name","Angio Flag","Intervention Drug Information Sequence","Intervention Drug Stop Time","Intervention Drug Dose","Intervention Drug Code Sequence","Additional Drug Sequence","Radionuclide","Radiopharmaceutical","Energy Window Centerline","Energy Window Total Width","Intervention Drug Name","Intervention Drug Start Time","Interventional Therapy Sequence","Therapy Type","Interventional Status","Therapy Description","Cine Rate","Slice Thickness","KVP","Counts Accumulated","Acquisition Termination Condition","Effective Series Duration","Acquisition Start Condition","Acquisition Start Condition Data","Acquisition Termination Condition Data","Repetition Time","Echo Time","Inversion Time","Number of Averages","Imaging Frequency","Imaged Nucleus","Echo Number(s)","Magnetic Field Strength","Spacing Between Slices","Number of Phase Encoding Steps","Data Collection Diameter","Echo Train Length","Percent Sampling","Percent Phase Field of View","Pixel Bandwidth","Device Serial Number","Plate ID","Secondary Capture Device ID","Hardcopy Creation Device ID","Date of Secondary Capture","Time of Secondary Capture","Secondary Capture Device Manufacturer","Hardcopy Device Manufacturer","Secondary Capture Device Manufacturer's Model Name","Secondary Capture Device Software Version(s)","Hardcopy Device Software Version","Hardcopy Device Manfuacturer's Model Name","Software Version(s)","Video Image Format Acquired","Digital Image Format Acquired","Protocol Name","Contrast/Bolus Route","Contrast/Bolus Volume","Contrast/Bolus Start Time","Contrast/Bolus Stop Time","Contrast/Bolus Total Dose","Syringe Counts","Contrast Flow Rate(s)","Contrast Flow Duration(s)","Contrast/Bolus Ingredient","Contrast/Bolus Ingredient Concentration","Spatial Resolution","Trigger Time","Trigger Source or Type","Nominal Interval","Frame Time","Framing Type","Frame Time Vector","Frame Delay","Image Trigger Delay","Multiplex Group Time Offset","Trigger Time Offset","Synchronization Trigger","Synchronization Channel","Trigger Sample Position","Radiopharmaceutical Route","Radionuclide Route","Radiopharmaceutical Volume","Radionuclide Volume DS","Radionuclide Start Time","Radiopharmaceutical Start Time","Radionuclide Stop Time","Radiopharmaceutical Stop Time","Radionuclide Total Dose","Radionuclide Total Dose","Radionuclide Half Life","Radionuclide Positron Fraction","Radiopharmaceutical Specific Activity","Beat Rejection Flag","Low R-R Value","High R-R Value","Intervals Acquired","Intervals Rejected","PVC Rejection","Skip Beats","Heart Rate","Cardiac Number of Images","Trigger Window","Reconstruction Diameter","Distance Source to Detector","Distance Source to Patient","Estimated Radiographic Magnification Factor","Gantry/Detector Tilt","Gantry/Detector Slew","Table Height","Table Traverse","Table Motion","Table Vertical Increment","Table Lateral Increment","Table Longitudinal Increment","Table Angle","Table Type","Rotation Direction","Angular Position","Radial Position","Scan Arc","Angular Step","Center of Rotation Offset","Rotation Offset","Field of View Shape","Field of View Dimension(s)","Exposure Time","X-ray Tube Current","Exposure","Exposure in uAs","Average Pulse Width","Radiation Setting","Rectification Type","Radiation Mode","Image Area Dose Product","Filter Type","Type of Filters","Intensifier Size","Imager Pixel Spacing","Grid","Generator Power","Collimator/grid Name","Collimator Type","Focal Distance","X Focus Center","Y Focus Center","Focal Spot(s)","Anode Target Material","Body Part Thickness","Compression Force","Date of Last Calibration","Time of Last Calibration","Convolution Kernel","Upper/Lower Pixel Values","Actual Frame Duration","Count Rate","Preferred Playback Sequencing","Receiving Coil","Transmitting Coil","Plate Type","Phosphor Type","Scan Velocity","Whole Body Technique","Scan Length","Acquisition Matrix","Phase Encoding Direction","Flip Angle","Variable Flip Angle Flag","SAR","dB/dt","Acquisition Device Processing Description","Acquisition Device Processing Code","Cassette Orientation","Cassette Size","Exposures on Plate","Relative X-ray Exposure","Column Angulation","Tomo Layer Height","Tomo Angle","Tomo Time","Tomo Type","Tomo Class","Number of Tomosynthesis Source Images","Positioner Motion","Positioner Type","Positioner Primary Angle","Positioner Secondary Angle","Positioner Primary Angle Increment","Positioner Secondary Angle Increment","Detector Primary Angle","Detector Secondary Angle","Shutter Shape","Shutter Left Vertical Edge","Shutter Right Vertical Edge","Shutter Upper Horizontal Edge","Shutter Lower Horizontal Edge","Center of Circular Shutter","Radius of Circular Shutter","Vertices of the Polygonal Shutter","Shutter Presentation Value","Shutter Overlay Group","Collimator Shape","Collimator Left Vertical Edge","Collimator Right Vertical Edge","Collimator Upper Horizontal Edge","Collimator Lower Horizontal Edge","Center of Circular Collimator","Radius of Circular Collimator","Vertices of the Polygonal Collimator","Acquisition Time Synchronized","Time Source","Time Distribution Protocol","Comments","Output Power","Transducer Data","Focus Depth","Processing Function","Postprocessing Function","Mechanical Index","Thermal Index","Cranial Thermal Index","Soft Tissue Thermal Index","Soft Tissue-focus Thermal Index","Soft Tissue-surface Thermal Index","Dynamic Range","Total Gain","Depth of Scan Field","Patient Position","View Position","Projection Eponymous Name Code Sequence","Image Transformation Matrix","Image Translation Vector","Sensitivity","Sequence of Ultrasound Regions","Region Spatial Format","Region Data Type","Region Flags","Region Location Min X0","Region Location Min Y0","Region Location Max X1","Region Location Max Y1","Reference Pixel X0","Reference Pixel Y0","Physical Units X Direction","Physical Units Y Direction","Reference Pixel Physical Value X","Reference Pixel Physical Value Y","Physical Delta X","Physical Delta Y","Transducer Frequency","Transducer Type","Pulse Repetition Frequency","Doppler Correction Angle","Steering Angle","Doppler Sample Volume X Position","Doppler Sample Volume Y Position","TM-Line Position X0","TM-Line Position Y0","TM-Line Position X1","TM-Line Position Y1","Pixel Component Organization","Pixel Component Mask","Pixel Component Range Start","Pixel Component Range Stop","Pixel Component Physical Units","Pixel Component Data Type","Number of Table Break Points","Table of X Break Points","Table of Y Break Points","Number of Table Entries","Table of Pixel Values","Table of Parameter Values","Detector Conditions Nominal Flag","Detector Temperature","Detector Type","Detector Configuration","Detector Description","Detector Mode","Detector ID","Date of Last Detector Calibration","Time of Last Detector Calibration","Exposures on Detector Since Last Calibration","Exposures on Detector Since Manufactured","Detector Time Since Last Exposure","Detector Active Time","Detector Activation Offset From Exposure","Detector Binning","Detector Element Physical Size","Detector Element Spacing","Detector Active Shape","Detector Active Dimension(s)","Detector Active Origin","Field of View Origin","Field of View Rotation","Field of View Horizontal Flip","Grid Absorbing Material","Grid Spacing Material","Grid Thickness","Grid Pitch","Grid Aspect Ratio","Grid Period","Grid Focal Distance","Filter Material","Filter Thickness Minimum","Filter Thickness Maximum","Exposure Control Mode","Exposure Control Mode Description","Exposure Status","Phototimer Setting","Exposure Time in \[Micro]S","X-Ray Tube Current in \[Micro]A","Relationship Group Length","Study Instance UID","Series Instance UID","Study ID","Series Number","Acquisition Number","Instance Number","Isotope Number","Phase Number","Interval Number","Time Slot Number","Angle Number","Item Number","Patient Orientation","Overlay Number","Curve Number","Lookup Table Number","Image Position","Image Position (Patient)","Image Orientation","Image Orientation (Patient)","Location","Frame of Reference UID","Laterality","Image Laterality","Image Geometry Type","Masking Image","Temporal Position Identifier","Number of Temporal Positions","Temporal Resolution","Synchronization Frame of Reference UID","Series in Study","Acquisitions in Series","Images in Acquisition","Acquisitions in Study","Reference","Position Reference Indicator","Slice Location","Other Study Numbers","Number of Patient Related Studies","Number of Patient Related Series","Number of Patient Related Instances","Number of Study Related Series","Number of Study Related Instances","Number of Series Related Instances","Source Image IDs","Modifying Device ID","Modified Image ID","Modified Image Date","Modifying Device Manufacturer","Modified Image Time","Modified Image Description","Image Comments","Original Image Identification","Original Image Identification Nomenclature","Image Presentation Group Length","Samples per Pixel","Photometric Interpretation","Image Dimensions","Planar Configuration","Number of Frames","Frame Increment Pointer","Rows","Columns","Planes","Ultrasound Color Data Present","Pixel Spacing","Zoom Factor","Zoom Center","Pixel Aspect Ratio","Image Format","Manipulated Image","Corrected Image","Compression Code","Bits Allocated","Bits Stored","High Bit","Pixel Representation","Smallest Valid Pixel Value","Largest Valid Pixel Value","Smallest Image Pixel Value","Largest Image Pixel Value","Smallest Pixel Value in Series","Largest Pixel Value in Series","Smallest Image Pixel Value in Plane","Largest Image Pixel Value in Plane","Pixel Padding Value","Image Location","Quality Control Image","Burned In Annotation","Pixel Intensity Relationship","Pixel Intensity Relationship Sign","Window Center","Window Width","Rescale Intercept","Rescale Slope","Rescale Type","Window Center & Width Explanation","Gray Scale","Recommended Viewing Mode","Gray Lookup Table Descriptor","Red Palette Color Lookup Table Descriptor","Green Palette Color Lookup Table Descriptor","Blue Palette Color Lookup Table Descriptor","Palette Color Lookup Table UID","Gray Lookup Table Data","Red Palette Color Lookup Table Data","Green Palette Color Lookup Table Data","Blue Palette Color Lookup Table Data","Segmented Red Palette Color Lookup Table Data","Segmented Green Palette Color Lookup Table Data","Segmented Blue Palette Color Lookup Table Data","Implant Present","Partial View","Partial View Description","Lossy Image Compression","Lossy Image Compression Ratio","Modality LUT Sequence","LUT Descriptor","LUT Explanation","Modality LUT Type","LUT Data","VOI LUT Sequence","Softcopy VOI LUT Sequence","Comments","Bi-Plane Acquisition Sequence","Representative Frame Number","Frame Numbers of Interest (FOI)","Frame(s) of Interest Description","Mask Pointer(s)","R Wave Pointer","Mask Subtraction Sequence","Mask Operation","Applicable Frame Range","Mask Frame Numbers","Contrast Frame Averaging","Mask Sub-pixel Shift","TID Offset","Mask Operation Explanation","Study Group Length","Study Status ID","Study Priority ID","Study ID Issuer","Study Verified Date","Study Verified Time","Study Read Date","Study Read Time","Scheduled Study Start Date","Scheduled Study Start Time","Scheduled Study Stop Date","Scheduled Study Stop Time","Scheduled Study Location","Scheduled Study Location AE Title(s)","Reason for Study","Requesting Physician","Requesting Service","Study Arrival Date","Study Arrival Time","Study Completion Date","Study Completion Time","Study Component Status ID","Requested Procedure Description","Requested Procedure Code Sequence","Requested Contrast Agent","Study Comments","Visit Group Length","Referenced Patient Alias Sequence","Visit Status ID","Admission ID","Issuer of Admission ID","Route of Admissions","Scheduled Admission Date","Scheduled Admission Time","Scheduled Discharge Date","Scheduled Discharge Time","Scheduled Patient Institution Residence","Admitting Date","Admitting Time","Discharge Date","Discharge Time","Discharge Diagnosis Description","Discharge Diagnosis Code Sequence","Special Needs","Current Patient Location","Patient's Institution Residence","Patient State","Visit Comments","Waveform Group Length","Waveform Originality","Number of Waveform Channels","Number of Waveform Samples","Sampling Frequency","Multiplex Group Label","Channel Definition Sequence","Waveform Channel Number","Channel Label","Channel Status","Channel Source Sequence","Channel Source Modifiers Sequence","Source Waveform Sequence","Channel Derivation Description","Channel Sensitivity","Channel Sensitivity Units Sequence","Channel Sensitivity Correction Factor","Channel Baseline","Channel Time Skew","Channel Sample Skew","Channel Offset","Waveform Bits Stored","Filter Low Frequency","Filter High Frequency","Notch Filter Frequency","Notch Filter Bandwidth","Proceedure Group Length","Scheduled Station AE Title","Scheduled Procedure Step Start Date","Scheduled Procedure Step Start Time","Scheduled Procedure Step End Date","Scheduled Procedure Step End Time","Scheduled Performing Physician's Name","Scheduled Procedure Step Description","Scheduled Action Item Code Sequence","Scheduled Procedure Step ID","Scheduled Station Name","Scheduled Procedure Step Location","Pre-Medication","Scheduled Procedure Step Status","Scheduled Procedure Step Sequence","Referenced Standalone SOP Instance Sequence","Performed Station AE Title","Performed Station Name","Performed Location","Performed Procedure Step Start Date","Performed Procedure Step Start Time","Performed Procedure Step End Date","Performed Procedure Step End Time","Performed Procedure Step Status","Performed Procedure Step ID","Performed Procedure Step Description","Performed Procedure Type Description","Performed Action Item Sequence","Scheduled Step Attributes Sequence","Request Attributes Sequence","Comments on the Performed Procedure Steps","Quantity Sequence","Quantity","Measuring Units Sequence","Billing Item Sequence","Total Time of Fluoroscopy","Total Number of Exposures","Entrance Dose","Exposed Area","Distance Source to Entrance","Distance Source to Support","Comments on Radiation Dose","X-Ray Output","Half Value Layer","Organ Dose","Organ Exposed","Billing Procedure Step Sequence","Film Consumption Sequence","Billing Supplies and Devices Sequence","Referenced Procedure Step Sequence","Performed Series Sequence","Comments on the Scheduled Procedure Step","Specimen Accession Number","Specimen Sequence","Specimen Identifier","Acquisition Context Sequence","Acquisition Context Description","Specimen Type Code Sequence","Slide Identifier","Image Center Point Coordinates Sequence","X offset in Slide Coordinate System","Y offset in Slide Coordinate System","Z offset in Slide Coordinate System","Pixel Spacing Sequence","Coordinate System Axis Code Sequence","Measurement Units Code Sequence","Requested Procedure ID","Reason for the Requested Procedure","Requested Procedure Priority","Patient Transport Arrangements","Requested Procedure Location","Placer Order Number / Procedure","Filler Order Number / Procedure","Confidentiality Code","Reporting Priority","Names of Intended Recipients of Results","Requested Procedure Comments","Reason for the Imaging Service Request","Issue Date of Imaging Service Request","Issue Time of Imaging Service Request","Placer Order Number / Imaging Service Request","Filler Order Number / Imaging Service Request","Order Entered By","Order Enterer's Location","Order Callback Phone Number","Placer Order Number / Imaging Service Request","Filler Order Number / Imaging Service Request","Imaging Service Request Comments","Confidentiality Constraint on Patient Data Description","Entrance Dose in mGy","Relationship Type","Verifying Organization","Verification DateTime","Observation DateTime","Value Type","Concept-name Code Sequence","Continuity Of Content","Verifying Observer Sequence","Verifying Observer Name","Verifying Observer Identification Code Sequence","Referenced Waveform Channels","DateTime","Date","Time","Person Name","UID","Temporal Range Type","Referenced Sample Positions","Referenced Frame Numbers","Referenced Time Offsets","Referenced Datetime","Text Value","Concept Code Sequence","Annotation Group Number","Modifier Code Sequence","Measured Value Sequence","Numeric Value","Predecessor Documents Sequence","Referenced Request Sequence","Performed Procedure Code Sequence","Current Requested Procedure Evidence Sequence","Pertinent Other Evidence Sequence","Completion Flag","Completion Flag Description","Verification Flag","Content Template Sequence","Identical Documents Sequence","Content Sequence","Annotation Sequence","Template Identifier","Template Version","Template Local Version","Template Extension Flag","Template Extension Organization UID","Template Extension Creator UID","Referenced Content Item Identifier","Calibration Group Length","Calibration Image","Device Sequence","Device Length","Device Diameter","Device Diameter Units","Device Volume","Inter-marker Distance","Device Description","Nuclear Medicine Group Length","Energy Window Vector","Number of Energy Windows","Energy Window Information Sequence","Energy Window Range Sequence","Energy Window Lower Limit","Energy Window Upper Limit","Radiopharmaceutical Information Sequence","Residual Syringe Counts","Energy Window Name","Detector Vector","Number of Detectors","Detector Information Sequence","Phase Vector","Number of Phases","Phase Information Sequence","Number of Frames in Phase","Phase Delay","Pause Between Frames","Rotation Vector","Number of Rotations","Rotation Information Sequence","Number of Frames in Rotation","R-R Interval Vector","Number of R-R Intervals","Gated Information Sequence","Data Information Sequence","Time Slot Vector","Number of Time Slots","Time Slot Information Sequence","Time Slot Time","Slice Vector","Number of Slices","Angular View Vector","Time Slice Vector","Number of Time Slices","Start Angle","Type of Detector Motion","Trigger Vector","Number of Triggers in Phase","View Code Sequence","View Modifier Code Sequence","Radionuclide Code Sequence","Administration Route Code Sequence","Radiopharmaceutical Code Sequence","Calibration Data Sequence","Energy Window Number","Image ID","Patient Orientation Code Sequence","Patient Orientation Modifier Code Sequence","Patient Gantry Relationship Code Sequence","Series Type","Units","Counts Source","Reprojection Method","Randoms Correction Method","Attenuation Correction Method","Decay Correction","Reconstruction Method","Detector Lines of Response Used","Scatter Correction Method","Axial Acceptance","Axial Mash","Transverse Mash","Detector Element Size","Coincidence Window Width","Secondary Counts Type","Frame Reference Time","Primary (Prompts) Counts Accumulated","Secondary Counts Accumulated","Slice Sensitivity Factor","Decay Factor","Dose Calibration Factor","Scatter Fraction Factor","Dead Time Factor","Image Index","Counts Included","Dead Time Correction Flag","Histogram Group Length","Histogram Sequence","Histogram Number of Bins","Histogram First Bin Value","Histogram Last Bin Value","Histogram Bin Width","Histogram Explanation","Histogram Data","Presentation State Group Length","Graphic Annotation Sequence","Graphic Layer","Bounding Box Annotation Units","Anchor Point Annotation Units","Graphic Annotation Units","Unformatted Text Value","Text Object Sequence","Graphic Object Sequence","Bounding Box Top Left Hand Corner","Bounding Box Bottom Right Hand Corner","Bounding Box Text Horizontal Justification","Anchor Point","Anchor Point Visibility","Graphic Dimensions","Number of Graphic Points","Graphic Data","Graphic Type","Graphic Filled","Image Horizontal Flip","Image Rotation","Displayed Area Top Left Hand Corner","Displayed Area Bottom Right Hand Corner","Displayed Area Selection Sequence","Graphic Layer Sequence","Graphic Layer Order","Graphic Layer Recommended Display Grayscale Value","Graphic Layer Recommended Display RGB Value","Graphic Layer Description","Presentation Label","Presentation Description","Presentation Creation Date","Presentation Creation Time","Presentation Creator's Name","Presentation Size Mode","Presentation Pixel Spacing","Presentation Pixel Aspect Ratio","Presentation Pixel Magnification Ratio","Storage Group Length","Storage Media File-set ID","Storage Media File-set UID","Icon Image Sequence","Topic Title","Topic Subject","Topic Author","Topic Key Words","SOP Instance Status","SOP Authorization Date and Time","SOP Authorization Comment","Authorization Equipment Certification Number","Film Session Group Length","Number of Copies","Printer Configuration Sequence","Print Priority","Medium Type","Film Destination","Film Session Label","Memory Allocation","Maximum Memory Allocation","Color Image Printing Flag","Collation Flag","Annotation Flag","Image Overlay Flag","Presentation LUT Flag","Image Box Presentation LUT Flag","Memory Bit Depth","Printing Bit Depth","Media Installed Sequence","Other Media Available Sequence","Supported Image Display Formats Sequence","Referenced Film Box Sequence","Referenced Stored Print Sequence","Film Box Group Length","Image Display Format","Annotation Display Format ID","Film Orientation","Film Size ID","Printer Resolution ID","Default Printer Resolution ID","Magnification Type","Smoothing Type","Default Magnification Type","Other Magnification Types Available","Default Smoothing Type","Other Smoothing Types Available","Border Density","Empty Image Density","Min Density","Max Density","Trim","Configuration Information","Configuration Information Description","Maximum Collated Films","Illumination","Reflected Ambient Light","Printer Pixel Spacing","Referenced Film Session Sequence","Referenced Image Box Sequence","Referenced Basic Annotation Box Sequence","Image Box Group Length","Image Position","Polarity","Requested Image Size","Requested Decimate/Crop Behavior","Requested Resolution ID","Requested Image Size Flag","Decimate/Crop Result","Basic Grayscale Image Sequence","Basic Color Image Sequence","Referenced Image Overlay Box Sequence","Referenced VOI LUT Box Sequence","Annotation Group Length","Annotation Position","Text String","Overlay Box Group Length","Referenced Overlay Plane Sequence","Referenced Overlay Plane Groups","Overlay Pixel Data Sequence","Overlay Magnification Type","Overlay Smoothing Type","Overlay or Image Magnification","Magnify to Number of Columns","Overlay Foreground Density","Overlay Background Density","Overlay Mode","Threshold Density","Referenced Image Box Sequence","Presentation LUT Group Length","Presentation LUT Sequence","Presentation LUT Shape","Referenced Presentation LUT Sequence","Print Job Group Length","Print Job ID","Execution Status","Execution Status Info","Creation Date","Creation Time","Originator","Destination AE","Owner ID","Number of Films","Referenced Print Job Sequence","Printer Group Length","Printer Status","Printer Status Info","Printer Name","Print Queue ID","Queue Group Length","Queue Status","Print Job Description Sequence","Referenced Print Job Sequence","Print Content Group Length","Print Management Capabilities Sequence","Printer Characteristics Sequence","Film Box Content Sequence","Image Box Content Sequence","Annotation Content Sequence","Image Overlay Box Content Sequence","Presentation LUT Content Sequence","Proposed Study Sequence","Original Image Sequence","RT Image Group Length","RT Image Label","RT Image Name","RT Image Description","Reported Values Origin","RT Image Plane","X-Ray Image Receptor Translation","X-Ray Image Receptor Angle","RT Image Orientation","Image Plane Pixel Spacing","RT Image Position","Radiation Machine Name","Radiation Machine SAD","Radiation Machine SSD","RT Image SID","Source to Reference Object Distance","Fraction Number","Exposure Sequence","Meterset Exposure","DVH Group Length","DVH Type","Dose Units","Dose Type","Dose Comment","Normalization Point","Dose Summation Type","Grid Frame Offset Vector","Dose Grid Scaling","RT Dose ROI Sequence","Dose Value","DVH Normalization Point","DVH Normalization Dose Value","DVH Sequence","DVH Dose Scaling","DVH Volume Units","DVH Number of Bins","DVH Data","DVH Referenced ROI Sequence","DVH ROI Contribution Type","DVH Minimum Dose","DVH Maximum Dose","DVH Mean Dose","RT Structure Set Group Length","Structure Set Label","Structure Set Name","Structure Set Description","Structure Set Date","Structure Set Time","Referenced Frame of Reference Sequence","RT Referenced Study Sequence","RT Referenced Series Sequence","Contour Image Sequence","Structure Set ROI Sequence","ROI Number","Referenced Frame of Reference UID","ROI Name","ROI Description","ROI Display Color","ROI Volume","RT Related ROI Sequence","RT ROI Relationship","ROI Generation Algorithm","ROI Generation Description","ROI Contour Sequence","Contour Sequence","Contour Geometric Type","Contour Slab Thickness","Contour Offset Vector","Number of Contour Points","Contour Number","Attached Contours","Contour Data","RT ROI Observations Sequence","Observation Number","Referenced ROI Number","ROI Observation Label","RT ROI Identification Code Sequence","ROI Observation Description","Related RT ROI Observations Sequence","RT ROI Interpreted Type","ROI Interpreter","ROI Physical Properties Sequence","ROI Physical Property","ROI Physical Property Value","Frame of Reference Relationship Sequence","Related Frame of Reference UID","Frame of Reference Transformation Type","Frame of Reference Transformation Matrix","Frame of Reference Transformation Comment","Measured Dose Reference Sequence","Measured Dose Description","Measured Dose Type","Measured Dose Value","Treatment Session Beam Sequence","Current Fraction Number","Treatment Control Point Date","Treatment Control Point Time","Treatment Termination Status","Treatment Termination Code","Treatment Verification Status","Referenced Treatment Record Sequence","Specified Primary Meterset","Specified Secondary Meterset","Delivered Primary Meterset","Delivered Secondary Meterset","Specified Treatment Time","Delivered Treatment Time","Control Point Delivery Sequence","Specified Meterset","Delivered Meterset","Dose Rate Delivered","Treatment Summary Calculated Dose Reference Sequence","Cumulative Dose to Dose Reference","First Treatment Date","Most Recent Treatment Date","Number of Fractions Delivered","Override Sequence","Override Parameter Pointer","Measured Dose Reference Number","Override Reason","Calculated Dose Reference Sequence","Calculated Dose Reference Number","Calculated Dose Reference Description","Calculated Dose Reference Dose Value","Start Meterset","End Meterset","Referenced Measured Dose Reference Sequence","Referenced Measured Dose Reference Number","Referenced Calculated Dose Reference Sequence","Referenced Calculated Dose Reference Number","Beam Limiting Device Leaf Pairs Sequence","Recorded Wedge Sequence","Recorded Compensator Sequence","Recorded Block Sequence","Treatment Summary Measured Dose Reference Sequence","Recorded Source Sequence","Source Serial Number","Treatment Session Application Setup Sequence","Application Setup Check","Recorded Brachy Accessory Device Sequence","Referenced Brachy Accessory Device Number","Recorded Channel Sequence","Specified Channel Total Time","Delivered Channel Total Time","Specified Number of Pulses","Delivered Number of Pulses","Specified Pulse Repetition Interval","Delivered Pulse Repetition Interval","Recorded Source Applicator Sequence","Referenced Source Applicator Number","Recorded Channel Shield Sequence","Referenced Channel Shield Number","Brachy Control Point Delivered Sequence","Safe Position Exit Date","Safe Position Exit Time","Safe Position Return Date","Safe Position Return Time","Current Treatment Status","Treatment Status Comment","Fraction Group Summary Sequence","Referenced Fraction Number","Fraction Group Type","Beam Stopper Position","Fraction Status Summary Sequence","Treatment Date","Treatment Time","RT Plan Group Length","RT Plan Label","RT Plan Name","RT Plan Description","RT Plan Date","RT Plan Time","Treatment Protocols","Treatment Intent","Treatment Sites","RT Plan Geometry","Prescription Description","Dose Reference Sequence","Dose Reference Number","Dose Reference Structure Type","Nominal Beam Energy Unit","Dose Reference Description","Dose Reference Point Coordinates","Nominal Prior Dose","Dose Reference Type","Constraint Weight","Delivery Warning Dose","Delivery Maximum Dose","Target Minimum Dose","Target Prescription Dose","Target Maximum Dose","Target Underdose Volume Fraction","Organ at Risk Full-volume Dose","Organ at Risk Limit Dose","Organ at Risk Maximum Dose","Organ at Risk Overdose Volume Fraction","Tolerance Table Sequence","Tolerance Table Number","Tolerance Table Label","Gantry Angle Tolerance","Beam Limiting Device Angle Tolerance","Beam Limiting Device Tolerance Sequence","Beam Limiting Device Position Tolerance","Patient Support Angle Tolerance","Table Top Eccentric Angle Tolerance","Table Top Vertical Position Tolerance","Table Top Longitudinal Position Tolerance","Table Top Lateral Position Tolerance","RT Plan Relationship","Fraction Group Sequence","Fraction Group Number","Number of Fractions Planned","Number of Fractions Per Day","Repeat Fraction Cycle Length","Fraction Pattern","Number of Beams","Beam Dose Specification Point","Beam Dose","Beam Meterset","Number of Brachy Application Setups","Brachy Application Setup Dose Specification Point","Brachy Application Setup Dose","Beam Sequence","Treatment Machine Name","Primary Dosimeter Unit","Source-Axis Distance","Beam Limiting Device Sequence","RT Beam Limiting Device Type","Source to Beam Limiting Device Distance","Number of Leaf/Jaw Pairs","Leaf Position Boundaries","Beam Number","Beam Name","Beam Description","Beam Type","Radiation Type","Reference Image Number","Planned Verification Image Sequence","Imaging Device-Specific Acquisition Parameters","Treatment Delivery Type","Number of Wedges","Wedge Sequence","Wedge Number","Wedge Type","Wedge ID","Wedge Angle","Wedge Factor","Wedge Orientation","Source to Wedge Tray Distance","Number of Compensators","Material ID","Total Compensator Tray Factor","Compensator Sequence","Compensator Number","Compensator ID","Source to Compensator Tray Distance","Compensator Rows","Compensator Columns","Compensator Pixel Spacing","Compensator Position","Compensator Transmission Data","Compensator Thickness Data","Number of Boli","Compensator Type","Number of Blocks","Total Block Tray Factor","Block Sequence","Block Tray ID","Source to Block Tray Distance","Block Type","Block Divergence","Block Number","Block Name","Block Thickness","Block Transmission","Block Number of Points","Block Data","Applicator Sequence","Applicator ID","Applicator Type","Applicator Description","Cumulative Dose Reference Coefficient","Final Cumulative Meterset Weight","Number of Control Points","Control Point Sequence","Control Point Index","Nominal Beam Energy","Dose Rate Set","Wedge Position Sequence","Wedge Position","Beam Limiting Device Position Sequence","Leaf/Jaw Positions","Gantry Angle","Gantry Rotation Direction","Beam Limiting Device Angle","Beam Limiting Device Rotation Direction","Patient Support Angle","Patient Support Rotation Direction","Table Top Eccentric Axis Distance","Table Top Eccentric Angle","Table Top Eccentric Rotation Direction","Table Top Vertical Position","Table Top Longitudinal Position","Table Top Lateral Position","Isocenter Position","Surface Entry Point","Source to Surface Distance","Cumulative Meterset Weight","Patient Setup Sequence","Patient Setup Number","Patient Additional Position","Fixation Device Sequence","Fixation Device Type","Fixation Device Label","Fixation Device Description","Fixation Device Position","Shielding Device Sequence","Shielding Device Type","Shielding Device Label","Shielding Device Description","Shielding Device Position","Setup Technique","Setup Technique Description","Setup Device Sequence","Setup Device Type","Setup Device Label","Setup Device Description","Setup Device Parameter","Setup Reference Description","Table Top Vertical Setup Displacement","Table Top Longitudinal Setup Displacement","Table Top Lateral Setup Displacement","Brachy Treatment Technique","Brachy Treatment Type","Treatment Machine Sequence","Source Sequence","Source Number","Source Type","Source Manufacturer","Active Source Diameter","Active Source Length","Source Encapsulation Nominal Thickness","Source Encapsulation Nominal Transmission","Source Isotope Name","Source Isotope Half Life","Reference Air Kerma Rate","Air Kerma Rate Reference Date","Air Kerma Rate Reference Time","Application Setup Sequence","Application Setup Type","Application Setup Number","Application Setup Name","Application Setup Manufacturer","Template Number","Template Type","Template Name","Total Reference Air Kerma","Brachy Accessory Device Sequence","Brachy Accessory Device Number","Brachy Accessory Device ID","Brachy Accessory Device Type","Brachy Accessory Device Name","Brachy Accessory Device Nominal Thickness","Brachy Accessory Device Nominal Transmission","Channel Sequence","Channel Number","Channel Length","Channel Total Time","Source Movement Type","Number of Pulses","Pulse Repetition Interval","Source Applicator Number","Source Applicator ID","Source Applicator Type","Source Applicator Name","Source Applicator Length","Source Applicator Manufacturer","Source Applicator Wall Nominal Thickness","Source Applicator Wall Nominal Transmission","Source Applicator Step Size","Transfer Tube Number","Transfer Tube Length","Channel Shield Sequence","Channel Shield Number","Channel Shield ID","Channel Shield Name","Channel Shield Nominal Thickness","Channel Shield Nominal Transmission","Final Cumulative Time Weight","Brachy Control Point Sequence","Control Point Relative Position","Control Point 3D Position","Cumulative Time Weight","RT Relationship Group Length","Referenced RT Plan Sequence","Referenced Beam Sequence","Referenced Beam Number","Referenced Reference Image Number","Start Cumulative Meterset Weight","End Cumulative Meterset Weight","Referenced Brachy Application Setup Sequence","Referenced Brachy Application Setup Number","Referenced Source Number","Referenced Fraction Group Sequence","Referenced Fraction Group Number","Referenced Verification Image Sequence","Referenced Reference Image Sequence","Referenced Dose Reference Sequence","Referenced Dose Reference Number","Brachy Referenced Dose Reference Sequence","Referenced Structure Set Sequence","Referenced Patient Setup Number","Referenced Dose Sequence","Referenced Tolerance Table Number","Referenced Bolus Sequence","Referenced Wedge Number","Referenced Compensator Number","Referenced Block Number","Referenced Control Point Index","RT Approval Group Length","Approval Status","Review Date","Review Time","Reviewer Name","Text Group Length","Arbitrary","Comments","Results Group Length","Results ID","Results ID Issuer","Referenced Interpretation Sequence","Interpretation Recorded Date","Interpretation Recorded Time","Interpretation Recorder","Reference to Recorded Sound","Interpretation Transcription Date","Interpretation Transcription Time","Interpretation Transcriber","Interpretation Text","Interpretation Author","Interpretation Approver Sequence","Interpretation Approval Date","Interpretation Approval Time","Physician Approving Interpretation","Interpretation Diagnosis Description","Interpretation Diagnosis Code Sequence","Results Distribution List Sequence","Distribution Name","Distribution Address","Interpretation ID","Interpretation ID Issuer","Interpretation Type ID","Interpretation Status ID","Impressions","Results Comments","Waveform Group Length","Waveform Sequence","Channel Minimum Value","Channel Maximum Value","Waveform Bits Allocated","Waveform Sample Interpretation","Waveform Padding Value","Waveform Data","Pixel Data Group Length","Pixel Data","Data Set Trailing Padding","Item","Item Delimitation Item","Sequence Delimitation Item","Curve 50* Group Length","Curve 50* Dimensions","Curve 50* Number of Points","Curve 50* Type of Data","Curve 50* Description","Curve 50* Axis Units","Curve 50* Axis Labels","Curve 50* Data Value Representation","Curve 50* Minimum Coordinate Value","Curve 50* Maximum Coordinate Value","Curve 50* Range","Curve 50* Data Descriptor","Curve 50* Coordinate Start Value","Curve 50* Coordinate Step Value","Curve 50* Activation Layer","Audio 50* Type","Audio 50* Sample Format","Audio 50* Number of Channels","Audio 50* Number of Samples","Audio 50* Sample Rate","Audio 50* Total Time","Audio 50* Sample Data","Audio 50* Comments","Curve 50* Label","Referenced Overlay 50* Sequence","Referenced Overlay 50* Group","Curve 50* Data","Overlay 60* Group Length","Overlay 60* Rows","Overlay 60* Columns","Overlay 60* Planes","Number of Frames in Overlay 60*","Overlay 60* Description","Overlay 60* Type","Overlay 60* Subtype","Overlay 60* Origin","Image 60* Frame Origin","Overlay 60* Plane Origin","Overlay 60* Compression Code","Overlay 60* Bits Allocated","Overlay 60* Bit Position","Overlay 60* Format","Overlay 60* Location","Overlay 60* Activation Layer","Overlay 60* Descriptor - Gray","Overlay 60* Descriptor - Red","Overlay 60* Descriptor - Green","Overlay 60* Descriptor - Blue","Overlay 60* - Gray","Overlay 60* - Red","Overlay 60* - Green","Overlay 60* - Blue","ROI 60* Area","ROI 60* Mean","ROI 60* Standard Deviation","Overlay 60* Label","Overlay 60* Data","Overlay 60* Comments"};


End[]

SetAttributes[
{Dicom,
DicomImport,
DicomDicitionary},
{Protected, ReadProtected}
];

EndPackage[]
