(* ::Package:: *)

(************************************************************************)
(* This file was generated automatically by the Mathematica front end.  *)
(* It contains Initialization cells from a Notebook file, which         *)
(* typically will have the same name as this file except ending in      *)
(* ".nb" instead of ".m".                                               *)
(*                                                                      *)
(* This file is intended to be loaded into the Mathematica kernel using *)
(* the package loading commands Get or Needs.  Doing so is equivalent   *)
(* to using the Evaluate Initialization Cells menu command in the front *)
(* end.                                                                 *)
(*                                                                      *)
(* DO NOT EDIT THIS FILE.  This entire file is regenerated              *)
(* automatically each time the parent Notebook file is saved in the     *)
(* Mathematica front end.  Any changes you make to this file will be    *)
(* overwritten.                                                         *)
(************************************************************************)



(* TimeSamp for Package Version Control *)

Unprotect[TimeStamp];

TimeStamp::usage="TimeStamp[context] should be set to a Date[]-List indicating the version of the corresponding package.";

TimeStamp["MathVisionTools`Converters`FDF`"] = {2010,2,2,12,0,0};

Protect[TimeStamp];


(*:Name: MathVisionTools`Converters`FDF` *)

(*:Author: Markus van Almsick*)

(*:Email address: M.v.Almsick@tue.nl*)

(*:Context: MathVisionTools`Converters`FDF`*)

(*:Package Version: 1.1 *)

(*:Mathematica Version: 6.0 *)

(*:Copyright: Copyright 2010, Technische Universiteit Eindhoven*)

(*:Title: FDF *)

(*:Summary: This package implements the import of FDF headers and the retrieval of 2Dfov and 3Dfov data matrices from FDF files. *)

(*:Keywords: MR, Data, File, Import, FDF *)

(*:Requirements: MathLink Binaries *)

(*:Source: None *)

(*:History: Version 1.0 by Markus van Almsick, July 2003 *)
(*:History: Version 1.1 by Markus van Almsick, February 2010 *)

(*:Limitations: Binaries for Windows, Linux, and MacOSX only*)

(*:Discussion: *)

(*:To do: *)


BeginPackage["MathVisionTools`Converters`FDF`"]

Unprotect[
FDFImport,
FDFHeaderImport,
FDF,
FDFHeader,
FDFSelection,
FDFHeaderParsing
]


FDFImport::usage="FDFImport[fname] loads an FDF data file into Mathematica. The imported data is a nested List expression of Real numbers. If option FDFHeader is set to True FDF header information is attached to the FDF data within a Mathematica expression with head FDF."

FDFHeaderImport::usage="FDFHeaderImport[fname] loads the String that constitutes the header of the FDF data file. Set FDFHeaderParsing to True to obtain a list of substitution rules instead of a simple String, which is the default."

FDF::usage="FDF[data, {tags}] is a Mathematica expression to represent FDF files. The first argument is a nested List containing the data of the FDF file. The second argument is a list of rules replacing FDF header keywords with their respective values."

FDFHeader::usage="FDFHeader is an option of FDFImport. If set to True, FDFImport renders a Mathematica expression with head FDF that contains as its first argument a nested List of data and as its second argument a List of FDF header information encoded as Mathematica replacement rules. The default is False, so that FDFImport simply renders the data."

FDFSelection::usage="FDFSelection is an option of FDFImport. It can be set to a List of Range specifications to extract a subset of data from an FDF file. The default is All."

FDFHeaderParsing::usage="FDFHeaderParsing is an option of FDFHeaderImport. If FDFHeaderParsing is set to True, FDFHeaderImport converts the FDF header string into a List of Mathematica substitution rules."

FDF::file = "Cannot find FDF file `1`"

FDF::nosup = "Data format in FDF file `1` is no supported."

Options[FDFImport]={Path:> $Path, FDFHeader-> False,FDFSelection-> All};

Options[FDFHeaderImport]={Path:> $Path, FDFHeaderParsing-> False};


Begin["`Private`"]


(* Connection MathLink Binary *)

MLBinaryName = Switch[$SystemID,
"Windows","FDF.exe",
"Darwin","FDF",
"Linux","FDF",
"MacOSX-x86","FDF",
_,"FDF"];

MLBinaryPath=Map[ToFileName[{#,"MathVisionTools","Converters","Binaries",$SystemID},MLBinaryName]&,$Path];

MLBinaryFiles = FileNames[MLBinaryPath];

FDF::linkc="The LinkObject to the FDF I/O binary is dead; attempt to connect failed";

If[MLBinaryFiles==={},
MLBinaryLink=$Failed,
If[Links[First[MLBinaryFiles]]==={},
Off[LinkConnect::"linkc"];
MLBinaryLink = Install[First[MLBinaryFiles]];
On[LinkConnect::"linkc"],
MLBinaryLink = First[Links[First[MLBinaryFiles]]]
]
];

If[Head[MLBinaryLink]===$Failed,Message[FDF::linkc]];


(* FDF Header Import Function *)

FDFHeaderImport[fname_String, opts___Rule]:= 
If[
Length[fnames = FileNames[fname,Join[{""},(Path /. {opts} /. Options[FDFHeaderImport])]]
]>0,
If[
"FDFHeaderParsing"/. ({opts} /. StringRule) /. (Options[FDFHeaderImport] /. StringRule),
First[Rest[Transpose[ParseFDFHeader[ReadFDFHeader[First[fnames]]]]]],
ReadFDFHeader[First[fnames]],ReadFDFHeader[First[fnames]]
],
Message[FDF::file,First[fnames]];$Failed
]


(* Selection To Range Conversion Function *)

SelectionToRange[sel_Integer, max_Integer]={#,#,1}&[Max[Min[sel,max],1]];

SelectionToRange[{sel1_Integer,sel2_Integer,sel3_Integer:1}, max_Integer]:=Append[Map[Max[Min[#,max],1]&,{sel1,sel2}],sel3];

SelectionToRange[All, max_Integer]={1,max,1};

SelectionToRange[sel_List, max_List]:=MapThread[SelectionToRange,{sel,max},1];


(* Parsing FDF Header C-String *)

ParseFDFHeader[header_String]:=Prepend[Apply[{First[#1],Rule[Last[#1],#2]}&[ImportString[#1,"Words"],ToExpression[#2]]&,Map[mtvStringSplit[#," = "]&,Cases[ImportString[StringReplace[header,{"char *"->"char* ","char  *"->"char*  ","[]"->"","\f"->"",";"->""}],"Lines"],_String?(StringMatchQ[#,"*=*"]&)]],{1}],{"int","headerlength"->StringLength[header]+1}];

mtvStringSplit[s_String,token_String]:=Map[StringTake[s,#]&,Partition[Flatten[Append[Prepend[StringPosition[s,token],1],StringLength[s]]],2]];


(* FDF data file Import *)

StringRule = {HoldPattern[s_->r_]:> (ToString[s]->r),HoldPattern[s_:>r_]:> (ToString[s]:>r)};

FDFImport[fname_String, selections:(_Integer|{__Integer}|All)...,opts___Rule]:= 
Module[
{fnames},
If[
Length[fnames = FileNames[FileNameTake[fname],Prepend[(Path /. {opts} /. Options[FDFImport]),DirectoryName[fname]]]
]>0,
FDFHead = First[Rest[Transpose[ParseFDFHeader[ReadFDFHeader[First[fnames]]]]]];
FDFRange = "FDFSelection" /. ({opts} /. StringRule) /. (Options[FDFImport] /. StringRule);
If[FDFRange===All, FDFRange={}];
If[{selections}=!={}, FDFRange ={selections}];
FDFRange = SelectionToRange[PadRight[FDFRange,Length[ "matrix"/.FDFHead],All],"matrix"/.FDFHead];
FDFData = ReadFDFMatrix @@ ({First[fnames], "float", Round["bits"], "headerlength",Round[ "rank"],"matrix",FDFRange}/.FDFHead);
If[
False,
Message[FDF::nosup,First[fnames]];$Failed,
If["FDFHeader"/. ({opts} /. StringRule) /. (Options[FDFImport] /. StringRule),
FDF[FDFData,FDFHead],
FDFData,FDFData
]
],
Message[FDF::file,First[fnames]];$Failed
]
]


If[
$VersionNumber<6,
Experimental`RegisterConverter[Import,
"FDF",
{"*.fdf","*.FDF"},
None,
FDFImport[
#1,
Apply[Sequence,ConversionOptions/.Rest[{##}]/.ConversionOptions->{}]
]&,
"TextFormat"->False
]
]


End[]

SetAttributes[
{FDFImport,
FDFHeaderImport,
FDF,
FDFHeader,
FDFSelection,
FDFHeaderParsing},
{Protected, ReadProtected}
];

EndPackage[]
