(* ::Package:: *)

(************************************************************************)
(* This file was generated automatically by the Mathematica front end.  *)
(* It contains Initialization cells from a Notebook file, which         *)
(* typically will have the same name as this file except ending in      *)
(* ".nb" instead of ".m".                                               *)
(*                                                                      *)
(* This file is intended to be loaded into the Mathematica kernel using *)
(* the package loading commands Get or Needs.  Doing so is equivalent   *)
(* to using the Evaluate Initialization Cells menu command in the front *)
(* end.                                                                 *)
(*                                                                      *)
(* DO NOT EDIT THIS FILE.  This entire file is regenerated              *)
(* automatically each time the parent Notebook file is saved in the     *)
(* Mathematica front end.  Any changes you make to this file will be    *)
(* overwritten.                                                         *)
(************************************************************************)



(*:Name: MathVisionTools`Convolution` *)

(*:Author: Bart M.ter Haar Romeny Ph.D.and Markus van Almsick*)

(*:Email address: B.terHaarRomeny@isi.uu.nl, M.v.Almsick@tue.nl*)

(*:Context: MathVisionTools`Convolution`*)

(*:Package Version: 1.0 *)

(*:Mathematica Version: 4.0 *)

(*:Copyright: Copyright 2002, Technische Universiteit Eindhoven*)

(*:Title: Convolution *)

(*:Summary: This package implements symbolic convolution with the commands convolve and convolute *)

(*:Keywords: Convolve, Fourier, scale-space, computer vision, 
  differential operator *)

(*:Requirements: None *)

(*:Source: *)

(*:History: Version 1.0 by Bart M.ter Haar Romeny and Markus van Almsick, 
  October 2002 *)

(*:Limitations: *)

(*:Discussion: *)

(*:To do:  *)


BeginPackage["MathVisionTools`Convolve`"]
Needs["MathVisionTools`GaussianDerivative`"]
Unprotect[
  Convolve,
  Convolute,
  GaussianKernel,
  GaussianDKernel
  ]


Convolve::usage = "Convolve[f, g, y, x] gives the convolute of f and g with respect to y and resulting variable x."

Convolute::usage = "Convolute[{sf1,sg1},{sf2,sg2},...][f,g] represents the convolute of f and g with slot sf1 of f convolved with slot sg1 of g, and slot sf2 of f convolved with slot sg2 of g and so on for higher-dimensional cases."


Begin["`Private`"]


SetAttributes[Convolve,HoldAll]


Convolve[f_,g_,{t_},{x_}] := Convolve[f,g,t,x] 


Convolve[f_,g_,t_,x_]:=Convolve[g,f,t,x]/;Not[ConvolveOrderedQ[f,g]]
ConvolveOrderedQ[f_,g_]:= OrderedQ[{f,g}]


Convolve[f_ + g_,h_,t_,x_] := Convolve[f,h,t,x] + Convolve[g,h,t,x];
Convolve[f_ ,g_+ h_,t_,x_] := Convolve[f,g,t,x] + Convolve[f,h,t,x];


Convolve[f_,c_ g_,t_List,x_List] := 
    c Convolve[f,g,t,x] /; Apply[And,Map[FreeQ[c,#]&,t]];
Convolve[f_,c_ g_,t_List,x_List] := 
    c Convolve[f,g,t,x] /; Apply[And,Map[FreeQ[c,#]&,t]];
Convolve[c_ f_,g_,t_,x_] := c Convolve[f,g,t,x] /; FreeQ[c,t];
Convolve[f_,c_ g_,t_,x_] := c Convolve[f,g,t,x] /; FreeQ[c,t];


Convolve[
    fSineXi_?(FreeQ[#,xi]&) * fCumXi_?(Not[FreeQ[#,xi]]&),
    g_,
    xs:{x1___,xi_,x2___},
    ys_List
    ]:=
  Module[
    {xipos=First[Position[xs,xi,1]]},
    Convolve[
      fSineXi * Convolve[fCumXi,g,xi,Take[ys,xipos]],
      g,
      {x1,x2},
      Drop[ys,xipos]]
    ]
Convolve[
    f_,
    gSineXi_?(FreeQ[#,xi]&) * gCumXi_?(Not[FreeQ[#,xi]]&),
    xs:{x1___,xi_,x2___},
    ys_List
    ]:=
  Module[
    {xipos=First[Position[xs,xi,1]]},
    Convolve[
      f,
      gSineXi * Convolve[f,gCumXi,xi,Take[ys,xipos]],
      {x1,x2},
      Drop[ys,xipos]]
    ]


GaussianKernel/:Convolve[GaussianKernel[t_List,{x__}],f_,{x__},{y__}] := 
    GaussianDerivative[Apply[Sequence,Map[{#,0}&,t]]][f][y]/; 
      MatchQ[f,func_[x]];

GaussianKernel/:Convolve[GaussianKernel[t_,{x__}],f_,{x__},{y__}] := 
    GaussianDerivative[Apply[Sequence,Table[{t,0},{Length[t]}]]][f][y]/; 
      MatchQ[f,func_[x]];

GaussianKernel/:Convolve[GaussianKernel[t_,x_],f_,x_,y_] := 
    GaussianDerivative[{t,0}][f][y]/; MatchQ[f,func_[x]];


GaussianDKernel/:
    Convolve[GaussianDKernel[t_List,n_List,{x__}],f_,{x__},{y__}] := 
    GaussianDerivative[Apply[Sequence,Transpose[{t,n}]]][f][y]/; 
      MatchQ[f,func_[x]];

GaussianDKernel/:Convolve[GaussianDKernel[t_,n_List,{x__}],f_,{x__},{y__}] := 
    GaussianDerivative[Apply[Sequence,Map[{t,#}&,n]]][f][y]/; 
      MatchQ[f,func_[x]];

GaussianDKernel/:Convolve[GaussianDKernel[t_List,n_,{x__}],f_,{x__},{y__}] := 
    GaussianDerivative[Apply[Sequence,Map[{#,n}&,t]]][f][y]/; 
      MatchQ[f,func_[x]];

GaussianDKernel/:Convolve[GaussianDKernel[t_,n_,x_],f_,x_,y_] := 
    GaussianDerivative[{t,n}][f][y]/; MatchQ[f,func_[x]];


Convolute/:Derivative[n__Integer][Convolute[ord__List][f_,g_]] :=
  Convolute[ord][Derivative[Apply[Sequence,Part[
            PadRight[{n},Length[{ord}],0],
            First[Transpose[{ord}]]
            ]
          ]
        ][f],
    g
    ] 


Convolve[f_,g_,t_List,x_List] :=
  Module[
      {F,G,fg,\[Omega] = Table[Unique[\[Omega]],{Length[t]}]},
      Simplify[fg,x\[Element]Reals]/; 
        FreeQ[F= FourierTransform[f,t,\[Omega]],FourierTransform] \[And] 
          FreeQ[G= FourierTransform[g,t,\[Omega]],FourierTransform] \[And] 
          FreeQ[fg=InverseFourierTransform[Simplify[F * G,\[Omega]\[Element]Reals],\[Omega],x],
            InverseFourierTransform]
      ]/; Length[t]=== Length[x]

Convolve[f_,g_,t_,x_] :=
  Module[
    {F,G,fg,\[Omega]},
    Simplify[fg,x\[Element]Reals]/; 
      FreeQ[F= FourierTransform[f,t,\[Omega]],FourierTransform] \[And] 
        FreeQ[G= FourierTransform[g,t,\[Omega]],FourierTransform] \[And] 
        FreeQ[fg=  InverseFourierTransform[Simplify[F * G,\[Omega]\[Element]Reals],\[Omega],x],
          InverseFourierTransform]
    ]


Convolve[f_,g_,t_,x_] := 
  Convolute[{1,1}][f,g][x]/;MatchQ[f,func_[t]] && MatchQ[g,func_[t]]

Convolve[f_,g_,{t__},{x__}] := 
  Apply[Convolute[##][f,g][x]&,
      Transpose[{Ordering[Ordering[{t}[[Ordering[{tf}]]]]],
          Ordering[Ordering[{t}[[Ordering[{tg}]]]]]}]]/;
    MatchQ[f,func_[__?(Sort[{##}]===Sort[{t}]&)]] && 
      MatchQ[g,func_[__?(Sort[{##}]===Sort[{t}]&)]]


IndexRangeQ[n_Integer][x_] := 
  And[IntegerQ[#],Positive[#],#<=n]&[ToExpression[x]]


MakeExpression[RowBox[{lhs___,f_,"\[Star]",g_,rhs___}],StandardForm]:=
  MakeExpression[
    RowBox[{lhs,
        RowBox[{RowBox[{"Convolute","[",
                RowBox[{"{",RowBox[{"1",",","1"}],"}"}],"]"}],"[",
            RowBox[{f,",",g}],"]"}],rhs}],StandardForm]


MakeBoxes[Convolute[{1,1}][f_,g_],StandardForm]:=
  RowBox[{Parenthesize[f,StandardForm,Star],"\[Star]",
      Parenthesize[g,StandardForm,Star]}]


MakeExpression[
    RowBox[{lhs___,f_,OverscriptBox["\[Star]",RowBox[{"(","1",")"}]],g_,
        rhs___}],StandardForm]:=
  MakeExpression[
    RowBox[{lhs,
        RowBox[{RowBox[{"Convolute","[",
                RowBox[{"{",RowBox[{"1",",","1"}],"}"}],"]"}],"[",
            RowBox[{f,",",g}],"]"}],rhs}],StandardForm]


MakeExpression[
    RowBox[{lhs___,f_,
        OverscriptBox["\[Star]",
          RowBox[{"(",RowBox[{"1","\[LeftRightArrow]","1"}],")"}]],g_,
        rhs___}],StandardForm]:=
  MakeExpression[
    RowBox[{lhs,
        RowBox[{RowBox[{"Convolute","[",
                RowBox[{"{",RowBox[{"1",",","1"}],"}"}],"]"}],"[",
            RowBox[{f,",",g}],"]"}],rhs}],StandardForm]


MakeExpression[
    RowBox[{lhs___,f_,OverscriptBox["\[Star]",RowBox[{"(","2",")"}]],g_,
        rhs___}],StandardForm]:=
  MakeExpression[
    RowBox[{lhs,
        RowBox[{RowBox[{"Convolute","[",
                RowBox[{RowBox[{"{",RowBox[{"1",",","1"}],"}"}],",",
                    RowBox[{"{",RowBox[{"2",",","2"}],"}"}]}],"]"}],"[",
            RowBox[{f,",",g}],"]"}],rhs}],StandardForm]


MakeBoxes[Convolute[{1,1},{2,2}][f_,g_],StandardForm]:=
  RowBox[{Parenthesize[f,StandardForm,Star],
      OverscriptBox["\[Star]",RowBox[{"(","2",")"}]],
      Parenthesize[g,StandardForm,Star]}]


MakeExpression[
    RowBox[{lhs___,f_,
        OverscriptBox["\[Star]",
          RowBox[{"(",
              GridBox[{{RowBox[{sf1_?(IndexRangeQ[2]),"\[LeftRightArrow]",
                        sg1_?(IndexRangeQ[2])}]},{RowBox[{sf2_?(IndexRangeQ[
                              2]),"\[LeftRightArrow]",
                        sg2_?(IndexRangeQ[2])}]}}],")"}]],g_,rhs___}],
    StandardForm]:=
  MakeExpression[
    RowBox[{lhs,
        RowBox[{RowBox[{"Convolute","[",
                RowBox[{RowBox[{"{",RowBox[{sf1,",",sg1}],"}"}],",",
                    RowBox[{"{",RowBox[{sf2,",",sg2}],"}"}]}],"]"}],"[",
            RowBox[{f,",",g}],"]"}],rhs}],StandardForm]


MakeBoxes[
    Convolute[{sf1_?(IndexRangeQ[2]),
          sg1_?(IndexRangeQ[2])},{sf2_?(IndexRangeQ[2]),
          sg2_?(IndexRangeQ[2])}][f_,g_],StandardForm]:=
  RowBox[{Parenthesize[f,StandardForm,Star],
      OverscriptBox["\[Star]",
        RowBox[{"(",
            GridBox[{{RowBox[{Parenthesize[sf1,StandardForm,LeftRightArrow],
                      "\[LeftRightArrow]",
                      Parenthesize[sg1,StandardForm,
                        LeftRightArrow]}]},{RowBox[{Parenthesize[sf2,
                        StandardForm,LeftRightArrow],"\[LeftRightArrow]",
                      Parenthesize[sg2,StandardForm,LeftRightArrow]}]}}],
            ")"}]],Parenthesize[g,StandardForm,Star]}]


MakeBoxes[Convolute[{1,1},{2,2},{3,3}][f_,g_],StandardForm]:=
  RowBox[{Parenthesize[f,StandardForm,Star],
      OverscriptBox["\[Star]",RowBox[{"(","3",")"}]],
      Parenthesize[g,StandardForm,Star]}]


MakeExpression[
    RowBox[{lhs___,f_,
        OverscriptBox["\[Star]",
          RowBox[{"(",
              GridBox[{{RowBox[{sf1_?(IndexRangeQ[3]),"\[LeftRightArrow]",
                        sg1_?(IndexRangeQ[3])}]},{RowBox[{sf2_?(IndexRangeQ[
                              3]),"\[LeftRightArrow]",
                        sg2_?(IndexRangeQ[3])}]},{RowBox[{sf3_?(IndexRangeQ[
                              3]),"\[LeftRightArrow]",
                        sg3_?(IndexRangeQ[3])}]}}],")"}]],g_,rhs___}],
    StandardForm]:=
  MakeExpression[
    RowBox[{lhs,
        RowBox[{RowBox[{"Convolute","[",
                RowBox[{RowBox[{"{",RowBox[{sf1,",",sg1}],"}"}],",",
                    RowBox[{"{",RowBox[{sf2,",",sg2}],"}"}],",",
                    RowBox[{"{",RowBox[{sf3,",",sg3}],"}"}]}],"]"}],"[",
            RowBox[{f,",",g}],"]"}],rhs}],StandardForm]


MakeBoxes[
    Convolute[{sf1_?(IndexRangeQ[3]),
          sg1_?(IndexRangeQ[3])},{sf2_?(IndexRangeQ[3]),
          sg2_?(IndexRangeQ[3])},{sf3_?(IndexRangeQ[3]),
          sg3_?(IndexRangeQ[3])}][f_,g_],StandardForm]:=
  RowBox[{Parenthesize[f,StandardForm,Star],
      OverscriptBox["\[Star]",
        RowBox[{"(",
            GridBox[{{RowBox[{Parenthesize[sf1,StandardForm,LeftRightArrow],
                      "\[LeftRightArrow]",
                      Parenthesize[sg1,StandardForm,
                        LeftRightArrow]}]},{RowBox[{Parenthesize[sf2,
                        StandardForm,LeftRightArrow],"\[LeftRightArrow]",
                      Parenthesize[sg2,StandardForm,
                        LeftRightArrow]}]},{RowBox[{Parenthesize[sf3,
                        StandardForm,LeftRightArrow],"\[LeftRightArrow]",
                      Parenthesize[sg3,StandardForm,LeftRightArrow]}]}}],
            ")"}]],Parenthesize[g,StandardForm,Star]}]


MakeExpression[
    RowBox[{lhs___,f_,OverscriptBox["\[Star]",RowBox[{"(","4",")"}]],g_,
        rhs___}],StandardForm]:=
  MakeExpression[
    RowBox[{lhs,
        RowBox[{RowBox[{"Convolute","[",
                RowBox[{RowBox[{"{",RowBox[{"1",",","1"}],"}"}],",",
                    RowBox[{"{",RowBox[{"2",",","2"}],"}"}],",",
                    RowBox[{"{",RowBox[{"3",",","3"}],"}"}],",",
                    RowBox[{"{",RowBox[{"4",",","4"}],"}"}]}],"]"}],"[",
            RowBox[{f,",",g}],"]"}],rhs}],StandardForm]


MakeBoxes[Convolute[{1,1},{2,2},{3,3},{4,4}][f_,g_],StandardForm]:=
  RowBox[{Parenthesize[f,StandardForm,Star],
      OverscriptBox["\[Star]",RowBox[{"(","4",")"}]],
      Parenthesize[g,StandardForm,Star]}]


MakeExpression[
    RowBox[{lhs___,f_,
        OverscriptBox["\[Star]",
          RowBox[{"(",
              GridBox[{{RowBox[{sf1_?(IndexRangeQ[4]),"\[LeftRightArrow]",
                        sg1_?(IndexRangeQ[4])}]},{RowBox[{sf2_?(IndexRangeQ[
                              4]),"\[LeftRightArrow]",
                        sg2_?(IndexRangeQ[4])}]},{RowBox[{sf3_?(IndexRangeQ[
                              4]),"\[LeftRightArrow]",
                        sg3_?(IndexRangeQ[4])}]},{RowBox[{sf4_?(IndexRangeQ[
                              4]),"\[LeftRightArrow]",
                        sg4_?(IndexRangeQ[4])}]}}],")"}]],g_,rhs___}],
    StandardForm]:=
  MakeExpression[
    RowBox[{lhs,
        RowBox[{RowBox[{"Convolute","[",
                RowBox[{RowBox[{"{",RowBox[{sf1,",",sg1}],"}"}],",",
                    RowBox[{"{",RowBox[{sf2,",",sg2}],"}"}],",",
                    RowBox[{"{",RowBox[{sf3,",",sg3}],"}"}],",",
                    RowBox[{"{",RowBox[{sf4,",",sg4}],"}"}]}],"]"}],"[",
            RowBox[{f,",",g}],"]"}],rhs}],StandardForm]


MakeBoxes[
    Convolute[{sf1_?(IndexRangeQ[4]),
          sg1_?(IndexRangeQ[4])},{sf2_?(IndexRangeQ[4]),
          sg2_?(IndexRangeQ[4])},{sf3_?(IndexRangeQ[4]),
          sg3_?(IndexRangeQ[4])},{sf4_?(IndexRangeQ[4]),
          sg4_?(IndexRangeQ[4])}][f_,g_],StandardForm]:=
  RowBox[{Parenthesize[f,StandardForm,Star],
      OverscriptBox["\[Star]",
        RowBox[{"(",
            GridBox[{{RowBox[{Parenthesize[sf1,StandardForm,LeftRightArrow],
                      "\[LeftRightArrow]",
                      Parenthesize[sg1,StandardForm,
                        LeftRightArrow]}]},{RowBox[{Parenthesize[sf2,
                        StandardForm,LeftRightArrow],"\[LeftRightArrow]",
                      Parenthesize[sg2,StandardForm,
                        LeftRightArrow]}]},{RowBox[{Parenthesize[sf3,
                        StandardForm,LeftRightArrow],"\[LeftRightArrow]",
                      Parenthesize[sg3,StandardForm,
                        LeftRightArrow]}]},{RowBox[{Parenthesize[sf4,
                        StandardForm,LeftRightArrow],"\[LeftRightArrow]",
                      Parenthesize[sg4,StandardForm,LeftRightArrow]}]}}],
            ")"}]],Parenthesize[g,StandardForm,Star]}]


End[]

Protect[
Convolve,
Convolute,
GaussianKernel,
GaussianDKernel
]

EndPackage[]
