(* ::Package:: *)

(************************************************************************)
(* This file was generated automatically by the Mathematica front end.  *)
(* It contains Initialization cells from a Notebook file, which         *)
(* typically will have the same name as this file except ending in      *)
(* ".nb" instead of ".m".                                               *)
(*                                                                      *)
(* This file is intended to be loaded into the Mathematica kernel using *)
(* the package loading commands Get or Needs.  Doing so is equivalent   *)
(* to using the Evaluate Initialization Cells menu command in the front *)
(* end.                                                                 *)
(*                                                                      *)
(* DO NOT EDIT THIS FILE.  This entire file is regenerated              *)
(* automatically each time the parent Notebook file is saved in the     *)
(* Mathematica front end.  Any changes you make to this file will be    *)
(* overwritten.                                                         *)
(************************************************************************)



(* TimeSamp for Package Version Control *)

Unprotect[TimeStamp];

TimeStamp::usage="TimeStamp[context] should be set to a Date[]-List indicating the version of the corresponding package.";

TimeStamp["MathVisionTools`Ellipsefit`"] ={2008,1,23,14,50,0};

Protect[TimeStamp];


(*:Name: MathVisionTools`EllipseFit`*)

(*:Author: Han van Triest  and Markus van Almsick *)

(*:Email address: J.w.v.Triest@tue.nl,  M.v.Almsick@tue.nl *)

(*:Context: MathVisionTools`EllipseFit`*)

(*:Package Version: 1.1*)

(*:Mathematica Version: 5.2*)

(*:Copyright: Copyright 2008, Technische Universiteit Eindhoven*)

(*:Title: EllipseFit*)

(*:Summary: Package containing functions for the fitting of a ellipse specific conic to a set of data points. Furthermore, a function is provided for the fitting of an ellipsoid to three dimensional data.*)

(*:Keywords: Least Squares Ellipse Fitting, LeastSquares Ellipsoid Fitting*)

(*:Requirements: None *)

(*:Source: Fitzgibbon, IEEE PAMI, 21, 5, 1999, pp 476-480 *)

(*:History: Version 1.0 by J.W. van Triest, 6-8-2007 *)
(*:History: Version 1.1 by M. van ALmsick, 23-1-2008 *)

(*:Limitations: *)

(*:Discussion: *)

(*:To do: *)


BeginPackage["MathVisionTools`EllipseFit`"]

Unprotect[
ListEllipseFit,EllipseProperties,EllipseOrigin,EllipseRadii,EllipseOrientation,QuadraticCurve
]


ListEllipseFit::usage="ListEllipseFit[data] fits an ellipse model to a set of 2-dimensional coordinates {{x1,y1},{x2,y2},...{xn,yn}}. The result is given in the form of the coefficient list {a,b,c,d,e} of the quadratic equation a \!\(\*SuperscriptBox[\"x\", \"2\"]\) + b x y + c \!\(\*SuperscriptBox[\"y\", \"2\"]\) + d x + e y + 1 = 0."


EllipseProperties::usage="EllipseProperties[{a,b,c,d,e,f:1}] renders a list of rules that specify the EllipseOrigin, EllipseRadii, EllipseOrientation for an ellipse given by its quadratic equation a \!\(\*SuperscriptBox[\"x\", \"2\"]\) + b x y + c \!\(\*SuperscriptBox[\"y\", 
RowBox[{\"2\", \" \"}]]\)+ d x + e y + f == 0. Coefficient f is optional."


EllipseOrigin::usage="EllipseOrigin is an option tag for the function EllipseProperties that defines the center of an ellipse."


EllipseRadii::usage="EllipseRadii is an option tag for the function EllipseProperties that defines the radii of an ellipse along its major and minor axes."


EllipseOrientation::usage="EllipseOrientation is an option tag for the function EllipseProperties that defines the angle of the major and minor axes of an ellipse with respect to the x- and y-axis."


QuadraticCurve::usage="QuadraticCurve[{a,b,c,d,e,f}] renders the Graphic primitive of an ellipse defined by the quadratic equation a \!\(\*SuperscriptBox[\"x\", \"2\"]\) + b x y + c \!\(\*SuperscriptBox[\"y\", 
RowBox[{\"2\", \" \"}]]\)+ d x + e y + f == 0. Currently, only an empty List is rendered for all other quadratic curves."


Begin["`Private`"]


(* Utility Functions *)


(* Messages *)
ListEllipseFit::invaldat="Input data is not a list of 2D coordinates, data must consist of a list of coordinates.";

ListEllipseFit::symb="The data contain symbolic values. Cannot fit an ellipse on a set of symbolic data points.";


(* ListEllipseFit *)
ListEllipseFit[data_]:=
Module[
{designMat,eigenSys,X},

(* Check data validity *)
If[
\[Not](MatchQ[Dimensions[data],{_,2}]),
Message[ListEllipseFit::invaldat];Return[$Failed]
];
X=Apply[ {#1^2,#1 #2,#2^2,#1,#2,1}&,data,{1}];
Chop[Most[#]/Last[#]]&[If[
MatrixRank[X]<6,
First[NullSpace[X]],

(* Calculate the designers matrix *)
designMat=Transpose[X].X;

(* Calculate the fit, the fit is associated with the single positive eigenvalue *)
Off[Inverse::"luc"];
eigenSys=Eigensystem[Inverse[designMat].\!\(\*
TagBox[
RowBox[{"(", "", GridBox[{
{"0", "0", "2", "0", "0", "0"},
{"0", 
RowBox[{"-", "1"}], "0", "0", "0", "0"},
{"2", "0", "0", "0", "0", "0"},
{"0", "0", "0", "0", "0", "0"},
{"0", "0", "0", "0", "0", "0"},
{"0", "0", "0", "0", "0", "0"}
},
GridBoxAlignment->{"Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
GridBoxSpacings->{"Columns" -> {Offset[0.27999999999999997`], {Offset[0.7]}, Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {Offset[0.2], {Offset[0.4]}, Offset[0.2]}, "RowsIndexed" -> {}}], "", ")"}],
Function[BoxForm`e$, MatrixForm[BoxForm`e$]]]\)];
On[Inverse::"luc"];
Select[Transpose[eigenSys],Positive[#[[1]]]&][[1,2]]
]]
];


EllipseProperties[{a_,b_,c_,d_,e_,f_:1}] := 
Module[
{\[CapitalDelta]=4 a c f-c d^2+b d e-a e^2-b^2 f,J = 4 a c-b^2, l=a+c},
If[
\[CapitalDelta]!=0 \[And] J>0 \[And] \[CapitalDelta]/l<0,
{EllipseOrigin -> 1/J {b e-2 c d,b d-2 a e}, 
EllipseRadii ->Sqrt[2/J ] { Sqrt[-\[CapitalDelta]/(l-Sqrt[(a-c)^2+b^2] )],Sqrt[-\[CapitalDelta]/(l+Sqrt[(a-c)^2+b^2])]},
EllipseOrientation-> 1/2 (ArcTan[a-c,b]+\[Pi])},
$Failed
]
]


QuadraticCurve[{a_,b_,c_,d_,e_,f_:1}] :=
Module[
{\[CapitalDelta]=4 a c f-c d^2+b d e-a e^2-b^2 f,J = 4 a c-b^2, l=a+c},
If[
\[CapitalDelta]!=0 \[And] J>0 \[And] \[CapitalDelta]/l<0,
Rotate[
Circle[ 1/J {b e-2 c d,b d-2 a e},Sqrt[2/J ] {Sqrt[-\[CapitalDelta]/(l+Sqrt[(a-c)^2+b^2])] ,Sqrt[-\[CapitalDelta]/(l-Sqrt[(a-c)^2+b^2] )]}],1/2 ArcTan[a-c,b]
],
{}
]
]


End[]

SetAttributes[
{ListEllipseFit,EllipseProperties,EllipseOrigin,EllipseRadii,EllipseOrientation,QuadraticCurve},
{Protected,ReadProtected}
]

EndPackage[]
