(* ::Package:: *)

(************************************************************************)
(* This file was generated automatically by the Mathematica front end.  *)
(* It contains Initialization cells from a Notebook file, which         *)
(* typically will have the same name as this file except ending in      *)
(* ".nb" instead of ".m".                                               *)
(*                                                                      *)
(* This file is intended to be loaded into the Mathematica kernel using *)
(* the package loading commands Get or Needs.  Doing so is equivalent   *)
(* to using the Evaluate Initialization Cells menu command in the front *)
(* end.                                                                 *)
(*                                                                      *)
(* DO NOT EDIT THIS FILE.  This entire file is regenerated              *)
(* automatically each time the parent Notebook file is saved in the     *)
(* Mathematica front end.  Any changes you make to this file will be    *)
(* overwritten.                                                         *)
(************************************************************************)



(* TimeSamp for Package Version Control *)

Unprotect[TimeStamp];

TimeStamp::usage="TimeStamp[context] should be set to a Date[]-List indicating the version of the corresponding package.";

TimeStamp["MathVisionTools`GConvolution`"] = {2005,4,25,12,30,0};

Protect[TimeStamp];


(*:Name: MathVisionTools`GConvolution` *)

(*:Author: Renske de Boer, Erik Franken, Markus van Almsick*)

(*:Email address: M.v.Almsick@tue.nl*)

(*:Context: MathVisionTools`GConvolution`*)

(*:Package Version: 1.1 *)

(*:Mathematica Version: 5.1 *)

(*:Copyright: Copyright 2005, Technische Universiteit Eindhoven*)

(*:Title: G-Convolution of the 2D Euclidean Group *)

(*:Summary: This package implements the left invariant G-convolution of the Euclidean group in 2D. *)

(*:Keywords: Euclidean group, rigid transformation, symmetry group, convolution, gconvolution *)

(*:Requirements: None *)

(*:Source: None *)

(*:History: Version 1.0 by Markus van Almsick, March 2005 *)

(*:Limitations: *)

(*:Discussion: *)

(*:To do: *)


BeginPackage[
"MathVisionTools`GConvolution`",
"MathVisionTools`ImageTransformation`"
]

Unprotect[
GConjugateKernel,
GListConvolve,GListCorrelate
]


GConjugateKernel::usage = 
"GConjugateKernel[ker, \[CapitalDelta]\[Alpha]] transforms a G-convolution kernel into the corresponding G-correlation kernel and vice versa. \[CapitalDelta]\[Alpha] is the step size of the kernel in \[Alpha]."

GListConvolve::usage="GListConvolve[ker, bndl] forms the G-convolution of the kernel ker with an orientation bundle bndl. Both, kernel and bundle, must be 3-dimensional arrays. The first dimension is orientation, the second and third dimensions are spatial. The kernel in the G-convolution is rotated around its center axis. The default boundary conditions are cyclic in direction and space.\n GListConvolve[{mmin,mmax,\[CapitalDelta]m},{mker,..}, bndl] performs the G-convolution of a steerable kernel with an orientation bundle bndl. The steerable kernel components mker are given in a List starting with the mmin-component and ending with the mmax-component in steps of \[CapitalDelta]m."

GListCorrelate::usage="GListCorrelate[ker, bndl] forms the G-correlation of the kernel ker with an orientation bundle bndl. Both, kernel and bundle, must be 3-dimensional arrays. The first dimension is orientation, the second and third dimensions are spatial. The kernel in the G-convolution is rotated around its center axis. The default boundary conditions are cyclic in direction and space.\n GListCorrelate[{mmin,mmax,\[CapitalDelta]m},{mker,..}, bndl] performs the G-correlation of a steerable kernel with an orientation bundle bndl. The steerable kernel components mker are given in a List starting with the mmin-component and ending with the mmax-component in steps of \[CapitalDelta]m."


Begin["`Private`"]


CyclicTake[a_?ArrayQ,{lower_Integer,upper_Integer}]:= 
Module[
{n=Length[a]},
If[
lower<=upper,
If[
Quotient[lower-1,n]=== Quotient[upper-1,n],
Take[a,{Mod[lower-1,n]+1,Mod[upper-1,n]+1}],
Join[Take[a,-Mod[-lower,n]-1],Sequence@@Table[a,{Quotient[upper-1,n]-Quotient[lower-1,n]-1}],Take[a,Mod[upper-1,n]+1]]
],
{}
]
]


GConjugateKernel[kernel_?ArrayQ,d\[Alpha]_?NumericQ]:=
Module[
{kernelCenter = Ceiling[Dimensions[kernel]/2]},
Map[Reverse,Rotate3DConvoluteKernel[kernel,0,kernelCenter[[1]],kernelCenter[[2]],kernelCenter[[3]],N[-d\[Alpha]]],{0,2}]
]/; ArrayDepth[kernel]===3


GConjugateKernel[{mmin_,mmax_,dm_},mkernels_?ArrayQ,d\[Alpha]_?NumericQ]:=
Module[
{kn = Dimensions[mkernels][[2]]},
k0=Ceiling[kn/2];
Map[Reverse,Table[Exp[I m d\[Alpha] k],{m,mmin,mmax,dm},{k,1-k0,kn-k0}] mkernels,3]
]/; ArrayDepth[mkernels]===4\[And] Length[mkernels]===Length[Range[mmin,mmax,dm]]


Rotate3DCorrelateKernel=
Compile[
{{img,_Real,3},{\[Alpha],_Real},{y0,_Real},{x0,_Real}},
Module[
{kn,yn,xn,s = Sin[\[Alpha]], c = Cos[\[Alpha]]},
{kn,yn,xn} = Dimensions[img];
Transpose[
Table[
NLinear2DImageInterpolation3D[img,c x-s y+x0,s x+c y+y0,xn,yn,kn,0],
{y,1-y0,yn-y0},{x,1-x0,xn-x0}
],
{2,3,1}
]
],
{{NLinear2DImageInterpolation3D[_,_,_,_,_,_,_],_Real,1}}
];


GListCorrelate[kernel_?ArrayQ,bndl_?ArrayQ] :=
Module[
{kernelHeight = Length[kernel],kernelCenter = Ceiling[Dimensions[kernel]/2],
bndlHeight=Length[bndl]},
2\[Pi] / bndlHeight * 
Table[
With[
{rotKernel = Rotate3DCorrelateKernel[kernel,-2\[Pi] \[Alpha]k/bndlHeight,kernelCenter[[2]],kernelCenter[[3]]]},
First[ListCorrelate[rotKernel,CyclicTake[bndl,{\[Alpha]k-kernelCenter[[1]]+2,\[Alpha]k+kernelCenter[[1]]}],
{#,-#}&[Prepend[Rest[kernelCenter],1]],0]]
],
{\[Alpha]k,0,bndlHeight-1}
]
]/; ArrayDepth[kernel] === ArrayDepth[bndl] ===3


Rotate3DConvoluteKernel=
Compile[
{{img,_Real,3},{\[Alpha],_Real},{k0,_Integer},{y0,_Real},{x0,_Real},{d\[Alpha],_Real}},
Module[
{kn,yn,xn},
{kn,yn,xn} = Dimensions[img];
Table[
With[
{s = Sin[\[Alpha]-k d\[Alpha]], c = Cos[\[Alpha]-k d\[Alpha]]},
Table[
NLinearImageInterpolation[img[[k+k0]],c x-s y+x0,s x+c y+y0,xn,yn,0],
{y,1-y0,yn-y0},{x,1-x0,xn-x0}
]
],
{k,1-k0,kn-k0}
]
],
{{NLinearImageInterpolation[_,_,_,_,_,_],_Real}}
];


GListConvolve[kernel_?ArrayQ,bndl_?ArrayQ] :=
Module[
{kernelHeight = Length[kernel],kernelCenter = Ceiling[Dimensions[kernel]/2],
bndlHeight=Length[bndl]},
2\[Pi] / bndlHeight * Table[
With[
{rotKernel = Rotate3DConvoluteKernel[kernel,-2\[Pi] \[Alpha]k/bndlHeight,##,-2 \[Pi]/bndlHeight]&@@kernelCenter},
First[ListConvolve[rotKernel,CyclicTake[bndl,{\[Alpha]k-kernelCenter[[1]]+2,\[Alpha]k+kernelCenter[[1]]}],{-#,#}&[Prepend[Rest[kernelCenter],1]],0]]
],
{\[Alpha]k,0,bndlHeight-1}
]
]/; ArrayDepth[kernel] === ArrayDepth[bndl] ===3


GListCorrelate[{mmin_,mmax_,dm_},mkernels_?ArrayQ,bndl_?ArrayQ] :=
Module[
{kernelHeight = Length[mkernels[[1]]],kernelCenter = Ceiling[Rest[Dimensions[mkernels]]/2],
bndlHeight=Length[bndl]},
2\[Pi] / bndlHeight * Table[
With[
{rotKernel = Table[Exp[-2I \[Pi] m \[Alpha]k/bndlHeight],{m,mmin,mmax,dm}].mkernels},
First[ListCorrelate[rotKernel,CyclicTake[bndl,{\[Alpha]k-kernelCenter[[1]]+2,\[Alpha]k+kernelCenter[[1]]}],
{#,-#}&[Prepend[Rest[kernelCenter],1]],0]]
],
{\[Alpha]k,0,bndlHeight-1}
]
]/; ArrayDepth[mkernels]===4 \[And] ArrayDepth[bndl] ===3\[And] Length[mkernels]===Length[Range[mmin,mmax,dm]]


GListConvolve[{mmin_,mmax_,dm_},mkernels_?ArrayQ,bndl_?ArrayQ] :=
GListCorrelate[{mmin,mmax,dm},GConjugateKernel[{mmin,mmax,dm},mkernels,2\[Pi]/Length[bndl]],bndl]/;  ArrayDepth[mkernels]===4 \[And] ArrayDepth[bndl] ===3\[And] Length[mkernels]===Length[Range[mmin,mmax,dm]]


End[]

SetAttributes[
{GConjugateKernel,
GListConvolve,GListCorrelate},
{Protected, ReadProtected,Locked}
];

EndPackage[]
