(* ::Package:: *)

(************************************************************************)
(* This file was generated automatically by the Mathematica front end.  *)
(* It contains Initialization cells from a Notebook file, which         *)
(* typically will have the same name as this file except ending in      *)
(* ".nb" instead of ".m".                                               *)
(*                                                                      *)
(* This file is intended to be loaded into the Mathematica kernel using *)
(* the package loading commands Get or Needs.  Doing so is equivalent   *)
(* to using the Evaluate Initialization Cells menu command in the front *)
(* end.                                                                 *)
(*                                                                      *)
(* DO NOT EDIT THIS FILE.  This entire file is regenerated              *)
(* automatically each time the parent Notebook file is saved in the     *)
(* Mathematica front end.  Any changes you make to this file will be    *)
(* overwritten.                                                         *)
(************************************************************************)



(* TimeSamp for Package Version Control *)

Unprotect[TimeStamp];

TimeStamp::usage="TimeStamp[context] should be set to a Date[]-List indicating the version of the corresponding package.";

TimeStamp["MathVisionTools`"] = {2007,6,25,11,38,0};

Protect[TimeStamp];


(*:Name: MathVisionTools`ListFourierTransform` *)

(*:Authors: Markus van Almsick *)

(*:Email address: M.v.Almsick@tue.nl *)

(*:Context: MathVisionTools`ListFourierTransform`*)

(*:Package Version: 1.1 *)

(*:Mathematica Version: 5.0 *)

(*:Copyright: Copyright 2006, Technische Universiteit Eindhoven*)

(*:Title: ListFourierTransform *)

(*:Summary: This package implements ListFourierTransform *)

(*:Keywords: Fourier, FFT, FouierTransform, ListFourierTransform *)

(*:Requirements: None *)

(*:Source: None *)

(*:History: Version 1.0 by Markus van Almsick, April 2006 *)

(*:Limitations: *)

(*:Discussion: *)

(*:To do: *)


BeginPackage["MathVisionTools`ListFourierTransform`"]

Unprotect[
ListFourierTransform,ListInverseFourierTransform,ArrayTimes,ListFourierPositions,ListFourierFrequencies,ListFourierFilter
]


ListFourierTransform::usage="ListFourierTransform[list,{xmin,xmax}] finds the Fourier transform of a list of complex numbers that represents the discrete sampling of a function f[x] in an interval [xmin,xmax]. One can generate the n sampling positions \!\(\*SubscriptBox[\"x\", \"r\"]\) with ListFourierPositions[n,{xmin,xmax}]. The result of ListFourierTransform is equivalent to the sampling of the FourierTransform[f,x,\[Omega]]-function at the appropriate frequencies \!\(\*SubscriptBox[\"\[Omega]\", \"s\"]\) given by ListFourierFrequencies[n,{xmin,xmax}]. Higher-dimensional function calls like ListFourierTransform[array, {min1,max1}, {min2,max2},...] are implemented aswell.";

Options[ListFourierTransform] = {ListFourierFilter-> False};

ListInverseFourierTransform::usage="ListInverseFourierTransform[list,{xmin,xmax}] finds the inverse Fourier transform of a list of complex numbers that represents the discrete sampling of a Fourier transformed function \!\(\*OverscriptBox[\"f\", \"^\"]\)[\[Omega]] originally defined in position space in an interval [xmin,xmax]. One can generate the n sampling positions \!\(\*SubscriptBox[\"\[Omega]\", \"s\"]\) with ListFourierFrequencies[n,{xmin,xmax}]. The result of ListInverseFourierTransform is equivalent to the sampling of the InverseFourierTransform[\!\(\*OverscriptBox[\"f\", \"^\"]\),\[Omega],x]-function at the appropriate positions \!\(\*SubscriptBox[\"x\", \"r\"]\) given by ListFourierPositions[n,{xmin,xmax}]. Higher-dimensional function calls like ListInverseFourierTransform[array, {min1,max1}, {min2,max2},...] are implemented aswell.";

Options[ListInverseFourierTransform] = {ListFourierFilter-> False};

ListFourierFilter::usage=
"ListFourierFilter is an option of ListFourierTransform and ListInverseFourierTransform. If set to True the discrete data entering the Fourier transformation is multiplied with a Gaussian kernel with a standard deviation of \[Sigma] equal 1/6th of the Fourier domain interval. This filter dampens sync-effects, but also blurs the resulting data by \[Pi]/3 grid units (or pixels). For data arrays ListFourierFilter can take a List of Boolean values, one for each dimension."

ArrayTimes::usage="ArrayTimes[{list1, list2, ...}, array] threads Times over list1 and the first dimension of array, then threads Times over list2 and the second dimension of array, and so on. It is a fast alternative for Outer[Times,list1, list2, ...] * array.";

ListFourierPositions::usage="ListFourierPositions[n,{xmin,xmax}] generates all positions that ListFourierTransform[list,{xmin,xmax}] takes into account. The positions are \!\(\*SubscriptBox[\"x\", 
RowBox[{\"r\", \" \"}]]\)= r*\[CapitalDelta]x+xmin, with \[CapitalDelta]x = (xmax-xmin)/n and r = 1,2,...,n. Note, that ListFourierTransform assumes cylic boundary condition f[\!\(\*SubscriptBox[\"x\", \"0\"]\)] = f[\!\(\*SubscriptBox[\"x\", \"n\"]\)].";

ListFourierFrequencies::usage="ListFourierFrequencies[n,{xmin,xmax}] generates all frequencies \!\(\*SubscriptBox[\"\[Omega]\", \"s\"]\), for which ListFourierTransform[list,{xmin,xmax}] generates the Fourier coefficients \!\(\*OverscriptBox[\"f\", \"^\"]\)[\!\(\*SubscriptBox[\"\[Omega]\", \"s\"]\)]. The frequencies are \!\(\*SubscriptBox[\"\[Omega]\", \"s\"]\)= 2\[Pi] (s-Ceiling[\!\(\*FractionBox[\"n\", \"2\"]\)])/(xmax-xmin), with s = 1,2,...,n.";


Begin["`Private`"]


ListFourierPositions[n_,{xmin_,xmax_}]:= (xmax-xmin)/n Range[n]+xmin

ListFourierPositions[n_List,domains:{_,_}..]:= -Apply[Subtract,{domains},{1}]/n Range[n]+Map[First,{domains}]


ListFourierFrequencies[n_,{xmin_,xmax_}]:= (2\[Pi])/(xmax-xmin) Range[1-Ceiling[n/2],n-Ceiling[n/2]]

ListFourierFrequencies[n_List,domains:{_,_}..]:= (2\[Pi])/-Apply[Subtract,{domains},{1}] Range[1-Ceiling[n/2],n-Ceiling[n/2]]


nDimensionalFourier[f_List,d_Integer]:= 
Transpose[
Map[
Fourier,
Transpose[
f,
RotateRight[#,d]
],
{Length[#]-d}
],
RotateLeft[#,d]
]&[Range[ArrayDepth[f]]]


nDimensionalInverseFourier[f_List,d_Integer]:= 
Transpose[
Map[
InverseFourier,
Transpose[
f,
RotateRight[#,d]
],
{Length[#]-d}
],
RotateLeft[#,d]
]&[Range[ArrayDepth[f]]];


ArrayTimes[1|{1..},tensor_]= tensor;

ArrayTimes[{vecs__},tensor_]:=
Module[
{transpositions=RotateRight[Range[ArrayDepth[tensor]]]},
Transpose[
Fold[Transpose[#2 #1,transpositions]&,tensor,{vecs}],
RotateRight[transpositions,ArrayDepth[tensor]-Length[{vecs}]-1]
]
]/;MatchQ[Map[Length,{vecs}],Thread[Take[Dimensions[tensor],Length[{vecs}]]|0]]


ListFourierTransform[f_List,{xmin_,xmax_}, opts___Rule] :=
Module[
{\[CapitalDelta]x ,n = Length[f],r = ArrayDepth[f],a,b, filter=1},
{a,b}= FourierParameters/.{opts}/.Options[FourierTransform];
\[CapitalDelta]x = (xmax-xmin)/n;
If[
MatchQ[ListFourierFilter/.{opts}/.Options[ListFourierTransform],True|{True,___}],
filter = N[Exp[-((18 ListFourierPositions[n,{xmin,xmax}]^2)/Abs[xmax-xmin]^2)]]
];
Sqrt[(Abs[b]n)/(2\[Pi])^(1-a)] \[CapitalDelta]x Chop[Exp[N[2\[Pi] I (xmin+\[CapitalDelta]x)/(n \[CapitalDelta]x)] Range[1-Ceiling[n/2],n-Ceiling[n/2]]],$MachineEpsilon]*
RotateLeft[nDimensionalFourier[filter f,1],1-Ceiling[n/2]]
];

ListFourierTransform[f_?ArrayQ,domains:{_,_}.., opts___Rule] :=
Module[
{\[CapitalDelta] ,n= Take[Dimensions[f],Length[{domains}]],a,b, filter,filterBooleans},
{a,b}= FourierParameters/.{opts}/.Options[FourierTransform];
\[CapitalDelta] = -Apply[Subtract,{domains},{1}]/n;
filterBooleans=PadRight[#,Length[{domains}],#]&[If[Head[#]===List,#,{#}]&[ListFourierFilter/.{opts}/.Options[ListFourierTransform]]];
filter=MapThread[If[#1,#2,1,1]&,{filterBooleans,N[Exp[-((18 ListFourierPositions[n,domains]^2)/Abs[Apply[Subtract,{domains},{1}]]^2)]]}];
ArrayTimes[
Sqrt[(Abs[b]n)/(2\[Pi])^(1-a)] \[CapitalDelta] Chop[Exp[N[2\[Pi] I (Map[First,{domains}]+\[CapitalDelta])/(n \[CapitalDelta])]Range[1-Ceiling[n/2],n-Ceiling[n/2]]],$MachineEpsilon],
RotateLeft[nDimensionalFourier[ArrayTimes[filter,f],Length[{domains}]], 1-Ceiling[n/2]]
]
]/; ArrayDepth[f]>=Length[{domains}]


ListInverseFourierTransform[f_List,{xmin_,xmax_},opts___Rule] :=
Module[
{\[CapitalDelta]x ,n = Length[f],a,b, filter=1},
{a,b}= FourierParameters/.{opts}/.Options[InverseFourierTransform];
\[CapitalDelta]x = (xmax-xmin)/n;
If[
MatchQ[ListFourierFilter/.{opts}/.Options[ListInverseFourierTransform],True|{True,___}],
filter = N[Exp[-((9 Abs[xmax-xmin]^2 ListFourierFrequencies[n,{xmin,xmax}]^2)/(2 \[Pi]^2 n^2))]]
];
nDimensionalInverseFourier[RotateRight[
Sqrt[(2\[Pi])^(1-a)/(Abs[b]n)] 1/\[CapitalDelta]x Chop[filter Exp[N[-2\[Pi] I (xmin+\[CapitalDelta]x)/(n \[CapitalDelta]x)] Range[1-Ceiling[n/2],n-Ceiling[n/2]]],$MachineEpsilon] * f ,
1-Ceiling[n/2]
],
1
]
]

ListInverseFourierTransform[f_?ArrayQ,domains:{_,_}.., opts___Rule] :=
Module[
{\[CapitalDelta] ,n= Take[Dimensions[f],Length[{domains}]],a,b,filter,filterBooleans},
{a,b}= FourierParameters/.{opts}/.Options[InverseFourierTransform];
\[CapitalDelta] = -Apply[Subtract,{domains},{1}]/n;
filterBooleans=PadRight[#,Length[{domains}],#]&[If[Head[#]===List,#,{#}]&[ListFourierFilter/.{opts}/.Options[ListFourierTransform]]];
filter=MapThread[If[#1,#2,1,1]&,{filterBooleans,N[Exp[-((9 Abs[Apply[Subtract,{domains},{1}]]^2 ListFourierFrequencies[n,domains]^2)/(2 \[Pi]^2 n^2))]]}];
nDimensionalInverseFourier[
RotateRight[
ArrayTimes[
Sqrt[(2\[Pi])^(1-a)/(Abs[b]n)] 1/\[CapitalDelta] Chop[filter Exp[N[-2\[Pi] I (Map[First,{domains}]+\[CapitalDelta])/(n \[CapitalDelta])]Range[1-Ceiling[n/2],n-Ceiling[n/2]]],$MachineEpsilon],
f
],
1-Ceiling[n/2]
],
Length[{domains}]
]
]/; ArrayDepth[f]>=Length[{domains}]


End[]

SetAttributes[
{ListFourierTransform,ListInverseFourierTransform,ArrayTimes,ListFourierPositions,ListFourierFrequencies},
{Protected, ReadProtected}
];

EndPackage[]
