(* ::Package:: *)

(************************************************************************)
(* This file was generated automatically by the Mathematica front end.  *)
(* It contains Initialization cells from a Notebook file, which         *)
(* typically will have the same name as this file except ending in      *)
(* ".nb" instead of ".m".                                               *)
(*                                                                      *)
(* This file is intended to be loaded into the Mathematica kernel using *)
(* the package loading commands Get or Needs.  Doing so is equivalent   *)
(* to using the Evaluate Initialization Cells menu command in the front *)
(* end.                                                                 *)
(*                                                                      *)
(* DO NOT EDIT THIS FILE.  This entire file is regenerated              *)
(* automatically each time the parent Notebook file is saved in the     *)
(* Mathematica front end.  Any changes you make to this file will be    *)
(* overwritten.                                                         *)
(************************************************************************)



(* TimeSamp for Package Version Control *)

Unprotect[TimeStamp];

TimeStamp::usage="TimeStamp[context] should be set to a Date[]-List indicating the version of the corresponding package.";

TimeStamp["MathVisionTools`OrientationBundle`"] = {2009,10,12,23,0,0};

Protect[TimeStamp];


(*:Name: MathVisionTools`OrientationBundle` *)

(*:Author: Markus van Almsick*)

(*:Email address: M.v.Almsick@tue.nl*)

(*:Context: MathVisionTools`OrientationBundle`*)

(*:Package Version: 2.0 *)

(*:Mathematica Version: 6.0 *)

(*:Copyright: Copyright 2009, Technische Universiteit Eindhoven*)

(*:Title: Histogram, Entropy *)

(*:Summary: This package implements the Orientation Bundle transformation according to Kalitzin *)

(*:Keywords: Orientation, Transformation, Wavelet *)

(*:Requirements: None *)

(*:Source: None *)

(*:History: Version 1.0 by Markus van Almsick, June 2004
		  Version 1.1 by Markus van Almsick, April 2005,
							\[Alpha]=0 now corresponds to x-Direction 
		Version 1.3 by Markus van Almsick, August 2008 *)

(*:Limitations: *)

(*:Discussion: *)

(*:To do: *)


BeginPackage["MathVisionTools`OrientationBundle`"]

Unprotect[
OrientationTransform,
OrientationBundleTransform,
InverseOrientationBundleTransform,
DirectionalFourierFilter,
FourierOrientationBundleTransform,
InverseFourierOrientationBundleTransform
]


OrientationTransform::usage="OrientationTransform[img,filter,t] generates an orientation bundle of image img with filter of scale t. The filter must be given by a n\[Times]m table of Hankel-coefficients. The number of m-Hankel-coefficients determines the number of resulting orientations."

OrientationBundleTransform::usage="OrientationBundleTransform[img,t,\[Xi],n] generates an orientation bundle of image img with a \[Xi]-Kalitzin kernel of scale t with n orientations. \[Xi] is the ratio between angular and radial units."

InverseOrientationBundleTransform::usage="InverseOrientationBundleTransform[bndl,t,\[Xi]] reconstructs an image from an orientation bundle bndl with a \[Xi]-Kalitzin kernel of scale t and a angular versus radial ratio \[Xi]."

DirectionalFourierFilter::usage="DirectionalFourierFilter is an option of the OrientationBundleTransform function. One can assign a List of weighting coefficients {w0,w1,w2,...} to DirectionalFourierFilter. In this way, one can reduce or emphasize m-components in the construction of the orientation bundle. The default is {1,1,1,....}."

Options[OrientationBundleTransform]={DirectionalFourierFilter -> {1}};

FourierOrientationBundleTransform::usage="FourierOrientationBundleTransform[img,t,\[Xi],n] generates a Fourier orientation bundle of image img with a \[Xi]-Kalitzin kernel of scale t with n orientations. \[Xi] is the ratio between angular and radial units."

InverseFourierOrientationBundleTransform::usage="InverseFourierOrientationBundleTransform[bndl,t,\[Xi]] reconstructs an image from a Fourier orientation bundle bndl with a \[Xi]-Kalitzin kernel of scale t and a angular versus radial ratio \[Xi]."


Begin["`Private`"]


(* Utility Functions *)

SetAttributes[FourierRange, Listable];
FourierRange[dim_Integer] := (2\[Pi])/dim Join[Range[0,Quotient[dim,2]],Range[1+Quotient[-dim,2],-1]];

SetAttributes[ComplexPhase, Listable];
ComplexPhase[0|0.] = 0;
ComplexPhase[z_] = Sign[z];


OrientationTransform[img_?MatrixQ,filter_?(ArrayQ[#,2]&),t_?NumericQ,opts___Rule] :=
Module[
{mmax,nmax,mmin,mlen,coeff,\[Omega]$sqr,polys},
{mlen,nmax}=Dimensions[filter]-{0,1};
mmax=Quotient[mlen,2];
mmin=Quotient[mlen-1,2];
polys=
NestList[
Accumulate,
Rest[Fold[Append[#,Expand[{1- #2,2 #2-1-\[Omega]$sqr}.Take[#1,-2]/#2]]&, {0,1},Range[nmax]]],
mmax
]/Transpose[NestList[-#&,1,nmax]Partition[Sqrt[FoldList[Times,1,Range[nmax+mmax]]],mmax+1,1]/Sqrt[FoldList[Times,1,Range[nmax]]]];
coeff=CoefficientList[Total[RotateLeft[N[filter],mmin]*Join[polys,Take[polys,{mmin+1,2,-1}]],{2}],\[Omega]$sqr];
If[Last[Dimensions[coeff]]===1,
InternalOrientationBundleM[Normal[img],coeff[[All,1]],t,mmin,mmax],
InternalOrientationBundleNM[Normal[img],coeff,t,nmax,mmin,mmax]
]
]


InternalOrientationBundleM =  
Compile[
{{img,_Real,2},{coeff,_Complex,1},{t,_Real},{mmin,_Real},{mmax,_Real}},
Module[
{\[Omega]x,\[Omega]y,I\[Omega],I\[Omega]c,\[Omega]exp},
\[Omega]x = Sqrt[t] FourierRange[Dimensions[img][[2]]];
\[Omega]y = Sqrt[t] FourierRange[Dimensions[img][[1]]];
I\[Omega]= Outer[Plus,-I \[Omega]y,-\[Omega]x];
I\[Omega]c=Outer[Plus,-I \[Omega]y,\[Omega]x];
\[Omega]exp=Outer[Times,Exp[-\[Omega]y^2/2],Exp[-\[Omega]x^2/2]];
InverseFourier[Join[NestList[(I\[Omega]*#)&,#,mmax],Reverse[NestList[(I\[Omega]c*#)&,I\[Omega]c*#,mmin-1]]]&[Fourier[img]\[Omega]exp]* coeff]
],
{{FourierRange[_],_Real,1},{Fourier[_],_Complex,2},{InverseFourier[_],_Complex,3}}
];


InternalOrientationBundleNM =  
Compile[
{{img,_Real,2},{coeff,_Complex,2},{t,_Real},{nmax,_Real},{mmin,_Real},{mmax,_Real}},
Module[
{\[Omega]x,\[Omega]y,I\[Omega],I\[Omega]c,\[Omega]sqr,\[Omega]exp},
\[Omega]x = Sqrt[t] FourierRange[Dimensions[img][[2]]];
\[Omega]y = Sqrt[t] FourierRange[Dimensions[img][[1]]];
I\[Omega] = Outer[Plus,\[Omega]y,I \[Omega]x];
I\[Omega]c = Outer[Plus,-\[Omega]y, I \[Omega]x];
\[Omega]sqr=Outer[Plus,\[Omega]y^2,\[Omega]x^2];
\[Omega]exp=Outer[Times,Exp[-\[Omega]y^2/2],Exp[-\[Omega]x^2/2]];
InverseFourier[Join[NestList[(I\[Omega]*#)&,#,mmax],Reverse[NestList[(I\[Omega]c*#)&,I\[Omega]c*#,mmin-1]]]&[Fourier[img]]* (coeff.NestList[(\[Omega]sqr*#)&,\[Omega]exp,nmax])]
],
{{FourierRange[_],_Real,1},{Fourier[_],_Complex,2},{InverseFourier[_],_Complex,3}}
];


OrientationTransform[img_?MatrixQ,filter_?(ArrayQ[#,3]&),t_?NumericQ,opts___Rule] :=
Module[
{mmax,nmax,mmin,mlen,coeff,\[Omega]$sqr,polys},
{mlen,nmax}=Rest[Dimensions[filter]]-{0,1};
mmax=Quotient[mlen,2];
mmin=Quotient[mlen-1,2];
polys=
NestList[
Accumulate,
Rest[Fold[Append[#,Expand[{1- #2,2 #2-1-\[Omega]$sqr}.Take[#1,-2]/#2]]&, {0,1},Range[nmax]]],
mmax
]/Transpose[NestList[-#&,1,nmax]Partition[Sqrt[FoldList[Times,1,Range[nmax+mmax]]],mmax+1,1]/Sqrt[FoldList[Times,1,Range[nmax]]]];
coeff=Map[PadRight[CoefficientList[Total[RotateLeft[#,mmin]*Join[polys,Take[polys,{mmin+1,2,-1}]],{2}],\[Omega]$sqr],{mmin+mmax+1,nmax+1}]&,N[filter]];
If[Last[Dimensions[coeff]]===1,
ListInternalOrientationBundleM[Normal[img],coeff[[All,All,1]],t,mmin,mmax],
ListInternalOrientationBundleNM[Normal[img],coeff,t,nmax,mmin,mmax]
]
]


ListInternalOrientationBundleM =  
Compile[
{{img,_Real,2},{coeff,_Complex,2},{t,_Real},{mmin,_Real},{mmax,_Real}},
Module[
{\[Omega]x,\[Omega]y,I\[Omega],I\[Omega]c,\[Omega]exp},
\[Omega]x = Sqrt[t] FourierRange[Dimensions[img][[2]]];
\[Omega]y = Sqrt[t] FourierRange[Dimensions[img][[1]]];
I\[Omega]= Outer[Plus,-I \[Omega]y,-\[Omega]x];
I\[Omega]c=Outer[Plus,-I \[Omega]y,\[Omega]x];
\[Omega]exp=Outer[Times,Exp[-\[Omega]y^2/2],Exp[-\[Omega]x^2/2]];
Map[InverseFourier[Join[NestList[(I\[Omega]*#)&,#,mmax],Reverse[NestList[(I\[Omega]c*#)&,I\[Omega]c*#,mmin-1]]]&[Fourier[img]\[Omega]exp]* #]&,coeff]
],
{{FourierRange[_],_Real,1},{Fourier[_],_Complex,2},{InverseFourier[_],_Complex,3}}
];


ListInternalOrientationBundleNM =  
Compile[
{{img,_Real,2},{coeff,_Complex,3},{t,_Real},{nmax,_Real},{mmin,_Real},{mmax,_Real}},
Module[
{\[Omega]x,\[Omega]y,I\[Omega],I\[Omega]c,\[Omega]sqr,\[Omega]exp,Q1,Q2},
\[Omega]x = Sqrt[t] FourierRange[Dimensions[img][[2]]];
\[Omega]y = Sqrt[t] FourierRange[Dimensions[img][[1]]];
I\[Omega] = Outer[Plus,\[Omega]y,I \[Omega]x];
I\[Omega]c = Outer[Plus,-\[Omega]y, I \[Omega]x];
\[Omega]sqr=Outer[Plus,\[Omega]y^2,\[Omega]x^2];
\[Omega]exp=Outer[Times,Exp[-\[Omega]y^2/2],Exp[-\[Omega]x^2/2]];
Q1=Join[NestList[(I\[Omega]*#)&,#,mmax],Reverse[NestList[(I\[Omega]c*#)&,I\[Omega]c*#,mmin-1]]]&[Fourier[img]];
Q2=NestList[(\[Omega]sqr*#)&,\[Omega]exp,nmax];
Map[InverseFourier[Q1*(#.Q2)]&,coeff]
],
{{FourierRange[_],_Real,1},{Fourier[_],_Complex,2},{InverseFourier[_],_Complex,3}}
];


(* OrientationBundle *)

OrientationBundleTransform[img_?(MatrixQ[#,NumericQ]&),t_?NumericQ,\[Xi]_:1,n_Integer?Positive,opts___Rule] := 
InternalOrientationBundle[Normal[img],t,\[Xi],n,
Re[PadRight[DirectionalFourierFilter /. {opts} /. Options[OrientationBundleTransform],n,1]]]/;\[Xi]>0;

InternalOrientationBundle = Compile[
{{img,_Real,2},{t,_Real},{\[Xi],_Real},{n,_Integer},{w,_Real,1}},
Module[
{\[Omega]x,\[Omega]y,\[Omega], m0Bundle},
\[Omega]x =  FourierRange[Dimensions[img][[2]]];
\[Omega]y =  FourierRange[Dimensions[img][[1]]];
\[Omega] = Outer[Plus,-\[Omega]y,I \[Omega]x];
If[\[Xi]>1,\[Omega] = \[Omega] Abs[\[Omega]]^(\[Xi]-1)];
If[1>\[Xi]>0,\[Omega] = ComplexPhase[\[Omega]] Abs[\[Omega]]^\[Xi]];
m0Bundle=E^(-t Abs[\[Omega]]^2/2);
InverseFourier[w *FoldList[(Sqrt[t/#2]  \[Omega] * #1)&,Fourier[img]* m0Bundle,Range[ n-1]]]
],
{{ComplexPhase[_],_Complex,2},{Abs[_],_Real,2},{FourierRange[_],_Real,1},{Fourier[_],_Complex,2},{InverseFourier[_],_Complex,3}}
];


(* FourierOrientationBundle *)

FourierOrientationBundleTransform[img_?(MatrixQ[#,NumericQ]&),t_?NumericQ,\[Xi]_:1,n_Integer?Positive] := 
InternalFourierOrientationBundle[Normal[img],t,\[Xi],n]/;\[Xi]>0;

InternalFourierOrientationBundle = Compile[
{{img,_Real,2},{t,_Real},{\[Xi],_Real},{n,_Integer}},
Module[
{\[Omega]x,\[Omega]y,\[Omega], m0Bundle},
\[Omega]x =  FourierRange[Dimensions[img][[2]]];
\[Omega]y =  FourierRange[Dimensions[img][[1]]];
\[Omega] = Outer[Plus,-\[Omega]y,I \[Omega]x];
If[\[Xi]>1,\[Omega] = \[Omega] Abs[\[Omega]]^(\[Xi]-1)];
If[1>\[Xi]>0,\[Omega] = ComplexPhase[\[Omega]] Abs[\[Omega]]^\[Xi]];
m0Bundle=E^(-t Abs[\[Omega]]^2/2);
Map[InverseFourier,FoldList[(Sqrt[t/#2]  \[Omega] * #1)&,Fourier[img]* m0Bundle,Range[ n-1]]]
],
{{ComplexPhase[_],_Complex,2},{Abs[_],_Real,2},{FourierRange[_],_Real,1},{Fourier[_],_Complex,2},{InverseFourier[_],_Complex,2}}
];


(* InverseOrientationBundle *)

InverseOrientationBundleTransform[bundle_?(ArrayQ[#,3,NumericQ]&),t_?NumericQ,\[Xi]_:1] := InternalInverseOrientationBundle[bundle,t,\[Xi]]/;\[Xi]>0;

InternalInverseOrientationBundle = 
Compile[{{bundle,_Complex,3},{t,_Real},{\[Xi],_Real}},
Module[
{n=Length[bundle], \[Omega]x, \[Omega]y,\[Omega]c,m0Bundle},
\[Omega]x =  FourierRange[Dimensions[bundle][[3]]];
\[Omega]y =  FourierRange[Dimensions[bundle][[2]]];
\[Omega]c = Outer[Plus, -\[Omega]y,-I \[Omega]x];
If[\[Xi]>1,\[Omega]c = \[Omega]c Abs[\[Omega]c]^(\[Xi]-1)];
If[1>\[Xi]>0,\[Omega]c = ComplexPhase[\[Omega]c] Abs[\[Omega]c]^\[Xi]];
m0Bundle=E^(-t Abs[\[Omega]c]^2/2);
Chop[InverseFourier[
Apply[Plus,FoldList[(Sqrt[t/#2] \[Omega]c * #1)&,m0Bundle,Range[n-1]] * Fourier[bundle]]
]]
],
{{ComplexPhase[_],_Complex,2},{Abs[_],_Real,2},{FourierRange[_],_Real,1},{FoldList[_,_,_],_Complex,3},{Fourier[_],_Complex,3},{InverseFourier[_],_Complex,2}}
];


(* InverseFourierOrientationBundle *)

InverseFourierOrientationBundle[bundle_?(ArrayQ[#,3,NumericQ]&),t_?NumericQ,\[Xi]_:1] := InternalInverseOrientationBundle[bundle,t,\[Xi]]/;\[Xi]>0;

InverseFourierOrientationBundle = 
Compile[{{bundle,_Complex,3},{t,_Real},{\[Xi],_Real}},
Module[
{n=Length[bundle], \[Omega]x, \[Omega]y,\[Omega]c,m0Bundle},
\[Omega]x =  FourierRange[Dimensions[bundle][[3]]];
\[Omega]y =  FourierRange[Dimensions[bundle][[2]]];
\[Omega]c = Outer[Plus, -\[Omega]y,-I \[Omega]x];
If[\[Xi]>1,\[Omega]c = \[Omega]c Abs[\[Omega]c]^(\[Xi]-1)];
If[1>\[Xi]>0,\[Omega]c = ComplexPhase[\[Omega]c] Abs[\[Omega]c]^\[Xi]];
m0Bundle=E^(-t Abs[\[Omega]c]^2/2);
Chop[InverseFourier[
Apply[Plus,FoldList[(Sqrt[t/#2] \[Omega]c * #1)&,m0Bundle,Range[n-1]] * Map[Fourier,bundle]]
]]
],
{{ComplexPhase[_],_Complex,2},{Abs[_],_Real,2},{FourierRange[_],_Real,1},{FoldList[_,_,_],_Complex,3},{Fourier[_],_Complex,2},{InverseFourier[_],_Complex,2}}
];


End[]

SetAttributes[
{OrientationTransform,
OrientationBundleTransform,
InverseOrientationBundleTransform,
FourierOrientationBundleTransform,
InverseFourierOrientationBundleTransform,
DirectionalFourierFilter},
{Protected, ReadProtected}
];

EndPackage[]
