(* ::Package:: *)

(************************************************************************)
(* This file was generated automatically by the Mathematica front end.  *)
(* It contains Initialization cells from a Notebook file, which         *)
(* typically will have the same name as this file except ending in      *)
(* ".nb" instead of ".m".                                               *)
(*                                                                      *)
(* This file is intended to be loaded into the Mathematica kernel using *)
(* the package loading commands Get or Needs.  Doing so is equivalent   *)
(* to using the Evaluate Initialization Cells menu command in the front *)
(* end.                                                                 *)
(*                                                                      *)
(* DO NOT EDIT THIS FILE.  This entire file is regenerated              *)
(* automatically each time the parent Notebook file is saved in the     *)
(* Mathematica front end.  Any changes you make to this file will be    *)
(* overwritten.                                                         *)
(************************************************************************)



(* TimeSamp for Package Version Control *)

Unprotect[TimeStamp];

TimeStamp::usage="TimeStamp[context] should be set to a Date[]-List indicating the version of the corresponding package.";

TimeStamp["MathVisionTools`RegionGrowing`"] = {2008,8,13,11,43,0};

Protect[TimeStamp];


(*:Name: MathVisionTools`RegionGrowing` *)

(*:Authors: Edwin Bennink, Markus van Almsick *)

(*:Email address: H.E.Bennink@student.tue.nl, M.v.Almsick@tue.nl *)

(*:Context: MathVisionTools`RegionGrowing`*)

(*:Package Version: 1.2 *)

(*:Mathematica Version: 5.0 *)

(*:Copyright: Copyright 2005, Technische Universiteit Eindhoven*)

(*:Title: RegionGrowing *)

(*:Summary: This package implements Region Growing *)

(*:Keywords: Region, Growing, Segmentation *)

(*:Requirements: None *)

(*:Source: None *)

(*:History: Version 1.0 by Edwin Bennink, February 2005
         Version 1.1 by Markus van Almsick, March 2005
         Version 1.2 by Markus van Almsick, August 2008 *)

(*:Limitations: *)

(*:Discussion: *)

(*:To do: try to speed up the procedure with Sow and Reap *)


BeginPackage["MathVisionTools`RegionGrowing`"]

Unprotect[
RegionGrowing,AdjacencyNumbers
]


RegionGrowing::usage="RegionGrowing[{img1, img2, ... }, pos, adjacency, costfunc] grows a binary region by sequentially adding adjacent pixels or voxels that match the criterium defined by the boolean cost function costfunc. The cost function must accept two arguments,the first being the List of img-values at the position of a region seed,the second being the List of img values at the position of a neighbor, for which the membership to the region is under investigation. The costfunction must be a boolean function that renders True or False. The seed point of the region is given by pos. adjacency specifies the neigborhod of points that is considered in the regiong rowing process. adjacency=1 accounts for immediate neighbors. adjacency=2 accounts for immediate and diagonal neighbors in a plane. adjacency=3 adds neighbors along the diagonals in a volumen, and so on. The result is a binary image, in which the region and background have the values 1 and 0 respectively. \nRegionGrowing[{img1, img2, ... }, {pos1, pos2, ... }, adjacency, costfunc] applies region growing to multiple seed points.";

AdjacencyNumbers::usage="AdjacencyNumbers[n] render the possible adjacency numbers for an array of rank or depth n. The adjacency numbers are the number of immediate and diagonal neighbors in a plane, volume, etc. into account.";

Options[RegionGrowing]={MaxIterations->\[Infinity]};


Begin["`Private`"]


AdjacencyNumbers[n_Integer] := Rest[FoldList[Plus,0,Table[Binomial[n,k] 2^k,{k,1,n}]]]


RegionGrowing[data_?ArrayQ,seed:{__Integer},adjR2_Integer,costFunction_,(opts___)?OptionQ]:=
RegionGrowing[data,{seed},adjR2,costFunction,opts] /; ArrayDepth[data] === Last[Dimensions[seed]]+1

RegionGrowing[data_?ArrayQ,seeds:{{__Integer}..},adjR2_Integer,costFunction_,(opts___)?OptionQ]:=
Module[
{region,neighbor,neighborhood,candidates,seedStorage = seeds,
dims = Rest[Dimensions[data]],rank=ArrayDepth[data]-1,
maxIterator=MaxIterations/.{opts}/.Options[RegionGrowing],
iterator=1, source},
neighborhood=Select[Flatten[Outer[List,Sequence@@Table[{-1,0,1},{rank}]],rank-1],(1<= Norm[#]<=Sqrt[adjR2])&];
region=PadRight[PadLeft[ReplacePart[Array[0&,dims],1,seedStorage],dims+1,1],dims+2,1];
While[iterator<maxIterator \[And] seedStorage!={},
iterator++; 
source = First[seedStorage];
candidates = Pick[#,Extract[region,#+1],0]&[Map[(source+#)&,neighborhood]];
Scan[
(region=ReplacePart[region,1,#+1];AppendTo[seedStorage,#])&,Pick[candidates,Map[costFunction[Map[Extract[#,source]&,data],#]&,Transpose[Map[Extract[#,candidates]&,data]]]]
];
seedStorage = Rest[seedStorage]
];
Take[region,Sequence@@Transpose[{Table[2,{rank}],dims + 1}]]
]/;ArrayDepth[data] === Last[Dimensions[seeds]]+1


End[]

SetAttributes[
{RegionGrowing,AdjacencyNumbers},
{Protected, ReadProtected}
];

EndPackage[]
