(* Mathematica package *)

(*******************************************************)
(*****************************************Begin Package*)
BeginPackage["OrientationScores`OtherTools`"]
Unprotect["OrientationScores`OtherTools`*"]




OrientationMap::usage = "OrientationMap[os] has output {oMap, cMap}, where oMap 
	(orientation) gives an overview of the most dominant orientation per pixel, 
	and cMap (confidence) the absolute value of corresponding pixel and 
	orientation in the orientation score."

OrientationPlot::usage = "OrientationPlot[os] plots the oMap and cMap (see 
	OrientationMap) by colorcoding the orientations and specifying confidence 
	with brightness. OrientationPlot[oMap,cMap,No] does the same, however now 
	you have to specify the number of orientations."
	

MPsi::usage = "MPsi[waveletStack] calculates M_\[Psi] of the wavelet stack.
This M_\[Psi] demonstrates the coverate of the wavelets in the Fourier domain."

OSStackMovieFrames



(*******************************************************)
(*****************************************Begin Private*)
Begin["Private`"]




OrientationMap[imOS_]:=
Module[{},
	{
		Map[Position[#,Max[#]][[1,1]]&,Transpose[Abs@imOS,{3,1,2}],{2}]
	,
		Map[Max,Transpose[Abs@imOS,{3,1,2}],{2}]
	}
]








Options[OrientationPlot]=Options[ArrayPlot];
SetOptions[OrientationPlot,Frame->None,PlotRangePadding->0];
AppendTo[Options[OrientationPlot],"OrientationLegend"->True];

OrientationPlot[oMap_,cMap_,NoIn_,OptionsPattern[]]:=
Module[{No,oPlot},
	If[NoIn==-1,No=Max[oMap],No=NoIn];
	oPlot=ArrayPlot[Replace[Transpose[{oMap,cMap/Max[cMap]},{3,1,2}],{x_,y_}->Hue[(x-1)/No,1,y],2],(#-> OptionValue[#])&/@Options[OrientationPlot][[1;;-2,1]]];
	Return[
		If[OptionValue["OrientationLegend"],
			Column@{oPlot,OrientationPlotColorLegend[No,OptionValue[ImageSize]]}
		,
		oPlot
		]
	]
]
OrientationPlot[os_,OptionsPattern[]]:=
Module[{oMap,cMap,oPlot},
	{oMap,cMap}=OrientationMap[os];
	oPlot=ArrayPlot[Replace[Transpose[{oMap,cMap/Max[cMap]},{3,1,2}],{x_,y_}->Hue[(x-1)/Length[os],1,y],2],(#-> OptionValue[#])&/@Options[OrientationPlot][[1;;-2,1]]];
	Return[
		If[OptionValue["OrientationLegend"],
			Column@{oPlot,OrientationPlotColorLegend[Length[os],OptionValue[ImageSize]]}
			,
			oPlot
		]
	]
]

OrientationPlotColorLegend[No_,size_:Automatic]:=
Show[
	Table[
		Graphics[{Hue[ \[Theta]/\[Pi],1,.8 ],Thickness[0.01],Line[{{2*\[Theta]/(\[Pi]/No),0},{2*\[Theta]/(\[Pi]/No),0}}+{-{Cos[\[Theta]-\[Pi]/2],Sin[\[Theta]-\[Pi]/2]},{Cos[\[Theta]-\[Pi]/2],Sin[\[Theta]-\[Pi]/2]}}]}]
		,{\[Theta],0,\[Pi]-\[Pi]/No,\[Pi]/No}
	]
	,ImageSize->size
]


MPsi[waveletStack_]:=RotateRight[Total[Abs[Fourier /@ waveletStack]^1],Floor[Dimensions[waveletStack][[2;;3]]/2]]





OSStackMovieFrames[os_, periodicity_, imageSize_: 800, d_: 10, 
  stackSampleDistance_: 1, dxy_: 1] := 
 Module[{stackResponses, xmin, xmax, ymin, ymax, zmin, zmax, axes, 
   subimsize, preComputed},
  (*the stack:*)
  stackResponses = Table[
    ListPlot3D[
     Table[(i - 1)*d, {2}, {2}], DataRange -> {{0, 1}, {0, 1}}, 
     Mesh -> None, TextureCoordinateScaling -> False, 
     PlotStyle -> 
      Texture[ImageAdjust@
        Image[Re@os[[i, 1 ;; -1 ;; dxy, 1 ;; -1 ;; dxy]]]],
     Axes -> False, Boxed -> False, PlotRange -> {0, d*Length[os]}, 
     BoxRatios -> {1, 1, 1}, ImageSize -> 400, Lighting -> "Neutral", 
     ViewPoint -> {-2, -4, 
       1.6}(*you can specify viewpoint or do that manually later*)],
    {i, 1, Length[os], 
     stackSampleDistance}(*here you specify which planes to show*)];
  {xmin, xmax} = {0, 1}; {ymin, ymax} = {0, 1}; {zmin, zmax} = {0, 
    Length[os]*d};
  (*axes:*)
  axes =
   Show[Graphics3D[{Thickness[0.0075], 
      Line[{{xmin, 0, 0}, {xmax, 0, 0}}], 
      Line[{{0, ymin, 0}, {0, ymax, 0}}], 
      Line[{{0, 0, zmin}, {0, 0, zmax}}], 
      Line[{{xmax, 0, 0}, {.95 xmax, 0, 0.05 zmax}}], 
      Line[{{xmax, 0, 0}, {.95 xmax, 0, -0.05 zmax}}], 
      Line[{{0, ymax, 0}, {0, .95 ymax, 0.05 zmax}}], 
      Line[{{0, ymax, 0}, {0, .95 ymax, -0.05 zmax}}], 
      Line[{{0, 0, zmax}, {0.05 xmax, 0, .95 zmax}}], 
      Line[{{0, 0, zmax}, {-0.05 xmax, 0, .95 zmax}}], 
      PointSize[0.01], Point[{0, 0, 0}], Thickness[0.004]}], 
    Boxed -> False, 
    PlotRange -> {{.7 xmin, .7 xmax}, {.7 ymin, .7 ymax}, {.8 zmin, \
.8 zmax}}];
  (*manipulate:*)
  subimsize = imageSize/2;
  preComputed = Table[
    Row[{
      Show[stackResponses, axes, 
       Graphics3D[{FontSize -> 18, 
         Text["\[Theta]", {-.10, 0, Length[os] d}], 
         Text["x", {.9, 0, -20}], Text["y", {-.10, .7, 0}]}], 
       Graphics3D[{Red, Thickness[0.01], 
         Line[{{0, 0, 0 + (\[Theta]i - 1) d}, {0, 1, 
            0 + (\[Theta]i - 1) d}, {1, 1, 0 + (\[Theta]i - 1) d}, {1,
             0, 0 + (\[Theta]i - 1) d}, {0, 0, 
            0 + (\[Theta]i - 1) d}}]}], Axes -> False, 
       AxesLabel -> {"y", "x", "\[Theta]"},
       LabelStyle -> Directive[Bold, FontSize -> 12], 
       AxesOrigin -> {0, 1, 180}, Ticks -> False, PlotRange -> All, 
       ImageSize -> subimsize]
      ,
      Show[
       ImageAdjust@
        Image[Re[os[[\[Theta]i, 10 ;; -10, 10 ;; -10]]], 
         ImageSize -> subimsize],
       Graphics[{Red, Thick, 
         Arrow[{{55, 55}, {55, 55} + 
            50 {Cos[(periodicity (\[Theta]i - 1) )/Length[os] - \[Pi]/
                 2], Sin[(periodicity (\[Theta]i - 1) )/
                 Length[os] - \[Pi]/2]}}]}],
       Graphics[{Red, Thick, 
         Arrow[{{55, 55}, {55, 55} - 
            50 {Cos[(periodicity (\[Theta]i - 1) )/Length[os] - \[Pi]/
                 2], Sin[(periodicity (\[Theta]i - 1) )/
                 Length[os] - \[Pi]/2]}}]}]]}], {\[Theta]i, 
     1, (Length[os])/1, 1}];
  preComputed]







(*******************************************************)
(*******************************************End Private*)
End[]

(*******************************************************)
(*******************************************End Package*)
Protect["OrientationScores`OtherTools`*"]
EndPackage[]