(* Mathematica package *)

(*******************************************************)
(*****************************************Begin Package*)
BeginPackage["RetinalImageAnalysis`General`"]
Unprotect["RetinalImageAnalysis`General`*"]


GiveTestImage::usage = "GiveTestImage[] gives a test image of the EasyScan 
database. The test image is return in the form {imR, imG, imB}, the output thus
has dimensions {3,dimx,dimy}.

GiveTestImage[type] gives a test image of the database \"type\", type can be
\"ES\", \"MaastrichtStudy\", \"HRF\", \"STARE\" or \"DRIVE\"."

(*******************************************************)
(*****************************************Begin Private*)
Begin["Private`"]

GiveTestImage[type_: "ES"] := Module[{applicationPaths,applicationPath,imRed, imGreen, imBlue},
  
  applicationPaths=Extract[$Path, Position[
  	Length /@ (StringCases[#, "Applications"] & /@ $Path)
  	, 1]
  ];
  applicationPath = First@Extract[
  	applicationPaths,
  	Position[
  		Length /@ (FileNames[# <> "\\RetinalImageAnalysis"] & /@ applicationPaths)
  	, 1]
  ];
  
  Switch[type
   
   , "ES",
   imRed = 
    Import[applicationPath <> 
        "\\RetinalImageAnalysis\\Data\\Images\\ES_1_IR.jpg", "Data"];
   If[Length[Dimensions[imRed]] > 2, imRed = imRed[[All, All, 1]]];
   imGreen = 
    Import[applicationPath <> 
        "\\RetinalImageAnalysis\\Data\\Images\\ES_1_Green.jpg", "Data"];
   If[Length[Dimensions[imGreen]] > 2, 
    imGreen = imGreen[[All, All, 1]]];
   imBlue = 0*imGreen;
   {imRed, imGreen, imBlue}
   
   , "ES2",
   imRed = 
    Import[applicationPath <> 
        "\\RetinalImageAnalysis\\Data\\Images\\ES_2_IR.jpg", "Data"];
   If[Length[Dimensions[imRed]] > 2, imRed = imRed[[All, All, 1]]];
   imGreen = 
    Import[applicationPath <> 
        "\\RetinalImageAnalysis\\Data\\Images\\ES_2_Green.jpg", "Data"];
   If[Length[Dimensions[imGreen]] > 2, 
    imGreen = imGreen[[All, All, 1]]];
   imBlue = 0*imGreen;
   {imRed, imGreen, imBlue}
   
   
   , "MaastrichtStudy",
   Transpose[
    Import[applicationPath <> 
        "\\RetinalImageAnalysis\\Data\\Images\\MaastrichtStudy_1.jpg", 
     "Data"], {2, 3, 1}]
   
   , "HRF",
   Transpose[
    Import[applicationPath <> 
        "\\RetinalImageAnalysis\\Data\\Images\\HRF_1.jpg", "Data"], {2, 3, 1}]
   
   , "DRIVE",
   Transpose[
    Import[
     applicationPath <> 
        "\\RetinalImageAnalysis\\Data\\Images\\DRIVE_1.tif", "Data"],
    {2, 3, 1}]
   
   , "STARE",
   Transpose[
    Import[
     applicationPath <> 
        "\\RetinalImageAnalysis\\Data\\Images\\STARE_1.ppm", "Data"],
    {2, 3, 1}]
   ]
  ]




(*******************************************************)
(*******************************************End Private*)
End[]

(*******************************************************)
(*******************************************End Package*)
Protect["RetinalImageAnalysis`General`*"]
EndPackage[]