(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     30316,        840]
NotebookOptionsPosition[     28612,        781]
NotebookOutlinePosition[     29048,        800]
CellTagsIndexPosition[     29005,        797]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Bilateral Filter Package", "Title",
 CellChangeTimes->{{3.488872101057067*^9, 3.488872101307316*^9}}],

Cell["\<\
Markus van Almsick
Technische Universiteit Eindhoven
\[Copyright]2007\
\>", "Subsubtitle"],

Cell[CellGroupData[{

Cell["Prefix", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "TimeSamp", " ", "for", " ", "Package", " ", "Version", " ", "Control"}], 
   " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Unprotect", "[", "TimeStamp", "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"TimeStamp", "::", "usage"}], "=", 
     "\"\<TimeStamp[context] should be set to a Date[]-List indicating the \
version of the corresponding package.\>\""}], ";"}], "\[IndentingNewLine]", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{
     "TimeStamp", "[", "\"\<MathVisionTools`BilateralFilter`\>\"", "]"}], " ",
      "=", " ", 
     RowBox[{"{", 
      RowBox[{"2010", ",", "11", ",", "14", ",", "16", ",", "45", ",", "0"}], 
      "}"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Protect", "[", "TimeStamp", "]"}], ";"}]}]}]], "PackageInput",
 CellChangeTimes->{{3.498737254393471*^9, 3.498737262836357*^9}}],

Cell["\<\
The preamble of the package containing all kinds of remarks about authorship, \
contemns, and copyright.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Name", ":", " ", "MathVisionTools`BilateralFilter`"}]}], " ", 
   "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Author", ":", " ", 
     RowBox[{"Markus", " ", "van", " ", "Almsick"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Email", " ", 
     RowBox[{"address", ":", " ", 
      RowBox[{"m", ".", "van", ".", 
       RowBox[{"almsick", "@", "tue"}], ".", "nl"}]}]}]}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Context", ":", " ", "MathVisionTools`BilateralFilter`"}]}], 
   "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Package", " ", 
     RowBox[{"Version", ":", " ", "1.0"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Mathematica", " ", 
     RowBox[{"Version", ":", " ", "8.0"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"Copyright", ":", " ", 
      RowBox[{"Copyright", " ", "2007"}]}]}], ",", " ", 
    RowBox[{"Technische", " ", "Universiteit", " ", "Eindhoven"}]}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Title", ":", " ", "BilateralFilter"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Summary", ":", " ", 
     RowBox[{
     "This", " ", "package", " ", "implements", " ", "bilateral", " ", 
      "filters"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"Keywords", ":", " ", 
      RowBox[{"Bilateral", " ", "Filter"}]}]}], ",", " ", "Tomasi", ",", " ", 
    "Manduchi"}], " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Requirements", ":", " ", "None"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"Source", ":", " ", 
      RowBox[{
      "Bilateral", " ", "Filtering", " ", "for", " ", "Gray", " ", "and", " ",
        "Color", " ", "Images"}]}]}], ",", " ", 
    RowBox[{
     RowBox[{"C", ".", "Tomasi"}], " ", "and", " ", 
     RowBox[{"R", ".", "Manduchi"}]}], ",", " ", 
    RowBox[{
    "Proceedings", " ", "of", " ", "the", " ", "1998", " ", "IEEE", " ", 
     "International", "\n", "Conference", " ", "on", " ", "Computer", " ", 
     "Vision"}]}], " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"History", ":", " ", 
      RowBox[{
      "Version", " ", "1.0", " ", "by", " ", "Markus", " ", "van", " ", 
       "Almsick"}]}]}], ",", " ", 
    RowBox[{"July", " ", "2007"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Limitations", ":"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Discussion", ":"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"To", " ", 
     RowBox[{"do", ":"}]}]}], " ", "*)"}]}]], "PackageInput",
 InitializationCell->True,
 CellChangeTimes->{{3.464020733510845*^9, 3.4640207363949957`*^9}, {
  3.4987372684642057`*^9, 3.498737325542418*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Begin Package", "Section"],

Cell["\<\
Declaring the package and unlocking all symbols defined in the code.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"BeginPackage", "[", 
   RowBox[{
   "\"\<MathVisionTools`BilateralFilter`\>\"", ",", "\[IndentingNewLine]", 
    "\"\<MathVisionTools`Common`MathVisionToolsCommon`\>\"", ",", 
    "\[IndentingNewLine]", "\"\<MathVisionTools`ImageFrame`\>\""}], "]"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{"Unprotect", "[", "\[IndentingNewLine]", 
  RowBox[{
  "BilateralGrayscaleFilter", ",", "\[IndentingNewLine]", 
   "BilateralColorFilter"}], " ", "\[IndentingNewLine]", 
  "]"}]}], "PackageInput",
 InitializationCell->True,
 CellChangeTimes->{{3.4987373385538063`*^9, 3.4987373418107224`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Online Help and Options", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"BilateralGrayscaleFilter", "::", "usage"}], "=", 
    "\"\<BilateralGrayscaleFilter[\[Sigma],\[Mu],img] applies a bilateral \
filter on image img with a geometric spread \[Sigma] and a photometric spread \
\[Mu]. The image may have up to 4 dimensions, but must consist of scalar \
numbers. Default values are \[Sigma] = 1.6 and \[Mu] = \
StandardDeviation[img]/2.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"BilateralColorFilter", "::", "usage"}], "=", 
    "\"\<BilateralColorFilter[\[Sigma],\[Mu],img] is not yet \
implemented.\>\""}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "BilateralGrayscaleFilter", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"ImageBoundary", "\[Rule]", "Constant"}], "}"}]}], 
  ";"}]}], "PackageInput",
 InitializationCell->True,
 CellChangeTimes->{{3.498737369706397*^9, 3.498737379990738*^9}, 
   3.4987374298522253`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Package Code", "Section"],

Cell["Starting the private context of the package.", "Text"],

Cell[BoxData[
 RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}]], "PackageInput",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["Bilateral Filter for Grayscale Image up to 4 Dimensions", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"BilateralGrayscaleFilter", "::", "bigdim"}], "=", 
   "\"\<Bilateral filters are only implemented for images of up to 4 \
dimensions.\>\""}], ";"}]], "PackageInput",
 CellChangeTimes->{3.498737417758275*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"BilateralGrayscaleFilter", "[", 
   RowBox[{
    RowBox[{"\[Sigma]_", "?", 
     RowBox[{"NumericQ", ":", "1.6"}]}], ",", 
    RowBox[{"img_", "?", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"ArrayQ", "[", 
        RowBox[{"#", ",", 
         RowBox[{"1", "|", "2", "|", "3", "|", "4"}], ",", "NumericQ"}], 
        "]"}], "&"}], ")"}]}], ",", "opts___Rule"}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"BilateralGrayscaleFilter", "[", 
   RowBox[{"\[Sigma]", ",", 
    RowBox[{
     FractionBox["1", "2"], 
     SqrtBox[
      RowBox[{"Variance", "[", 
       RowBox[{"Flatten", "[", "img", "]"}], "]"}]]}], ",", "img", ",", 
    "opts"}], "]"}]}]], "PackageInput",
 CellChangeTimes->{{3.49873741888279*^9, 3.498737420227734*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"BilateralGrayscaleFilter", "[", 
   RowBox[{
    RowBox[{"\[Sigma]_", "?", "NumericQ"}], ",", 
    RowBox[{"\[Mu]_", "?", "NumericQ"}], ",", 
    RowBox[{"img_", "?", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"ArrayQ", "[", 
        RowBox[{"#", ",", "1", ",", "NumericQ"}], "]"}], "&"}], ")"}]}], ",", 
    "opts___Rule"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Sigma]3", " ", "=", " ", 
        RowBox[{"Ceiling", "[", 
         RowBox[{"3", " ", "\[Sigma]"}], "]"}]}], ",", "framedImg", ",", 
       "filterFunction", ",", "gaussian"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gaussian", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Exp", "[", 
          RowBox[{"-", 
           FractionBox[
            SuperscriptBox["x", "2"], 
            RowBox[{"2", " ", 
             SuperscriptBox["\[Sigma]", "2"]}]]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"-", "\[Sigma]3"}], ",", "\[Sigma]3"}], "}"}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"filterFunction", " ", "=", " ", "\[IndentingNewLine]", 
       RowBox[{"Compile", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"patch", ",", "_Real", ",", "1"}], "}"}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Module", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"kern", "=", 
             RowBox[{
              RowBox[{"Exp", "[", 
               RowBox[{
                RowBox[{"-", 
                 FractionBox["1", 
                  RowBox[{"2", 
                   SuperscriptBox["\[Mu]", "2"]}]]}], 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"patch", "-", 
                   RowBox[{"patch", "\[LeftDoubleBracket]", 
                    RowBox[{"\[Sigma]3", "+", "1"}], 
                    "\[RightDoubleBracket]"}]}], ")"}], "2"]}], "]"}], "*", 
              "gaussian"}]}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Total", "[", 
             RowBox[{"kern", "*", "patch"}], "]"}], "/", 
            RowBox[{"Total", "[", "kern", "]"}]}]}], "\[IndentingNewLine]", 
          "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\[Sigma]3", ",", "_Integer"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"gaussian", ",", "_Real", ",", "1"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Total", "[", "_", "]"}], ",", "_Real"}], "}"}]}], 
          "}"}]}], "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"framedImg", "=", 
       RowBox[{"ImageFrame", "[", 
        RowBox[{"img", ",", "\[Sigma]3", ",", 
         RowBox[{"ImageBoundary", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ImageBoundary", "/.", " ", 
             RowBox[{"{", "opts", "}"}]}], "/.", 
            RowBox[{"Options", "[", "BilateralGrayscaleFilter", "]"}]}], 
           ")"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Array", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"filterFunction", "[", 
          RowBox[{"Take", "[", 
           RowBox[{"framedImg", ",", 
            RowBox[{"{", 
             RowBox[{"#", ",", 
              RowBox[{"#", "+", 
               RowBox[{"2", " ", "\[Sigma]3"}]}]}], "}"}]}], "]"}], "]"}], 
         "&"}], ",", " ", "\[IndentingNewLine]", 
        RowBox[{"Dimensions", "[", "img", "]"}]}], "\[IndentingNewLine]", 
       "]"}]}]}], "\[IndentingNewLine]", "]"}], "/;", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "1"}]}]}]], "PackageInput",\

 CellChangeTimes->{{3.498737421918271*^9, 3.498737425572763*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"BilateralGrayscaleFilter", "[", 
   RowBox[{
    RowBox[{"\[Sigma]_", "?", "NumericQ"}], ",", 
    RowBox[{"\[Mu]_", "?", "NumericQ"}], ",", 
    RowBox[{"img_", "?", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"ArrayQ", "[", 
        RowBox[{"#", ",", "2", ",", "NumericQ"}], "]"}], "&"}], ")"}]}], ",", 
    "opts___Rule"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Sigma]3", " ", "=", " ", 
        RowBox[{"Ceiling", "[", 
         RowBox[{"3", " ", "\[Sigma]"}], "]"}]}], ",", "framedImg", ",", 
       "filterFunction", ",", "gaussian"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gaussian", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Exp", "[", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"]}], 
            RowBox[{"2", " ", 
             SuperscriptBox["\[Sigma]", "2"]}]]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"-", "\[Sigma]3"}], ",", "\[Sigma]3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", 
           RowBox[{"-", "\[Sigma]3"}], ",", "\[Sigma]3"}], "}"}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"filterFunction", " ", "=", " ", "\[IndentingNewLine]", 
       RowBox[{"Compile", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"patch", ",", "_Real", ",", "2"}], "}"}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Module", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"kern", "=", 
             RowBox[{
              RowBox[{"Exp", "[", 
               RowBox[{
                RowBox[{"-", 
                 FractionBox["1", 
                  RowBox[{"2", 
                   SuperscriptBox["\[Mu]", "2"]}]]}], 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"patch", "-", 
                   RowBox[{"patch", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"\[Sigma]3", "+", "1"}], ",", 
                    RowBox[{"\[Sigma]3", "+", "1"}]}], 
                    "\[RightDoubleBracket]"}]}], ")"}], "2"]}], "]"}], "*", 
              "gaussian"}]}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Total", "[", 
             RowBox[{
              RowBox[{"kern", "*", "patch"}], ",", "2"}], "]"}], "/", 
            RowBox[{"Total", "[", 
             RowBox[{"kern", ",", "2"}], "]"}]}]}], "\[IndentingNewLine]", 
          "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\[Sigma]3", ",", "_Integer"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"gaussian", ",", "_Real", ",", "2"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Total", "[", 
              RowBox[{"_", ",", "2"}], "]"}], ",", "_Real"}], "}"}]}], 
          "}"}]}], "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"framedImg", "=", 
       RowBox[{"ImageFrame", "[", 
        RowBox[{"img", ",", "\[Sigma]3", ",", 
         RowBox[{"ImageBoundary", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ImageBoundary", "/.", " ", 
             RowBox[{"{", "opts", "}"}]}], "/.", 
            RowBox[{"Options", "[", "BilateralGrayscaleFilter", "]"}]}], 
           ")"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Array", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"filterFunction", "[", 
          RowBox[{"Take", "[", 
           RowBox[{"framedImg", ",", 
            RowBox[{"{", 
             RowBox[{"#1", ",", 
              RowBox[{"#1", "+", 
               RowBox[{"2", " ", "\[Sigma]3"}]}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"#2", ",", 
              RowBox[{"#2", "+", 
               RowBox[{"2", " ", "\[Sigma]3"}]}]}], "}"}]}], "]"}], "]"}], 
         "&"}], ",", " ", "\[IndentingNewLine]", 
        RowBox[{"Dimensions", "[", "img", "]"}]}], "\[IndentingNewLine]", 
       "]"}]}]}], "\[IndentingNewLine]", "]"}], "/;", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "2"}]}]}]], "PackageInput",\

 CellChangeTimes->{{3.498737439207016*^9, 3.498737441318245*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"BilateralGrayscaleFilter", "[", 
   RowBox[{
    RowBox[{"\[Sigma]_", "?", "NumericQ"}], ",", 
    RowBox[{"\[Mu]_", "?", "NumericQ"}], ",", 
    RowBox[{"img_", "?", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"ArrayQ", "[", 
        RowBox[{"#", ",", "3", ",", "NumericQ"}], "]"}], "&"}], ")"}]}], ",", 
    "opts___Rule"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Sigma]3", " ", "=", " ", 
        RowBox[{"Ceiling", "[", 
         RowBox[{"3", " ", "\[Sigma]"}], "]"}]}], ",", "framedImg", ",", 
       "filterFunction", ",", "gaussian"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gaussian", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Exp", "[", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"], "+", 
             SuperscriptBox["z", "2"]}], 
            RowBox[{"2", " ", 
             SuperscriptBox["\[Sigma]", "2"]}]]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"-", "\[Sigma]3"}], ",", "\[Sigma]3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", 
           RowBox[{"-", "\[Sigma]3"}], ",", "\[Sigma]3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", 
           RowBox[{"-", "\[Sigma]3"}], ",", "\[Sigma]3"}], "}"}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"filterFunction", " ", "=", " ", "\[IndentingNewLine]", 
       RowBox[{"Compile", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"patch", ",", "_Real", ",", "3"}], "}"}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Module", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"kern", "=", 
             RowBox[{
              RowBox[{"Exp", "[", 
               RowBox[{
                RowBox[{"-", 
                 FractionBox["1", 
                  RowBox[{"2", 
                   SuperscriptBox["\[Mu]", "2"]}]]}], 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"patch", "-", 
                   RowBox[{"patch", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"\[Sigma]3", "+", "1"}], ",", 
                    RowBox[{"\[Sigma]3", "+", "1"}], ",", 
                    RowBox[{"\[Sigma]3", "+", "1"}]}], 
                    "\[RightDoubleBracket]"}]}], ")"}], "2"]}], "]"}], "*", 
              "gaussian"}]}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Total", "[", 
             RowBox[{
              RowBox[{"kern", "*", "patch"}], ",", "3"}], "]"}], "/", 
            RowBox[{"Total", "[", 
             RowBox[{"kern", ",", "3"}], "]"}]}]}], "\[IndentingNewLine]", 
          "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\[Sigma]3", ",", "_Integer"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"gaussian", ",", "_Real", ",", "3"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Total", "[", 
              RowBox[{"_", ",", "3"}], "]"}], ",", "_Real"}], "}"}]}], 
          "}"}]}], "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"framedImg", "=", 
       RowBox[{"ImageFrame", "[", 
        RowBox[{"img", ",", "\[Sigma]3", ",", 
         RowBox[{"ImageBoundary", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ImageBoundary", "/.", " ", 
             RowBox[{"{", "opts", "}"}]}], "/.", 
            RowBox[{"Options", "[", "BilateralGrayscaleFilter", "]"}]}], 
           ")"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Array", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"filterFunction", "[", 
          RowBox[{"Take", "[", 
           RowBox[{"framedImg", ",", 
            RowBox[{"{", 
             RowBox[{"#1", ",", 
              RowBox[{"#1", "+", 
               RowBox[{"2", " ", "\[Sigma]3"}]}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"#2", ",", 
              RowBox[{"#2", "+", 
               RowBox[{"2", " ", "\[Sigma]3"}]}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"#3", ",", 
              RowBox[{"#3", "+", 
               RowBox[{"2", " ", "\[Sigma]3"}]}]}], "}"}]}], "]"}], "]"}], 
         "&"}], ",", " ", "\[IndentingNewLine]", 
        RowBox[{"Dimensions", "[", "img", "]"}]}], "\[IndentingNewLine]", 
       "]"}]}]}], "\[IndentingNewLine]", "]"}], "/;", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 CellChangeTimes->{{3.498737444681847*^9, 3.498737446938805*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"BilateralGrayscaleFilter", "[", 
   RowBox[{
    RowBox[{"\[Sigma]_", "?", "NumericQ"}], ",", 
    RowBox[{"\[Mu]_", "?", "NumericQ"}], ",", 
    RowBox[{"img_", "?", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"ArrayQ", "[", 
        RowBox[{"#", ",", "4", ",", "NumericQ"}], "]"}], "&"}], ")"}]}], ",", 
    "opts___Rule"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Sigma]3", " ", "=", " ", 
        RowBox[{"Ceiling", "[", 
         RowBox[{"3", " ", "\[Sigma]"}], "]"}]}], ",", "framedImg", ",", 
       "filterFunction", ",", "gaussian"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"gaussian", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Exp", "[", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"], "+", 
             SuperscriptBox["z", "2"], "+", 
             SuperscriptBox["t", "2"]}], 
            RowBox[{"2", " ", 
             SuperscriptBox["\[Sigma]", "2"]}]]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"-", "\[Sigma]3"}], ",", "\[Sigma]3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"y", ",", 
           RowBox[{"-", "\[Sigma]3"}], ",", "\[Sigma]3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"z", ",", 
           RowBox[{"-", "\[Sigma]3"}], ",", "\[Sigma]3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", 
           RowBox[{"-", "\[Sigma]3"}], ",", "\[Sigma]3"}], "}"}]}], "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"filterFunction", " ", "=", " ", "\[IndentingNewLine]", 
       RowBox[{"Compile", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"patch", ",", "_Real", ",", "4"}], "}"}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Module", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"kern", "=", 
             RowBox[{
              RowBox[{"Exp", "[", 
               RowBox[{
                RowBox[{"-", 
                 FractionBox["1", 
                  RowBox[{"2", 
                   SuperscriptBox["\[Mu]", "2"]}]]}], 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"patch", "-", 
                   RowBox[{"patch", "\[LeftDoubleBracket]", 
                    RowBox[{
                    RowBox[{"\[Sigma]3", "+", "1"}], ",", 
                    RowBox[{"\[Sigma]3", "+", "1"}], ",", 
                    RowBox[{"\[Sigma]3", "+", "1"}], ",", 
                    RowBox[{"\[Sigma]3", "+", "1"}]}], 
                    "\[RightDoubleBracket]"}]}], ")"}], "2"]}], "]"}], "*", 
              "gaussian"}]}], "}"}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"Total", "[", 
             RowBox[{
              RowBox[{"kern", "*", "patch"}], ",", "4"}], "]"}], "/", 
            RowBox[{"Total", "[", 
             RowBox[{"kern", ",", "4"}], "]"}]}]}], "\[IndentingNewLine]", 
          "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\[Sigma]3", ",", "_Integer"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"gaussian", ",", "_Real", ",", "4"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Total", "[", 
              RowBox[{"_", ",", "4"}], "]"}], ",", "_Real"}], "}"}]}], 
          "}"}]}], "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"framedImg", "=", 
       RowBox[{"ImageFrame", "[", 
        RowBox[{"img", ",", "\[Sigma]3", ",", 
         RowBox[{"ImageBoundary", "\[Rule]", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ImageBoundary", "/.", " ", 
             RowBox[{"{", "opts", "}"}]}], "/.", 
            RowBox[{"Options", "[", "BilateralGrayscaleFilter", "]"}]}], 
           ")"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Array", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"filterFunction", "[", 
          RowBox[{"Take", "[", 
           RowBox[{"framedImg", ",", 
            RowBox[{"{", 
             RowBox[{"#1", ",", 
              RowBox[{"#1", "+", 
               RowBox[{"2", " ", "\[Sigma]3"}]}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"#2", ",", 
              RowBox[{"#2", "+", 
               RowBox[{"2", " ", "\[Sigma]3"}]}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"#3", ",", 
              RowBox[{"#3", "+", 
               RowBox[{"2", " ", "\[Sigma]3"}]}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"#4", ",", 
              RowBox[{"#4", "+", 
               RowBox[{"2", " ", "\[Sigma]3"}]}]}], "}"}]}], "]"}], "]"}], 
         "&"}], ",", " ", "\[IndentingNewLine]", 
        RowBox[{"Dimensions", "[", "img", "]"}]}], "\[IndentingNewLine]", 
       "]"}]}]}], "\[IndentingNewLine]", "]"}], "/;", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "4"}]}]}]], "PackageInput",\

 CellChangeTimes->{{3.498737451027245*^9, 3.49873745276405*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Closing Package", "Section"],

Cell["Closing the package and locking all the symbols.", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"End", "[", "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SetAttributes", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "BilateralGrayscaleFilter", ",", "\[IndentingNewLine]", 
       "BilateralColorFilter"}], " ", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"Protected", ",", " ", "ReadProtected"}], "}"}]}], 
    "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{"EndPackage", "[", "]"}]}], "PackageInput",
 InitializationCell->True,
 CellChangeTimes->{3.498737456239706*^9}]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowSize->{1025, 762},
WindowMargins->{{15, Automatic}, {Automatic, 0}},
ShowSelection->True,
Magnification->1,
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (November 7, \
2010)",
StyleDefinitions->"PackageNotebook.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 107, 1, 96, "Title"],
Cell[677, 25, 100, 4, 79, "Subsubtitle"],
Cell[CellGroupData[{
Cell[802, 33, 25, 0, 48, "Section"],
Cell[830, 35, 1023, 26, 161, "PackageInput"],
Cell[1856, 63, 128, 3, 26, "Text"],
Cell[1987, 68, 3611, 98, 506, "PackageInput",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[5635, 171, 32, 0, 48, "Section"],
Cell[5670, 173, 92, 2, 26, "Text"],
Cell[5765, 177, 624, 14, 146, "PackageInput",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[6426, 196, 42, 0, 48, "Section"],
Cell[6471, 198, 1041, 25, 146, "PackageInput",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[7549, 228, 31, 0, 48, "Section"],
Cell[7583, 230, 60, 0, 26, "Text"],
Cell[7646, 232, 108, 2, 40, "PackageInput",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[7779, 238, 77, 0, 42, "Subsection"],
Cell[7859, 240, 254, 6, 40, "PackageInput"],
Cell[8116, 248, 781, 22, 76, "PackageInput"],
Cell[8900, 272, 4020, 101, 414, "PackageInput"],
Cell[12923, 375, 4567, 115, 414, "PackageInput"],
Cell[17493, 492, 4953, 124, 414, "PackageInput"],
Cell[22449, 618, 5338, 133, 414, "PackageInput"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[27836, 757, 34, 0, 48, "Section"],
Cell[27873, 759, 64, 0, 26, "Text"],
Cell[27940, 761, 644, 16, 161, "PackageInput",
 InitializationCell->True]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
