(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     73526,       1760]
NotebookOptionsPosition[     24481,        702]
NotebookOutlinePosition[     71485,       1695]
CellTagsIndexPosition[     71442,       1692]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["EllipseFit Package", "Title",
 CellChangeTimes->{{3.488887267814867*^9, 3.488887268610532*^9}}],

Cell["\<\
Han van Triest, Markus van Almsick
Technische Universiteit Eindhoven
\[Copyright]2008\
\>", "Subsubtitle"],

Cell[CellGroupData[{

Cell["Prefix", "Section"],

Cell[TextData[{
 "Time stamp for version control is a ",
 StyleBox["List", "Input"],
 " with year, month, day, hour, minute, and second."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "TimeSamp", " ", "for", " ", "Package", " ", "Version", " ", "Control"}], 
   " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Unprotect", "[", "TimeStamp", "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"TimeStamp", "::", "usage"}], "=", 
     "\"\<TimeStamp[context] should be set to a Date[]-List indicating the \
version of the corresponding package.\>\""}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"TimeStamp", "[", "\"\<MathVisionTools`Ellipsefit`\>\"", "]"}], 
     " ", "=", 
     RowBox[{"{", 
      RowBox[{"2008", ",", "1", ",", "23", ",", "14", ",", "50", ",", "0"}], 
      "}"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Protect", "[", "TimeStamp", "]"}], ";"}]}]}]], "PackageInput"],

Cell["\<\
The preamble of the package containing all kinds of remarks about authorship, \
content, and copyright.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Name", ":", " ", "MathVisionTools`EllipseFit`"}]}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Author", ":", " ", 
     RowBox[{
     "Han", " ", "van", " ", "Triest", "  ", "and", " ", "Markus", " ", "van",
       " ", "Almsick"}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"Email", " ", 
      RowBox[{"address", ":", " ", 
       RowBox[{"J", ".", "w", ".", "v", ".", 
        RowBox[{"Triest", "@", "tue"}], ".", "nl"}]}]}]}], ",", "  ", 
    RowBox[{"M", ".", "v", ".", 
     RowBox[{"Almsick", "@", "tue"}], ".", "nl"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Context", ":", " ", "MathVisionTools`EllipseFit`"}]}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Package", " ", 
     RowBox[{"Version", ":", " ", "1.1"}]}]}], "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Mathematica", " ", 
     RowBox[{"Version", ":", " ", "5.2"}]}]}], "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"Copyright", ":", " ", 
      RowBox[{"Copyright", " ", "2008"}]}]}], ",", " ", 
    RowBox[{"Technische", " ", "Universiteit", " ", "Eindhoven"}]}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Title", ":", " ", "EllipseFit"}]}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"Summary", ":", " ", 
      RowBox[{
      "Package", " ", "containing", " ", "functions", " ", "for", " ", "the", 
       " ", "fitting", " ", "of", " ", "a", " ", "ellipse", " ", "specific", 
       " ", "conic", " ", "to", " ", "a", " ", "set", " ", "of", " ", "data", 
       " ", 
       RowBox[{"points", ".", " ", "Furthermore"}]}]}]}], ",", " ", 
    RowBox[{
    "a", " ", "function", " ", "is", " ", "provided", " ", "for", " ", "the", 
     " ", "fitting", " ", "of", " ", "an", " ", "ellipsoid", " ", "to", " ", 
     "three", " ", "dimensional", " ", 
     RowBox[{"data", "."}]}]}], "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"Keywords", ":", " ", 
      RowBox[{"Least", " ", "Squares", " ", "Ellipse", " ", "Fitting"}]}]}], 
    ",", " ", 
    RowBox[{"LeastSquares", " ", "Ellipsoid", " ", "Fitting"}]}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Requirements", ":", " ", "None"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"Source", ":", " ", "Fitzgibbon"}]}], ",", " ", 
    RowBox[{"IEEE", " ", "PAMI"}], ",", " ", "21", ",", " ", "5", ",", " ", 
    "1999", ",", " ", 
    RowBox[{
     RowBox[{"pp", " ", "476"}], "-", "480"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"History", ":", " ", 
      RowBox[{"Version", " ", "1.0", " ", "by", " ", 
       RowBox[{"J", ".", "W", ".", " ", "van"}], " ", "Triest"}]}]}], ",", 
    " ", 
    RowBox[{"6", "-", "8", "-", "2007"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"History", ":", " ", 
      RowBox[{"Version", " ", "1.1", " ", "by", " ", 
       RowBox[{"M", ".", " ", "van"}], " ", "ALmsick"}]}]}], ",", 
    StyleBox[" ",
     FontColor->GrayLevel[0]], 
    RowBox[{"23", "-", "1", "-", "2008"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Limitations", ":"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Discussion", ":"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"To", " ", 
     RowBox[{"do", ":"}]}]}], " ", "*)"}]}]], "PackageInput",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Begin Package", "Section"],

Cell["\<\
Declaring the package and unlocking all symbols defined in the code.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"BeginPackage", "[", "\"\<MathVisionTools`EllipseFit`\>\"", "]"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{"Unprotect", "[", "\[IndentingNewLine]", 
  RowBox[{
  "ListEllipseFit", ",", "EllipseProperties", ",", "EllipseOrigin", ",", 
   "EllipseRadii", ",", "EllipseOrientation", ",", "QuadraticCurve"}], 
  "\[IndentingNewLine]", "]"}]}], "PackageInput",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Online Help and Options", "Section"],

Cell["\<\
A short but comprehensive online description for each command, function and \
symbol that is made available by this package:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ListEllipseFit", "::", "usage"}], "=", 
  "\"\<ListEllipseFit[data] fits an ellipse model to a set of 2-dimensional \
coordinates {{x1,y1},{x2,y2},...{xn,yn}}. The result is given in the form of \
the coefficient list {a,b,c,d,e} of the quadratic equation a \
\!\(\*SuperscriptBox[\(x\), \(2\)]\) + b x y + c \!\(\*SuperscriptBox[\(y\), \
\(2\)]\) + d x + e y + 1 = 0.\>\""}]], "PackageInput",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"EllipseProperties", "::", "usage"}], "=", 
  "\"\<EllipseProperties[{a,b,c,d,e,f:1}] renders a list of rules that \
specify the EllipseOrigin, EllipseRadii, EllipseOrientation for an ellipse \
given by its quadratic equation a \!\(\*SuperscriptBox[\(x\), \(2\)]\) + b x \
y + c \!\(\*SuperscriptBox[\(y\), \(\(2\)\(\\\ \)\)]\)+ d x + e y + f == 0. \
Coefficient f is optional.\>\""}]], "PackageInput",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"EllipseOrigin", "::", "usage"}], "=", 
  "\"\<EllipseOrigin is an option tag for the function EllipseProperties that \
defines the center of an ellipse.\>\""}]], "PackageInput",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"EllipseRadii", "::", "usage"}], "=", 
  "\"\<EllipseRadii is an option tag for the function EllipseProperties that \
defines the radii of an ellipse along its major and minor axes.\>\""}]], \
"PackageInput",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"EllipseOrientation", "::", "usage"}], "=", 
  "\"\<EllipseOrientation is an option tag for the function EllipseProperties \
that defines the angle of the major and minor axes of an ellipse with respect \
to the x- and y-axis.\>\""}]], "PackageInput",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"QuadraticCurve", "::", "usage"}], "=", 
  "\"\<QuadraticCurve[{a,b,c,d,e,f}] renders the Graphic primitive of an \
ellipse defined by the quadratic equation a \!\(\*SuperscriptBox[\(x\), \
\(2\)]\) + b x y + c \!\(\*SuperscriptBox[\(y\), \(\(2\)\(\\\ \)\)]\)+ d x + \
e y + f == 0. Currently, only an empty List is rendered for all other \
quadratic curves.\>\""}]], "PackageInput",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Package Code", "Section"],

Cell["Starting the private context of the package.", "Text"],

Cell[BoxData[
 RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}]], "PackageInput",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["Utility Functions", "Subsection"],

Cell["\<\
Functions that are used in this package only. These functions do not have to \
be declared above with an online-help usage command.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Utility", " ", "Functions"}], " ", "*)"}]], "PackageInput",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ListEllipseFit", "Subsection"],

Cell[TextData[StyleBox["Feel free to derive the algorithm of command1 at this \
point thus documenting your program.",
 FontColor->GrayLevel[0.500008]]], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "Messages", " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"ListEllipseFit", "::", "invaldat"}], "=", 
     "\"\<Input data is not a list of 2D coordinates, data must consist of a \
list of coordinates.\>\""}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ListEllipseFit", "::", "symb"}], "=", 
     "\"\<The data contain symbolic values. Cannot fit an ellipse on a set of \
symbolic data points.\>\""}], ";"}]}]}]], "PackageInput",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", "ListEllipseFit", " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ListEllipseFit", "[", "data_", "]"}], ":=", 
    "\[IndentingNewLine]", 
    RowBox[{"Module", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"designMat", ",", "eigenSys", ",", "X"}], "}"}], ",", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"Check", " ", "data", " ", "validity"}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"If", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"\[Not]", 
          RowBox[{"(", 
           RowBox[{"MatchQ", "[", 
            RowBox[{
             RowBox[{"Dimensions", "[", "data", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"_", ",", "2"}], "}"}]}], "]"}], ")"}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Message", "[", 
           RowBox[{"ListEllipseFit", "::", "invaldat"}], "]"}], ";", 
          RowBox[{"Return", "[", "$Failed", "]"}]}]}], "\[IndentingNewLine]", 
        "]"}], ";", "\[IndentingNewLine]", 
       StyleBox[
        RowBox[{"X", "=", 
         RowBox[{"Apply", "[", " ", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              SuperscriptBox["#1", "2"], ",", 
              RowBox[{"#1", " ", "#2"}], ",", 
              SuperscriptBox["#2", "2"], ",", "#1", ",", "#2", ",", "1"}], 
             "}"}], "&"}], ",", "data", ",", 
           RowBox[{"{", "1", "}"}]}], "]"}]}],
        FormatType->StandardForm], 
       StyleBox[";",
        FormatType->StandardForm], 
       StyleBox["\[IndentingNewLine]",
        FormatType->StandardForm], 
       RowBox[{
        RowBox[{
         RowBox[{
          StyleBox["Chop",
           FormatType->StandardForm], 
          StyleBox["[",
           FormatType->StandardForm], 
          RowBox[{
           RowBox[{"Most", "[", "#", "]"}], "/", 
           RowBox[{"Last", "[", "#", "]"}]}], "]"}], "&"}], "[", 
        RowBox[{
         StyleBox["If",
          FormatType->StandardForm], 
         StyleBox["[",
          FormatType->StandardForm], 
         StyleBox["\[IndentingNewLine]",
          FormatType->StandardForm], 
         RowBox[{
          RowBox[{
           RowBox[{"MatrixRank", "[", "X", "]"}], "<", "6"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           StyleBox["First",
            FormatType->StandardForm], 
           StyleBox["[",
            FormatType->StandardForm], 
           RowBox[{"NullSpace", "[", "X", "]"}], "]"}], ",", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          RowBox[{"(*", " ", 
           RowBox[{"Calculate", " ", "the", " ", "designers", " ", "matrix"}],
            " ", "*)"}], 
          StyleBox["\[IndentingNewLine]",
           FormatType->StandardForm], 
          RowBox[{
           StyleBox[
            RowBox[{"designMat", "=", 
             RowBox[{
              RowBox[{"Transpose", "[", "X", "]"}], ".", "X"}]}],
            FormatType->StandardForm], 
           StyleBox[";",
            FormatType->StandardForm], 
           StyleBox["\[IndentingNewLine]",
            FormatType->StandardForm], 
           StyleBox["\[IndentingNewLine]",
            FormatType->StandardForm], 
           StyleBox[
            RowBox[{"(*", " ", 
             RowBox[{
              RowBox[{"Calculate", " ", "the", " ", "fit"}], ",", " ", 
              RowBox[{
              "the", " ", "fit", " ", "is", " ", "associated", " ", "with", 
               " ", "the", " ", "single", " ", "positive", " ", 
               "eigenvalue"}]}], " ", "*)"}],
            FormatType->StandardForm], 
           StyleBox["\[IndentingNewLine]",
            FormatType->StandardForm], 
           RowBox[{
            StyleBox["Off",
             FormatType->StandardForm], 
            StyleBox["[",
             FormatType->StandardForm], 
            RowBox[{"Inverse", "::", "\"\<luc\>\""}], "]"}], ";", 
           "\[IndentingNewLine]", 
           StyleBox[
            RowBox[{"eigenSys", "=", 
             RowBox[{"Eigensystem", "[", 
              RowBox[{
               RowBox[{"Inverse", "[", "designMat", "]"}], ".", 
               TagBox[
                RowBox[{"(", "\[NoBreak]", GridBox[{
                   {"0", "0", "2", "0", "0", "0"},
                   {"0", 
                    RowBox[{"-", "1"}], "0", "0", "0", "0"},
                   {"2", "0", "0", "0", "0", "0"},
                   {"0", "0", "0", "0", "0", "0"},
                   {"0", "0", "0", "0", "0", "0"},
                   {"0", "0", "0", "0", "0", "0"}
                  },
                  
                  GridBoxAlignment->{
                   "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
                  GridBoxSpacings->{"Columns" -> {
                    Offset[0.27999999999999997`], {
                    Offset[0.7]}, 
                    Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, 
                    "Rows" -> {
                    Offset[0.2], {
                    Offset[0.4]}, 
                    Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
                Function[BoxForm`e$, 
                 MatrixForm[BoxForm`e$]]]}], "]"}]}],
            FormatType->StandardForm], 
           StyleBox[";",
            FormatType->StandardForm], 
           StyleBox["\[IndentingNewLine]",
            FormatType->StandardForm], 
           RowBox[{
            StyleBox["On",
             FormatType->StandardForm], 
            StyleBox["[",
             FormatType->StandardForm], 
            RowBox[{"Inverse", "::", "\"\<luc\>\""}], "]"}], ";", 
           StyleBox["\[IndentingNewLine]",
            FormatType->StandardForm], 
           RowBox[{
            RowBox[{"Select", "[", 
             RowBox[{
              RowBox[{"Transpose", "[", "eigenSys", "]"}], ",", 
              RowBox[{
               RowBox[{"Positive", "[", 
                RowBox[{
                "#", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                "]"}], "&"}]}], "]"}], "\[LeftDoubleBracket]", 
            RowBox[{"1", ",", "2"}], "\[RightDoubleBracket]"}]}]}], 
         "\[IndentingNewLine]", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
     "]"}]}], ";"}]}]], "PackageInput",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["EllipseProperties", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EllipseProperties", "[", 
   RowBox[{"{", 
    RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", 
     RowBox[{"f_:", "1"}]}], "}"}], "]"}], " ", ":=", " ", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "=", 
       RowBox[{
        RowBox[{"4", " ", "a", " ", "c", " ", "f"}], "-", 
        RowBox[{"c", " ", 
         SuperscriptBox["d", "2"]}], "+", 
        RowBox[{"b", " ", "d", " ", "e"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["e", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "f"}]}]}], ",", 
      RowBox[{"J", " ", "=", " ", 
       RowBox[{
        RowBox[{"4", " ", "a", " ", "c"}], "-", 
        SuperscriptBox["b", "2"]}]}], ",", " ", 
      RowBox[{"l", "=", 
       RowBox[{"a", "+", "c"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"If", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"\[CapitalDelta]", "\[NotEqual]", "0"}], " ", "\[And]", " ", 
       RowBox[{"J", ">", "0"}], " ", "\[And]", " ", 
       RowBox[{
        RowBox[{"\[CapitalDelta]", "/", "l"}], "<", "0"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"EllipseOrigin", " ", "\[Rule]", " ", 
         RowBox[{
          FractionBox["1", "J"], 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"b", " ", "e"}], "-", 
             RowBox[{"2", " ", "c", " ", "d"}]}], ",", 
            RowBox[{
             RowBox[{"b", " ", "d"}], "-", 
             RowBox[{"2", " ", "a", " ", "e"}]}]}], "}"}]}]}], ",", " ", 
        "\[IndentingNewLine]", 
        RowBox[{"EllipseRadii", " ", "\[Rule]", 
         RowBox[{
          SqrtBox[
           FractionBox["2", 
            RowBox[{"J", " "}]]], " ", 
          RowBox[{"{", " ", 
           RowBox[{
            SqrtBox[
             FractionBox[
              RowBox[{"-", "\[CapitalDelta]"}], 
              RowBox[{"l", "-", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
                 SuperscriptBox["b", "2"]}]], " "}]]], ",", 
            SqrtBox[
             FractionBox[
              RowBox[{"-", "\[CapitalDelta]"}], 
              RowBox[{"l", "+", 
               SqrtBox[
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"(", 
                   RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
                 SuperscriptBox["b", "2"]}]]}]]]}], "}"}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"EllipseOrientation", "\[Rule]", " ", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ArcTan", "[", 
             RowBox[{
              RowBox[{"a", "-", "c"}], ",", "b"}], "]"}], "+", "\[Pi]"}], 
           ")"}]}]}]}], "}"}], ",", "\[IndentingNewLine]", "$Failed"}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "PackageInput"]
}, Closed]],

Cell[CellGroupData[{

Cell["QuadraticCurve", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"QuadraticCurve", "[", 
   RowBox[{"{", 
    RowBox[{"a_", ",", "b_", ",", "c_", ",", "d_", ",", "e_", ",", 
     RowBox[{"f_:", "1"}]}], "}"}], "]"}], " ", ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\[CapitalDelta]", "=", 
       RowBox[{
        RowBox[{"4", " ", "a", " ", "c", " ", "f"}], "-", 
        RowBox[{"c", " ", 
         SuperscriptBox["d", "2"]}], "+", 
        RowBox[{"b", " ", "d", " ", "e"}], "-", 
        RowBox[{"a", " ", 
         SuperscriptBox["e", "2"]}], "-", 
        RowBox[{
         SuperscriptBox["b", "2"], " ", "f"}]}]}], ",", 
      RowBox[{"J", " ", "=", " ", 
       RowBox[{
        RowBox[{"4", " ", "a", " ", "c"}], "-", 
        SuperscriptBox["b", "2"]}]}], ",", " ", 
      RowBox[{"l", "=", 
       RowBox[{"a", "+", "c"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"If", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"\[CapitalDelta]", "\[NotEqual]", "0"}], " ", "\[And]", " ", 
       RowBox[{"J", ">", "0"}], " ", "\[And]", " ", 
       RowBox[{
        RowBox[{"\[CapitalDelta]", "/", "l"}], "<", "0"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Rotate", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Circle", "[", " ", 
         RowBox[{
          RowBox[{
           FractionBox["1", "J"], 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"b", " ", "e"}], "-", 
              RowBox[{"2", " ", "c", " ", "d"}]}], ",", 
             RowBox[{
              RowBox[{"b", " ", "d"}], "-", 
              RowBox[{"2", " ", "a", " ", "e"}]}]}], "}"}]}], ",", 
          RowBox[{
           SqrtBox[
            FractionBox["2", 
             RowBox[{"J", " "}]]], " ", 
           RowBox[{"{", 
            RowBox[{
             SqrtBox[
              FractionBox[
               RowBox[{"-", "\[CapitalDelta]"}], 
               RowBox[{"l", "+", 
                SqrtBox[
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
                  SuperscriptBox["b", "2"]}]]}]]], " ", ",", 
             SqrtBox[
              FractionBox[
               RowBox[{"-", "\[CapitalDelta]"}], 
               RowBox[{"l", "-", 
                SqrtBox[
                 RowBox[{
                  SuperscriptBox[
                   RowBox[{"(", 
                    RowBox[{"a", "-", "c"}], ")"}], "2"], "+", 
                  SuperscriptBox["b", "2"]}]], " "}]]]}], "}"}]}]}], "]"}], 
        ",", 
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"ArcTan", "[", 
          RowBox[{
           RowBox[{"a", "-", "c"}], ",", "b"}], "]"}]}]}], 
       "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", "}"}]}], "\[IndentingNewLine]", "]"}]}], 
   "\[IndentingNewLine]", "]"}]}]], "PackageInput"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Closing Package", "Section"],

Cell["Closing the package and locking all the symbols.", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"End", "[", "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetAttributes", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "ListEllipseFit", ",", "EllipseProperties", ",", "EllipseOrigin", ",", 
      "EllipseRadii", ",", "EllipseOrientation", ",", "QuadraticCurve"}], 
     "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"Protected", ",", "ReadProtected"}], "}"}]}], 
   "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"EndPackage", "[", "]"}]}], "PackageInput",
 InitializationCell->True]
}, Closed]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowSize->{1130, 881},
WindowMargins->{{59, Automatic}, {Automatic, 15}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
ShowSelection->True,
Magnification->1.5,
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (November 10, 2008)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell["Style Definitions", "Subtitle"], 
      Cell[
      "Modify the definitions below to change the default appearance of all \
cells in a given style.  Make modifications to any definition using commands \
in the Format menu.", "Text"], 
      Cell[
       CellGroupData[{
         Cell["Style Environment Names", "Section"], 
         Cell[
          StyleData[All, "Working"], PageWidth -> WindowWidth, 
          CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
          ScriptMinSize -> 9], 
         Cell[
          StyleData[All, "Presentation"], PageWidth -> WindowWidth, 
          CellLabelMargins -> {{24, Inherited}, {Inherited, Inherited}}, 
          ScriptMinSize -> 12], 
         Cell[
          StyleData[All, "Condensed"], PageWidth -> WindowWidth, 
          CellLabelMargins -> {{8, Inherited}, {Inherited, Inherited}}, 
          ScriptMinSize -> 8], 
         Cell[
          StyleData[All, "Printout"], PageWidth -> PaperWidth, 
          CellLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          ScriptMinSize -> 5, 
          PrivateFontOptions -> {"FontType" -> "Outline"}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Notebook Options", "Section"], 
         Cell[
         "The options defined for the style below will be used at the \
Notebook level.", "Text"], 
         Cell[
          StyleData["Notebook"], PageHeaders -> {{
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"], None, 
             Cell[
              TextData[{
                ValueBox["FileName"]}], "Header"]}, {
             Cell[
              TextData[{
                ValueBox["FileName"]}], "Header"], None, 
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"]}}, CellFrameLabelMargins -> 
          6, StyleMenuListing -> None]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headings", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Title"], CellMargins -> {{12, Inherited}, {20, 40}}, 
             CellGroupingRules -> {"TitleGrouping", 0}, PageBreakBelow -> 
             False, DefaultNewInlineCellStyle -> "None", 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", Inherited}, 
             LineSpacing -> {1, 11}, LanguageCategory -> "NaturalLanguage", 
             CounterIncrements -> "Title", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}, {"Subtitle", 0}, {"Subsubtitle", 0}}, FontFamily -> 
             "Helvetica", FontSize -> 36, FontWeight -> "Bold"], 
            Cell[
             StyleData["Title", "Presentation"], 
             CellMargins -> {{24, 10}, {20, 40}}, LineSpacing -> {1, 0}, 
             FontSize -> 44], 
            Cell[
             StyleData["Title", "Condensed"], 
             CellMargins -> {{8, 10}, {4, 8}}, FontSize -> 20], 
            Cell[
             StyleData["Title", "Printout"], 
             CellMargins -> {{2, 10}, {12, 30}}, FontSize -> 24]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subtitle"], 
             CellMargins -> {{12, Inherited}, {20, 15}}, 
             CellGroupingRules -> {"TitleGrouping", 10}, PageBreakBelow -> 
             False, DefaultNewInlineCellStyle -> "None", 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", Inherited}, 
             LanguageCategory -> "NaturalLanguage", CounterIncrements -> 
             "Subtitle", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}, {"Subsubtitle", 0}}, FontFamily -> "Helvetica", 
             FontSize -> 24], 
            Cell[
             StyleData["Subtitle", "Presentation"], 
             CellMargins -> {{24, 10}, {20, 20}}, LineSpacing -> {1, 0}, 
             FontSize -> 36], 
            Cell[
             StyleData["Subtitle", "Condensed"], 
             CellMargins -> {{8, 10}, {4, 4}}, FontSize -> 14], 
            Cell[
             StyleData["Subtitle", "Printout"], 
             CellMargins -> {{2, 10}, {12, 8}}, FontSize -> 18]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubtitle"], 
             CellMargins -> {{12, Inherited}, {20, 15}}, 
             CellGroupingRules -> {"TitleGrouping", 20}, PageBreakBelow -> 
             False, DefaultNewInlineCellStyle -> "None", 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", Inherited}, 
             LanguageCategory -> "NaturalLanguage", CounterIncrements -> 
             "Subsubtitle", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}}, FontFamily -> "Helvetica", FontSize -> 14, 
             FontSlant -> "Italic"], 
            Cell[
             StyleData["Subsubtitle", "Presentation"], 
             CellMargins -> {{24, 10}, {20, 20}}, LineSpacing -> {1, 0}, 
             FontSize -> 24], 
            Cell[
             StyleData["Subsubtitle", "Condensed"], 
             CellMargins -> {{8, 10}, {8, 8}}, FontSize -> 12], 
            Cell[
             StyleData["Subsubtitle", "Printout"], 
             CellMargins -> {{2, 10}, {12, 8}}, FontSize -> 14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], CellDingbat -> "\[FilledSquare]", 
             CellMargins -> {{25, Inherited}, {8, 24}}, 
             CellGroupingRules -> {"SectionGrouping", 30}, PageBreakBelow -> 
             False, DefaultNewInlineCellStyle -> "None", 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", Inherited}, 
             LineSpacing -> {1, 7}, LanguageCategory -> "NaturalLanguage", 
             CounterIncrements -> "Section", 
             CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}}, 
             FontFamily -> "Helvetica", FontSize -> 16, FontWeight -> "Bold"], 
            Cell[
             StyleData["Section", "Presentation"], 
             CellMargins -> {{40, 10}, {11, 32}}, LineSpacing -> {1, 0}, 
             FontSize -> 24], 
            Cell[
             StyleData["Section", "Condensed"], 
             CellMargins -> {{18, Inherited}, {6, 12}}, FontSize -> 12], 
            Cell[
             StyleData["Section", "Printout"], 
             CellMargins -> {{13, 0}, {7, 22}}, FontSize -> 14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], CellDingbat -> "\[FilledSmallSquare]", 
             CellMargins -> {{22, Inherited}, {8, 20}}, 
             CellGroupingRules -> {"SectionGrouping", 40}, PageBreakBelow -> 
             False, DefaultNewInlineCellStyle -> "None", 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", Inherited}, 
             LanguageCategory -> "NaturalLanguage", CounterIncrements -> 
             "Subsection", CounterAssignments -> {{"Subsubsection", 0}}, 
             FontFamily -> "Times", FontSize -> 14, FontWeight -> "Bold"], 
            Cell[
             StyleData["Subsection", "Presentation"], 
             CellMargins -> {{36, 10}, {11, 32}}, LineSpacing -> {1, 0}, 
             FontSize -> 22], 
            Cell[
             StyleData["Subsection", "Condensed"], 
             CellMargins -> {{16, Inherited}, {6, 12}}, FontSize -> 12], 
            Cell[
             StyleData["Subsection", "Printout"], 
             CellMargins -> {{9, 0}, {7, 22}}, FontSize -> 12]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubsection"], CellDingbat -> 
             "\[FilledSmallSquare]", 
             CellMargins -> {{22, Inherited}, {8, 18}}, 
             CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
             False, DefaultNewInlineCellStyle -> "None", 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", Inherited}, 
             LanguageCategory -> "NaturalLanguage", CounterIncrements -> 
             "Subsubsection", FontFamily -> "Times", FontWeight -> "Bold"], 
            Cell[
             StyleData["Subsubsection", "Presentation"], 
             CellMargins -> {{34, 10}, {11, 26}}, LineSpacing -> {1, 0}, 
             FontSize -> 18], 
            Cell[
             StyleData["Subsubsection", "Condensed"], 
             CellMargins -> {{17, Inherited}, {6, 12}}, FontSize -> 10], 
            Cell[
             StyleData["Subsubsection", "Printout"], 
             CellMargins -> {{9, 0}, {7, 14}}, FontSize -> 11]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Body Text", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], CellMargins -> {{12, 10}, {7, 7}}, 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", Inherited}, 
             Hyphenation -> True, LineSpacing -> {1, 3}, CounterIncrements -> 
             "Text"], 
            Cell[
             StyleData["Text", "Presentation"], 
             CellMargins -> {{24, 10}, {10, 10}}, LineSpacing -> {1, 5}, 
             FontSize -> 16], 
            Cell[
             StyleData["Text", "Condensed"], CellMargins -> {{8, 10}, {6, 6}},
              LineSpacing -> {1, 1}, FontSize -> 11], 
            Cell[
             StyleData["Text", "Printout"], CellMargins -> {{2, 2}, {6, 6}}, 
             TextJustification -> 0.5, FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SmallText"], CellMargins -> {{12, 10}, {6, 6}}, 
             DefaultNewInlineCellStyle -> "None", Hyphenation -> True, 
             LineSpacing -> {1, 3}, LanguageCategory -> "NaturalLanguage", 
             CounterIncrements -> "SmallText", FontFamily -> "Helvetica", 
             FontSize -> 9], 
            Cell[
             StyleData["SmallText", "Presentation"], 
             CellMargins -> {{24, 10}, {8, 8}}, LineSpacing -> {1, 5}, 
             FontSize -> 12], 
            Cell[
             StyleData["SmallText", "Condensed"], 
             CellMargins -> {{8, 10}, {5, 5}}, LineSpacing -> {1, 2}, 
             FontSize -> 9], 
            Cell[
             StyleData["SmallText", "Printout"], 
             CellMargins -> {{2, 2}, {5, 5}}, TextJustification -> 0.5, 
             FontSize -> 7]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Input/Output", "Section"], 
         Cell[
         "The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). ", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Input"], CellMargins -> {{45, 10}, {5, 7}}, 
             Evaluatable -> True, CellGroupingRules -> "InputGrouping", 
             CellHorizontalScrolling -> True, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, DefaultFormatType -> 
             DefaultInputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, 
             AutoItalicWords -> {}, LanguageCategory -> "Mathematica", 
             FormatType -> InputForm, ShowStringCharacters -> True, 
             NumberMarks -> True, LinebreakAdjustments -> {0.85, 2, 10, 0, 1},
              CounterIncrements -> "Input", FontWeight -> "Bold"], 
            Cell[
             StyleData["Input", "Presentation"], 
             CellMargins -> {{72, Inherited}, {8, 10}}, LineSpacing -> {1, 0},
              FontSize -> 16], 
            Cell[
             StyleData["Input", "Condensed"], 
             CellMargins -> {{40, 10}, {2, 3}}, FontSize -> 11], 
            Cell[
             StyleData["Input", "Printout"], CellMargins -> {{39, 0}, {4, 6}},
              LinebreakAdjustments -> {0.85, 2, 10, 1, 1}, FontSize -> 9]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["PackageInput"], CellMargins -> {{45, 10}, {5, 7}}, 
             Evaluatable -> True, CellGroupingRules -> "InputGrouping", 
             CellHorizontalScrolling -> True, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, InitializationCell -> True, 
             DefaultFormatType -> DefaultInputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, 
             AutoItalicWords -> {}, LanguageCategory -> "Mathematica", 
             FormatType -> InputForm, ShowStringCharacters -> True, 
             NumberMarks -> True, LinebreakAdjustments -> {0.85, 2, 10, 0, 1},
              CounterIncrements -> "Input", FontWeight -> "Bold", Background -> 
             RGBColor[0.500008, 1, 0.566644]], 
            Cell[
             StyleData["PackageInput", "Presentation"], 
             CellMargins -> {{72, Inherited}, {8, 10}}, LineSpacing -> {1, 0},
              FontSize -> 16], 
            Cell[
             StyleData["PackageInput", "Condensed"], 
             CellMargins -> {{40, 10}, {2, 3}}, FontSize -> 11], 
            Cell[
             StyleData["PackageInput", "Printout"], 
             CellMargins -> {{39, 0}, {4, 6}}, 
             LinebreakAdjustments -> {0.85, 2, 10, 1, 1}, FontSize -> 9, 
             Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          StyleData["InputOnly"], Evaluatable -> True, CellGroupingRules -> 
          "InputGrouping", CellHorizontalScrolling -> True, DefaultFormatType -> 
          DefaultInputFormatType, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, LanguageCategory -> "Mathematica", 
          FormatType -> InputForm, ShowStringCharacters -> True, NumberMarks -> 
          True, LinebreakAdjustments -> {0.85, 2, 10, 0, 1}, 
          CounterIncrements -> "Input", StyleMenuListing -> None, FontWeight -> 
          "Bold"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Output"], CellMargins -> {{47, 10}, {7, 5}}, 
             CellEditDuplicate -> True, CellGroupingRules -> "OutputGrouping",
              CellHorizontalScrolling -> True, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, DefaultFormatType -> 
             DefaultOutputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, 
             AutoItalicWords -> {}, LanguageCategory -> None, FormatType -> 
             InputForm, CounterIncrements -> "Output"], 
            Cell[
             StyleData["Output", "Presentation"], 
             CellMargins -> {{72, Inherited}, {10, 8}}, LineSpacing -> {1, 0},
              FontSize -> 16], 
            Cell[
             StyleData["Output", "Condensed"], 
             CellMargins -> {{41, Inherited}, {3, 2}}, FontSize -> 11], 
            Cell[
             StyleData["Output", "Printout"], 
             CellMargins -> {{39, 0}, {6, 4}}, FontSize -> 9]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Message"], 
             CellMargins -> {{45, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "OutputGrouping", PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             DefaultFormatType -> DefaultOutputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, 
             AutoItalicWords -> {}, LanguageCategory -> None, FormatType -> 
             InputForm, CounterIncrements -> "Message", StyleMenuListing -> 
             None, FontSize -> 11, FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["Message", "Presentation"], 
             CellMargins -> {{72, Inherited}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 0}, FontSize -> 16], 
            Cell[
             StyleData["Message", "Condensed"], 
             CellMargins -> {{41, Inherited}, {Inherited, Inherited}}, 
             FontSize -> 11], 
            Cell[
             StyleData["Message", "Printout"], 
             CellMargins -> {{39, Inherited}, {Inherited, Inherited}}, 
             FontSize -> 7, FontColor -> GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Print"], 
             CellMargins -> {{45, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "OutputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             GeneratedCell -> True, CellAutoOverwrite -> True, ShowCellLabel -> 
             False, DefaultFormatType -> DefaultOutputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, 
             AutoItalicWords -> {}, LanguageCategory -> None, FormatType -> 
             InputForm, CounterIncrements -> "Print", StyleMenuListing -> 
             None], 
            Cell[
             StyleData["Print", "Presentation"], 
             CellMargins -> {{72, Inherited}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 0}, FontSize -> 16], 
            Cell[
             StyleData["Print", "Condensed"], 
             CellMargins -> {{41, Inherited}, {Inherited, Inherited}}, 
             FontSize -> 11], 
            Cell[
             StyleData["Print", "Printout"], 
             CellMargins -> {{39, Inherited}, {Inherited, Inherited}}, 
             FontSize -> 8]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Graphics"], 
             CellMargins -> {{4, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "GraphicsGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             DefaultFormatType -> DefaultOutputFormatType, LanguageCategory -> 
             None, FormatType -> InputForm, CounterIncrements -> "Graphics", 
             ImageMargins -> {{43, Inherited}, {Inherited, 0}}, 
             StyleMenuListing -> None, FontFamily -> "Courier", FontSize -> 
             10], 
            Cell[
             StyleData["Graphics", "Presentation"], 
             ImageMargins -> {{62, Inherited}, {Inherited, 0}}], 
            Cell[
             StyleData["Graphics", "Condensed"], 
             ImageMargins -> {{38, Inherited}, {Inherited, 0}}, Magnification -> 
             0.6], 
            Cell[
             StyleData["Graphics", "Printout"], 
             ImageMargins -> {{30, Inherited}, {Inherited, 0}}, Magnification -> 
             0.8]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CellLabel"], LanguageCategory -> None, 
             StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 
             9, FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["CellLabel", "Presentation"], FontSize -> 12], 
            Cell[
             StyleData["CellLabel", "Condensed"], FontSize -> 9], 
            Cell[
             StyleData["CellLabel", "Printout"], FontFamily -> "Courier", 
             FontSize -> 8, FontSlant -> "Italic", FontColor -> 
             GrayLevel[0]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Inline Formatting", "Section"], 
         Cell[
         "These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.", "Text"], 
         Cell[
          StyleData["RM"], StyleMenuListing -> None, FontWeight -> "Plain", 
          FontSlant -> "Plain"], 
         Cell[
          StyleData["BF"], StyleMenuListing -> None, FontWeight -> "Bold"], 
         Cell[
          StyleData["IT"], StyleMenuListing -> None, FontSlant -> "Italic"], 
         Cell[
          StyleData["TR"], StyleMenuListing -> None, FontFamily -> "Times", 
          FontWeight -> "Plain", FontSlant -> "Plain"], 
         Cell[
          StyleData["TI"], StyleMenuListing -> None, FontFamily -> "Times", 
          FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["TB"], StyleMenuListing -> None, FontFamily -> "Times", 
          FontWeight -> "Bold", FontSlant -> "Plain"], 
         Cell[
          StyleData["TBI"], StyleMenuListing -> None, FontFamily -> "Times", 
          FontWeight -> "Bold", FontSlant -> "Italic"], 
         Cell[
          StyleData["MR"], 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           StyleMenuListing -> None, FontFamily -> "Courier", FontWeight -> 
          "Plain", FontSlant -> "Plain"], 
         Cell[
          StyleData["MO"], 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           StyleMenuListing -> None, FontFamily -> "Courier", FontWeight -> 
          "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["MB"], 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           StyleMenuListing -> None, FontFamily -> "Courier", FontWeight -> 
          "Bold", FontSlant -> "Plain"], 
         Cell[
          StyleData["MBO"], 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           StyleMenuListing -> None, FontFamily -> "Courier", FontWeight -> 
          "Bold", FontSlant -> "Italic"], 
         Cell[
          StyleData["SR"], StyleMenuListing -> None, FontFamily -> 
          "Helvetica", FontWeight -> "Plain", FontSlant -> "Plain"], 
         Cell[
          StyleData["SO"], StyleMenuListing -> None, FontFamily -> 
          "Helvetica", FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["SB"], StyleMenuListing -> None, FontFamily -> 
          "Helvetica", FontWeight -> "Bold", FontSlant -> "Plain"], 
         Cell[
          StyleData["SBO"], StyleMenuListing -> None, FontFamily -> 
          "Helvetica", FontWeight -> "Bold", FontSlant -> "Italic"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SO10"], StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 10, FontWeight -> "Plain", FontSlant -> 
             "Italic"], 
            Cell[
             StyleData["SO10", "Printout"], StyleMenuListing -> None, 
             FontFamily -> "Helvetica", FontSize -> 7, FontWeight -> "Plain", 
             FontSlant -> "Italic"], 
            Cell[
             StyleData["SO10", "EnhancedPrintout"], StyleMenuListing -> None, 
             FontFamily -> "Futura", FontSize -> 7, FontWeight -> "Plain", 
             FontSlant -> "Italic"]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Formulas and Programming", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["InlineFormula"], CellMargins -> {{10, 4}, {0, 8}}, 
             CellHorizontalScrolling -> True, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Formula", ScriptLevel -> 1, SingleLetterItalics -> True], 
            Cell[
             StyleData["InlineFormula", "Presentation"], 
             CellMargins -> {{24, 10}, {10, 10}}, LineSpacing -> {1, 5}, 
             FontSize -> 16], 
            Cell[
             StyleData["InlineFormula", "Condensed"], 
             CellMargins -> {{8, 10}, {6, 6}}, LineSpacing -> {1, 1}, 
             FontSize -> 11], 
            Cell[
             StyleData["InlineFormula", "Printout"], 
             CellMargins -> {{2, 0}, {6, 6}}, FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayFormula"], 
             CellMargins -> {{42, Inherited}, {Inherited, Inherited}}, 
             CellHorizontalScrolling -> True, DefaultFormatType -> 
             DefaultInputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Formula", ScriptLevel -> 0, SingleLetterItalics -> True, 
             UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
            Cell[
             StyleData["DisplayFormula", "Presentation"], 
             LineSpacing -> {1, 5}, FontSize -> 16], 
            Cell[
             StyleData["DisplayFormula", "Condensed"], LineSpacing -> {1, 1}, 
             FontSize -> 11], 
            Cell[
             StyleData["DisplayFormula", "Printout"], FontSize -> 10]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Program"], CellFrame -> {{0, 0}, {0.5, 0.5}}, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, Hyphenation -> False, LanguageCategory -> "Formula", 
             ScriptLevel -> 1, FontFamily -> "Courier"], 
            Cell[
             StyleData["Program", "Presentation"], 
             CellMargins -> {{24, 10}, {10, 10}}, LineSpacing -> {1, 5}, 
             FontSize -> 16], 
            Cell[
             StyleData["Program", "Condensed"], 
             CellMargins -> {{8, 10}, {6, 6}}, LineSpacing -> {1, 1}, 
             FontSize -> 11], 
            Cell[
             StyleData["Program", "Printout"], 
             CellMargins -> {{2, 0}, {6, 6}}, FontSize -> 9]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Outline Styles", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Outline1"], CellMargins -> {{12, 10}, {7, 7}}, 
             CellGroupingRules -> {"SectionGrouping", 50}, 
             ParagraphIndent -> -38, CounterIncrements -> "Outline1", 
             FontSize -> 18, FontWeight -> "Bold", 
             CounterBoxOptions -> {CounterFunction :> CapitalRomanNumeral}], 
            Cell[
             StyleData["Outline1", "Printout"], 
             CounterBoxOptions -> {CounterFunction :> CapitalRomanNumeral}]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Outline2"], CellMargins -> {{59, 10}, {7, 7}}, 
             CellGroupingRules -> {"SectionGrouping", 60}, 
             ParagraphIndent -> -27, CounterIncrements -> "Outline2", 
             FontSize -> 15, FontWeight -> "Bold", 
             CounterBoxOptions -> {CounterFunction :> (Part[
                 CharacterRange["A", "Z"], #]& )}], 
            Cell[
             StyleData["Outline2", "Printout"], 
             CounterBoxOptions -> {CounterFunction :> (Part[
                 CharacterRange["A", "Z"], #]& )}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Outline3"], CellMargins -> {{108, 10}, {7, 7}}, 
             CellGroupingRules -> {"SectionGrouping", 70}, 
             ParagraphIndent -> -21, CounterIncrements -> "Outline3", 
             FontSize -> 12, 
             CounterBoxOptions -> {CounterFunction :> Identity}], 
            Cell[
             StyleData["Outline3", "Printout"], 
             CounterBoxOptions -> {CounterFunction :> Identity}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Outline4"], CellMargins -> {{158, 10}, {7, 7}}, 
             CellGroupingRules -> {"SectionGrouping", 80}, 
             ParagraphIndent -> -18, CounterIncrements -> "Outline4", 
             FontSize -> 10, CounterBoxOptions -> {CounterFunction :> (Part[
                 CharacterRange["a", "z"], #]& )}], 
            Cell[
             StyleData["Outline4", "Printout"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Hyperlink Styles", "Section"], 
         Cell[
         "The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Hyperlink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`NotebookLocate[#2]}]& ), ButtonNote -> 
               ButtonData}], 
            Cell[
             StyleData["Hyperlink", "Presentation"], FontSize -> 16], 
            Cell[
             StyleData["Hyperlink", "Condensed"], FontSize -> 11], 
            Cell[
             StyleData["Hyperlink", "Printout"], FontSize -> 10, 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
         "The following styles are for linking automatically to the on-line \
help system.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MainBookLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["MainBook", #]}]& )}], 
            Cell[
             StyleData["MainBookLink", "Presentation"], FontSize -> 16], 
            Cell[
             StyleData["MainBookLink", "Condensed"], FontSize -> 11], 
            Cell[
             StyleData["MainBookLink", "Printout"], FontSize -> 10, 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["AddOnsLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontFamily -> "Courier", 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["AddOns", #]}]& )}], 
            Cell[
             StyleData["AddOnsLink", "Presentation"], FontSize -> 16], 
            Cell[
             StyleData["AddOnsLink", "Condensed"], FontSize -> 11], 
            Cell[
             StyleData["AddOnsLink", "Printout"], FontSize -> 10, 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["RefGuideLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontFamily -> "Courier", 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["RefGuide", #]}]& )}], 
            Cell[
             StyleData["RefGuideLink", "Presentation"], FontSize -> 16], 
            Cell[
             StyleData["RefGuideLink", "Condensed"], FontSize -> 11], 
            Cell[
             StyleData["RefGuideLink", "Printout"], FontSize -> 10, 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["GettingStartedLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["GettingStarted", #]}]& )}], 
            Cell[
             StyleData["GettingStartedLink", "Presentation"], FontSize -> 16], 
            Cell[
             StyleData["GettingStartedLink", "Condensed"], FontSize -> 11], 
            Cell[
             StyleData["GettingStartedLink", "Printout"], FontSize -> 10, 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OtherInformationLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["OtherInformation", #]}]& )}], 
            Cell[
             StyleData["OtherInformationLink", "Presentation"], FontSize -> 
             16], 
            Cell[
             StyleData["OtherInformationLink", "Condensed"], FontSize -> 11], 
            
            Cell[
             StyleData["OtherInformationLink", "Printout"], FontSize -> 10, 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headers and Footers", "Section"], 
         Cell[
          StyleData["Header"], CellMargins -> {{0, 0}, {4, 1}}, 
          DefaultNewInlineCellStyle -> "None", LanguageCategory -> 
          "NaturalLanguage", StyleMenuListing -> None, FontSize -> 10, 
          FontSlant -> "Italic"], 
         Cell[
          StyleData["Footer"], CellMargins -> {{0, 0}, {0, 4}}, 
          DefaultNewInlineCellStyle -> "None", LanguageCategory -> 
          "NaturalLanguage", StyleMenuListing -> None, FontSize -> 9, 
          FontSlant -> "Italic"], 
         Cell[
          StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
          StyleMenuListing -> None, FontFamily -> "Times", FontSize -> 10]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Palette Styles", "Section"], 
         Cell[
         "The cells below define styles that define standard ButtonFunctions, \
for use in palette buttons.", "Text"], 
         Cell[
          StyleData["Paste"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, After]}]& )}], 
         Cell[
          StyleData["Evaluate"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               SelectionEvaluate[
                FrontEnd`InputNotebook[], All]}]& )}], 
         Cell[
          StyleData["EvaluateCell"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               FrontEnd`SelectionMove[
                FrontEnd`InputNotebook[], All, Cell, 1], 
               FrontEnd`SelectionEvaluateCreateCell[
                FrontEnd`InputNotebook[], All]}]& )}], 
         Cell[
          StyleData["CopyEvaluate"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`SelectionCreateCell[
                FrontEnd`InputNotebook[], All], 
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               FrontEnd`SelectionEvaluate[
                FrontEnd`InputNotebook[], All]}]& )}], 
         Cell[
          StyleData["CopyEvaluateCell"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`SelectionCreateCell[
                FrontEnd`InputNotebook[], All], 
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               FrontEnd`SelectionEvaluateCreateCell[
                FrontEnd`InputNotebook[], All]}]& )}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Placeholder Styles", "Section"], 
         Cell[
         "The cells below define styles useful for making placeholder objects \
in palette templates.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Placeholder"], Placeholder -> True, StyleMenuListing -> 
             None, FontSlant -> "Italic", FontColor -> 
             RGBColor[0.890623, 0.864698, 0.384756], 
             TagBoxOptions -> {
              Editable -> False, Selectable -> False, StripWrapperBoxes -> 
               False}], 
            Cell[
             StyleData["Placeholder", "Presentation"]], 
            Cell[
             StyleData["Placeholder", "Condensed"]], 
            Cell[
             StyleData["Placeholder", "Printout"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["PrimaryPlaceholder"], StyleMenuListing -> None, 
             DrawHighlighted -> True, FontSlant -> "Italic", Background -> 
             RGBColor[0.912505, 0.891798, 0.507774], 
             TagBoxOptions -> {
              Editable -> False, Selectable -> False, StripWrapperBoxes -> 
               False}], 
            Cell[
             StyleData["PrimaryPlaceholder", "Presentation"]], 
            Cell[
             StyleData["PrimaryPlaceholder", "Condensed"]], 
            Cell[
             StyleData["PrimaryPlaceholder", "Printout"]]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["FormatType Styles", "Section"], 
         Cell[
         "The cells below define styles that are mixed in with the styles of \
most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.", "Text"], 
         Cell[
          StyleData["CellExpression"], PageWidth -> Infinity, 
          CellMargins -> {{6, Inherited}, {Inherited, Inherited}}, 
          ShowCellLabel -> False, ShowSpecialCharacters -> False, 
          AllowInlineCells -> False, Hyphenation -> False, 
          AutoItalicWords -> {}, StyleMenuListing -> None, FontFamily -> 
          "Courier", FontSize -> 12, Background -> GrayLevel[1]], 
         Cell[
          StyleData["InputForm"], InputAutoReplacements -> {}, 
          AllowInlineCells -> False, Hyphenation -> False, StyleMenuListing -> 
          None, FontFamily -> "Courier"], 
         Cell[
          StyleData["OutputForm"], PageWidth -> Infinity, TextAlignment -> 
          Left, LineSpacing -> {0.6, 1}, StyleMenuListing -> None, FontFamily -> 
          "Courier"], 
         Cell[
          StyleData["StandardForm"], 
          InputAutoReplacements -> {
           "->" -> "\[Rule]", ":>" -> "\[RuleDelayed]", "<=" -> 
            "\[LessEqual]", ">=" -> "\[GreaterEqual]", "!=" -> "\[NotEqual]", 
            "==" -> "\[Equal]", Inherited}, LineSpacing -> {1.25, 0}, 
          StyleMenuListing -> None, FontFamily -> "Courier"], 
         Cell[
          StyleData["TraditionalForm"], 
          InputAutoReplacements -> {
           "->" -> "\[Rule]", ":>" -> "\[RuleDelayed]", "<=" -> 
            "\[LessEqual]", ">=" -> "\[GreaterEqual]", "!=" -> "\[NotEqual]", 
            "==" -> "\[Equal]", Inherited}, LineSpacing -> {1.25, 0}, 
          SingleLetterItalics -> True, TraditionalFunctionNotation -> True, 
          DelimiterMatching -> None, StyleMenuListing -> None], 
         Cell[
         "The style defined below is mixed in to any cell that is in an \
inline cell within another.", "Text"], 
         Cell[
          StyleData["InlineCell"], LanguageCategory -> "Formula", ScriptLevel -> 
          1, StyleMenuListing -> None], 
         Cell[
          StyleData["InlineCellEditing"], StyleMenuListing -> None, 
          Background -> RGBColor[1, 0.749996, 0.8]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Automatic Styles", "Section"], 
         Cell[
         "The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).", "Text"], 
         Cell[
          StyleData["UnmatchedBracket"], StyleMenuListing -> None, FontColor -> 
          RGBColor[0.760006, 0.330007, 0.8]]}, Closed]]}, Open]]}, Visible -> 
  False, FrontEndVersion -> 
  "7.0 for Mac OS X x86 (32-bit) (November 10, 2008)", StyleDefinitions -> 
  "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 101, 1, 144, "Title"],
Cell[671, 25, 116, 4, 118, "Subsubtitle"],
Cell[CellGroupData[{
Cell[812, 33, 25, 0, 72, "Section"],
Cell[840, 35, 149, 4, 58, "Text"],
Cell[992, 41, 940, 24, 436, "PackageInput"],
Cell[1935, 67, 127, 3, 58, "Text"],
Cell[2065, 72, 4293, 116, 1230, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[6395, 193, 32, 0, 40, "Section"],
Cell[6430, 195, 92, 2, 39, "Text"],
Cell[6525, 199, 421, 9, 176, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[6983, 213, 42, 0, 40, "Section"],
Cell[7028, 215, 148, 3, 58, "Text"],
Cell[7179, 220, 455, 8, 234, "PackageInput",
 InitializationCell->True],
Cell[7637, 230, 463, 8, 234, "PackageInput",
 InitializationCell->True],
Cell[8103, 240, 239, 5, 160, "PackageInput",
 InitializationCell->True],
Cell[8345, 247, 269, 6, 160, "PackageInput",
 InitializationCell->True],
Cell[8617, 255, 312, 6, 195, "PackageInput",
 InitializationCell->True],
Cell[8932, 263, 444, 8, 199, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[9413, 276, 31, 0, 40, "Section"],
Cell[9447, 278, 60, 0, 58, "Text"],
Cell[9510, 280, 108, 2, 90, "PackageInput",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[9643, 286, 39, 0, 94, "Subsection"],
Cell[9685, 288, 155, 3, 58, "Text"],
Cell[9843, 293, 132, 3, 90, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[10012, 301, 36, 0, 55, "Subsection"],
Cell[10051, 303, 161, 2, 58, "Text"],
Cell[10215, 307, 595, 15, 333, "PackageInput",
 InitializationCell->True],
Cell[10813, 324, 6486, 165, 1209, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[17336, 494, 39, 0, 55, "Subsection"],
Cell[17378, 496, 3175, 87, 729, "PackageInput"]
}, Closed]],
Cell[CellGroupData[{
Cell[20590, 588, 36, 0, 55, "Subsection"],
Cell[20629, 590, 3023, 82, 766, "PackageInput"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[23701, 678, 34, 0, 40, "Section"],
Cell[23738, 680, 64, 0, 58, "Text"],
Cell[23805, 682, 648, 16, 367, "PackageInput",
 InitializationCell->True]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
