(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    411017,      11647]
NotebookOptionsPosition[    390426,      11129]
NotebookOutlinePosition[    393521,      11208]
CellTagsIndexPosition[    393478,      11205]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Gaussian Derivative Package", "Title"],

Cell["\<\
Markus van Almsick
Technische Universiteit Eindhoven
\[Copyright]2010\
\>", "Subsubtitle"],

Cell["Version 3.1", "Text"],

Cell[CellGroupData[{

Cell["Prefix", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "TimeSamp", " ", "for", " ", "Package", " ", "Version", " ", "Control"}], 
   " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Unprotect", "[", "TimeStamp", "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"TimeStamp", "::", "usage"}], "=", 
     "\"\<TimeStamp[context] should be set to a Date[]-List indicating the \
version of the corresponding package.\>\""}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "TimeStamp", "[", "\"\<MathVisionTools`GaussianDerivative`\>\"", "]"}], 
    " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{"2010", ",", "11", ",", "14", ",", "15", ",", "35", ",", "0"}], 
     "}"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Protect", "[", "TimeStamp", "]"}], ";"}]}]}]], "PackageInput"],

Cell["\<\
The preamble of the package containing all kinds of remarks about authorship, \
contence, and copyright.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Name", ":", " ", "MathVisionTools`GaussianDerivative`"}]}], " ", 
   "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Author", ":", " ", 
     RowBox[{"Bart", " ", 
      RowBox[{"M", ".", "ter"}], " ", "Haar", " ", "Romeny", " ", 
      RowBox[{"Ph", ".", "D", ".", "and"}], " ", "Markus", " ", "van", " ", 
      "Almsick"}]}]}], "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"Email", " ", 
      RowBox[{"address", ":", " ", 
       RowBox[{"B", ".", 
        RowBox[{"terHaarRomeny", "@", "tue"}], ".", "nl"}]}]}]}], ",", " ", 
    RowBox[{"M", ".", "v", ".", 
     RowBox[{"Almsick", "@", "tue"}], ".", "nl"}]}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Context", ":", " ", "MathVisionTools`GaussianDerivative`"}]}], 
   "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Package", " ", 
     RowBox[{"Version", ":", " ", "3.1"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Mathematica", " ", 
     RowBox[{"Version", ":", " ", "7.0"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"Copyright", ":", " ", 
      RowBox[{
       RowBox[{"Copyright", " ", "2001"}], "-", "2007"}]}]}], ",", " ", 
    RowBox[{"Technische", " ", "Universiteit", " ", "Eindhoven"}]}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"Title", ":", " ", 
      RowBox[{"Gaussian", " ", "Kernel"}]}]}], ",", " ", 
    RowBox[{"Gaussian", " ", "Derivative"}], ",", " ", 
    RowBox[{"and", " ", "Gaussian", " ", "Filter"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"Summary", ":", " ", 
      RowBox[{
      "This", " ", "package", " ", "implements", " ", "the", " ", "Gaussian", 
       " ", "derivative", " ", "for", " ", "Scale", " ", "Space", " ", 
       RowBox[{
       "Theory", ".", " ", 
        "\"\<Front-End Vision and Multiscale Image Analysis\>\""}], " ", "by",
        " ", "Bart", " ", 
       RowBox[{"M", ".", "ter"}], " ", "Haar", " ", "Romeny", " ", "Kluwer", 
       " ", "Academic", " ", "Publishers"}]}]}], ",", "2001."}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"Keywords", ":", " ", "Gaussian"}]}], ",", " ", 
    RowBox[{"Gaussian", " ", "derivatives"}], ",", " ", "multiscale", ",", 
    " ", 
    RowBox[{"scale", "-", "space"}], ",", " ", 
    RowBox[{"computer", " ", "vision"}], ",", " ", 
    RowBox[{"differential", " ", "operator"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Requirements", ":", " ", "None"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{
     "Source", ":", " ", 
      "\"\<Front-End Vision and Multiscale Image Analysis\>\""}]}], ",", " ", 
    
    RowBox[{"by", " ", "Bart", " ", 
     RowBox[{"M", ".", "ter"}], " ", "Haar", " ", "Romeny", " ", "Kluwer", 
     " ", "Academic", " ", "Publishers"}], ",", "2003"}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"History", ":", " ", 
      RowBox[{"Version", " ", "1.0", " ", "by", " ", "Bart", " ", 
       RowBox[{"M", ".", "ter"}], " ", "Haar", " ", "Romeny", " ", "and", " ",
        "Markus", " ", "van", " ", "Almsick"}]}]}], ",", " ", 
    RowBox[{
    "October", " ", "2001", "\[IndentingNewLine]", "          ", "Version", 
     " ", "1.1", " ", "by", " ", "Bart", " ", 
     RowBox[{"M", ".", "ter"}], " ", "Haar", " ", "Romeny", " ", "and", " ", 
     "Markus", " ", "van", " ", "Almsick"}], ",", " ", 
    RowBox[{
    "May", " ", "2002", "\[IndentingNewLine]", "          ", "Version", " ", 
     "1.2", " ", "by", " ", "Bart", " ", 
     RowBox[{"M", ".", "ter"}], " ", "Haar", " ", "Romeny", " ", "and", " ", 
     "Markus", " ", "van", " ", "Almsick"}], ",", " ", 
    RowBox[{
    "Sept", " ", "2002", "\[IndentingNewLine]", "          ", "Version", " ", 
     "2.0", " ", "by", " ", "Bart", " ", 
     RowBox[{"M", ".", "ter"}], " ", "Haar", " ", "Romeny", " ", "and", " ", 
     "Markus", " ", "van", " ", "Almsick"}], ",", " ", 
    RowBox[{
    "Dec", " ", "2002", "\[IndentingNewLine]", "          ", "Version", " ", 
     "2.1", " ", "by", " ", "Bart", " ", 
     RowBox[{"M", ".", "ter"}], " ", "Haar", " ", "Romeny", " ", "and", " ", 
     "Markus", " ", "van", " ", "Almsick"}], ",", " ", 
    RowBox[{
    "Jan", " ", "2003", "\[IndentingNewLine]", "          ", "Version", " ", 
     "2.2", " ", "by", " ", "Bart", " ", 
     RowBox[{"M", ".", "ter"}], " ", "Haar", " ", "Romeny", " ", "and", " ", 
     "Markus", " ", "van", " ", "Almsick"}], ",", " ", 
    RowBox[{
    "Nov", " ", "2003", "\[IndentingNewLine]", "          ", "Version", " ", 
     "2.4", " ", "by", " ", "Bart", " ", 
     RowBox[{"M", ".", "ter"}], " ", "Haar", " ", "Romeny", " ", "and", " ", 
     "Markus", " ", "van", " ", "Almsick"}], ",", " ", 
    RowBox[{
    "Jan", " ", "2004", "\[IndentingNewLine]", "          ", "Version", " ", 
     "2.5", " ", "by", " ", "Bart", " ", 
     RowBox[{"M", ".", "ter"}], " ", "Haar", " ", "Romeny", " ", "and", " ", 
     "Markus", " ", "van", " ", "Almsick"}], ",", " ", 
    RowBox[{
    "April", " ", "2006", "\[IndentingNewLine]", "          ", "Version", " ",
      "2.6", " ", "by", " ", "Bart", " ", 
     RowBox[{"M", ".", "ter"}], " ", "Haar", " ", "Romeny", " ", "and", " ", 
     "Markus", " ", "van", " ", "Almsick"}], ",", " ", 
    RowBox[{
    "June", " ", "2007", "\[IndentingNewLine]", "          ", "Version", " ", 
     "2.8", " ", "by", " ", "Bart", " ", 
     RowBox[{"M", ".", "ter"}], " ", "Haar", " ", "Romeny", " ", "and", " ", 
     "Markus", " ", "van", " ", "Almsick"}], ",", " ", 
    RowBox[{
    "Feb", " ", "2008", "\[IndentingNewLine]", "          ", "Version", " ", 
     "2.9", " ", "by", " ", "Bart", " ", 
     RowBox[{"M", ".", "ter"}], " ", "Haar", " ", "Romeny", " ", "and", " ", 
     "Markus", " ", "van", " ", "Almsick"}], ",", " ", 
    RowBox[{
    "Oct", " ", "2009", "\[IndentingNewLine]", "          ", "Version", " ", 
     "3.0", " ", "by", " ", "Bart", " ", 
     RowBox[{"M", ".", "ter"}], " ", "Haar", " ", "Romeny", " ", "and", " ", 
     "Markus", " ", "van", " ", "Almsick"}], ",", " ", 
    RowBox[{
    "Dec", " ", "2009", "\[IndentingNewLine]", "          ", "Version", " ", 
     "3.1", " ", "by", " ", "Bart", " ", 
     RowBox[{"M", ".", "ter"}], " ", "Haar", " ", "Romeny", " ", "and", " ", 
     "Markus", " ", "van", " ", "Almsick"}], ",", " ", 
    RowBox[{"Dec", " ", "2010"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Limitations", ":"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Discussion", ":"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"To", " ", 
      RowBox[{"do", ":", "  ", 
       RowBox[{"Recursive", " ", "Implementation"}]}]}]}], ",", " ", 
    "Directional", ",", " ", "Parallel"}], " ", "*)"}]}]], "PackageInput",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Begin Package", "Section"],

Cell["\<\
Declaring the package and unlocking all symbols defined in the code.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"$VersionNumber", "\[GreaterEqual]", " ", "6"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"NotationPackageString", "=", "\"\<Notation`\>\""}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Notation`AutoLoadNotationPalette", " ", "=", " ", "False"}]}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"NotationPackageString", "=", "\"\<Utilities`Notation`\>\""}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{
      "Utilities`Notation`AutoLoadNotationPalette", " ", "=", " ", 
       "False"}]}]}], "\[IndentingNewLine]", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"BeginPackage", "[", "\[IndentingNewLine]", 
  RowBox[{
  "\"\<MathVisionTools`GaussianDerivative`\>\"", ",", "\[IndentingNewLine]", 
   "\"\<MathVisionTools`Common`MathVisionToolsCommon`\>\"", ",", 
   "\[IndentingNewLine]", "\"\<MathVisionTools`Convolve`\>\"", ",", 
   "\[IndentingNewLine]", "\"\<MathVisionTools`ImageFrame`\>\"", ",", 
   "\[IndentingNewLine]", "NotationPackageString"}], "\[IndentingNewLine]", 
  "]"}]}], "Input"],

Cell[BoxData[
 RowBox[{"BeginPackage", "[", "\[IndentingNewLine]", 
  RowBox[{
  "\"\<MathVisionTools`GaussianDerivative`\>\"", ",", "\[IndentingNewLine]", 
   "\"\<MathVisionTools`Common`MathVisionToolsCommon`\>\"", ",", 
   "\[IndentingNewLine]", "\"\<MathVisionTools`ImageFrame`\>\""}], 
  "\[IndentingNewLine]", "]"}]], "PackageInput"],

Cell[BoxData[
 RowBox[{"Unprotect", "[", "\[IndentingNewLine]", 
  RowBox[{
  "G", ",", "\[IndentingNewLine]", "NGaussianKernel", ",", 
   "\[IndentingNewLine]", "GaussianKernel", ",", "\[IndentingNewLine]", 
   "AngularGaussianKernel", ",", "\[IndentingNewLine]", "NGaussianDKernel", 
   ",", "\[IndentingNewLine]", "GaussianDKernel", ",", "\[IndentingNewLine]", 
   "GaussianD", ",", "\[IndentingNewLine]", "GaussianBlur", ",", 
   "\[IndentingNewLine]", "GaussianDerivative", ",", "\[IndentingNewLine]", 
   "GaussianDerivativeJet", ",", "\[IndentingNewLine]", 
   "GaussianDerivativeAt", ",", "\[IndentingNewLine]", "LocalMinimumMask", 
   ",", "\[IndentingNewLine]", "LocalMaximumMask", ",", "\[IndentingNewLine]",
    "ThresholdFilter", ",", "\[IndentingNewLine]", "ScaleTToSigma", ",", 
   "\[IndentingNewLine]", "SigmaToScaleT", ",", "\[IndentingNewLine]", 
   "Method", ",", "\[IndentingNewLine]", "KernelRange", ",", 
   "\[IndentingNewLine]", "ImageBoundary", ",", "\[IndentingNewLine]", 
   "Fourier", ",", "\[IndentingNewLine]", "Cyclic", ",", 
   "\[IndentingNewLine]", "Truncate", ",", "\[IndentingNewLine]", 
   "Reflective", ",", "\[IndentingNewLine]", "Constant"}], 
  "\[IndentingNewLine]", "]"}]], "PackageInput",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Online Help and Options", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"DefaultScaleParameter", "::", "usage"}], "=", 
   "\"\<The default linear scale parameter t = 1/2. Thus, the width or \
standard deviation of the Gaussian kernel is 1.\>\""}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SigmaToScaleT", "::", "usage"}], "=", 
    "\"\<SigmaToScaleT[\[Sigma]] converts the standard deviation \[Sigma] of \
the Gaussian kernel into the corresponding scale t.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ScaleTToSigma", "::", "usage"}], "=", 
    "\"\<ScaleTToSigma[t] converts the scale t into the corresponding \
standard deviation \[Sigma] of the Gaussian kernel.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"G", "::", "usage"}], "=", 
   "\"\<\\!\\(\\*SubscriptBox[\\(G\\), \\(t\\)]\\)[x] is a short input \
notation for GaussianKernel[t,x]. \\!\\(\\*SubsuperscriptBox[\\(G\\), \
\\(t\\), \\((n)\\)]\\)[x] is a short input notation for \
GaussianDKernel[t,n,x]. \\!\\(\\*SubsuperscriptBox[\\(G\\), \\(t\\), \\((nx, \
ny)\\)]\\)[x,y]and \\!\\(\\*SubsuperscriptBox[\\(G\\), \\(tx, ty\\), \\((nx, \
ny)\\)]\\)[x,y] denote the 2-dimensional case GaussianDKernel[t, {nx,ny}, \
{x,y}] and GaussianDKernel[{tx,ty}, {nx,ny}, {x,y}]. This generalizes to any \
dimension.\>\""}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GaussianKernel", "::", "usage"}], "=", 
   "\"\<GaussianKernel[t,x] renders the gaussian kernel numerically and \
symbolically. Note, that t is half the variance, which is the square of the \
Gaussian kernel width \[Sigma]. GaussianKernel generalizes to higher \
dimensions if t and x are Lists.\>\""}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"AngularGaussianKernel", "::", "usage"}], "=", 
   "\"\<AngularGaussianKernel[t,\[Alpha]] renders the angular gaussian kernel \
numerically and symbolically. The angular kernel is the Greens function of \
the diffusion equation on the interval [-\[Pi],\[Pi]] with periodic boundary \
conditions. Note, that t is half the variance, which is the square of the \
Gaussian kernel width \[Sigma].\>\""}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"NGaussianKernel", "::", "usage"}], "=", 
   "\"\<NGaussianKernel[t,x] renders the gaussian kernel numerically for Real \
t and x with compiled code. Note that t is half the variance, which is the \
square of the Gaussian kernel width \[Sigma].\>\""}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"GaussianDKernel", "::", "usage"}], "=", 
   "\"\<GaussianDKernel[t,n,x]. Note that t is half the variance, which is \
the square of the Gaussian kernel width \[Sigma]. n is the derivative order. \
GaussianDKernel generalizes to higher dimensions if t, n and x are \
Lists.\>\""}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"NGaussianDKernel", "::", "usage"}], "=", 
   "\"\<NGaussianDKernel[n][t,x] renders the \\!\\(\\*SuperscriptBox[\\(n\\), \
\\(th\\)]\\) derivative of the gaussian kernel numerically for non-negative \
Integer n and Real t and x with compiled code. Note that t is half the \
variance, which is the square of the Gaussian kernel width \[Sigma].\>\""}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"GaussianD", "::", "usage"}], "=", 
   "\"\<GaussianD[f,{x,t,n}] performs the \\!\\(\\*SuperscriptBox[\\(n\\), \
\\(th\\)]\\) Gaussian partial derivation on function f with respect to x. The \
Gaussian kernel variance is 2t. GaussianD[f,{x,\\!\\(\\*SubscriptBox[\\(t\\), \
\\(x\\)]\\),\\!\\(\\*SubscriptBox[\\(n\\), \
\\(x\\)]\\)},{y,\\!\\(\\*SubscriptBox[\\(t\\), \
\\(y\\)]\\),\\!\\(\\*SubscriptBox[\\(n\\), \\(y\\)]\\)},...] is the \
\\!\\(\\*SubsuperscriptBox[\\(n\\), \\(x\\), \\(th\\)]\\) Gaussian partial \
derivation with respect to x, the \\!\\(\\*SubsuperscriptBox[\\(n\\), \
\\(y\\), \\(th\\)]\\) Gaussian partial derivation with respect to y, and so \
on.\>\""}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"GaussianBlur", "::", "usage"}], "=", 
   "\"\<GaussianBlur[t][f] represents the Gaussian blur of function f at \
scale t, equivalent to GaussianDerivative[{t,0},{t,0},...][f]. GaussianBlur[{\
\\!\\(\\*SubscriptBox[\\(t\\), \\(x\\)]\\),\\!\\(\\*SubscriptBox[\\(t\\), \
\\(y\\)]\\),...}][f] represents the Gaussian blur of function f with a \
Gaussian kernel variance of 2\\!\\(\\*SubscriptBox[\\(t\\), \\(x\\)]\\) in \
x-direction, 2\\!\\(\\*SubscriptBox[\\(t\\), \\(y\\)]\\) in y-direction, and \
so forth.\>\""}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"GaussianDerivative", "::", "usage"}], "=", 
   "\"\<GaussianDerivative[{t,n}][f] represents the n-th order Gaussian \\\n\
derivative of function f at scale t, similar to Derivative[n][f] \\\n\
representing f'. GaussianDerivative[{\\!\\(\\*SubscriptBox[\\(t\\), \\\n\
\\(x\\)]\\),\\!\\(\\*SubscriptBox[\\(n\\), \
\\(x\\)]\\)},{\\!\\(\\*SubscriptBox[\\(t\\), \\\n\
\\(y\\)]\\),\\!\\(\\*SubscriptBox[\\(n\\), \\(y\\)]\\)},...][f] denotes the \
\\\n(\\!\\(\\*SubscriptBox[\\(n\\), \
\\(x\\)]\\),\\!\\(\\*SubscriptBox[\\(n\\), \\\n\
\\(y\\)]\\),...\\!\\(\\*SuperscriptBox[\\()\\), \\(th\\)]\\) Gaussian \
derivative of \\\na higher dimensional function f. Hereby, the Gaussian \
kernel variance is \\\n2\\!\\(\\*SubscriptBox[\\(t\\), \\(x\\)]\\) in x- and \
2\\!\\(\\*SubscriptBox[\\(t\\), \\\n\\(y\\)]\\) in y-direction. \
GaussianDerivative[{\\!\\(\\*SubscriptBox[\\(t\\), \\\n\
\\(x\\)]\\),\\!\\(\\*SubscriptBox[\\(n\\), \
\\(x\\)]\\)},{\\!\\(\\*SubscriptBox[\\(t\\), \\\n\
\\(y\\)]\\),\\!\\(\\*SubscriptBox[\\(n\\), \\(y\\)]\\)},...][img] also acts \
on \\\ndiscrete arrays of numeric values that represent images or \\\n\
higher-dimensional datasets. \\\n\
GaussianDerivative[{\\!\\(\\*SubscriptBox[\\(t\\), \\\n\
\\(x\\)]\\),\\!\\(\\*SubscriptBox[\\(n\\), \\(x\\)]\\),\\!\\(\\*SubscriptBox[\
\\(s\\), \\\n\\(x\\)]\\)},{\\!\\(\\*SubscriptBox[\\(t\\), \
\\(y\\)]\\),\\!\\(\\*SubscriptBox[\\(n\\), \\\n\
\\(y\\)]\\),\\!\\(\\*SubscriptBox[\\(s\\), \\(y\\)]\\)},...][img] renders \\\n\
derivatives shifted by s in units of scale t.\>\""}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GaussianDerivativeJet", "::", "usage"}], "=", 
   "\"\<GaussianDerivativeJet[t,n][img] provides a jet of all Gaussian \
derivatives of total order n at scale t.\>\""}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GaussianDerivativeAt", "::", "usage"}], "=", 
   "\"\<GaussianDerivativeAt[{x,\\!\\(\\*SubscriptBox[\\(t\\), \
\\(x\\)]\\),\\!\\(\\*SubscriptBox[\\(n\\), \
\\(x\\)]\\)},{y,\\!\\(\\*SubscriptBox[\\(t\\), \
\\(y\\)]\\),\\!\\(\\*SubscriptBox[\\(n\\), \\(y\\)]\\)},...][img] repesents \
the (\\!\\(\\*SubscriptBox[\\(n\\), \
\\(x\\)]\\),\\!\\(\\*SubscriptBox[\\(n\\), \\(y,  ... \
\\)]\\)\\!\\(\\*SuperscriptBox[\\()\\), \\(th\\)]\\) Gaussian derivative of \
image img at the specified location (x,y,...) in scale space. The Gaussian \
kernel variance is 2\\!\\(\\*SubscriptBox[\\(t\\), \\(x\\)]\\) in x- and 2\\!\
\\(\\*SubscriptBox[\\(t\\), \\(y\\)]\\) in y-direction. To determine Gaussian \
derivatives at more than one location enter \
GaussianDerivativeAt[{{x1,\\!\\(\\*SubscriptBox[\\(t\\), \
\\(x1\\)]\\),\\!\\(\\*SubscriptBox[\\(n\\), \
\\(x1\\)]\\)},{y1,\\!\\(\\*SubscriptBox[\\(t\\), \
\\(y1\\)]\\),\\!\\(\\*SubscriptBox[\\(n\\), \
\\(y1\\)]\\)},...},{{x2,\\!\\(\\*SubscriptBox[\\(t\\), \
\\(x2\\)]\\),\\!\\(\\*SubscriptBox[\\(n\\), \
\\(x2\\)]\\)},{y2,\\!\\(\\*SubscriptBox[\\(t\\), \
\\(y2\\)]\\),\\!\\(\\*SubscriptBox[\\(n\\), \
\\(y2\\)]\\)},...},...][img].\>\""}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"LocalMinimumMask", "::", "usage"}], " ", "=", " ", 
    "\"\<LocalMinimumMask[img] renders an image mask of 0s and 1s. The 1s are \
located at positions of minima where all immediate and diagonal neighboring \
pixels exhibit larger values.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"LocalMaximumMask", "::", "usage"}], " ", "=", " ", 
    "\"\<LocalMaximumMask[img] renders an image mask of 0s and 1s. The 1s are \
located at positions of maxima where all immediate and diagonal neighboring \
pixels exhibit smaller values.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ThresholdFilter", "::", "usage"}], "=", 
    "\"\<ThresholdFilter[img] renders all pixel values below 0 as 0. \
ThresholdFilter[c][img] renders all pixel values below c as 0.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"KernelRange", "::", "usage"}], "=", 
   "\"\<KernelRange is an option of GaussianD and GaussianDerivative. It \
determines the default range of the kernel used in the convolution.\>\""}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"ImageBoundary", "-", "Option"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Head", "[", 
      RowBox[{"ImageBoundary", "::", "usage"}], "]"}], "===", "MessageName"}],
     ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ImageBoundary", "::", "usage"}], "=", 
     "\"\<ImageBoundary is an option of GaussianD and GaussianDerivative \
working with the Convolve method. ImageBoundary determines the handling of an \
image frame in a convolution.\>\""}], ",", "\[IndentingNewLine]", 
    RowBox[{"If", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Not", "[", 
       RowBox[{"StringMatchQ", "[", 
        RowBox[{
         RowBox[{"ImageBoundary", "::", "usage"}], ",", 
         "\"\<*GaussianDerivative*\>\""}], "]"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ImageBoundary", "::", "usage"}], "=", 
       RowBox[{
        RowBox[{"ImageBoundary", "::", "usage"}], "<>", 
        "\"\<\\nImageBoundary is also an option of GaussianD and \
GaussianDerivative working with the Convolve method. ImageBoundary determines \
the handling of an image frame in a convolution.\>\""}]}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Convolve", "-", "Option"}], " ", "*)"}]}], "\[IndentingNewLine]", 

 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Head", "[", 
      RowBox[{"Convolve", "::", "usage"}], "]"}], "===", "MessageName"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Convolve", "::", "usage"}], "=", 
     "\"\<Is a value for the GaussianDerivative option Method. It calls upon \
the ListConvolve command to perform the convolution of the Gaussian \
derivation.\>\""}], ",", "\[IndentingNewLine]", 
    RowBox[{"If", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Not", "[", 
       RowBox[{"StringMatchQ", "[", 
        RowBox[{
         RowBox[{"Convolve", "::", "usage"}], ",", 
         "\"\<*GaussianDerivative*\>\""}], "]"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Convolve", "::", "usage"}], "=", 
       RowBox[{
        RowBox[{"Convolve", "::", "usage"}], "<>", 
        "\"\<\\nIt is also a value for the GaussianDerivative option Method. \
It calls upon the ListConvolve command to perform the convolution of the \
Gaussian derivation.\>\""}]}]}], "\[IndentingNewLine]", "]"}]}], 
   "\[IndentingNewLine]", "]"}], "\n", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Fourier", "-", "Option"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Not", "[", 
     RowBox[{"StringMatchQ", "[", 
      RowBox[{
       RowBox[{"Fourier", "::", "usage"}], ",", 
       "\"\<*GaussianDerivative*\>\""}], "]"}], "]"}], ",", 
    RowBox[{
     RowBox[{"Fourier", "::", "usage"}], "=", 
     RowBox[{
      RowBox[{"Fourier", "::", "usage"}], "<>", 
      "\"\<\\nFourier is also an option value for the GaussianDerivative \
Method. The convolution of the Gaussian derivative is performed via \
multiplication in the Fourier domain.\>\""}]}]}], "\[IndentingNewLine]", 
   "]"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Cyclic", "-", "Option"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Head", "[", 
      RowBox[{"Cyclic", "::", "usage"}], "]"}], "===", "MessageName"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Cyclic", "::", "usage"}], "=", 
     "\"\<Is a value for the GaussianDerivative option ImageBoundary. It \
calls upon the ListConvolve command to perform a cyclic convolution to \
maintain the image size.\>\""}], ",", "\[IndentingNewLine]", 
    RowBox[{"If", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Not", "[", 
       RowBox[{"StringMatchQ", "[", 
        RowBox[{
         RowBox[{"Cyclic", "::", "usage"}], ",", 
         "\"\<*GaussianDerivative*\>\""}], "]"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Cyclic", "::", "usage"}], "=", 
       RowBox[{
        RowBox[{"Cyclic", "::", "usage"}], "<>", 
        "\"\<\\nIt is also a value for the GaussianDerivative option \
ImageBoundary. It calls upon the ListConvolve command to perform a cyclic \
convolution to maintain the image size.\>\""}]}]}], "\[IndentingNewLine]", 
     "]"}]}], "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Truncate", "-", "Option"}], " ", "*)"}]}], "\[IndentingNewLine]", 

 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Head", "[", 
      RowBox[{"Truncate", "::", "usage"}], "]"}], "===", "MessageName"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Truncate", "::", "usage"}], "=", 
     "\"\<Is a value for the GaussianDerivative option ImageBoundary. It \
calls upon the ListConvolve command to truncate the incomplete convolution of \
the Gaussian kernel at the image boundary.\>\""}], ",", "\[IndentingNewLine]", 
    RowBox[{"If", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Not", "[", 
       RowBox[{"StringMatchQ", "[", 
        RowBox[{
         RowBox[{"Truncate", "::", "usage"}], ",", 
         "\"\<*GaussianDerivative*\>\""}], "]"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Truncate", "::", "usage"}], "=", 
       RowBox[{
        RowBox[{"Truncate", "::", "usage"}], "<>", 
        "\"\<\\nIt is also a value for the GaussianDerivative option \
ImageBoundary. It calls upon the ListConvolve command to truncate the \
incomplete convolution of the Gaussian kernel at the image \
boundary.\>\""}]}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
   "]"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Reflective", "-", "Option"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Head", "[", 
      RowBox[{"Reflective", "::", "usage"}], "]"}], "===", "MessageName"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Reflective", "::", "usage"}], "=", 
     "\"\<Is a value for the GaussianDerivative option ImageBoundary. It \
calls upon the ListConvolve command to ap-/prepend the reflected image on \
each image boundary before performing the convolution of the Gaussian kernel.\
\>\""}], ",", "\[IndentingNewLine]", 
    RowBox[{"If", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Not", "[", 
       RowBox[{"StringMatchQ", "[", 
        RowBox[{
         RowBox[{"Reflective", "::", "usage"}], ",", 
         "\"\<*GaussianDerivative*\>\""}], "]"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Reflective", "::", "usage"}], "=", 
       RowBox[{
        RowBox[{"Reflective", "::", "usage"}], "<>", 
        "\"\<\\nIt is also a value for the GaussianDerivative option \
ImageBoundary. It calls upon the ListConvolve command to ap-/prepend the \
reflected image on each image boundary before performing the convolution of \
the Gaussian kernel.\>\""}]}]}], "\[IndentingNewLine]", "]"}]}], 
   "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Constant", "-", "Option"}], " ", "*)"}]}], "\n", 
 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Not", "[", 
     RowBox[{"StringMatchQ", "[", 
      RowBox[{
       RowBox[{"Constant", "::", "usage"}], ",", 
       "\"\<*GaussianDerivative*\>\""}], "]"}], "]"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Constant", "::", "usage"}], "=", 
     RowBox[{
      RowBox[{"Constant", "::", "usage"}], "<>", 
      "\"\<\\nIt is also a value for the GaussianDerivative option \
ImageBoundary. It calls upon the ListConvolve to extend the value of each \
boundary pixel to infinity.\>\""}]}]}], "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Options", "[", "GaussianD", "]"}], "=", 
    RowBox[{"{", 
     RowBox[{"Assumptions", "\[RuleDelayed]", " ", "$Assumptions"}], "}"}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Options", "[", "GaussianDerivative", "]"}], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"KernelRange", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"Method", "\[Rule]", "Convolve"}], ",", 
      RowBox[{"ImageBoundary", "\[Rule]", "Cyclic"}], ",", " ", 
      RowBox[{"WorkingPrecision", "\[Rule]", " ", 
       RowBox[{"Log", "[", 
        RowBox[{"10", ",", 
         RowBox[{"2", "^", "16."}]}], "]"}]}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Options", "[", "GaussianDerivativeAt", "]"}], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"KernelRange", "\[Rule]", "Automatic"}], ",", 
      RowBox[{"ImageBoundary", "\[Rule]", "Cyclic"}], ",", " ", 
      RowBox[{"WorkingPrecision", "\[Rule]", " ", 
       RowBox[{"Log", "[", 
        RowBox[{"10", ",", 
         RowBox[{"2", "^", "16."}]}], "]"}]}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Options", "[", "LocalMinimumMask", "]"}], "=", 
    RowBox[{"{", 
     RowBox[{"ImageBoundary", "\[Rule]", "Cyclic"}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "LocalMaximumMask", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"ImageBoundary", "\[Rule]", "Cyclic"}], "}"}]}], 
  ";"}]}], "PackageInput",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Package Code", "Section"],

Cell["Starting the private context of the package.", "Text"],

Cell[BoxData[
 RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}]], "PackageInput",
 InitializationCell->True],

Cell["\<\
Open the palette for Gaussian Derivatives if started from a local kernel.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Not", "[", "MathVisionTools`$RemoteOperation", "]"}], "\[And]", 
     " ", 
     RowBox[{"Not", "[", "MathVisionTools`$ParallelOperation", "]"}]}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{"NotebookOpen", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"#", "=!=", 
          RowBox[{"{", "}"}]}], ",", 
         RowBox[{"First", "[", "#", "]"}]}], "]"}], "&"}], "[", 
      RowBox[{"FileNames", "[", 
       RowBox[{"\"\<GaussianDerivativePalette.nb\>\"", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"ToFileName", "[", 
           RowBox[{"{", 
            RowBox[{
            "$UserAddOnsDirectory", ",", "\"\<Applications\>\"", ",", 
             "\"\<MathVisionTools\>\"", ",", "\"\<FrontEnd\>\"", ",", 
             "\"\<Palettes\>\""}], "}"}], "]"}], ",", 
          RowBox[{"ToFileName", "[", 
           RowBox[{"{", 
            RowBox[{
            "$AddOnsDirectory", ",", "\"\<Applications\>\"", ",", 
             "\"\<MathVisionTools\>\"", ",", "\"\<FrontEnd\>\"", ",", 
             "\"\<Palettes\>\""}], "}"}], "]"}]}], "}"}]}], "]"}], "]"}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}], 
  ";"}]], "PackageInput"],

Cell[CellGroupData[{

Cell["Gaussian Kernel", "Subsection"],

Cell[TextData[{
 StyleBox["NOTE",
  FontWeight->"Bold"],
 ": we use the linear scale parameter ",
 Cell[BoxData[
  RowBox[{"t", " ", "=", " ", 
   RowBox[{
    FractionBox["2", "\[Tau]"], " ", 
    SuperscriptBox["\[Sigma]", "2"]}]}]]],
 " to denote the width of the Gaussian bell shape kernel. \[Sigma]  is the \
standard deviation and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Sigma]", "2"], TraditionalForm]]],
 " the variance of the kernel."
}], "Text",
 Background->RGBColor[1, 0, 0]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Gaussian", " ", "Kernel"}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Tau]", " ", "=", " ", "4"}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "global", " ", "factor", " ", "for", " ", "the", " ", "scaling", " ", 
      "parameter", " ", "t"}], ",", " ", 
     RowBox[{"default", " ", "is", " ", "4", " ", 
      RowBox[{"(", 
       RowBox[{"or", " ", "1"}], ")"}]}]}], " ", "*)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefaultScaleParameter", "=", 
     RowBox[{"2", "/", "\[Tau]"}]}], ";"}]}]}]], "PackageInput",
 InitializationCell->True],

Cell[BoxData[""], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ScaleTToSigma", "[", "t_", "]"}], " ", ":=", " ", 
  SqrtBox[
   RowBox[{"t", "/", "DefaultScaleParameter"}]]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SigmaToScaleT", "[", "\[Sigma]_", "]"}], ":=", 
  RowBox[{"DefaultScaleParameter", " ", 
   SuperscriptBox["\[Sigma]", "2"]}]}]], "PackageInput"],

Cell[CellGroupData[{

Cell["Numeric Implementation", "Subsubsection"],

Cell["\<\
Implementing a compiled version of the Gaussian kernel to speed up evaluation \
by a factor 3.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Numeric", " ", "Implementation"}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"NGaussianKernel", "=", 
     RowBox[{"Compile", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"t", ",", "_Real"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"t", "===", "0."}], ",", 
         RowBox[{"DiracDelta", "[", "x", "]"}], ",", 
         RowBox[{
          RowBox[{"Exp", "[", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"x", "^", "2"}]}], "/", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", " ", "t"}], ")"}]}], "]"}], "/", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"Pi", " ", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", " ", "t"}], ")"}]}], "]"}]}]}], "]"}]}], 
      "]"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"GaussianKernel", "[", "0", "]"}], "=", 
     RowBox[{"1", "/", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Pi", " ", 
        RowBox[{"(", 
         RowBox[{"\[Tau]", " ", "DefaultScaleParameter"}], ")"}]}], "]"}]}]}],
     ";"}], "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"GaussianKernel", "[", 
     RowBox[{"x_", "?", "NumberQ"}], "]"}], ":=", 
    RowBox[{"NGaussianKernel", "[", 
     RowBox[{"DefaultScaleParameter", ",", "x"}], "]"}]}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"GaussianKernel", "[", 
      RowBox[{
       RowBox[{"0", "|", "0."}], ",", 
       RowBox[{"x_", "?", "NumberQ"}]}], "]"}], "=", 
     RowBox[{"DiracDelta", "[", "x", "]"}]}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"GaussianKernel", "[", 
     RowBox[{
      RowBox[{"t_", "?", "NumberQ"}], ",", 
      RowBox[{"x_", "?", "NumberQ"}]}], "]"}], ":=", 
    RowBox[{"NGaussianKernel", "[", 
     RowBox[{"t", ",", "x"}], "]"}]}]}]}]], "PackageInput",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Symbolic Implementation", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Symbolic", " ", "Implementation"}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"GaussianKernel", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", "x__", "}"}]}], "]"}], "=", 
     RowBox[{"DiracDelta", "[", "x", "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"GaussianKernel", "[", 
      RowBox[{"0", ",", "x_"}], "]"}], "=", 
     RowBox[{"DiracDelta", "[", "x", "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"GaussianKernel", "[", 
      RowBox[{
       RowBox[{"t_:", "DefaultScaleParameter"}], ",", "x_"}], "]"}], "=", 
     RowBox[{
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"x", "^", "2"}]}], "/", 
        RowBox[{"(", 
         RowBox[{"\[Tau]", " ", "t"}], ")"}]}], "]"}], "/", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Pi", " ", 
        RowBox[{"(", 
         RowBox[{"\[Tau]", " ", "t"}], ")"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{"GaussianKernel", "/:", 
    RowBox[{
     RowBox[{"Derivative", "[", 
      RowBox[{"0", ",", "n_"}], "]"}], "[", "GaussianKernel", "]"}], ":=", 
    RowBox[{
     RowBox[{"GaussianDKernel", "[", 
      RowBox[{"#1", ",", "n", ",", "#2"}], "]"}], "&"}]}]}]}]], "PackageInput",\

 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Multidimensional Implementation", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Multidimensional", " ", "Implementation"}], " ", "*)"}], 
  "\[IndentingNewLine]", "\n", 
  RowBox[{
   RowBox[{
    RowBox[{"GaussianKernel", "[", "x_List", "]"}], ":=", 
    RowBox[{"Apply", "[", 
     RowBox[{"Times", ",", 
      RowBox[{"Map", "[", 
       RowBox[{"GaussianKernel", ",", "x"}], "]"}]}], "]"}]}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{"GaussianKernel", "[", 
     RowBox[{"t_List", ",", "x_List"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"Inner", "[", 
      RowBox[{"GaussianKernel", ",", "t", ",", "x", ",", "Times"}], "]"}], "/;", 
     RowBox[{
      RowBox[{"Dimensions", "[", "t", "]"}], "\[Equal]", 
      RowBox[{"Dimensions", "[", "x", "]"}]}]}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"GaussianKernel", "[", 
     RowBox[{"t_", ",", "x_List"}], "]"}], ":=", 
    RowBox[{"Apply", "[", 
     RowBox[{"Times", ",", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"GaussianKernel", "[", 
          RowBox[{"t", ",", "#"}], "]"}], "&"}], ",", "x"}], "]"}]}], 
     "]"}]}]}]}]], "PackageInput",
 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["GaussianKernel Input Notation", "Subsubsection"],

Cell[BoxData[
 RowBox[{"Notation", "[", 
  RowBox[{
   TagBox[
    RowBox[{"G", "[", "x__", "]"}],
    "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
   TagBox[
    RowBox[{"GaussianKernel", "[", 
     RowBox[{"{", "x__", "}"}], "]"}],
    "NotationTemplateTag"]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"GaussianKernel", " ", "Input", " ", "Notation"}], " ", "*)"}], 
  "\n", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{
        "lhs___", ",", "\"\<G\>\"", ",", "\"\<[\>\"", ",", "x__", ",", 
         "\"\<]\>\"", ",", "rhs___"}], "}"}], "]"}], ",", "StandardForm"}], 
     "]"}], ":=", 
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{"lhs", ",", 
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<GaussianKernel\>\"", ",", "\"\<[\>\"", ",", 
            RowBox[{"RowBox", "[", 
             RowBox[{"{", 
              RowBox[{"\"\<{\>\"", ",", 
               RowBox[{"stripSpuriousRowBox", "[", "x", "]"}], ",", 
               "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<]\>\""}], "}"}], "]"}], 
         ",", "rhs"}], "}"}], "]"}], ",", "StandardForm"}], "]"}]}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MakeBoxes", "[", 
     RowBox[{
      RowBox[{"GaussianKernel", "[", 
       RowBox[{"{", "x__", "}"}], "]"}], ",", "StandardForm"}], "]"}], ":=", 
    RowBox[{"RowBox", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<G\>\"", ",", "\"\<[\>\"", ",", 
       RowBox[{"makeHeldRowBoxOfBoxes", "[", 
        RowBox[{
         RowBox[{"{", "x", "}"}], ",", "StandardForm", ",", "None"}], "]"}], 
       ",", "\"\<]\>\""}], "}"}], "]"}]}]}]}]], "PackageInput",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"Notation", "[", 
  RowBox[{
   TagBox[
    RowBox[{"G", "[", "x_", "]"}],
    "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
   TagBox[
    RowBox[{"GaussianKernel", "[", "x_", "]"}],
    "NotationTemplateTag"]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"GaussianKernel", " ", "Input", " ", "Notation"}], " ", "*)"}], 
  "\n", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{
        "lhs___", ",", "\"\<G\>\"", ",", "\"\<[\>\"", ",", "x_", ",", 
         "\"\<]\>\"", ",", "rhs___"}], "}"}], "]"}], ",", "StandardForm"}], 
     "]"}], ":=", 
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{"lhs", ",", 
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{
           "\"\<GaussianKernel\>\"", ",", "\"\<[\>\"", ",", "x", ",", 
            "\"\<]\>\""}], "}"}], "]"}], ",", "rhs"}], "}"}], "]"}], ",", 
      "StandardForm"}], "]"}]}], "\n", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MakeBoxes", "[", 
     RowBox[{
      RowBox[{"GaussianKernel", "[", "x_", "]"}], ",", "StandardForm"}], 
     "]"}], ":=", 
    RowBox[{"RowBox", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<G\>\"", ",", "\"\<[\>\"", ",", 
       RowBox[{"MakeBoxes", "[", 
        RowBox[{"x", ",", "StandardForm"}], "]"}], ",", "\"\<]\>\""}], "}"}], 
     "]"}]}]}]}]], "PackageInput",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{"Notation", "[", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["G", "t_"], "[", "x__", "]"}],
    "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
   TagBox[
    RowBox[{"GaussianKernel", "[", 
     RowBox[{"t_", ",", 
      RowBox[{"{", "x__", "}"}]}], "]"}],
    "NotationTemplateTag"]}], "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{"lhs___", ",", 
        RowBox[{"SubscriptBox", "[", 
         RowBox[{"\"\<G\>\"", ",", "t_"}], "]"}], ",", "\"\<[\>\"", ",", 
        "x_RowBox", ",", "\"\<]\>\"", ",", "rhs___"}], "}"}], "]"}], ",", 
     "StandardForm"}], "]"}], ":=", 
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{"lhs", ",", 
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<GaussianKernel\>\"", ",", "\"\<[\>\"", ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{"t", ",", "\"\<,\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"stripSpuriousRowBox", "[", "x", "]"}], ",", 
                 "\"\<}\>\""}], "}"}], "]"}]}], "}"}], "]"}], ",", 
           "\"\<]\>\""}], "}"}], "]"}], ",", "rhs"}], "}"}], "]"}], ",", 
     "StandardForm"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{"GaussianKernel", "[", 
     RowBox[{"t_", ",", 
      RowBox[{"{", "x__", "}"}]}], "]"}], ",", "StandardForm"}], "]"}], ":=", 
  
  RowBox[{"RowBox", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"SubscriptBox", "[", 
      RowBox[{"\"\<G\>\"", ",", 
       RowBox[{"MakeBoxes", "[", 
        RowBox[{"t", ",", "StandardForm"}], "]"}]}], "]"}], ",", "\"\<[\>\"", 
     ",", 
     RowBox[{"makeHeldRowBoxOfBoxes", "[", 
      RowBox[{
       RowBox[{"{", "x", "}"}], ",", "StandardForm", ",", "None"}], "]"}], 
     ",", "\"\<]\>\""}], "}"}], "]"}]}]}], "PackageInput"],

Cell[BoxData[
 RowBox[{"Notation", "[", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["G", "t_"], "[", "x_", "]"}],
    "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
   TagBox[
    RowBox[{"GaussianKernel", "[", 
     RowBox[{"t_", ",", "x_"}], "]"}],
    "NotationTemplateTag"]}], "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{"lhs___", ",", 
        RowBox[{"SubscriptBox", "[", 
         RowBox[{"\"\<G\>\"", ",", "t_"}], "]"}], ",", "\"\<[\>\"", ",", "x_",
         ",", "\"\<]\>\"", ",", "rhs___"}], "}"}], "]"}], ",", 
     "StandardForm"}], "]"}], ":=", 
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{"lhs", ",", 
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<GaussianKernel\>\"", ",", "\"\<[\>\"", ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{"t", ",", "\"\<,\>\"", ",", "x"}], "}"}], "]"}], ",", 
           "\"\<]\>\""}], "}"}], "]"}], ",", "rhs"}], "}"}], "]"}], ",", 
     "StandardForm"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{"GaussianKernel", "[", 
     RowBox[{"t_", ",", "x_"}], "]"}], ",", "StandardForm"}], "]"}], ":=", 
  RowBox[{"RowBox", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"SubscriptBox", "[", 
      RowBox[{"\"\<G\>\"", ",", 
       RowBox[{"MakeBoxes", "[", 
        RowBox[{"t", ",", "StandardForm"}], "]"}]}], "]"}], ",", "\"\<[\>\"", 
     ",", 
     RowBox[{"MakeBoxes", "[", 
      RowBox[{"x", ",", "StandardForm"}], "]"}], ",", "\"\<]\>\""}], "}"}], 
   "]"}]}]}], "PackageInput"],

Cell[BoxData[
 RowBox[{"Notation", "[", 
  RowBox[{
   TagBox[
    RowBox[{
     SubscriptBox["G", "t__"], "[", "x__", "]"}],
    "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
   TagBox[
    RowBox[{"GaussianKernel", "[", 
     RowBox[{
      RowBox[{"{", "t__", "}"}], ",", 
      RowBox[{"{", "x__", "}"}]}], "]"}],
    "NotationTemplateTag"]}], "]"}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{"lhs___", ",", 
        RowBox[{"SubscriptBox", "[", 
         RowBox[{"\"\<G\>\"", ",", "t__"}], "]"}], ",", "\"\<[\>\"", ",", 
        "x__", ",", "\"\<]\>\"", ",", "rhs___"}], "}"}], "]"}], ",", 
     "StandardForm"}], "]"}], ":=", 
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{"lhs", ",", 
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<GaussianKernel\>\"", ",", "\"\<[\>\"", ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"stripSpuriousRowBox", "[", "t", "]"}], ",", 
                 "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<,\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"stripSpuriousRowBox", "[", "x", "]"}], ",", 
                 "\"\<}\>\""}], "}"}], "]"}]}], "}"}], "]"}], ",", 
           "\"\<]\>\""}], "}"}], "]"}], ",", "rhs"}], "}"}], "]"}], ",", 
     "StandardForm"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{"GaussianKernel", "[", 
     RowBox[{
      RowBox[{"{", "t__", "}"}], ",", 
      RowBox[{"{", "x__", "}"}]}], "]"}], ",", "StandardForm"}], "]"}], ":=", 
  
  RowBox[{"RowBox", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"SubscriptBox", "[", 
      RowBox[{"\"\<G\>\"", ",", 
       RowBox[{"makeHeldRowBoxOfBoxes", "[", 
        RowBox[{
         RowBox[{"{", "t", "}"}], ",", "StandardForm", ",", "None"}], "]"}]}],
       "]"}], ",", "\"\<[\>\"", ",", 
     RowBox[{"makeHeldRowBoxOfBoxes", "[", 
      RowBox[{
       RowBox[{"{", "x", "}"}], ",", "StandardForm", ",", "None"}], "]"}], 
     ",", "\"\<]\>\""}], "}"}], "]"}]}]}], "PackageInput"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Angular Gaussian Kernel", "Subsection"],

Cell[CellGroupData[{

Cell["Symbolic Implementation", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Symbolic", " ", "Implementation"}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"AngularGaussianKernel", "[", 
      RowBox[{"0", ",", "\[CurlyPhi]_"}], "]"}], "=", 
     RowBox[{"DiracDelta", "[", "\[CurlyPhi]", "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"AngularGaussianKernel", "[", 
      RowBox[{
       RowBox[{"t_:", "DefaultScaleParameter"}], ",", "\[CurlyPhi]_"}], "]"}],
      "=", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", "\[Pi]"}]], 
      RowBox[{"EllipticTheta", "[", 
       RowBox[{"3", ",", 
        RowBox[{"\[CurlyPhi]", "/", "2"}], ",", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "t"}]]}], "]"}]}]}], ";"}]}]}]], "PackageInput",
 InitializationCell->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Gaussian Derivative Kernel", "Subsection"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Gaussian", " ", "Derivative", " ", "Kernel"}], " ", 
  "*)"}]], "PackageInput",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["Numeric Implementation", "Subsubsection"],

Cell[TextData[{
 "To obtain efficient formulas for the n-th derivative of the Gaussian kernel \
we apply the Horner scheme to the hermite polynomials that occur when \
differentiating ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["1", 
     SqrtBox[
      RowBox[{"\[Pi]", " ", "t"}]]], 
    SuperscriptBox["\[ExponentialE]", 
     FractionBox[
      RowBox[{"-", 
       SuperscriptBox["x", "2"]}], "t"]]}], TraditionalForm]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{"If", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"VersionNumber", "<", " ", "6"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"<<", "Algebra`Horner`"}], ";", "\[IndentingNewLine]", 
    RowBox[{"HornerForm", "=", "Horner"}]}]}], "\[IndentingNewLine]", 
  "]"}]], "Input"],

Cell[TextData[{
 "We also apply the substitution ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     SuperscriptBox["x", "2"], "t"], "\[Rule]", " ", "y2"}], 
   TraditionalForm]]],
 " for even ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 ", and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["x", 
     SqrtBox["t"]], "\[Rule]", " ", "y"}], TraditionalForm]]],
 " for odd ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EfficientGaussianKernel", "[", 
   RowBox[{"n_", "?", "EvenQ"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"HornerForm", "[", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"-", "y2"}]]], 
        RowBox[{
         RowBox[{"Simplify", "[", 
          RowBox[{
           RowBox[{
            SubscriptBox["\[PartialD]", 
             RowBox[{"{", 
              RowBox[{"x", ",", "n"}], "}"}]], 
            RowBox[{
             SubscriptBox["G", "t"], "[", "x", "]"}]}], "/.", 
           "\[InvisibleSpace]", 
           RowBox[{"x", "\[Rule]", 
            SqrtBox[
             RowBox[{"y2", " ", "t"}]]}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SqrtBox["\[Pi]"], " ", 
           SuperscriptBox["t", 
            FractionBox[
             RowBox[{"n", "+", "1"}], "2"]]}], ")"}]}]}], "]"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "y2"}]]}], ")"}], "/", 
    RowBox[{"(", 
     SqrtBox[
      RowBox[{"\[Pi]", " ", 
       SuperscriptBox["t", 
        RowBox[{"n", "+", "1"}]]}]], ")"}]}], "/.", "\[InvisibleSpace]", 
   RowBox[{"t", "\[Rule]", 
    RowBox[{"\[Tau]", " ", "t"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EfficientGaussianKernel", "[", 
   RowBox[{"n_", "?", "OddQ"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"HornerForm", "[", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"-", 
           SuperscriptBox["y", "2"]}]]], 
        RowBox[{
         RowBox[{"Simplify", "[", 
          RowBox[{
           RowBox[{
            SubscriptBox["\[PartialD]", 
             RowBox[{"{", 
              RowBox[{"x", ",", "n"}], "}"}]], 
            RowBox[{
             SubscriptBox["G", "t"], "[", "x", "]"}]}], "/.", 
           "\[InvisibleSpace]", 
           RowBox[{"x", "\[Rule]", 
            RowBox[{"y", " ", 
             SqrtBox["t"]}]}]}], "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SqrtBox["\[Pi]"], " ", 
           SuperscriptBox["t", 
            FractionBox[
             RowBox[{"n", "+", "1"}], "2"]]}], ")"}]}]}], "]"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        SuperscriptBox["y", "2"]}]]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      SqrtBox["\[Pi]"], " ", 
      SuperscriptBox["t", 
       FractionBox[
        RowBox[{"n", "+", "1"}], "2"]]}], ")"}]}], "/.", "\[InvisibleSpace]", 
   
   RowBox[{"t", "\[Rule]", 
    RowBox[{"\[Tau]", " ", "t"}]}]}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"EfficientGaussianKernel", "[", "3", "]"}], "//", 
  "InputForm"}]], "Input"],

Cell["(y*(12 - 8*y^2))/(E^y^2*Sqrt[Pi]*t^2)", "Output"]
}, Open  ]],

Cell[TextData[{
 "The resulting formulas are placed into the body of a compiled function for \
the first 12 ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Numeric", " ", "Implementation"}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"NGaussianDKernel", "[", "0", "]"}], "=", 
     RowBox[{"Compile", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"t", ",", "_Real"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
       RowBox[{
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"x", "^", "2"}]}], "/", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", " ", "t"}], ")"}]}], "]"}], "/", 
        RowBox[{"Sqrt", "[", 
         RowBox[{"Pi", " ", 
          RowBox[{"(", 
           RowBox[{"\[Tau]", " ", "t"}], ")"}]}], "]"}]}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"NGaussianDKernel", "[", "1", "]"}], "=", 
     RowBox[{"Compile", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"t", ",", "_Real"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"y", "=", 
           RowBox[{"x", "/", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"\[Tau]", " ", "t"}], "]"}]}]}], "}"}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "*", "y"}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"E", "^", 
             RowBox[{"y", "^", "2"}]}], "*", 
            RowBox[{"Sqrt", "[", "Pi", "]"}], "*", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", " ", "t"}], ")"}]}], ")"}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"y", ",", "_Real"}], "}"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"NGaussianDKernel", "[", "2", "]"}], "=", 
     RowBox[{"Compile", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"t", ",", "_Real"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"y", "=", 
           RowBox[{
            RowBox[{"x", "^", "2"}], "/", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", " ", "t"}], ")"}]}]}], "}"}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", 
            RowBox[{"4", "*", "y"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"E", "^", "y"}], "*", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"Pi", " ", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"\[Tau]", " ", "t"}], ")"}], "^", "3"}]}], "]"}]}], 
           ")"}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"y", ",", "_Real"}], "}"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"NGaussianDKernel", "[", "3", "]"}], "=", 
     RowBox[{"Compile", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"t", ",", "_Real"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"y", "=", 
           RowBox[{"x", "/", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"\[Tau]", " ", "t"}], "]"}]}]}], "}"}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"y", "*", 
            RowBox[{"(", 
             RowBox[{"12", "-", 
              RowBox[{"8", "*", 
               RowBox[{"y", "^", "2"}]}]}], ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"E", "^", 
             RowBox[{"y", "^", "2"}]}], "*", 
            RowBox[{"Sqrt", "[", "Pi", "]"}], "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"\[Tau]", " ", "t"}], ")"}], "^", "2"}]}], ")"}]}]}], 
        "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"y", ",", "_Real"}], "}"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"NGaussianDKernel", "[", "4", "]"}], "=", 
     RowBox[{"Compile", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"t", ",", "_Real"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"y", "=", 
           RowBox[{
            RowBox[{"x", "^", "2"}], "/", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", " ", "t"}], ")"}]}]}], "}"}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"12", "+", 
            RowBox[{"y", "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "48"}], "+", 
               RowBox[{"16", "*", "y"}]}], ")"}]}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"E", "^", "y"}], "*", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"Pi", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"\[Tau]", " ", "t"}], ")"}], "^", "5"}]}], "]"}]}], 
           ")"}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"y", ",", "_Real"}], "}"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"NGaussianDKernel", "[", "5", "]"}], "=", 
     RowBox[{"Compile", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"t", ",", "_Real"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"y", "=", 
           RowBox[{"x", "/", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"\[Tau]", " ", "t"}], "]"}]}]}], "}"}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"y", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "120"}], "+", 
              RowBox[{
               RowBox[{"y", "^", "2"}], "*", 
               RowBox[{"(", 
                RowBox[{"160", "-", 
                 RowBox[{"32", "*", 
                  RowBox[{"y", "^", "2"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"E", "^", 
             RowBox[{"y", "^", "2"}]}], "*", 
            RowBox[{"Sqrt", "[", "Pi", "]"}], "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"\[Tau]", " ", "t"}], ")"}], "^", "3"}]}], ")"}]}]}], 
        "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"y", ",", "_Real"}], "}"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"NGaussianDKernel", "[", "6", "]"}], "=", 
     RowBox[{"Compile", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"t", ",", "_Real"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"y", "=", 
           RowBox[{
            RowBox[{"x", "^", "2"}], "/", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", " ", "t"}], ")"}]}]}], "}"}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "120"}], "+", 
            RowBox[{"y", "*", 
             RowBox[{"(", 
              RowBox[{"720", "+", 
               RowBox[{"y", "*", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "480"}], "+", 
                  RowBox[{"64", "*", "y"}]}], ")"}]}]}], ")"}]}]}], ")"}], 
          "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"E", "^", "y"}], "*", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"Pi", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"\[Tau]", " ", "t"}], ")"}], "^", "7"}]}], "]"}]}], 
           ")"}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"y", ",", "_Real"}], "}"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"NGaussianDKernel", "[", "7", "]"}], "=", 
     RowBox[{"Compile", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"t", ",", "_Real"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"y", "=", 
           RowBox[{"x", "/", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"\[Tau]", " ", "t"}], "]"}]}]}], "}"}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"y", "*", 
            RowBox[{"(", 
             RowBox[{"1680", "+", 
              RowBox[{
               RowBox[{"y", "^", "2"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3360"}], "+", 
                 RowBox[{
                  RowBox[{"y", "^", "2"}], "*", 
                  RowBox[{"(", 
                   RowBox[{"1344", "-", 
                    RowBox[{"128", "*", 
                    RowBox[{"y", "^", "2"}]}]}], ")"}]}]}], ")"}]}]}], 
             ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"E", "^", 
             RowBox[{"y", "^", "2"}]}], "*", 
            RowBox[{"Sqrt", "[", "Pi", "]"}], "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"\[Tau]", " ", "t"}], ")"}], "^", "4"}]}], ")"}]}]}], 
        "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"y", ",", "_Real"}], "}"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"NGaussianDKernel", "[", "8", "]"}], "=", 
     RowBox[{"Compile", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"t", ",", "_Real"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"y", "=", 
           RowBox[{
            RowBox[{"x", "^", "2"}], "/", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", " ", "t"}], ")"}]}]}], "}"}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1680", "+", 
            RowBox[{"y", "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "13440"}], "+", 
               RowBox[{"y", "*", 
                RowBox[{"(", 
                 RowBox[{"13440", "+", 
                  RowBox[{"y", "*", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3584"}], "+", 
                    RowBox[{"256", "*", "y"}]}], ")"}]}]}], ")"}]}]}], 
              ")"}]}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"E", "^", "y"}], "*", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"Pi", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"\[Tau]", " ", "t"}], ")"}], "^", "9"}]}], "]"}]}], 
           ")"}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"y", ",", "_Real"}], "}"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"NGaussianDKernel", "[", "9", "]"}], "=", 
     RowBox[{"Compile", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"t", ",", "_Real"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"y", "=", 
           RowBox[{"x", "/", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"\[Tau]", " ", "t"}], "]"}]}]}], "}"}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"y", "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "30240"}], "+", 
              RowBox[{
               RowBox[{"y", "^", "2"}], "*", 
               RowBox[{"(", 
                RowBox[{"80640", "+", 
                 RowBox[{
                  RowBox[{"y", "^", "2"}], "*", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "48384"}], "+", 
                    RowBox[{
                    RowBox[{"y", "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{"9216", "-", 
                    RowBox[{"512", "*", 
                    RowBox[{"y", "^", "2"}]}]}], ")"}]}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"E", "^", 
             RowBox[{"y", "^", "2"}]}], "*", 
            RowBox[{"Sqrt", "[", "Pi", "]"}], "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"\[Tau]", " ", "t"}], ")"}], "^", "5"}]}], ")"}]}]}], 
        "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"y", ",", "_Real"}], "}"}], "}"}]}], "]"}]}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"NGaussianDKernel", "[", "10", "]"}], "=", 
     RowBox[{"Compile", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"t", ",", "_Real"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"y", "=", 
           RowBox[{
            RowBox[{"x", "^", "2"}], "/", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", " ", "t"}], ")"}]}]}], "}"}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "30240"}], "+", 
            RowBox[{"y", "*", 
             RowBox[{"(", 
              RowBox[{"302400", "+", 
               RowBox[{"y", "*", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "403200"}], "+", 
                  RowBox[{"y", "*", 
                   RowBox[{"(", 
                    RowBox[{"161280", "+", 
                    RowBox[{"y", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "23040"}], "+", 
                    RowBox[{"1024", "*", "y"}]}], ")"}]}]}], ")"}]}]}], 
                 ")"}]}]}], ")"}]}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"E", "^", "y"}], "*", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"Pi", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"\[Tau]", " ", "t"}], ")"}], "^", "11"}]}], "]"}]}], 
           ")"}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"y", ",", "_Real"}], "}"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"NGaussianDKernel", "[", "11", "]"}], "=", 
     RowBox[{"Compile", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"t", ",", "_Real"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"y", "=", 
           RowBox[{"x", "/", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"\[Tau]", " ", "t"}], "]"}]}]}], "}"}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"y", "*", 
            RowBox[{"(", 
             RowBox[{"665280", "+", 
              RowBox[{
               RowBox[{"y", "^", "2"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2217600"}], "+", 
                 RowBox[{
                  RowBox[{"y", "^", "2"}], "*", 
                  RowBox[{"(", 
                   RowBox[{"1774080", "+", 
                    RowBox[{
                    RowBox[{"y", "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "506880"}], "+", 
                    RowBox[{
                    RowBox[{"y", "^", "2"}], "*", 
                    RowBox[{"(", 
                    RowBox[{"56320", "-", 
                    RowBox[{"2048", "*", 
                    RowBox[{"y", "^", "2"}]}]}], ")"}]}]}], ")"}]}]}], 
                   ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"E", "^", 
             RowBox[{"y", "^", "2"}]}], "*", 
            RowBox[{"Sqrt", "[", "Pi", "]"}], "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"\[Tau]", " ", "t"}], ")"}], "^", "6"}]}], ")"}]}]}], 
        "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"y", ",", "_Real"}], "}"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"NGaussianDKernel", "[", "12", "]"}], "=", 
     RowBox[{"Compile", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"t", ",", "_Real"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"y", "=", 
           RowBox[{
            RowBox[{"x", "^", "2"}], "/", 
            RowBox[{"(", 
             RowBox[{"\[Tau]", " ", "t"}], ")"}]}]}], "}"}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"665280", "+", 
            RowBox[{"y", "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "7983360"}], "+", 
               RowBox[{"y", "*", 
                RowBox[{"(", 
                 RowBox[{"13305600", "+", 
                  RowBox[{"y", "*", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "7096320"}], "+", 
                    RowBox[{"y", "*", 
                    RowBox[{"(", 
                    RowBox[{"1520640", "+", 
                    RowBox[{"y", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "135168"}], "+", 
                    RowBox[{"4096", "*", "y"}]}], ")"}]}]}], ")"}]}]}], 
                    ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"E", "^", "y"}], "*", 
            RowBox[{"Sqrt", "[", "Pi", "]"}], "*", 
            RowBox[{"Sqrt", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"\[Tau]", " ", "t"}], ")"}], "^", "13"}], "]"}]}], 
           ")"}]}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"y", ",", "_Real"}], "}"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"NGaussianDKernel", "[", 
      RowBox[{"n_Integer", "?", "Positive"}], "]"}], ":=", 
     RowBox[{"Compile", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"t", ",", "_Real"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"y", "=", 
           RowBox[{"x", "/", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"\[Tau]", " ", "t"}], "]"}]}]}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"HermiteH", "[", 
             RowBox[{"n", ",", "y"}], "]"}]}], "/", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Sqrt", "[", "Pi", "]"}], " ", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"-", 
                RowBox[{"Sqrt", "[", 
                 RowBox[{"\[Tau]", " ", "t"}], "]"}]}], ")"}], "^", 
              RowBox[{"(", 
               RowBox[{"n", "+", "1"}], ")"}]}]}], ")"}]}], "*", 
          RowBox[{"Exp", "[", 
           RowBox[{"-", 
            RowBox[{"y", "^", "2"}]}], "]"}]}]}], "\[IndentingNewLine]", 
        "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"y", ",", "_Real"}], "}"}], "}"}]}], "]"}]}], 
    ";"}]}]}]], "PackageInput",
 InitializationCell->True],

Cell["\<\
Refer to the numeric implementation whenever the Gaussian kernel is called \
with numerical arguments.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"GaussianDKernel", "[", 
    RowBox[{"0", ",", 
     RowBox[{"x_", "?", "NumberQ"}]}], "]"}], ":=", 
   RowBox[{"NGaussianKernel", "[", 
    RowBox[{"DefaultScaleParameter", ",", "x"}], "]"}]}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GaussianDKernel", "[", 
    RowBox[{"n_Integer", ",", 
     RowBox[{"x_", "?", "NumberQ"}]}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"NGaussianDKernel", "[", "n", "]"}], "[", 
     RowBox[{"DefaultScaleParameter", ",", "x"}], "]"}], "/;", 
    RowBox[{"1", "\[LessEqual]", "n", "\[LessEqual]", "12"}]}]}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"GaussianDKernel", "[", 
    RowBox[{
     RowBox[{"0", "|", "0."}], ",", "n_Integer", ",", "x_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"Derivative", "[", "n", "]"}], "[", "DiracDelta", "]"}], "[", 
    "x", "]"}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GaussianDKernel", "[", 
    RowBox[{
     RowBox[{"t_", "?", "NumberQ"}], ",", "0", ",", 
     RowBox[{"x_", "?", "NumberQ"}]}], "]"}], ":=", 
   RowBox[{"NGaussianKernel", "[", 
    RowBox[{"t", ",", "x"}], "]"}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GaussianDKernel", "[", 
   RowBox[{
    RowBox[{"t_", "?", "NumberQ"}], ",", "n_Integer", ",", 
    RowBox[{"x_", "?", "NumberQ"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"NGaussianDKernel", "[", "n", "]"}], "[", 
    RowBox[{"t", ",", "x"}], "]"}], "/;", 
   RowBox[{
   "1", "\[LessEqual]", "n", "\[LessEqual]", "12"}]}]}]}], "PackageInput",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Symbolic Implementation", "Subsubsection"],

Cell["\<\
For non-numeric arguments one has to render symbolic formulas. We consider 3 \
different cases: 
numeric order of differentiation, symbolic order of differentiation, and \
kernel of zero width resulting in a Dirac delta distribution.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Symbolic", " ", "Implementation"}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"GaussianDKernel", "[", 
     RowBox[{
      RowBox[{"t_:", "DefaultScaleParameter"}], ",", "0", ",", "x_"}], "]"}], 
    ":=", 
    RowBox[{"GaussianKernel", "[", 
     RowBox[{"t", ",", "x"}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"GaussianDKernel", "[", 
     RowBox[{
      RowBox[{"t_:", "DefaultScaleParameter"}], ",", 
      RowBox[{"n_Integer", "?", "NonNegative"}], ",", "x_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"Simplify", "[", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"HermiteH", "[", 
           RowBox[{"n", ",", 
            RowBox[{"x$dummy", "/", 
             RowBox[{"Sqrt", "[", 
              RowBox[{"\[Tau]", " ", "t"}], "]"}]}]}], "]"}], "/.", " ", 
          RowBox[{"x$dummy", "\[Rule]", " ", "x"}]}], ")"}]}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Sqrt", "[", "Pi", "]"}], " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"-", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"\[Tau]", " ", "t"}], "]"}]}], ")"}], "^", 
          RowBox[{"(", 
           RowBox[{"n", "+", "1"}], ")"}]}]}], ")"}]}], "]"}], "*", 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"x", "^", "2"}]}], "/", 
       RowBox[{"(", 
        RowBox[{"\[Tau]", " ", "t"}], ")"}]}], "]"}]}]}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"GaussianDKernel", "[", 
     RowBox[{
      RowBox[{"t_:", "DefaultScaleParameter"}], ",", "n_Symbol", ",", "x_"}], 
     "]"}], ":=", "\[IndentingNewLine]", 
    RowBox[{"If", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"N", "[", "t", "]"}], "===", " ", "0."}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"Derivative", "[", "n", "]"}], "[", "DiracDelta", "]"}], "[", 
       "x", "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"HermiteH", "[", 
          RowBox[{"n", ",", 
           RowBox[{"x", "/", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"\[Tau]", " ", "t"}], "]"}]}]}], "]"}]}], "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", "Pi", "]"}], " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"-", 
             RowBox[{"Sqrt", "[", 
              RowBox[{"\[Tau]", " ", "t"}], "]"}]}], ")"}], "^", 
           RowBox[{"(", 
            RowBox[{"n", "+", "1"}], ")"}]}]}], ")"}]}], "*", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"x", "^", "2"}]}], "/", 
         RowBox[{"(", 
          RowBox[{"\[Tau]", " ", "t"}], ")"}]}], "]"}]}]}], 
     "\[IndentingNewLine]", "]"}]}], "\n", "\[IndentingNewLine]", 
   RowBox[{"GaussianDKernel", "/:", 
    RowBox[{
     RowBox[{"Derivative", "[", 
      RowBox[{"0", ",", "0", ",", "n_"}], "]"}], "[", "GaussianDKernel", 
     "]"}], ":=", 
    RowBox[{
     RowBox[{"GaussianDKernel", "[", 
      RowBox[{
       RowBox[{"#1", "+", "n"}], ",", "#2", ",", "#3"}], "]"}], 
     "&"}]}]}]}]], "PackageInput",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Multidimensional Implementation", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Multidimensional", " ", "Implementation"}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"GaussianDKernel", "::", "dimfail1"}], "=", 
     "\"\<The number of variables and the number of derivative indices do not \
match.\>\""}], ";"}], "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"GaussianDKernel", "::", "dimfail2"}], "=", 
     "\"\<The number of variables, the number of derivative indices, and the \
number of scale parameters do not match.\>\""}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"GaussianDKernel", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", " ", ".."}], "}"}], ",", "x_List"}], "]"}], ":=", 
     RowBox[{"GaussianKernel", "[", "x", "]"}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"GaussianDKernel", "[", 
      RowBox[{"n_List", ",", "x_List"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"Inner", "[", 
       RowBox[{"GaussianDKernel", ",", "n", ",", "x", ",", "Times"}], "]"}], "/;", 
      RowBox[{
       RowBox[{"Dimensions", "[", "n", "]"}], "\[Equal]", 
       RowBox[{"Dimensions", "[", "x", "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"GaussianDKernel", "[", 
      RowBox[{"n_List", ",", "x_List"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Message", "[", 
         RowBox[{"GaussianDKernel", "::", "dimfail1"}], "]"}], ";", 
        RowBox[{"Throw", "[", "$Failed", "]"}]}], ")"}], "/;", 
      RowBox[{
       RowBox[{"Dimensions", "[", "n", "]"}], "\[NotEqual]", 
       RowBox[{"Dimensions", "[", "x", "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"GaussianDKernel", "[", 
      RowBox[{"t_List", ",", 
       RowBox[{"{", 
        RowBox[{"0", " ", ".."}], "}"}], ",", "x_List"}], "]"}], ":=", 
     RowBox[{"GaussianKernel", "[", 
      RowBox[{"t", ",", "x"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"GaussianDKernel", "[", 
      RowBox[{"t_List", ",", "n_List", ",", "x_List"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"Apply", "[", 
       RowBox[{"Times", ",", 
        RowBox[{"Apply", "[", 
         RowBox[{"GaussianDKernel", ",", 
          RowBox[{"Transpose", "[", 
           RowBox[{"{", 
            RowBox[{"t", ",", "n", ",", "x"}], "}"}], "]"}], ",", 
          RowBox[{"{", "1", "}"}]}], "]"}]}], "]"}], "/;", 
      RowBox[{
       RowBox[{"Dimensions", "[", "n", "]"}], "\[Equal]", 
       RowBox[{"Dimensions", "[", "t", "]"}], "\[Equal]", 
       RowBox[{"Dimensions", "[", "x", "]"}]}]}]}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"GaussianDKernel", "[", 
      RowBox[{"t_List", ",", "n_List", ",", "x_List"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Message", "[", 
         RowBox[{"GaussianDKernel", ":", "dimfail2"}], "]"}], ";", 
        RowBox[{"Throw", "[", "$Failed", "]"}]}], ")"}], "/;", 
      RowBox[{"Not", "[", 
       RowBox[{
        RowBox[{"Dimensions", "[", "n", "]"}], "\[Equal]", 
        RowBox[{"Dimensions", "[", "t", "]"}], "\[Equal]", 
        RowBox[{"Dimensions", "[", "x", "]"}]}], "]"}]}]}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"GaussianDKernel", "[", 
      RowBox[{"t_", ",", 
       RowBox[{"{", 
        RowBox[{"0", " ", ".."}], "}"}], ",", "x_List"}], "]"}], ":=", 
     RowBox[{"GaussianKernel", "[", 
      RowBox[{"t", ",", "x"}], "]"}]}], ";"}], "\[IndentingNewLine]", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"GaussianDKernel", "[", 
      RowBox[{"t_", ",", "n_List", ",", "x_List"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"Apply", "[", 
       RowBox[{"Times", ",", 
        RowBox[{"Apply", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"GaussianDKernel", "[", 
            RowBox[{"t", ",", "##"}], "]"}], "&"}], ",", 
          RowBox[{"Transpose", "[", 
           RowBox[{"{", 
            RowBox[{"n", ",", "x"}], "}"}], "]"}], ",", 
          RowBox[{"{", "1", "}"}]}], "]"}]}], "]"}], "/;", 
      RowBox[{
       RowBox[{"Dimensions", "[", "n", "]"}], "\[Equal]", 
       RowBox[{"Dimensions", "[", "x", "]"}]}]}]}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"GaussianDKernel", "[", 
      RowBox[{"t_", ",", "n_List", ",", "x_List"}], "]"}], ":=", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Message", "[", 
         RowBox[{"GaussianDKernel", ":", "dimfail2"}], "]"}], ";", 
        RowBox[{"Throw", "[", "$Failed", "]"}]}], ")"}], "/;", 
      RowBox[{
       RowBox[{"Dimensions", "[", "n", "]"}], "\[NotEqual]", 
       RowBox[{"Dimensions", "[", "x", "]"}]}]}]}], ";"}]}]}]], "PackageInput",\

 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["GaussianDKernel Input Notation", "Subsubsection"],

Cell[BoxData[
 RowBox[{"Notation", "[", 
  RowBox[{
   TagBox[
    RowBox[{
     SuperscriptBox["G", "\[Prime]",
      MultilineFunction->None], "[", "x_", "]"}],
    "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
   TagBox[
    RowBox[{"GaussianDKernel", "[", 
     RowBox[{"DefaultScaleParameter", ",", "x_"}], "]"}],
    "NotationTemplateTag"]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"GaussianDKernel", " ", "Input", " ", "Notation"}], " ", "*)"}], 
  "\n", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{"lhs___", ",", 
         RowBox[{"SuperscriptBox", "[", 
          RowBox[{"\"\<G\>\"", ",", "\"\<\[Prime]\>\""}], "]"}], ",", 
         "\"\<[\>\"", ",", "x_", ",", "\"\<]\>\"", ",", "rhs___"}], "}"}], 
       "]"}], ",", "StandardForm"}], "]"}], ":=", 
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{"lhs", ",", 
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<GaussianDKernel\>\"", ",", "\"\<[\>\"", ",", 
            RowBox[{"RowBox", "[", 
             RowBox[{"{", 
              RowBox[{"\"\<1\>\"", ",", "\"\<,\>\"", ",", "x"}], "}"}], "]"}],
             ",", "\"\<]\>\""}], "}"}], "]"}], ",", "rhs"}], "}"}], "]"}], 
      ",", "StandardForm"}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MakeBoxes", "[", 
     RowBox[{
      RowBox[{"GaussianDKernel", "[", 
       RowBox[{"1", ",", "x_"}], "]"}], ",", "StandardForm"}], "]"}], ":=", 
    RowBox[{"RowBox", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"SuperscriptBox", "[", 
        RowBox[{"\"\<G\>\"", ",", "\"\<\[Prime]\>\"", ",", 
         RowBox[{"MultilineFunction", "\[Rule]", "None"}]}], "]"}], ",", 
       "\"\<[\>\"", ",", 
       RowBox[{"MakeBoxes", "[", 
        RowBox[{"x", ",", "StandardForm"}], "]"}], ",", "\"\<]\>\""}], "}"}], 
     "]"}]}]}]}]], "PackageInput",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     RowBox[{
      SubsuperscriptBox["G", "t_", "\[Prime]",
       MultilineFunction->None], "[", "x_", "]"}],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{"GaussianDKernel", "[", 
      RowBox[{"t_", ",", "1", ",", "x_"}], "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{"lhs___", ",", 
         RowBox[{"SubsuperscriptBox", "[", 
          RowBox[{"\"\<G\>\"", ",", "t_", ",", "\"\<\[Prime]\>\""}], "]"}], 
         ",", "\"\<[\>\"", ",", "x_", ",", "\"\<]\>\"", ",", "rhs___"}], 
        "}"}], "]"}], ",", "StandardForm"}], "]"}], ":=", 
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{"lhs", ",", 
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<GaussianDKernel\>\"", ",", "\"\<[\>\"", ",", 
            RowBox[{"RowBox", "[", 
             RowBox[{"{", 
              RowBox[{
              "t", ",", "\"\<,\>\"", ",", "\"\<1\>\"", ",", "\"\<,\>\"", ",", 
               "x"}], "}"}], "]"}], ",", "\"\<]\>\""}], "}"}], "]"}], ",", 
         "rhs"}], "}"}], "]"}], ",", "StandardForm"}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MakeBoxes", "[", 
     RowBox[{
      RowBox[{"GaussianDKernel", "[", 
       RowBox[{"t_", ",", "1", ",", "x_"}], "]"}], ",", "StandardForm"}], 
     "]"}], ":=", 
    RowBox[{"RowBox", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"SubsuperscriptBox", "[", 
        RowBox[{"\"\<G\>\"", ",", 
         RowBox[{"MakeBoxes", "[", 
          RowBox[{"t", ",", "StandardForm"}], "]"}], ",", "\"\<\[Prime]\>\"", 
         ",", 
         RowBox[{"MultilineFunction", "\[Rule]", "None"}]}], "]"}], ",", 
       "\"\<[\>\"", ",", 
       RowBox[{"MakeBoxes", "[", 
        RowBox[{"x", ",", "StandardForm"}], "]"}], ",", "\"\<]\>\""}], "}"}], 
     "]"}]}]}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     RowBox[{
      SuperscriptBox["G", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "x_", "]"}],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{"GaussianDKernel", "[", 
      RowBox[{"2", ",", "x_"}], "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{"lhs___", ",", 
         RowBox[{"SuperscriptBox", "[", 
          RowBox[{"\"\<G\>\"", ",", "\"\<\[Prime]\[Prime]\>\""}], "]"}], ",", 
         "\"\<[\>\"", ",", "x_", ",", "\"\<]\>\"", ",", "rhs___"}], "}"}], 
       "]"}], ",", "StandardForm"}], "]"}], ":=", 
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{"lhs", ",", 
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<GaussianDKernel\>\"", ",", "\"\<[\>\"", ",", 
            RowBox[{"RowBox", "[", 
             RowBox[{"{", 
              RowBox[{"\"\<2\>\"", ",", "\"\<,\>\"", ",", "x"}], "}"}], "]"}],
             ",", "\"\<]\>\""}], "}"}], "]"}], ",", "rhs"}], "}"}], "]"}], 
      ",", "StandardForm"}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MakeBoxes", "[", 
     RowBox[{
      RowBox[{"GaussianDKernel", "[", 
       RowBox[{"2", ",", "x_"}], "]"}], ",", "StandardForm"}], "]"}], ":=", 
    RowBox[{"RowBox", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"SuperscriptBox", "[", 
        RowBox[{"\"\<G\>\"", ",", "\"\<\[Prime]\[Prime]\>\"", ",", 
         RowBox[{"MultilineFunction", "\[Rule]", "None"}]}], "]"}], ",", 
       "\"\<[\>\"", ",", 
       RowBox[{"MakeBoxes", "[", 
        RowBox[{"x", ",", "StandardForm"}], "]"}], ",", "\"\<]\>\""}], "}"}], 
     "]"}]}]}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     RowBox[{
      SubsuperscriptBox["G", "t_", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "x_", "]"}],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{"GaussianDKernel", "[", 
      RowBox[{"t_", ",", "2", ",", "x_"}], "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{"lhs___", ",", 
         RowBox[{"SubsuperscriptBox", "[", 
          RowBox[{"\"\<G\>\"", ",", "t_", ",", "\"\<\[Prime]\[Prime]\>\""}], 
          "]"}], ",", "\"\<[\>\"", ",", "x_", ",", "\"\<]\>\"", ",", 
         "rhs___"}], "}"}], "]"}], ",", "StandardForm"}], "]"}], ":=", 
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{"lhs", ",", 
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<GaussianDKernel\>\"", ",", "\"\<[\>\"", ",", 
            RowBox[{"RowBox", "[", 
             RowBox[{"{", 
              RowBox[{
              "t", ",", "\"\<,\>\"", ",", "\"\<2\>\"", ",", "\"\<,\>\"", ",", 
               "x"}], "}"}], "]"}], ",", "\"\<]\>\""}], "}"}], "]"}], ",", 
         "rhs"}], "}"}], "]"}], ",", "StandardForm"}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MakeBoxes", "[", 
     RowBox[{
      RowBox[{"GaussianDKernel", "[", 
       RowBox[{"t_", ",", "2", ",", "x_"}], "]"}], ",", "StandardForm"}], 
     "]"}], ":=", 
    RowBox[{"RowBox", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"SubsuperscriptBox", "[", 
        RowBox[{"\"\<G\>\"", ",", 
         RowBox[{"MakeBoxes", "[", 
          RowBox[{"t", ",", "StandardForm"}], "]"}], ",", 
         "\"\<\[Prime]\[Prime]\>\"", ",", 
         RowBox[{"MultilineFunction", "\[Rule]", "None"}]}], "]"}], ",", 
       "\"\<[\>\"", ",", 
       RowBox[{"MakeBoxes", "[", 
        RowBox[{"x", ",", "StandardForm"}], "]"}], ",", "\"\<]\>\""}], "}"}], 
     "]"}]}]}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     RowBox[{
      SuperscriptBox["G", 
       TagBox[
        RowBox[{"(", "n_", ")"}],
        Derivative],
       MultilineFunction->None], "[", "x_", "]"}],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{"GaussianDKernel", "[", 
      RowBox[{"n_", ",", "x_"}], "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{"lhs___", ",", 
         RowBox[{"SuperscriptBox", "[", 
          RowBox[{"\"\<G\>\"", ",", 
           RowBox[{"TagBox", "[", 
            RowBox[{
             RowBox[{"RowBox", "[", 
              RowBox[{"{", 
               RowBox[{"\"\<(\>\"", ",", "n_", ",", "\"\<)\>\""}], "}"}], 
              "]"}], ",", "Derivative"}], "]"}]}], "]"}], ",", "\"\<[\>\"", 
         ",", "x_", ",", "\"\<]\>\"", ",", "rhs___"}], "}"}], "]"}], ",", 
      "StandardForm"}], "]"}], ":=", 
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{"lhs", ",", 
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<GaussianDKernel\>\"", ",", "\"\<[\>\"", ",", 
            RowBox[{"RowBox", "[", 
             RowBox[{"{", 
              RowBox[{"n", ",", "\"\<,\>\"", ",", "x"}], "}"}], "]"}], ",", 
            "\"\<]\>\""}], "}"}], "]"}], ",", "rhs"}], "}"}], "]"}], ",", 
      "StandardForm"}], "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MakeBoxes", "[", 
     RowBox[{
      RowBox[{"GaussianDKernel", "[", 
       RowBox[{"n_", ",", "x_"}], "]"}], ",", "StandardForm"}], "]"}], ":=", 
    RowBox[{"RowBox", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"SuperscriptBox", "[", 
        RowBox[{"\"\<G\>\"", ",", 
         RowBox[{"TagBox", "[", 
          RowBox[{
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{"\"\<(\>\"", ",", 
              RowBox[{"MakeBoxes", "[", 
               RowBox[{"n", ",", "StandardForm"}], "]"}], ",", "\"\<)\>\""}], 
             "}"}], "]"}], ",", "Derivative"}], "]"}], ",", 
         RowBox[{"MultilineFunction", "\[Rule]", "None"}]}], "]"}], ",", 
       "\"\<[\>\"", ",", 
       RowBox[{"MakeBoxes", "[", 
        RowBox[{"x", ",", "StandardForm"}], "]"}], ",", "\"\<]\>\""}], "}"}], 
     "]"}]}]}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{"  ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     RowBox[{
      SubsuperscriptBox["G", "t_", 
       TagBox[
        RowBox[{"(", "n_", ")"}],
        Derivative],
       MultilineFunction->None], "[", "x_", "]"}],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{"GaussianDKernel", "[", 
      RowBox[{"t_", ",", "n_", ",", "x_"}], "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{"lhs___", ",", 
         RowBox[{"SubsuperscriptBox", "[", 
          RowBox[{"\"\<G\>\"", ",", "t_", ",", 
           RowBox[{"TagBox", "[", 
            RowBox[{
             RowBox[{"RowBox", "[", 
              RowBox[{"{", 
               RowBox[{"\"\<(\>\"", ",", "n_", ",", "\"\<)\>\""}], "}"}], 
              "]"}], ",", "Derivative"}], "]"}]}], "]"}], ",", "\"\<[\>\"", 
         ",", "x_", ",", "\"\<]\>\"", ",", "rhs___"}], "}"}], "]"}], ",", 
      "StandardForm"}], "]"}], ":=", 
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{"lhs", ",", 
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<GaussianDKernel\>\"", ",", "\"\<[\>\"", ",", 
            RowBox[{"RowBox", "[", 
             RowBox[{"{", 
              RowBox[{
              "t", ",", "\"\<,\>\"", ",", "n", ",", "\"\<,\>\"", ",", "x"}], 
              "}"}], "]"}], ",", "\"\<]\>\""}], "}"}], "]"}], ",", "rhs"}], 
        "}"}], "]"}], ",", "StandardForm"}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MakeBoxes", "[", 
     RowBox[{
      RowBox[{"GaussianDKernel", "[", 
       RowBox[{"t_", ",", "n_", ",", "x_"}], "]"}], ",", "StandardForm"}], 
     "]"}], ":=", 
    RowBox[{"RowBox", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"SubsuperscriptBox", "[", 
        RowBox[{"\"\<G\>\"", ",", 
         RowBox[{"MakeBoxes", "[", 
          RowBox[{"t", ",", "StandardForm"}], "]"}], ",", 
         RowBox[{"TagBox", "[", 
          RowBox[{
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{"\"\<(\>\"", ",", 
              RowBox[{"MakeBoxes", "[", 
               RowBox[{"n", ",", "StandardForm"}], "]"}], ",", "\"\<)\>\""}], 
             "}"}], "]"}], ",", "Derivative"}], "]"}], ",", 
         RowBox[{"MultilineFunction", "\[Rule]", "None"}]}], "]"}], ",", 
       "\"\<[\>\"", ",", 
       RowBox[{"MakeBoxes", "[", 
        RowBox[{"x", ",", "StandardForm"}], "]"}], ",", "\"\<]\>\""}], "}"}], 
     "]"}]}]}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     RowBox[{
      SuperscriptBox["G", 
       TagBox[
        RowBox[{"(", "n__", ")"}],
        Derivative],
       MultilineFunction->None], "[", "x__", "]"}],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{"GaussianDKernel", "[", 
      RowBox[{
       RowBox[{"{", "n__", "}"}], ",", 
       RowBox[{"{", "x__", "}"}]}], "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{"lhs___", ",", 
        RowBox[{"SuperscriptBox", "[", 
         RowBox[{"\"\<G\>\"", ",", 
          RowBox[{"TagBox", "[", 
           RowBox[{
            RowBox[{"RowBox", "[", 
             RowBox[{"{", 
              RowBox[{"\"\<(\>\"", ",", "n__", ",", "\"\<)\>\""}], "}"}], 
             "]"}], ",", "Derivative"}], "]"}]}], "]"}], ",", "\"\<[\>\"", 
        ",", "x__", ",", "\"\<]\>\"", ",", "rhs___"}], "}"}], "]"}], ",", 
     "StandardForm"}], "]"}], ":=", 
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{"lhs", ",", 
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<GaussianDKernel\>\"", ",", "\"\<[\>\"", ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"stripSpuriousRowBox", "[", "n", "]"}], ",", 
                 "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<,\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"stripSpuriousRowBox", "[", "x", "]"}], ",", 
                 "\"\<}\>\""}], "}"}], "]"}]}], "}"}], "]"}], ",", 
           "\"\<]\>\""}], "}"}], "]"}], ",", "rhs"}], "}"}], "]"}], ",", 
     "StandardForm"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{
   RowBox[{"MakeBoxes", "[", 
    RowBox[{
     RowBox[{"GaussianDKernel", "[", 
      RowBox[{
       RowBox[{"{", "n__", "}"}], ",", 
       RowBox[{"{", "x__", "}"}]}], "]"}], ",", "StandardForm"}], "]"}], ":=", 
   RowBox[{"RowBox", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"SuperscriptBox", "[", 
       RowBox[{"\"\<G\>\"", ",", 
        RowBox[{"TagBox", "[", 
         RowBox[{
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<(\>\"", ",", 
             RowBox[{"makeHeldRowBoxOfBoxes", "[", 
              RowBox[{
               RowBox[{"{", "n", "}"}], ",", "StandardForm", ",", "None"}], 
              "]"}], ",", "\"\<)\>\""}], "}"}], "]"}], ",", "Derivative"}], 
         "]"}], ",", 
        RowBox[{"MultilineFunction", "\[Rule]", "None"}]}], "]"}], ",", 
      "\"\<[\>\"", ",", 
      RowBox[{"makeHeldRowBoxOfBoxes", "[", 
       RowBox[{
        RowBox[{"{", "x", "}"}], ",", "StandardForm", ",", "None"}], "]"}], 
      ",", "\"\<]\>\""}], "}"}], "]"}]}]}]}], "PackageInput"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     RowBox[{
      SubsuperscriptBox["G", "t_", 
       TagBox[
        RowBox[{"(", "n__", ")"}],
        Derivative],
       MultilineFunction->None], "[", "x__", "]"}],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{"GaussianDKernel", "[", 
      RowBox[{"t_", ",", 
       RowBox[{"{", "n__", "}"}], ",", 
       RowBox[{"{", "x__", "}"}]}], "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{"lhs___", ",", 
         RowBox[{"SubsuperscriptBox", "[", 
          RowBox[{"\"\<G\>\"", ",", "t_", ",", 
           RowBox[{"TagBox", "[", 
            RowBox[{
             RowBox[{"RowBox", "[", 
              RowBox[{"{", 
               RowBox[{"\"\<(\>\"", ",", "n__", ",", "\"\<)\>\""}], "}"}], 
              "]"}], ",", "Derivative"}], "]"}]}], "]"}], ",", "\"\<[\>\"", 
         ",", "x__", ",", "\"\<]\>\"", ",", "rhs___"}], "}"}], "]"}], ",", 
      "StandardForm"}], "]"}], ":=", 
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{"lhs", ",", 
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<GaussianDKernel\>\"", ",", "\"\<[\>\"", ",", 
            RowBox[{"RowBox", "[", 
             RowBox[{"{", 
              RowBox[{"t", ",", "\"\<,\>\"", ",", 
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<{\>\"", ",", 
                  RowBox[{"stripSpuriousRowBox", "[", "n", "]"}], ",", 
                  "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<,\>\"", ",", 
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<{\>\"", ",", 
                  RowBox[{"stripSpuriousRowBox", "[", "x", "]"}], ",", 
                  "\"\<}\>\""}], "}"}], "]"}]}], "}"}], "]"}], ",", 
            "\"\<]\>\""}], "}"}], "]"}], ",", "rhs"}], "}"}], "]"}], ",", 
      "StandardForm"}], "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MakeBoxes", "[", 
     RowBox[{
      RowBox[{"GaussianDKernel", "[", 
       RowBox[{"t_", ",", 
        RowBox[{"{", "n__", "}"}], ",", 
        RowBox[{"{", "x__", "}"}]}], "]"}], ",", "StandardForm"}], "]"}], ":=", 
    RowBox[{"RowBox", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"SubsuperscriptBox", "[", 
        RowBox[{"\"\<G\>\"", ",", 
         RowBox[{"MakeBoxes", "[", 
          RowBox[{"t", ",", "StandardForm"}], "]"}], ",", 
         RowBox[{"TagBox", "[", 
          RowBox[{
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{"\"\<(\>\"", ",", 
              RowBox[{"makeHeldRowBoxOfBoxes", "[", 
               RowBox[{
                RowBox[{"{", "n", "}"}], ",", "StandardForm", ",", "None"}], 
               "]"}], ",", "\"\<)\>\""}], "}"}], "]"}], ",", "Derivative"}], 
          "]"}], ",", 
         RowBox[{"MultilineFunction", "\[Rule]", "None"}]}], "]"}], ",", 
       "\"\<[\>\"", ",", 
       RowBox[{"makeHeldRowBoxOfBoxes", "[", 
        RowBox[{
         RowBox[{"{", "x", "}"}], ",", "StandardForm", ",", "None"}], "]"}], 
       ",", "\"\<]\>\""}], "}"}], "]"}]}]}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     RowBox[{
      SubsuperscriptBox["G", "t__", 
       TagBox[
        RowBox[{"(", "n__", ")"}],
        Derivative],
       MultilineFunction->None], "[", "x__", "]"}],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{"GaussianDKernel", "[", 
      RowBox[{
       RowBox[{"{", "t__", "}"}], ",", 
       RowBox[{"{", "n__", "}"}], ",", 
       RowBox[{"{", "x__", "}"}]}], "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{"lhs___", ",", 
         RowBox[{"SubsuperscriptBox", "[", 
          RowBox[{"\"\<G\>\"", ",", "t__", ",", 
           RowBox[{"TagBox", "[", 
            RowBox[{
             RowBox[{"RowBox", "[", 
              RowBox[{"{", 
               RowBox[{"\"\<(\>\"", ",", "n__", ",", "\"\<)\>\""}], "}"}], 
              "]"}], ",", "Derivative"}], "]"}]}], "]"}], ",", "\"\<[\>\"", 
         ",", "x__", ",", "\"\<]\>\"", ",", "rhs___"}], "}"}], "]"}], ",", 
      "StandardForm"}], "]"}], ":=", 
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{"lhs", ",", 
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<GaussianDKernel\>\"", ",", "\"\<[\>\"", ",", 
            RowBox[{"RowBox", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<{\>\"", ",", 
                  RowBox[{"stripSpuriousRowBox", "[", "t", "]"}], ",", 
                  "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<,\>\"", ",", 
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<{\>\"", ",", 
                  RowBox[{"stripSpuriousRowBox", "[", "n", "]"}], ",", 
                  "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<,\>\"", ",", 
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<{\>\"", ",", 
                  RowBox[{"stripSpuriousRowBox", "[", "x", "]"}], ",", 
                  "\"\<}\>\""}], "}"}], "]"}]}], "}"}], "]"}], ",", 
            "\"\<]\>\""}], "}"}], "]"}], ",", "rhs"}], "}"}], "]"}], ",", 
      "StandardForm"}], "]"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MakeBoxes", "[", 
     RowBox[{
      RowBox[{"GaussianDKernel", "[", 
       RowBox[{
        RowBox[{"{", "t__", "}"}], ",", 
        RowBox[{"{", "n__", "}"}], ",", 
        RowBox[{"{", "x__", "}"}]}], "]"}], ",", "StandardForm"}], "]"}], ":=", 
    RowBox[{"RowBox", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"SubsuperscriptBox", "[", 
        RowBox[{"\"\<G\>\"", ",", 
         RowBox[{"makeHeldRowBoxOfBoxes", "[", 
          RowBox[{
           RowBox[{"{", "t", "}"}], ",", "StandardForm", ",", "None"}], "]"}],
          ",", 
         RowBox[{"TagBox", "[", 
          RowBox[{
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{"\"\<(\>\"", ",", 
              RowBox[{"makeHeldRowBoxOfBoxes", "[", 
               RowBox[{
                RowBox[{"{", "n", "}"}], ",", "StandardForm", ",", "None"}], 
               "]"}], ",", "\"\<)\>\""}], "}"}], "]"}], ",", "Derivative"}], 
          "]"}], ",", 
         RowBox[{"MultilineFunction", "\[Rule]", "None"}]}], "]"}], ",", 
       "\"\<[\>\"", ",", 
       RowBox[{"makeHeldRowBoxOfBoxes", "[", 
        RowBox[{
         RowBox[{"{", "x", "}"}], ",", "StandardForm", ",", "None"}], "]"}], 
       ",", "\"\<]\>\""}], "}"}], "]"}]}]}]}]], "PackageInput"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["GaussianBlur", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"GaussianBlur", "[", "t_", "]"}], "[", 
   RowBox[{"img_", "?", "ImageQ"}], "]"}], ":=", 
  RowBox[{"Image", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"GaussianBlur", "[", "t", "]"}], "[", 
     RowBox[{"ImageData", "[", 
      RowBox[{"img", ",", 
       RowBox[{"Interleaving", "\[Rule]", " ", "True"}]}], "]"}], "]"}], ",", 
    
    RowBox[{"Sequence", "@@", 
     RowBox[{"Options", "[", "img", "]"}]}]}], "]"}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"GaussianBlur", "[", 
     RowBox[{"0", "|", "0."}], "]"}], "[", "img_List", "]"}], " ", "=", 
   "img"}], ";"}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"GaussianBlur", "[", 
     RowBox[{"t_", "?", "NumericQ"}], "]"}], "[", "img_List", "]"}], " ", ":=",
    " ", 
   RowBox[{
    RowBox[{"GaussianDerivative", "[", 
     RowBox[{"Sequence", "@@", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"ArrayDepth", "[", "img", "]"}], "}"}]}], "]"}]}], "]"}], 
    "[", "img", "]"}]}], ";"}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"GaussianBlur", "[", 
    RowBox[{"{", 
     RowBox[{"ts__", "?", "NumericQ"}], "}"}], "]"}], "[", "img_List", "]"}], 
  " ", ":=", " ", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"GaussianDerivative", "[", 
     RowBox[{"Sequence", "@@", 
      RowBox[{"Thread", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", "ts", "}"}], ",", "0"}], "}"}], "]"}]}], "]"}], "[", 
    "img", "]"}], "/;", 
   RowBox[{
    RowBox[{"TensorRank", "[", "img", "]"}], "\[GreaterEqual]", 
    RowBox[{"Length", "[", 
     RowBox[{"{", "ts", "}"}], "]"}]}]}]}]], "PackageInput"]
}, Closed]],

Cell[CellGroupData[{

Cell["GaussianD", "Subsection"],

Cell[CellGroupData[{

Cell["Symbolical Implementation", "Subsubsection"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"N", "-", 
   RowBox[{"dimensional", " ", "Gaussian", " ", "D", " ", "operation"}]}], 
  " ", "*)"}]], "PackageInput",
 InitializationCell->True],

Cell[TextData[StyleBox["Utilties & Patterns:",
 FontWeight->"Bold"]], "Text"],

Cell["\<\
Utility function ConstantQ checks, if function f is constant with respect to \
the variables in the derivative specifications stns.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ConstantQ", "[", 
   RowBox[{"f_", ",", "stns_List"}], "]"}], " ", ":=", " ", 
  RowBox[{"FreeQ", "[", 
   RowBox[{"f", ",", 
    RowBox[{"Alternatives", "@@", 
     RowBox[{"Map", "[", 
      RowBox[{"First", ",", "stns"}], "]"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ConstantQ", "[", 
   RowBox[{"f_", ",", "symb"}], "]"}], " ", ":=", " ", 
  RowBox[{"FreeQ", "[", 
   RowBox[{"f", ",", "symb"}], "]"}]}]}], "PackageInput"],

Cell["\<\
Utility function GaussianDOrderQ checks, if the argument is an admissable \
derivative order, i.e. a non negative integer or a symbolic expression.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianDOrderQ", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"IntegerQ", "[", "#", "]"}], " ", "\[And]", " ", 
        RowBox[{"NonNegative", "[", "#", "]"}]}], ")"}], "\[Or]", " ", 
      RowBox[{"Not", "[", 
       RowBox[{"NumericQ", "[", "#", "]"}], "]"}]}], ")"}], "&"}]}], 
  ";"}]], "PackageInput"],

Cell["\<\
stnPattern is a Pattern for a Gaussian derivative specification, i.e. a List \
of a variable symbol, a scale parameter and an admissable derivative order.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"GaussianD", "::", "dvar"}], "=", " ", 
   "\"\<Multiple Gaussian derivative specifier `1` does not have the form \
{variable, t, n} where n is a nonnegative machine integer.\>\""}], 
  ";"}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"stnPattern", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"_Symbol", "|", "_Slot"}], ",", "_", ",", "_"}], "}"}], "?", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"GaussianDOrderQ", "[", 
         RowBox[{"Last", "[", "#", "]"}], "]"}], ",", "True", ",", 
        RowBox[{"Message", "[", 
         RowBox[{
          RowBox[{"GaussianD", "::", "dvar"}], ",", "#"}], "]"}]}], "]"}], 
      "&"}], ")"}]}]}], ";"}]], "PackageInput"],

Cell[TextData[StyleBox["Preprocessing",
 FontWeight->"Bold"]], "Text"],

Cell["\<\
Every Gaussian derivative specification is extended to a List containing a \
variable symbol, a scale parameter and an admissable derivative order with \
defautl 1.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianD", "[", 
   RowBox[{"f_", ",", 
    RowBox[{"stns", ":", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"_Symbol", "|", "_Slot"}], ",", "__"}], "}"}], ".."}]}], ",", 
    "opts___Rule"}], "]"}], ":=", " ", 
  RowBox[{
   RowBox[{"GaussianD", "[", 
    RowBox[{"f", ",", 
     RowBox[{"Sequence", " ", "@@", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"PadRight", "[", 
          RowBox[{"#", ",", "3", ",", "1"}], "]"}], "&"}], ",", 
        RowBox[{"{", "stns", "}"}]}], "]"}]}], ",", "opts"}], "]"}], " ", "/;",
    " ", 
   RowBox[{"Not", "[", 
    RowBox[{"MatchQ", "[", 
     RowBox[{
      RowBox[{"Dimensions", "[", 
       RowBox[{"{", "stns", "}"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"_", ",", "3"}], "}"}]}], "]"}], "]"}]}]}]], "PackageInput"],

Cell[TextData[StyleBox["General Rules",
 FontWeight->"Bold"]], "Text"],

Cell["\<\
Omitting identity operations (e.g. GaussianD[f[x], {x, 0, 0}] = f[x]).\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianD", "[", 
   RowBox[{"f_", ",", 
    RowBox[{"stn1", ":", 
     RowBox[{"stnPattern", "..."}]}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"_Symbol", "|", "_Slot"}], ",", 
      RowBox[{"0", "|", "0.0"}], ",", "0"}], "}"}], ",", 
    RowBox[{"stn2", ":", 
     RowBox[{"stnPattern", "..."}]}], ",", "opts___Rule"}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"GaussianD", "[", 
   RowBox[{"f", ",", "stn1", ",", "stn2", ",", "opts"}], 
   "]"}]}]], "PackageInput",
 InitializationCell->True],

Cell["Constant c:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianD", "[", 
   RowBox[{"c_", ",", 
    RowBox[{"stns", ":", 
     RowBox[{"stnPattern", ".."}]}], ",", "opts___Rule"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"\[Piecewise]", GridBox[{
      {"0", 
       RowBox[{"Or", " ", "@@", 
        RowBox[{"Thread", "[", 
         RowBox[{
          RowBox[{"Map", "[", 
           RowBox[{"Last", ",", 
            RowBox[{"{", "stns", "}"}]}], "]"}], ">", "0"}], "]"}]}]},
      {"c", 
       TagBox["True",
        "PiecewiseDefault",
        AutoDelete->False,
        DeletionWarning->True]}
     }]}], " ", "/;", " ", 
   RowBox[{"ConstantQ", "[", 
    RowBox[{"c", ",", 
     RowBox[{"{", "stns", "}"}]}], "]"}]}]}]], "PackageInput",
 InitializationCell->True],

Cell["Constant factor c:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianD", "[", 
   RowBox[{
    RowBox[{"c_", " ", "f_"}], ",", 
    RowBox[{"stns", ":", 
     RowBox[{"stnPattern", ".."}]}], ",", "opts___Rule"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"c", " ", 
    RowBox[{"GaussianD", "[", 
     RowBox[{"f", ",", "stns", ",", "opts"}], "]"}]}], "/;", " ", 
   RowBox[{"ConstantQ", "[", 
    RowBox[{"c", ",", 
     RowBox[{"{", "stns", "}"}]}], "]"}]}]}]], "PackageInput",
 InitializationCell->True],

Cell["\<\
Separation of variables (e.g. GaussianD[f[x] g[y], {x,tx,nx}, {y,tu,ny}] = \
GaussianD[f[x], {x,tx,nx}] GaussianD[g[y], {y,tu,ny}]).\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianD", "[", 
   RowBox[{
    RowBox[{"f_", " ", "*", " ", "g_"}], ",", 
    RowBox[{"stn1", ":", 
     RowBox[{"stnPattern", "..."}]}], ",", 
    RowBox[{"stn", ":", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"_Symbol", "|", "_Slot"}], ",", "_", ",", "_"}], "}"}]}], ",", 
    
    RowBox[{"stn2", ":", 
     RowBox[{"stnPattern", "..."}]}], ",", "opts___Rule"}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"GaussianD", "[", 
     RowBox[{"f", ",", "stn", ",", "opts"}], "]"}], " ", "*", " ", 
    RowBox[{"GaussianD", "[", 
     RowBox[{"g", ",", "stn1", ",", " ", "stn2", ",", "opts"}], "]"}]}], "/;",
    " ", 
   RowBox[{
    RowBox[{"ConstantQ", "[", 
     RowBox[{"f", ",", 
      RowBox[{"{", 
       RowBox[{"stn1", ",", "stn2"}], "}"}]}], "]"}], " ", "\[And]", "  ", 
    RowBox[{"ConstantQ", "[", 
     RowBox[{"g", ",", 
      RowBox[{"{", "stn", "}"}]}], "]"}]}]}]}]], "PackageInput",
 InitializationCell->True],

Cell["Summation rule:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianD", "[", 
   RowBox[{
    RowBox[{"f_", "+", "g_"}], ",", 
    RowBox[{"stn", ":", 
     RowBox[{"stnPattern", ".."}]}], ",", "opts___Rule"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"GaussianD", "[", 
    RowBox[{"f", ",", "stn", ",", "opts"}], "]"}], " ", "+", " ", 
   RowBox[{"GaussianD", "[", 
    RowBox[{"g", ",", "stn", ",", "opts"}], "]"}]}]}]], "PackageInput",
 InitializationCell->True],

Cell["Chain rule for inner linear functions in one dimension:", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"GaussianD", "[", 
    RowBox[{
     RowBox[{"f_", "[", 
      RowBox[{
       RowBox[{"a_.", " ", "x_"}], " ", "+", " ", "b_"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x_", ",", "t_", ",", "n_"}], "}"}], ",", "opts___Rule"}], 
    "]"}], " ", ":=", " ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Module", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", "\[Tau]", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       SuperscriptBox["a", "n"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"GaussianD", "[", 
          RowBox[{
           RowBox[{"f", "[", "x", "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "\[Tau]", ",", "n"}], "}"}], ",", "opts"}], 
          "]"}], "/.", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"x", "\[Rule]", " ", 
            RowBox[{
             RowBox[{"a", " ", "x"}], "+", "b"}]}], ",", " ", 
           RowBox[{"\[Tau]", "\[Rule]", " ", 
            RowBox[{
             SuperscriptBox["a", "2"], "t"}]}]}], "}"}]}], ")"}]}]}], 
     "\[IndentingNewLine]", "]"}], "/;", " ", 
    RowBox[{"ConstantQ", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"a", ",", "b"}], "}"}], ",", "x"}], "]"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"GaussianD", "[", 
   RowBox[{
    RowBox[{"f_", "[", 
     RowBox[{"a_", " ", "x_"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "t_", ",", "n_"}], "}"}], ",", "opts___Rule"}], "]"}],
   " ", ":=", " ", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "\[Tau]", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      SuperscriptBox["a", "n"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"GaussianD", "[", 
         RowBox[{
          RowBox[{"f", "[", "x", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "\[Tau]", ",", "n"}], "}"}], ",", "opts"}], 
         "]"}], "/.", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x", "\[Rule]", " ", 
           RowBox[{"a", " ", "x"}]}], ",", " ", 
          RowBox[{"\[Tau]", "\[Rule]", " ", 
           RowBox[{
            SuperscriptBox["a", "2"], "t"}]}]}], "}"}]}], ")"}]}]}], 
    "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{"ConstantQ", "[", 
    RowBox[{"a", ",", "x"}], "]"}]}]}]}], "PackageInput"],

Cell[TextData[StyleBox["Specific Rules",
 FontWeight->"Bold"]], "Text"],

Cell["\<\
Definition of explicit rules are implemented in GaussianD and not \
GaussianDerivative, since the chain rule does not apply to GaussianD!\
\>", "Text"],

Cell[TextData[{
 "Power rule (for integer powers and for fractional powers).\nNote the \
branching problems for symbolic n and p, in particular consider Pochhammer \
continuation in p for p\[Element]Integers.\nExclude the case ",
 Cell[BoxData[
  SuperscriptBox["x", "x"]]],
 "!"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianD", "[", 
   RowBox[{"x_", ",", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "t_", ",", 
      RowBox[{"n_", "?", "GaussianDOrderQ"}]}], "}"}], ",", "opts___Rule"}], 
   "]"}], ":=", 
  RowBox[{"\[Piecewise]", GridBox[{
     {"0", 
      RowBox[{"Refine", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"1", "<", "n"}], "/.", "\[InvisibleSpace]", 
         RowBox[{"{", "opts", "}"}]}], "/.", "\[InvisibleSpace]", 
        RowBox[{"Options", "[", "GaussianD", "]"}]}], "]"}]},
     {
      RowBox[{"n", "!"}], 
      RowBox[{"Refine", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"1", "\[Equal]", "n"}], "/.", "\[InvisibleSpace]", 
         RowBox[{"{", "opts", "}"}]}], "/.", "\[InvisibleSpace]", 
        RowBox[{"Options", "[", "GaussianD", "]"}]}], "]"}]},
     {
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], 
        RowBox[{"1", "+", "n"}]], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "t"}], ")"}], 
        RowBox[{"n", "/", "2"}]], " ", "x", " ", 
       RowBox[{"Pochhammer", "[", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         FractionBox[
          RowBox[{"2", "+", "n"}], "2"]}], "]"}], " ", 
       RowBox[{"Hypergeometric1F1", "[", 
        RowBox[{
         FractionBox["n", "2"], ",", 
         FractionBox["3", "2"], ",", 
         RowBox[{"-", 
          FractionBox[
           SuperscriptBox["x", "2"], 
           RowBox[{"4", " ", "t"}]]}]}], "]"}]}], 
      RowBox[{"Refine", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           FractionBox["n", "2"], "+", "1"}], "\[Element]", "Integers"}], "/.",
          "\[InvisibleSpace]", 
         RowBox[{"{", "opts", "}"}]}], "/.", "\[InvisibleSpace]", 
        RowBox[{"Options", "[", "GaussianD", "]"}]}], "]"}]},
     {
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "n"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "t"}], ")"}], 
        RowBox[{
         FractionBox[
          RowBox[{"n", "-", "1"}], "2"], " "}]], " ", 
       RowBox[{"Pochhammer", "[", 
        RowBox[{
         RowBox[{"-", "1"}], ",", 
         FractionBox[
          RowBox[{"n", "+", "1"}], "2"]}], "]"}], " ", 
       RowBox[{"Hypergeometric1F1", "[", 
        RowBox[{
         FractionBox[
          RowBox[{"n", "-", "1"}], "2"], ",", 
         FractionBox["1", "2"], ",", 
         RowBox[{"-", 
          FractionBox[
           SuperscriptBox["x", "2"], 
           RowBox[{"4", " ", "t"}]]}]}], "]"}]}], 
      RowBox[{"Refine", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"n", "+", "1"}], "2"], "\[Element]", "Integers"}], "/.", 
         "\[InvisibleSpace]", 
         RowBox[{"{", "opts", "}"}]}], "/.", "\[InvisibleSpace]", 
        RowBox[{"Options", "[", "GaussianD", "]"}]}], "]"}]}
    }]}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianD", "[", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x_", "p_"], "/;", " ", 
     RowBox[{"FreeQ", "[", 
      RowBox[{"p", ",", "x"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "t_", ",", 
      RowBox[{"n_", "?", "GaussianDOrderQ"}]}], "}"}], ",", "opts___Rule"}], 
   "]"}], ":=", 
  RowBox[{"\[Piecewise]", GridBox[{
     {"0", 
      RowBox[{"Refine", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"0", "\[LessEqual]", "p", "<", "n"}], "\[And]", 
         RowBox[{"p", "\[Element]", "Integers"}]}], ",", 
        RowBox[{
         RowBox[{"Assumptions", "/.", "\[InvisibleSpace]", 
          RowBox[{"{", "opts", "}"}]}], "/.", "\[InvisibleSpace]", 
         RowBox[{"Options", "[", "GaussianD", "]"}]}]}], "]"}]},
     {
      RowBox[{"n", "!"}], 
      RowBox[{"Refine", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"0", "\[LessEqual]", "p"}], "\[And]", 
         RowBox[{"p", "\[Element]", "Integers"}], "\[And]", 
         RowBox[{"p", "==", "n"}]}], ",", 
        RowBox[{
         RowBox[{"Assumptions", "/.", "\[InvisibleSpace]", 
          RowBox[{"{", "opts", "}"}]}], "/.", "\[InvisibleSpace]", 
         RowBox[{"Options", "[", "GaussianD", "]"}]}]}], "]"}]},
     {
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], 
        RowBox[{"n", "+", "1"}]], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "t"}], ")"}], 
        RowBox[{
         FractionBox["1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"n", "-", "p", "+", "1"}], ")"}]}]], " ", "x", " ", 
       RowBox[{"Pochhammer", "[", 
        RowBox[{
         RowBox[{"-", "p"}], ",", 
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"n", "+", "p", "+", "1"}], ")"}]}]}], "]"}], " ", 
       RowBox[{"Hypergeometric1F1", "[", 
        RowBox[{
         RowBox[{
          FractionBox["1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"n", "-", "p", "+", "1"}], ")"}]}], ",", 
         FractionBox["3", "2"], ",", 
         RowBox[{"-", 
          FractionBox[
           SuperscriptBox["x", "2"], 
           RowBox[{"4", " ", "t"}]]}]}], "]"}]}], 
      RowBox[{"Refine", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"0", "\[LessEqual]", "p"}], "\[And]", 
         RowBox[{"p", "\[Element]", "Integers"}], "\[And]", 
         RowBox[{
          FractionBox[
           RowBox[{"n", "+", "p", "+", "1"}], "2"], "\[Element]", 
          "Integers"}]}], ",", 
        RowBox[{
         RowBox[{"Assumptions", "/.", "\[InvisibleSpace]", 
          RowBox[{"{", "opts", "}"}]}], "/.", "\[InvisibleSpace]", 
         RowBox[{"Options", "[", "GaussianD", "]"}]}]}], "]"}]},
     {
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "n"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "t"}], ")"}], 
        FractionBox[
         RowBox[{"n", "-", "p"}], "2"]], " ", 
       RowBox[{"Pochhammer", "[", 
        RowBox[{
         RowBox[{"-", "p"}], ",", 
         FractionBox[
          RowBox[{"n", "+", "p"}], "2"]}], "]"}], " ", 
       RowBox[{"Hypergeometric1F1", "[", 
        RowBox[{
         FractionBox[
          RowBox[{"n", "-", "p"}], "2"], ",", 
         FractionBox["1", "2"], ",", 
         RowBox[{"-", 
          FractionBox[
           SuperscriptBox["x", "2"], 
           RowBox[{"4", " ", "t"}]]}]}], "]"}]}], 
      RowBox[{"Refine", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"0", "\[LessEqual]", "p"}], "\[And]", 
         RowBox[{"p", "\[Element]", "Integers"}], "\[And]", 
         RowBox[{
          FractionBox[
           RowBox[{"n", "+", "p"}], "2"], "\[Element]", "Integers"}]}], ",", 
        RowBox[{
         RowBox[{"Assumptions", "/.", "\[InvisibleSpace]", 
          RowBox[{"{", "opts", "}"}]}], "/.", "\[InvisibleSpace]", 
         RowBox[{"Options", "[", "GaussianD", "]"}]}]}], "]"}]},
     {
      RowBox[{
       FractionBox["1", "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], "n"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "t"}], ")"}], 
           FractionBox[
            RowBox[{"n", "-", "p"}], "2"]], " ", 
          RowBox[{"Pochhammer", "[", 
           RowBox[{
            RowBox[{"-", "p"}], ",", 
            FractionBox[
             RowBox[{"n", "+", "p"}], "2"]}], "]"}], " ", 
          RowBox[{"Hypergeometric1F1", "[", 
           RowBox[{
            FractionBox[
             RowBox[{"n", "-", "p"}], "2"], ",", 
            FractionBox["1", "2"], ",", 
            RowBox[{"-", 
             FractionBox[
              SuperscriptBox["x", "2"], 
              RowBox[{"4", " ", "t"}]]}]}], "]"}]}], "-", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"-", "t"}], ")"}], 
           FractionBox[
            RowBox[{"n", "-", "p", "+", "1"}], "2"]], " ", "x", " ", 
          RowBox[{"Pochhammer", "[", 
           RowBox[{
            RowBox[{"-", "p"}], ",", 
            FractionBox[
             RowBox[{"n", "+", "p", "+", "1"}], "2"]}], "]"}], " ", 
          RowBox[{"Hypergeometric1F1", "[", 
           RowBox[{
            FractionBox[
             RowBox[{"n", "-", "p", "+", "1"}], "2"], ",", 
            FractionBox["3", "2"], ",", 
            RowBox[{"-", 
             FractionBox[
              SuperscriptBox["x", "2"], 
              RowBox[{"4", " ", "t"}]]}]}], "]"}]}]}], ")"}]}], 
      RowBox[{"Refine", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Not", "[", 
          RowBox[{"p", " ", "\[Element]", " ", "Integers"}], "]"}], " ", 
         "\[Or]", " ", 
         RowBox[{"p", "<", " ", "0"}]}], ",", " ", 
        RowBox[{
         RowBox[{"Assumptions", " ", "/.", " ", 
          RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
         RowBox[{"Options", "[", "GaussianD", "]"}]}]}], "]"}]}
    }]}]}]], "PackageInput"],

Cell["Trigonometric functions:", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"GaussianD", "[", 
    RowBox[{
     RowBox[{"Cos", "[", "x_", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x_", ",", "t_", ",", 
       RowBox[{"n_", "?", "GaussianDOrderQ"}]}], "}"}], ",", "opts___Rule"}], 
    "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", "t"}]], " ", 
    RowBox[{
     RowBox[{
      RowBox[{"Derivative", "[", "n", "]"}], "[", "Cos", "]"}], "[", "x", 
     "]"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"GaussianD", "[", 
    RowBox[{
     RowBox[{"Sin", "[", "x_", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x_", ",", "t_", ",", 
       RowBox[{"n_", "?", "GaussianDOrderQ"}]}], "}"}], ",", "opts___Rule"}], 
    "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{"-", "t"}]], " ", 
    RowBox[{
     RowBox[{
      RowBox[{"Derivative", "[", "n", "]"}], "[", "Sin", "]"}], "[", "x", 
     "]"}]}]}], ";"}]}], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianD", "[", 
   RowBox[{
    RowBox[{"ArcTan", "[", "x_", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "t_", ",", 
      RowBox[{"n_", "?", "GaussianDOrderQ"}]}], "}"}], ",", "opts___Rule"}], 
   "]"}], " ", ":=", " ", 
  RowBox[{"\[Piecewise]", GridBox[{
     {
      RowBox[{
       RowBox[{
        FractionBox["\[Pi]", 
         RowBox[{"2", " "}]], " ", 
        RowBox[{"Re", "[", 
         RowBox[{"Erf", "[", 
          FractionBox[
           RowBox[{"x", "+", "\[ImaginaryI]"}], 
           RowBox[{"2", " ", 
            SqrtBox["t"]}]], "]"}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", 
         RowBox[{"4", " ", "t"}]], 
        RowBox[{"Re", "[", 
         RowBox[{"\[ImaginaryI]", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"x", "+", "\[ImaginaryI]"}], ")"}], "2"], " ", 
          RowBox[{"HypergeometricPFQ", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", "1"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              FractionBox["3", "2"], ",", "2"}], "}"}], ",", 
            RowBox[{"-", 
             FractionBox[
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"x", "+", "\[ImaginaryI]"}], ")"}], "2"], 
              RowBox[{"4", " ", "t"}]]}]}], "]"}]}], "]"}], "a"}]}], 
      RowBox[{"n", "===", "0"}]},
     {
      RowBox[{
       FractionBox[
        RowBox[{
         SqrtBox["\[Pi]"], " "}], 
        RowBox[{"2", " ", 
         SqrtBox["t"]}]], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"-", 
            FractionBox[
             RowBox[{
              SuperscriptBox["x", "2"], "-", "1"}], 
             RowBox[{"4", " ", "t"}]]}]], " ", 
          RowBox[{"Cos", "[", 
           FractionBox["x", 
            RowBox[{"2", " ", "t"}]], "]"}]}], "+", 
         RowBox[{"Re", "[", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{"-", 
             FractionBox[
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"x", "+", "\[ImaginaryI]"}], ")"}], "2"], 
              RowBox[{"4", " ", "t"}]]}]], " ", 
           RowBox[{"Erf", "[", 
            FractionBox[
             RowBox[{
              RowBox[{"\[ImaginaryI]", " ", "x"}], "-", "1"}], 
             RowBox[{"2", " ", 
              SqrtBox["t"]}]], "]"}]}], "]"}]}], ")"}]}], 
      RowBox[{"n", "===", "1"}]},
     {
      RowBox[{
       FractionBox["1", "2"], "  ", 
       RowBox[{"(", " ", 
        RowBox[{
         RowBox[{
          SuperscriptBox["t", 
           RowBox[{"-", 
            FractionBox["n", "2"]}]], 
          RowBox[{"Gamma", "[", 
           FractionBox["n", "2"], "]"}], " ", 
          RowBox[{"Re", "[", 
           RowBox[{
            SuperscriptBox["\[ImaginaryI]", 
             RowBox[{"n", "+", "1"}]], " ", 
            RowBox[{"Hypergeometric1F1", "[", 
             RowBox[{
              FractionBox["n", "2"], ",", 
              FractionBox["1", "2"], ",", 
              RowBox[{"-", 
               FractionBox[
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"x", "+", "\[ImaginaryI]"}], ")"}], "2"], 
                RowBox[{"4", " ", "t"}]]}]}], "]"}]}], "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["t", 
           RowBox[{"-", 
            FractionBox[
             RowBox[{"n", "+", "1"}], "2"]}]], " ", 
          RowBox[{"Gamma", "[", 
           FractionBox[
            RowBox[{"n", "+", "1"}], "2"], "]"}], " ", 
          RowBox[{"Re", "[", 
           RowBox[{
            SuperscriptBox["\[ImaginaryI]", "n"], " ", 
            RowBox[{"(", 
             RowBox[{"x", "+", "\[ImaginaryI]"}], ")"}], " ", 
            RowBox[{"Hypergeometric1F1", "[", 
             RowBox[{
              FractionBox[
               RowBox[{"n", "+", "1"}], "2"], ",", 
              FractionBox["3", "2"], ",", 
              RowBox[{"-", 
               FractionBox[
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"x", "+", "\[ImaginaryI]"}], ")"}], "2"], 
                RowBox[{"4", " ", "t"}]]}]}], "]"}]}], "]"}]}]}], ")"}]}], 
      RowBox[{"n", " ", "\[GreaterEqual]", " ", "2"}]}
    }]}]}]], "PackageInput"],

Cell["Exponential functions:", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"GaussianD", "[", 
    RowBox[{
     RowBox[{"Exp", "[", "x_", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x_", ",", "t_", ",", 
       RowBox[{"n_", "?", "GaussianDOrderQ"}]}], "}"}], ",", "opts___Rule"}], 
    "]"}], "   ", "=", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"t", "+", "x"}]]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"GaussianD", "[", 
    RowBox[{
     RowBox[{"Cosh", "[", "x_", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x_", ",", "t_", ",", 
       RowBox[{"n_", "?", "GaussianDOrderQ"}]}], "}"}], ",", "opts___Rule"}], 
    "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", "t"], " ", 
    RowBox[{
     RowBox[{
      RowBox[{"Derivative", "[", "n", "]"}], "[", "Cosh", "]"}], "[", "x", 
     "]"}]}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"GaussianD", "[", 
    RowBox[{
     RowBox[{"Sinh", "[", "x_", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x_", ",", "t_", ",", 
       RowBox[{"n_", "?", "GaussianDOrderQ"}]}], "}"}], ",", "opts___Rule"}], 
    "]"}], " ", "=", " ", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", "t"], " ", 
    RowBox[{
     RowBox[{
      RowBox[{"Derivative", "[", "n", "]"}], "[", "Sinh", "]"}], "[", "x", 
     "]"}]}]}], ";"}]}], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianD", "[", 
   RowBox[{
    RowBox[{"Erf", "[", "x_", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "t_", ",", 
      RowBox[{"n_", "?", "GaussianDOrderQ"}]}], "}"}], ",", "opts___Rule"}], 
   "]"}], " ", ":=", " ", 
  RowBox[{"\[Piecewise]", GridBox[{
     {
      RowBox[{"Erf", "[", 
       FractionBox["x", 
        SqrtBox[
         RowBox[{"1", "+", 
          RowBox[{"4", " ", "t"}]}]]], "]"}], 
      RowBox[{"n", "===", "0"}]},
     {
      RowBox[{"2", " ", 
       RowBox[{"GaussianDKernel", "[", 
        RowBox[{
         RowBox[{"t", "+", 
          FractionBox["1", "4"]}], ",", 
         RowBox[{"n", "-", "1"}], ",", "x"}], "]"}]}], 
      RowBox[{"n", "\[GreaterEqual]", "1"}]}
    }]}]}]], "PackageInput"],

Cell["\<\
Abs function, DiracDelta distribution and derivatives thereof:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianD", "[", 
   RowBox[{
    RowBox[{"DiracDelta", "[", "x_", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "t_", ",", 
      RowBox[{"n_", "?", "GaussianDOrderQ"}]}], "}"}], ",", "opts___Rule"}], 
   "]"}], " ", ":=", " ", 
  RowBox[{"GaussianDKernel", "[", 
   RowBox[{"t", ",", "n", ",", "x"}], "]"}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianD", "[", 
   RowBox[{
    RowBox[{"Abs", "[", "x_", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "t_", ",", 
      RowBox[{"n_", "?", "GaussianDOrderQ"}]}], "}"}], ",", "opts___Rule"}], 
   "]"}], " ", ":=", " ", 
  RowBox[{"\[Piecewise]", GridBox[{
     {
      RowBox[{
       RowBox[{"2", " ", 
        SqrtBox[
         FractionBox["t", "\[Pi]"]], " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", 
          FractionBox[
           SuperscriptBox["x", "2"], 
           RowBox[{"4", " ", "t"}]]}]]}], "+", 
       RowBox[{"x", " ", 
        RowBox[{"Erf", "[", 
         FractionBox["x", 
          RowBox[{"2", " ", 
           SqrtBox["t"]}]], "]"}]}]}], 
      RowBox[{"n", "===", "0"}]},
     {
      RowBox[{"Erf", "[", 
       FractionBox["x", 
        RowBox[{"2", " ", 
         SqrtBox["t"]}]], "]"}], 
      RowBox[{"n", "===", "1"}]},
     {
      RowBox[{"2", " ", 
       RowBox[{"GaussianDKernel", "[", 
        RowBox[{"t", ",", 
         RowBox[{"n", "-", "2"}], ",", "x"}], "]"}]}], 
      RowBox[{"n", "\[GreaterEqual]", "2"}]}
    }]}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianD", "[", 
   RowBox[{
    RowBox[{"UnitStep", "[", "x_", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "t_", ",", 
      RowBox[{"n_", "?", "GaussianDOrderQ"}]}], "}"}], ",", "opts___Rule"}], 
   "]"}], " ", ":=", 
  RowBox[{"\[Piecewise]", GridBox[{
     {
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         RowBox[{"Erf", "[", 
          FractionBox["x", 
           RowBox[{"2", " ", 
            SqrtBox["t"]}]], "]"}]}], ")"}]}], 
      RowBox[{"n", "===", "0"}]},
     {
      RowBox[{"GaussianDKernel", "[", 
       RowBox[{"t", ",", 
        RowBox[{"n", "-", "1"}], ",", "x"}], "]"}], 
      RowBox[{"n", "\[GreaterEqual]", "1"}]}
    }]}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianD", "[", 
   RowBox[{
    RowBox[{"Sign", "[", "x_", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "t_", ",", 
      RowBox[{"n_", "?", "GaussianDOrderQ"}]}], "}"}], ",", "opts___Rule"}], 
   "]"}], " ", ":=", 
  RowBox[{"\[Piecewise]", GridBox[{
     {
      RowBox[{"Erf", "[", 
       FractionBox["x", 
        RowBox[{"2", " ", 
         SqrtBox["t"]}]], "]"}], 
      RowBox[{"n", "===", "0"}]},
     {
      RowBox[{"2", " ", 
       RowBox[{"GaussianDKernel", "[", 
        RowBox[{"t", ",", 
         RowBox[{"n", "-", "1"}], ",", "x"}], "]"}]}], 
      RowBox[{"n", "\[GreaterEqual]", "1"}]}
    }]}]}]], "PackageInput"],

Cell["Gabor functions:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianD", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", 
      RowBox[{"\[Nu]_.", " ", "x_"}], "]"}], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"s_.", " ", 
       SuperscriptBox["x_", "2"]}]]}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "t_", ",", 
      RowBox[{"n_", "?", "GaussianDOrderQ"}]}], "}"}], ",", "opts___Rule"}], 
   "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    FractionBox[
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"t", " ", 
         SuperscriptBox["\[Nu]", "2"]}], 
        RowBox[{"1", "-", 
         RowBox[{"4", " ", "s", " ", "t"}]}]]}]], 
     SqrtBox[
      RowBox[{"1", "-", 
       RowBox[{"4", " ", "s", " ", "t"}]}]]], 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"s", " ", 
          SuperscriptBox["x", "2"]}], 
         RowBox[{"1", "-", 
          RowBox[{"4", " ", "s", " ", "t"}]}]]], " ", 
       RowBox[{"Cos", "[", 
        FractionBox[
         RowBox[{"\[Nu]", " ", "x"}], 
         RowBox[{"1", "-", 
          RowBox[{"4", " ", "s", " ", "t"}]}]], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "n"}], "}"}]}], "]"}]}], "/;", " ", 
   RowBox[{"Refine", "[", 
    RowBox[{
     RowBox[{"s", "\[LessEqual]", "0"}], " ", ",", " ", 
     RowBox[{
      RowBox[{"Assumptions", " ", "/.", " ", 
       RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
      RowBox[{"Options", "[", "GaussianD", "]"}]}]}], 
    "]"}]}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianD", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"\[Nu]_.", " ", "x_"}], "]"}], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"s_.", " ", 
       SuperscriptBox["x_", "2"]}]]}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "t_", ",", 
      RowBox[{"n_", "?", "GaussianDOrderQ"}]}], "}"}], ",", "opts___Rule"}], 
   "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    FractionBox[
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"t", " ", 
         SuperscriptBox["\[Nu]", "2"]}], 
        RowBox[{"1", "-", 
         RowBox[{"4", " ", "s", " ", "t"}]}]]}]], 
     SqrtBox[
      RowBox[{"1", "-", 
       RowBox[{"4", " ", "s", " ", "t"}]}]]], 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"s", " ", 
          SuperscriptBox["x", "2"]}], 
         RowBox[{"1", "-", 
          RowBox[{"4", " ", "s", " ", "t"}]}]]], " ", 
       RowBox[{"Sin", "[", 
        FractionBox[
         RowBox[{"\[Nu]", " ", "x"}], 
         RowBox[{"1", "-", 
          RowBox[{"4", " ", "s", " ", "t"}]}]], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "n"}], "}"}]}], "]"}]}], "/;", " ", 
   RowBox[{"Refine", "[", 
    RowBox[{
     RowBox[{"s", "\[LessEqual]", "0"}], ",", " ", 
     RowBox[{
      RowBox[{"Assumptions", " ", "/.", " ", 
       RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
      RowBox[{"Options", "[", "GaussianD", "]"}]}]}], 
    "]"}]}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianD", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Exp", "[", 
      RowBox[{"\[ImaginaryI]", " ", "\[Nu]_.", " ", "x_"}], "]"}], " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"s_.", " ", 
       SuperscriptBox["x_", "2"]}]]}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "t_", ",", 
      RowBox[{"n_", "?", "GaussianDOrderQ"}]}], "}"}], ",", "opts___Rule"}], 
   "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    FractionBox[
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"t", " ", 
         SuperscriptBox["\[Nu]", "2"]}], 
        RowBox[{"1", "-", 
         RowBox[{"4", " ", "s", " ", "t"}]}]]}]], 
     SqrtBox[
      RowBox[{"1", "-", 
       RowBox[{"4", " ", "s", " ", "t"}]}]]], 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"s", " ", 
          SuperscriptBox["x", "2"]}], 
         RowBox[{"1", "-", 
          RowBox[{"4", " ", "s", " ", "t"}]}]]], " ", 
       RowBox[{"Exp", "[", 
        FractionBox[
         RowBox[{"\[ImaginaryI]", " ", "\[Nu]", " ", "x"}], 
         RowBox[{"1", "-", 
          RowBox[{"4", " ", "s", " ", "t"}]}]], "]"}]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "n"}], "}"}]}], "]"}]}], "/;", " ", 
   RowBox[{"Refine", "[", 
    RowBox[{
     RowBox[{"s", "\[LessEqual]", "0"}], ",", " ", 
     RowBox[{
      RowBox[{"Assumptions", " ", "/.", " ", 
       RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
      RowBox[{"Options", "[", "GaussianD", "]"}]}]}], 
    "]"}]}]}]], "PackageInput"],

Cell[TextData[StyleBox["Fundamental Rules",
 FontWeight->"Bold"]], "Text"],

Cell["Concatenation of Gaussian derivations:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianD", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"GaussianDerivative", "[", "tn__", "]"}], "[", "img_", "]"}], 
     "[", 
     RowBox[{"s", ":", 
      RowBox[{"_Symbol", "|", 
       RowBox[{"_Slot", ".."}]}]}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"stns", ":", 
     RowBox[{"stnPattern", ".."}]}], ",", "\[IndentingNewLine]", 
    "opts___Rule"}], "\[IndentingNewLine]", "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"GaussianDerivative", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Sequence", "@@", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"{", "tn", "}"}], "+", 
         RowBox[{"Replace", "[", 
          RowBox[{
           RowBox[{"{", "s", "}"}], ",", 
           RowBox[{"Append", "[", 
            RowBox[{
             RowBox[{"Map", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"First", "[", "#", "]"}], "\[Rule]", 
                  RowBox[{"Rest", "[", "#", "]"}]}], ")"}], "&"}], ",", 
               RowBox[{"{", "stns", "}"}]}], "]"}], ",", 
             RowBox[{"_", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"0", ",", "0"}], "}"}]}]}], "]"}], ",", 
           RowBox[{"{", "1", "}"}]}], "]"}]}], ")"}]}], ",", 
      "\[IndentingNewLine]", "opts"}], "\[IndentingNewLine]", "]"}], "[", 
    "img", "]"}], "[", "s", "]"}]}]], "PackageInput",
 InitializationCell->True],

Cell["Processing a List of functions:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianD", "[", 
   RowBox[{"f_List", ",", 
    RowBox[{"stns", ":", 
     RowBox[{"stnPattern", ".."}]}], ",", "opts___Rule"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"GaussianD", "[", 
       RowBox[{"#", ",", "stns", ",", "opts"}], "]"}], "&"}], ",", "f"}], 
    "]"}], " ", "/;", " ", 
   RowBox[{"Not", "[", 
    RowBox[{"ArrayQ", "[", 
     RowBox[{"f", ",", "_", ",", "NumericQ"}], "]"}], 
    "]"}]}]}]], "PackageInput",
 InitializationCell->True],

Cell["Nesting of multidimensional Gaussian derivatives.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianD", "[", 
   RowBox[{"f_", ",", 
    RowBox[{"stnFirst", ":", "stnPattern"}], ",", 
    RowBox[{"stnRest", ":", 
     RowBox[{"stnPattern", ".."}]}], ",", " ", "opts___Rule"}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"GaussianD", "[", "\[IndentingNewLine]", 
    RowBox[{
    "result", ",", "\[IndentingNewLine]", "stnRest", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Assumptions", " ", "\[Rule]", " ", 
      RowBox[{"Prepend", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Head", "[", "#", "]"}], "===", "List"}], ",", "#", ",", 
            
            RowBox[{"{", "#", "}"}]}], "]"}], "&"}], "[", 
         RowBox[{
          RowBox[{"Assumptions", " ", "/.", " ", 
           RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
          RowBox[{"Options", "[", "GaussianD", "]"}]}], "]"}], ",", " ", 
        RowBox[{
         RowBox[{
         "stnFirst", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
         "\[GreaterEqual]", " ", "0"}]}], "\[IndentingNewLine]", "]"}]}], ",",
      "\[IndentingNewLine]", 
     RowBox[{"Sequence", " ", "@@", " ", 
      RowBox[{"DeleteCases", "[", 
       RowBox[{
        RowBox[{"{", "opts", "}"}], ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Assumptions", "\[Rule]", "_"}], ")"}], "|", 
         RowBox[{"(", 
          RowBox[{"Assumptions", "\[RuleDelayed]", "_"}], ")"}]}]}], 
       "]"}]}]}], "\[IndentingNewLine]", "]"}], " ", "/;", " ", 
   RowBox[{"FreeQ", "[", 
    RowBox[{
     RowBox[{"result", "=", 
      RowBox[{"GaussianD", "[", 
       RowBox[{"f", ",", "stnFirst", ",", "opts"}], "]"}]}], ",", 
     RowBox[{"GaussianD", "|", "GaussianDerivative"}]}], 
    "]"}]}]}]], "PackageInput"],

Cell["\<\
Gaussian derivation via Fourier transformation: (fractional and even negative \
derivatives!) (Dynamic programming)
Unprotect for dynamical assignment and prepending the downvalue list!\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianD", "[", 
   RowBox[{"f_", ",", 
    RowBox[{"stns", ":", 
     RowBox[{"stnPattern", ".."}]}], ",", " ", "opts___Rule"}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "result", ",", "xs", ",", "ts", ",", "ns", ",", "\[IndentingNewLine]", 
      RowBox[{"symbs", " ", "=", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"Thread", "[", 
          RowBox[{"#", "\[Rule]", " ", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              TagBox[
               StyleBox[
                RowBox[{"Pattern", "[", 
                 RowBox[{"#", ",", 
                  RowBox[{"Blank", "[", "]"}]}], "]"}],
                ShowSpecialCharacters->False,
                ShowStringCharacters->True,
                NumberMarks->True],
               FullForm], "&"}], ",", "#"}], "]"}]}], "]"}], "&"}], "[", 
        RowBox[{"Union", "[", 
         RowBox[{"Cases", "[", 
          RowBox[{
           RowBox[{"{", "stns", "}"}], ",", "_Symbol", ",", 
           RowBox[{"{", "2", "}"}]}], "]"}], "]"}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"ys", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Unique", "[", "\"\<y\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"Length", "[", 
           RowBox[{"{", "stns", "}"}], "]"}], "}"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"\[Omega]s", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Unique", "[", "\"\<\[Omega]\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"Length", "[", 
           RowBox[{"{", "stns", "}"}], "]"}], "}"}]}], "]"}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"xs", ",", "ts", ",", "ns"}], "}"}], "=", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", "stns", "}"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Unprotect", "[", "GaussianD", "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"PrependTo", "[", 
           RowBox[{
            RowBox[{"DownValues", "[", "GaussianD", "]"}], ",", 
            RowBox[{
             RowBox[{"HoldPattern", "[", 
              RowBox[{"GaussianD", "[", 
               RowBox[{"#1", ",", "##2", ",", " ", "opts"}], "]"}], "]"}], 
             "\[Rule]", "result"}]}], "]"}], ";", "\[IndentingNewLine]", 
          RowBox[{"Protect", "[", "GaussianD", "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"Return", "[", "result", "]"}]}], ")"}], "&"}], "[", 
       RowBox[{
        RowBox[{"f", " ", "/.", "symbs"}], ",", " ", 
        RowBox[{"Sequence", "@@", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"{", "stns", "}"}], " ", "/.", " ", "symbs"}], ")"}]}]}], 
       "]"}], " ", "/;", " ", "\[IndentingNewLine]", 
      RowBox[{"If", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"FreeQ", "[", 
         RowBox[{
          RowBox[{"result", "=", 
           RowBox[{"FourierTransform", "[", 
            RowBox[{
             RowBox[{"f", "/.", 
              RowBox[{"Thread", "[", 
               RowBox[{"xs", "\[Rule]", "ys"}], "]"}]}], ",", "ys", ",", 
             "\[Omega]s"}], "]"}]}], ",", "FourierTransform"}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"ts", ",", "ns"}], "}"}], "=", 
          RowBox[{"Transpose", "[", 
           RowBox[{"Map", "[", 
            RowBox[{"Rest", ",", 
             RowBox[{"{", "stns", "}"}]}], "]"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"FreeQ", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"result", "=", 
            RowBox[{
             RowBox[{"InverseFourierTransform", "[", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"FullSimplify", "[", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{
                  RowBox[{"Apply", "[", 
                   RowBox[{"Times", ",", 
                    SuperscriptBox[
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], "  ", "\[Omega]s"}], 
                    ")"}], "ns"]}], "]"}], " ", 
                  RowBox[{"Exp", "[", 
                   RowBox[{"-", 
                    RowBox[{"ts", ".", 
                    RowBox[{"(", " ", 
                    SuperscriptBox["\[Omega]s", "2"], ")"}]}]}], "]"}], "  ", 
                  "result"}], ",", "\[IndentingNewLine]", 
                 RowBox[{"Prepend", "[", 
                  RowBox[{
                   RowBox[{"Thread", "[", 
                    RowBox[{"ts", ">", "0"}], "]"}], ",", 
                   RowBox[{"Element", "[", 
                    RowBox[{"\[Omega]s", ",", "Reals"}], "]"}]}], "]"}]}], 
                "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
               "\[Omega]s", ",", "ys"}], "\[IndentingNewLine]", "]"}], "/.", 
             RowBox[{"Thread", "[", 
              RowBox[{"ys", "\[Rule]", "xs"}], "]"}]}]}], ",", 
           "\[IndentingNewLine]", "InverseFourierTransform"}], 
          "\[IndentingNewLine]", "]"}]}], ",", "\[IndentingNewLine]", 
        "False"}], "\[IndentingNewLine]", "]"}]}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "PackageInput",
 InitializationCell->True],

Cell["GaussianD of an abstract function.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianD", "[", 
   RowBox[{
    RowBox[{"f_Symbol", "[", 
     RowBox[{"s", ":", 
      RowBox[{"_Slot", ".."}]}], "]"}], ",", 
    RowBox[{"stns", ":", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"_Slot", ",", "_", ",", 
        RowBox[{"_", ":", "0"}]}], "}"}], ".."}]}], ",", "opts___Rule"}], 
   "]"}], ":=", 
  RowBox[{
   RowBox[{"GaussianDerivative", "[", 
    RowBox[{
     RowBox[{"Apply", "[", 
      RowBox[{"Sequence", ",", 
       RowBox[{"Replace", "[", 
        RowBox[{
         RowBox[{"{", "s", "}"}], ",", 
         RowBox[{"Append", "[", 
          RowBox[{
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"First", "[", "#", "]"}], "\[Rule]", 
                RowBox[{"Rest", "[", "#", "]"}]}], ")"}], "&"}], ",", 
             RowBox[{"{", "stns", "}"}]}], "]"}], ",", 
           RowBox[{"_", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0"}], "}"}]}]}], "]"}], ",", 
         RowBox[{"{", "1", "}"}]}], "]"}]}], "]"}], ",", "opts"}], "]"}], "[",
    "f", "]"}]}]], "PackageInput",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianD", "[", 
   RowBox[{
    RowBox[{"f_Symbol", "[", 
     RowBox[{"s", ":", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"_Symbol", "|", "_Slot"}], ")"}], ".."}]}], "]"}], ",", 
    RowBox[{"stns", ":", 
     RowBox[{"stnPattern", ".."}]}], ",", "opts___Rule"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"GaussianDerivative", "[", 
     RowBox[{
      RowBox[{"Apply", "[", 
       RowBox[{"Sequence", ",", 
        RowBox[{"Replace", "[", 
         RowBox[{
          RowBox[{"{", "s", "}"}], ",", 
          RowBox[{"Append", "[", 
           RowBox[{
            RowBox[{"Map", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"First", "[", "#", "]"}], "\[Rule]", 
                 RowBox[{"Rest", "[", "#", "]"}]}], ")"}], "&"}], ",", 
              RowBox[{"{", "stns", "}"}]}], "]"}], ",", 
            RowBox[{"_", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}]}]}], "]"}], ",", 
          RowBox[{"{", "1", "}"}]}], "]"}]}], "]"}], ",", "opts"}], "]"}], 
    "[", "f", "]"}], "[", "s", "]"}]}]], "PackageInput",
 InitializationCell->True],

Cell["GaussianD of an abstract derivative.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianD", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"GaussianDerivative", "[", 
       RowBox[{"tns", ":", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"_", ",", "_"}], "}"}], ".."}]}], "]"}], "[", "f_Symbol", 
      "]"}], "[", 
     RowBox[{"s", ":", 
      RowBox[{"_Slot", ".."}]}], "]"}], ",", 
    RowBox[{"stns", ":", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"_Slot", ",", "_", ",", 
        RowBox[{"_", ":", "0"}]}], "}"}], ".."}]}], ",", "opts___Rule"}], 
   "]"}], ":=", 
  RowBox[{
   RowBox[{"GaussianDerivative", "[", 
    RowBox[{
     RowBox[{"Apply", "[", 
      RowBox[{"Sequence", ",", 
       RowBox[{
        RowBox[{"{", "tns", "}"}], "+", 
        RowBox[{"Replace", "[", 
         RowBox[{
          RowBox[{"{", "s", "}"}], ",", 
          RowBox[{"Append", "[", 
           RowBox[{
            RowBox[{"Map", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"First", "[", "#", "]"}], "\[Rule]", 
                 RowBox[{"Rest", "[", "#", "]"}]}], ")"}], "&"}], ",", 
              RowBox[{"{", "stns", "}"}]}], "]"}], ",", 
            RowBox[{"_", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0"}], "}"}]}]}], "]"}], ",", 
          RowBox[{"{", "1", "}"}]}], "]"}]}]}], "]"}], ",", "opts"}], "]"}], 
   "[", "f", "]"}]}]], "PackageInput",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianD", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"GaussianDerivative", "[", 
       RowBox[{"tns", ":", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"_", ",", "_"}], "}"}], ".."}]}], "]"}], "[", "f_Symbol", 
      "]"}], "[", 
     RowBox[{"s", ":", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"_Symbol", "|", "_Slot"}], ")"}], ".."}]}], "]"}], ",", 
    RowBox[{"stns", ":", 
     RowBox[{"stnPattern", ".."}]}], ",", "opts___Rule"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"GaussianDerivative", "[", 
     RowBox[{
      RowBox[{"Apply", "[", 
       RowBox[{"Sequence", ",", 
        RowBox[{
         RowBox[{"{", "tns", "}"}], "+", 
         RowBox[{"Replace", "[", 
          RowBox[{
           RowBox[{"{", "s", "}"}], ",", 
           RowBox[{"Append", "[", 
            RowBox[{
             RowBox[{"Map", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"First", "[", "#", "]"}], "\[Rule]", 
                  RowBox[{"Rest", "[", "#", "]"}]}], ")"}], "&"}], ",", 
               RowBox[{"{", "stns", "}"}]}], "]"}], ",", 
             RowBox[{"_", "\[Rule]", 
              RowBox[{"{", 
               RowBox[{"0", ",", "0"}], "}"}]}]}], "]"}], ",", 
           RowBox[{"{", "1", "}"}]}], "]"}]}]}], "]"}], ",", "opts"}], "]"}], 
    "[", "f", "]"}], "[", "s", "]"}]}]], "PackageInput",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["GaussianD Input Notation", "Subsubsection"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     RowBox[{
      SubscriptBox["\[PartialD]", 
       RowBox[{
        SubscriptBox["G", "t_"], "[", "x_", "]"}]], "f_"}],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{"GaussianD", "[", 
      RowBox[{"f_", ",", 
       RowBox[{"{", 
        RowBox[{"x_", ",", "t_", ",", "1"}], "}"}]}], "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"GaussianD", " ", "Input", " ", "Notation"}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{"lhs___", ",", 
         RowBox[{"SubscriptBox", "[", 
          RowBox[{"\"\<\[PartialD]\>\"", ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"SubscriptBox", "[", 
               RowBox[{"\"\<G\>\"", ",", "t_"}], "]"}], ",", "\"\<[\>\"", ",",
               "x_", ",", "\"\<]\>\""}], "}"}], "]"}]}], "]"}], ",", "f_", 
         ",", "rhs___"}], "}"}], "]"}], ",", "StandardForm"}], "]"}], ":=", 
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{"lhs", ",", 
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<GaussianD\>\"", ",", "\"\<[\>\"", ",", 
            RowBox[{"RowBox", "[", 
             RowBox[{"{", 
              RowBox[{"f", ",", "\"\<,\>\"", ",", 
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<{\>\"", ",", 
                  RowBox[{"RowBox", "[", 
                   RowBox[{"{", 
                    RowBox[{
                    "x", ",", "\"\<,\>\"", ",", "t", ",", "\"\<,\>\"", ",", 
                    "\"\<1\>\""}], "}"}], "]"}], ",", "\"\<}\>\""}], "}"}], 
                "]"}]}], "}"}], "]"}], ",", "\"\<]\>\""}], "}"}], "]"}], ",", 
         "rhs"}], "}"}], "]"}], ",", "StandardForm"}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MakeBoxes", "[", 
     RowBox[{
      RowBox[{"GaussianD", "[", 
       RowBox[{"f_", ",", 
        RowBox[{"{", 
         RowBox[{"x_", ",", "t_", ",", "1"}], "}"}]}], "]"}], ",", 
      "StandardForm"}], "]"}], ":=", 
    RowBox[{"RowBox", "[", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"SubscriptBox", "[", 
        RowBox[{"\"\<\[PartialD]\>\"", ",", 
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"SubscriptBox", "[", 
             RowBox[{"\"\<G\>\"", ",", 
              RowBox[{"MakeBoxes", "[", 
               RowBox[{"t", ",", "StandardForm"}], "]"}]}], "]"}], ",", 
            "\"\<[\>\"", ",", 
            RowBox[{"MakeBoxes", "[", 
             RowBox[{"x", ",", "StandardForm"}], "]"}], ",", "\"\<]\>\""}], 
           "}"}], "]"}]}], "]"}], ",", 
       RowBox[{"Parenthesize", "[", 
        RowBox[{"f", ",", "StandardForm", ",", "D"}], "]"}]}], "}"}], 
     "]"}]}]}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     RowBox[{
      SubsuperscriptBox["\[PartialD]", 
       RowBox[{
        SubscriptBox["G", "t_"], "[", "x_", "]"}], 
       RowBox[{"(", "n_", ")"}]], "f_"}],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{"GaussianD", "[", 
      RowBox[{"f_", ",", 
       RowBox[{"{", 
        RowBox[{"x_", ",", "t_", ",", "n_"}], "}"}]}], "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{"lhs___", ",", 
        RowBox[{"SubsuperscriptBox", "[", 
         RowBox[{"\"\<\[PartialD]\>\"", ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"SubscriptBox", "[", 
              RowBox[{"\"\<G\>\"", ",", "t_"}], "]"}], ",", "\"\<[\>\"", ",", 
             "x_", ",", "\"\<]\>\""}], "}"}], "]"}], ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<(\>\"", ",", "n_", ",", "\"\<)\>\""}], "}"}], 
           "]"}]}], "]"}], ",", "f_", ",", "rhs___"}], "}"}], "]"}], ",", 
     "StandardForm"}], "]"}], ":=", 
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{"lhs", ",", 
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<GaussianD\>\"", ",", "\"\<[\>\"", ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{"f", ",", "\"\<,\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{
                   "x", ",", "\"\<,\>\"", ",", "t", ",", "\"\<,\>\"", ",", 
                    "n"}], "}"}], "]"}], ",", "\"\<}\>\""}], "}"}], "]"}]}], 
             "}"}], "]"}], ",", "\"\<]\>\""}], "}"}], "]"}], ",", "rhs"}], 
       "}"}], "]"}], ",", "StandardForm"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{"GaussianD", "[", 
     RowBox[{"f_", ",", 
      RowBox[{"{", 
       RowBox[{"x_", ",", "t_", ",", "n_"}], "}"}]}], "]"}], ",", 
    "StandardForm"}], "]"}], ":=", 
  RowBox[{"RowBox", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"SubsuperscriptBox", "[", 
      RowBox[{"\"\<\[PartialD]\>\"", ",", 
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"SubscriptBox", "[", 
           RowBox[{"\"\<G\>\"", ",", 
            RowBox[{"MakeBoxes", "[", 
             RowBox[{"t", ",", "StandardForm"}], "]"}]}], "]"}], ",", 
          "\"\<[\>\"", ",", 
          RowBox[{"MakeBoxes", "[", 
           RowBox[{"x", ",", "StandardForm"}], "]"}], ",", "\"\<]\>\""}], 
         "}"}], "]"}], ",", 
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<(\>\"", ",", 
          RowBox[{"MakeBoxes", "[", 
           RowBox[{"n", ",", "StandardForm"}], "]"}], ",", "\"\<)\>\""}], 
         "}"}], "]"}]}], "]"}], ",", 
     RowBox[{"Parenthesize", "[", 
      RowBox[{"f", ",", "StandardForm", ",", "D"}], "]"}]}], "}"}], 
   "]"}]}]}], "PackageInput"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     RowBox[{
      SubsuperscriptBox["\[PartialD]", 
       RowBox[{
        SubscriptBox["G", 
         RowBox[{"t1_", ",", "t2_"}]], "[", 
        RowBox[{"x1_", ",", "x2_"}], "]"}], 
       RowBox[{"(", 
        RowBox[{"n1_", ",", "n2_"}], ")"}]], "f_"}],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{"GaussianD", "[", 
      RowBox[{"f_", ",", 
       RowBox[{"{", 
        RowBox[{"x1_", ",", "t1_", ",", "n1_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x2_", ",", "t2_", ",", "n2_"}], "}"}]}], "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{"lhs___", ",", 
        RowBox[{"SubsuperscriptBox", "[", 
         RowBox[{"\"\<\[PartialD]\>\"", ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"SubscriptBox", "[", 
              RowBox[{"\"\<G\>\"", ",", 
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{"t1_", ",", "\"\<,\>\"", ",", "t2_"}], "}"}], 
                "]"}]}], "]"}], ",", "\"\<[\>\"", ",", 
             RowBox[{"RowBox", "[", 
              RowBox[{"{", 
               RowBox[{"x1_", ",", "\"\<,\>\"", ",", "x2_"}], "}"}], "]"}], 
             ",", "\"\<]\>\""}], "}"}], "]"}], ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<(\>\"", ",", 
             RowBox[{"RowBox", "[", 
              RowBox[{"{", 
               RowBox[{"n1_", ",", "\"\<,\>\"", ",", "n2_"}], "}"}], "]"}], 
             ",", "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", "f_", ",", 
        "rhs___"}], "}"}], "]"}], ",", "StandardForm"}], "]"}], ":=", 
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{"lhs", ",", 
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<GaussianD\>\"", ",", "\"\<[\>\"", ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{"f", ",", "\"\<,\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{
                   "x1", ",", "\"\<,\>\"", ",", "t1", ",", "\"\<,\>\"", ",", 
                    "n1"}], "}"}], "]"}], ",", "\"\<}\>\""}], "}"}], "]"}], 
              ",", "\"\<,\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{
                   "x2", ",", "\"\<,\>\"", ",", "t2", ",", "\"\<,\>\"", ",", 
                    "n2"}], "}"}], "]"}], ",", "\"\<}\>\""}], "}"}], "]"}]}], 
             "}"}], "]"}], ",", "\"\<]\>\""}], "}"}], "]"}], ",", "rhs"}], 
       "}"}], "]"}], ",", "StandardForm"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{"GaussianD", "[", 
     RowBox[{"f_", ",", 
      RowBox[{"{", 
       RowBox[{"x1_", ",", "t1_", ",", "n1_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x2_", ",", "t2_", ",", "n2_"}], "}"}]}], "]"}], ",", 
    "StandardForm"}], "]"}], ":=", 
  RowBox[{"RowBox", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"SubsuperscriptBox", "[", 
      RowBox[{"\"\<\[PartialD]\>\"", ",", 
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"SubscriptBox", "[", 
           RowBox[{"\"\<G\>\"", ",", 
            RowBox[{"RowBox", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"MakeBoxes", "[", 
                RowBox[{"t1", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
               ",", 
               RowBox[{"MakeBoxes", "[", 
                RowBox[{"t2", ",", "StandardForm"}], "]"}]}], "}"}], "]"}]}], 
           "]"}], ",", "\"\<[\>\"", ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"x1", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
             ",", 
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"x2", ",", "StandardForm"}], "]"}]}], "}"}], "]"}], 
          ",", "\"\<]\>\""}], "}"}], "]"}], ",", 
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<(\>\"", ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"n1", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
             ",", 
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"n2", ",", "StandardForm"}], "]"}]}], "}"}], "]"}], 
          ",", "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", 
     RowBox[{"Parenthesize", "[", 
      RowBox[{"f", ",", "StandardForm", ",", "D"}], "]"}]}], "}"}], 
   "]"}]}]}], "PackageInput"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     RowBox[{
      SubsuperscriptBox["\[PartialD]", 
       RowBox[{
        SubscriptBox["G", "t_"], "[", 
        RowBox[{"x1_", ",", "x2_"}], "]"}], 
       RowBox[{"(", 
        RowBox[{"n1_", ",", "n2_"}], ")"}]], "f_"}],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{"GaussianD", "[", 
      RowBox[{"f_", ",", 
       RowBox[{"{", 
        RowBox[{"x1_", ",", "t_", ",", "n1_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x2_", ",", "t_", ",", "n2_"}], "}"}]}], "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{"lhs___", ",", 
        RowBox[{"SubsuperscriptBox", "[", 
         RowBox[{"\"\<\[PartialD]\>\"", ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"SubscriptBox", "[", 
              RowBox[{"\"\<G\>\"", ",", "t_"}], "]"}], ",", "\"\<[\>\"", ",", 
             
             RowBox[{"RowBox", "[", 
              RowBox[{"{", 
               RowBox[{"x1_", ",", "\"\<,\>\"", ",", "x2_"}], "}"}], "]"}], 
             ",", "\"\<]\>\""}], "}"}], "]"}], ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<(\>\"", ",", 
             RowBox[{"RowBox", "[", 
              RowBox[{"{", 
               RowBox[{"n1_", ",", "\"\<,\>\"", ",", "n2_"}], "}"}], "]"}], 
             ",", "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", "f_", ",", 
        "rhs___"}], "}"}], "]"}], ",", "StandardForm"}], "]"}], ":=", 
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{"lhs", ",", 
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<GaussianD\>\"", ",", "\"\<[\>\"", ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{"f", ",", "\"\<,\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{
                   "x1", ",", "\"\<,\>\"", ",", "t", ",", "\"\<,\>\"", ",", 
                    "n1"}], "}"}], "]"}], ",", "\"\<}\>\""}], "}"}], "]"}], 
              ",", "\"\<,\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{
                   "x2", ",", "\"\<,\>\"", ",", "t", ",", "\"\<,\>\"", ",", 
                    "n2"}], "}"}], "]"}], ",", "\"\<}\>\""}], "}"}], "]"}]}], 
             "}"}], "]"}], ",", "\"\<]\>\""}], "}"}], "]"}], ",", "rhs"}], 
       "}"}], "]"}], ",", "StandardForm"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{"GaussianD", "[", 
     RowBox[{"f_", ",", 
      RowBox[{"{", 
       RowBox[{"x1_", ",", "t_", ",", "n1_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x2_", ",", "t_", ",", "n2_"}], "}"}]}], "]"}], ",", 
    "StandardForm"}], "]"}], ":=", 
  RowBox[{"RowBox", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"SubsuperscriptBox", "[", 
      RowBox[{"\"\<\[PartialD]\>\"", ",", 
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"SubscriptBox", "[", 
           RowBox[{"\"\<G\>\"", ",", 
            RowBox[{"MakeBoxes", "[", 
             RowBox[{"t", ",", "StandardForm"}], "]"}]}], "]"}], ",", 
          "\"\<[\>\"", ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"x1", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
             ",", 
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"x2", ",", "StandardForm"}], "]"}]}], "}"}], "]"}], 
          ",", "\"\<]\>\""}], "}"}], "]"}], ",", 
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<(\>\"", ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"n1", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
             ",", 
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"n2", ",", "StandardForm"}], "]"}]}], "}"}], "]"}], 
          ",", "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", 
     RowBox[{"Parenthesize", "[", 
      RowBox[{"f", ",", "StandardForm", ",", "D"}], "]"}]}], "}"}], 
   "]"}]}]}], "PackageInput"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     RowBox[{
      SubsuperscriptBox["\[PartialD]", 
       RowBox[{
        SubscriptBox["G", 
         RowBox[{"t1_", ",", "t2_", ",", "t3_"}]], "[", 
        RowBox[{"x1_", ",", "x2_", ",", "x3_"}], "]"}], 
       RowBox[{"(", 
        RowBox[{"n1_", ",", "n2_", ",", "n3_"}], ")"}]], "f_"}],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{"GaussianD", "[", 
      RowBox[{"f_", ",", 
       RowBox[{"{", 
        RowBox[{"x1_", ",", "t1_", ",", "n1_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x2_", ",", "t2_", ",", "n2_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x3_", ",", "t3_", ",", "n3_"}], "}"}]}], "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{"lhs___", ",", 
        RowBox[{"SubsuperscriptBox", "[", 
         RowBox[{"\"\<\[PartialD]\>\"", ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"SubscriptBox", "[", 
              RowBox[{"\"\<G\>\"", ",", 
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{
                 "t1_", ",", "\"\<,\>\"", ",", "t2_", ",", "\"\<,\>\"", ",", 
                  "t3_"}], "}"}], "]"}]}], "]"}], ",", "\"\<[\>\"", ",", 
             RowBox[{"RowBox", "[", 
              RowBox[{"{", 
               RowBox[{
               "x1_", ",", "\"\<,\>\"", ",", "x2_", ",", "\"\<,\>\"", ",", 
                "x3_"}], "}"}], "]"}], ",", "\"\<]\>\""}], "}"}], "]"}], ",", 
          
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<(\>\"", ",", 
             RowBox[{"RowBox", "[", 
              RowBox[{"{", 
               RowBox[{
               "n1_", ",", "\"\<,\>\"", ",", "n2_", ",", "\"\<,\>\"", ",", 
                "n3_"}], "}"}], "]"}], ",", "\"\<)\>\""}], "}"}], "]"}]}], 
         "]"}], ",", "f_", ",", "rhs___"}], "}"}], "]"}], ",", 
     "StandardForm"}], "]"}], ":=", 
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{"lhs", ",", 
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<GaussianD\>\"", ",", "\"\<[\>\"", ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{"f", ",", "\"\<,\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{
                   "x1", ",", "\"\<,\>\"", ",", "t1", ",", "\"\<,\>\"", ",", 
                    "n1"}], "}"}], "]"}], ",", "\"\<}\>\""}], "}"}], "]"}], 
              ",", "\"\<,\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{
                   "x2", ",", "\"\<,\>\"", ",", "t2", ",", "\"\<,\>\"", ",", 
                    "n2"}], "}"}], "]"}], ",", "\"\<}\>\""}], "}"}], "]"}], 
              ",", "\"\<,\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{
                   "x3", ",", "\"\<,\>\"", ",", "t3", ",", "\"\<,\>\"", ",", 
                    "n3"}], "}"}], "]"}], ",", "\"\<}\>\""}], "}"}], "]"}]}], 
             "}"}], "]"}], ",", "\"\<]\>\""}], "}"}], "]"}], ",", "rhs"}], 
       "}"}], "]"}], ",", "StandardForm"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{"GaussianD", "[", 
     RowBox[{"f_", ",", 
      RowBox[{"{", 
       RowBox[{"x1_", ",", "t1_", ",", "n1_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x2_", ",", "t2_", ",", "n2_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x3_", ",", "t3_", ",", "n3_"}], "}"}]}], "]"}], ",", 
    "StandardForm"}], "]"}], ":=", 
  RowBox[{"RowBox", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"SubsuperscriptBox", "[", 
      RowBox[{"\"\<\[PartialD]\>\"", ",", 
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"SubscriptBox", "[", 
           RowBox[{"\"\<G\>\"", ",", 
            RowBox[{"RowBox", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"MakeBoxes", "[", 
                RowBox[{"t1", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
               ",", 
               RowBox[{"MakeBoxes", "[", 
                RowBox[{"t2", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
               ",", 
               RowBox[{"MakeBoxes", "[", 
                RowBox[{"t3", ",", "StandardForm"}], "]"}]}], "}"}], "]"}]}], 
           "]"}], ",", "\"\<[\>\"", ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"x1", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
             ",", 
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"x2", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
             ",", 
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"x3", ",", "StandardForm"}], "]"}]}], "}"}], "]"}], 
          ",", "\"\<]\>\""}], "}"}], "]"}], ",", 
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<(\>\"", ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"n1", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
             ",", 
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"n2", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
             ",", 
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"n3", ",", "StandardForm"}], "]"}]}], "}"}], "]"}], 
          ",", "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", 
     RowBox[{"Parenthesize", "[", 
      RowBox[{"f", ",", "StandardForm", ",", "D"}], "]"}]}], "}"}], 
   "]"}]}]}], "PackageInput"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     RowBox[{
      SubsuperscriptBox["\[PartialD]", 
       RowBox[{
        SubscriptBox["G", "t_"], "[", 
        RowBox[{"x1_", ",", "x2_", ",", "x3_"}], "]"}], 
       RowBox[{"(", 
        RowBox[{"n1_", ",", "n2_", ",", "n3_"}], ")"}]], "f_"}],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{"GaussianD", "[", 
      RowBox[{"f_", ",", 
       RowBox[{"{", 
        RowBox[{"x1_", ",", "t_", ",", "n1_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x2_", ",", "t_", ",", "n2_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x3_", ",", "t_", ",", "n3_"}], "}"}]}], "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{"lhs___", ",", 
        RowBox[{"SubsuperscriptBox", "[", 
         RowBox[{"\"\<\[PartialD]\>\"", ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"SubscriptBox", "[", 
              RowBox[{"\"\<G\>\"", ",", "t_"}], "]"}], ",", "\"\<[\>\"", ",", 
             
             RowBox[{"RowBox", "[", 
              RowBox[{"{", 
               RowBox[{
               "x1_", ",", "\"\<,\>\"", ",", "x2_", ",", "\"\<,\>\"", ",", 
                "x3_"}], "}"}], "]"}], ",", "\"\<]\>\""}], "}"}], "]"}], ",", 
          
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<(\>\"", ",", 
             RowBox[{"RowBox", "[", 
              RowBox[{"{", 
               RowBox[{
               "n1_", ",", "\"\<,\>\"", ",", "n2_", ",", "\"\<,\>\"", ",", 
                "n3_"}], "}"}], "]"}], ",", "\"\<)\>\""}], "}"}], "]"}]}], 
         "]"}], ",", "f_", ",", "rhs___"}], "}"}], "]"}], ",", 
     "StandardForm"}], "]"}], ":=", 
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{"lhs", ",", 
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<GaussianD\>\"", ",", "\"\<[\>\"", ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{"f", ",", "\"\<,\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{
                   "x1", ",", "\"\<,\>\"", ",", "t", ",", "\"\<,\>\"", ",", 
                    "n1"}], "}"}], "]"}], ",", "\"\<}\>\""}], "}"}], "]"}], 
              ",", "\"\<,\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{
                   "x2", ",", "\"\<,\>\"", ",", "t", ",", "\"\<,\>\"", ",", 
                    "n2"}], "}"}], "]"}], ",", "\"\<}\>\""}], "}"}], "]"}], 
              ",", "\"\<,\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{
                   "x3", ",", "\"\<,\>\"", ",", "t", ",", "\"\<,\>\"", ",", 
                    "n3"}], "}"}], "]"}], ",", "\"\<}\>\""}], "}"}], "]"}]}], 
             "}"}], "]"}], ",", "\"\<]\>\""}], "}"}], "]"}], ",", "rhs"}], 
       "}"}], "]"}], ",", "StandardForm"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{"GaussianD", "[", 
     RowBox[{"f_", ",", 
      RowBox[{"{", 
       RowBox[{"x1_", ",", "t_", ",", "n1_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x2_", ",", "t_", ",", "n2_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x3_", ",", "t_", ",", "n3_"}], "}"}]}], "]"}], ",", 
    "StandardForm"}], "]"}], ":=", 
  RowBox[{"RowBox", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"SubsuperscriptBox", "[", 
      RowBox[{"\"\<\[PartialD]\>\"", ",", 
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"SubscriptBox", "[", 
           RowBox[{"\"\<G\>\"", ",", 
            RowBox[{"MakeBoxes", "[", 
             RowBox[{"t", ",", "StandardForm"}], "]"}]}], "]"}], ",", 
          "\"\<[\>\"", ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"x1", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
             ",", 
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"x2", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
             ",", 
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"x3", ",", "StandardForm"}], "]"}]}], "}"}], "]"}], 
          ",", "\"\<]\>\""}], "}"}], "]"}], ",", 
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<(\>\"", ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"n1", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
             ",", 
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"n2", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
             ",", 
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"n3", ",", "StandardForm"}], "]"}]}], "}"}], "]"}], 
          ",", "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", 
     RowBox[{"Parenthesize", "[", 
      RowBox[{"f", ",", "StandardForm", ",", "D"}], "]"}]}], "}"}], 
   "]"}]}]}], "PackageInput"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     RowBox[{
      SubsuperscriptBox["\[PartialD]", 
       RowBox[{
        SubscriptBox["G", 
         RowBox[{"t1_", ",", "t2_", ",", "t3_", ",", "t4_"}]], "[", 
        RowBox[{"x1_", ",", "x2_", ",", "x3_", ",", "x4_"}], "]"}], 
       RowBox[{"(", 
        RowBox[{"n1_", ",", "n2_", ",", "n3_", ",", "n4_"}], ")"}]], "f_"}],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{"GaussianD", "[", 
      RowBox[{"f_", ",", 
       RowBox[{"{", 
        RowBox[{"x1_", ",", "t1_", ",", "n1_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x2_", ",", "t2_", ",", "n2_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x3_", ",", "t3_", ",", "n3_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x4_", ",", "t4_", ",", "n4_"}], "}"}]}], "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{"lhs___", ",", 
        RowBox[{"SubsuperscriptBox", "[", 
         RowBox[{"\"\<\[PartialD]\>\"", ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"SubscriptBox", "[", 
              RowBox[{"\"\<G\>\"", ",", 
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{
                 "t1_", ",", "\"\<,\>\"", ",", "t2_", ",", "\"\<,\>\"", ",", 
                  "t3_", ",", "\"\<,\>\"", ",", "t4_"}], "}"}], "]"}]}], 
              "]"}], ",", "\"\<[\>\"", ",", 
             RowBox[{"RowBox", "[", 
              RowBox[{"{", 
               RowBox[{
               "x1_", ",", "\"\<,\>\"", ",", "x2_", ",", "\"\<,\>\"", ",", 
                "x3_", ",", "\"\<,\>\"", ",", "x4_"}], "}"}], "]"}], ",", 
             "\"\<]\>\""}], "}"}], "]"}], ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<(\>\"", ",", 
             RowBox[{"RowBox", "[", 
              RowBox[{"{", 
               RowBox[{
               "n1_", ",", "\"\<,\>\"", ",", "n2_", ",", "\"\<,\>\"", ",", 
                "n3_", ",", "\"\<,\>\"", ",", "n4_"}], "}"}], "]"}], ",", 
             "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", "f_", ",", "rhs___"}],
        "}"}], "]"}], ",", "StandardForm"}], "]"}], ":=", 
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{"lhs", ",", 
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<GaussianD\>\"", ",", "\"\<[\>\"", ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{"f", ",", "\"\<,\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{
                   "x1", ",", "\"\<,\>\"", ",", "t1", ",", "\"\<,\>\"", ",", 
                    "n1"}], "}"}], "]"}], ",", "\"\<}\>\""}], "}"}], "]"}], 
              ",", "\"\<,\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{
                   "x2", ",", "\"\<,\>\"", ",", "t2", ",", "\"\<,\>\"", ",", 
                    "n2"}], "}"}], "]"}], ",", "\"\<}\>\""}], "}"}], "]"}], 
              ",", "\"\<,\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{
                   "x3", ",", "\"\<,\>\"", ",", "t3", ",", "\"\<,\>\"", ",", 
                    "n3"}], "}"}], "]"}], ",", "\"\<}\>\""}], "}"}], "]"}], 
              ",", "\"\<,\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{
                   "x4", ",", "\"\<,\>\"", ",", "t4", ",", "\"\<,\>\"", ",", 
                    "n4"}], "}"}], "]"}], ",", "\"\<}\>\""}], "}"}], "]"}]}], 
             "}"}], "]"}], ",", "\"\<]\>\""}], "}"}], "]"}], ",", "rhs"}], 
       "}"}], "]"}], ",", "StandardForm"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{"GaussianD", "[", 
     RowBox[{"f_", ",", 
      RowBox[{"{", 
       RowBox[{"x1_", ",", "t1_", ",", "n1_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x2_", ",", "t2_", ",", "n2_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x3_", ",", "t3_", ",", "n3_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x4_", ",", "t4_", ",", "n4_"}], "}"}]}], "]"}], ",", 
    "StandardForm"}], "]"}], ":=", 
  RowBox[{"RowBox", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"SubsuperscriptBox", "[", 
      RowBox[{"\"\<\[PartialD]\>\"", ",", 
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"SubscriptBox", "[", 
           RowBox[{"\"\<G\>\"", ",", 
            RowBox[{"RowBox", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"MakeBoxes", "[", 
                RowBox[{"t1", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
               ",", 
               RowBox[{"MakeBoxes", "[", 
                RowBox[{"t2", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
               ",", 
               RowBox[{"MakeBoxes", "[", 
                RowBox[{"t3", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
               ",", 
               RowBox[{"MakeBoxes", "[", 
                RowBox[{"t4", ",", "StandardForm"}], "]"}]}], "}"}], "]"}]}], 
           "]"}], ",", "\"\<[\>\"", ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"x1", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
             ",", 
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"x2", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
             ",", 
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"x3", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
             ",", 
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"x4", ",", "StandardForm"}], "]"}]}], "}"}], "]"}], 
          ",", "\"\<]\>\""}], "}"}], "]"}], ",", 
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<(\>\"", ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"n1", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
             ",", 
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"n2", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
             ",", 
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"n3", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
             ",", 
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"n4", ",", "StandardForm"}], "]"}]}], "}"}], "]"}], 
          ",", "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", 
     RowBox[{"Parenthesize", "[", 
      RowBox[{"f", ",", "StandardForm", ",", "D"}], "]"}]}], "}"}], 
   "]"}]}]}], "PackageInput"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     RowBox[{
      SubsuperscriptBox["\[PartialD]", 
       RowBox[{
        SubscriptBox["G", "t_"], "[", 
        RowBox[{"x1_", ",", "x2_", ",", "x3_", ",", "x4_"}], "]"}], 
       RowBox[{"(", 
        RowBox[{"n1_", ",", "n2_", ",", "n3_", ",", "n4_"}], ")"}]], "f_"}],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{"GaussianD", "[", 
      RowBox[{"f_", ",", 
       RowBox[{"{", 
        RowBox[{"x1_", ",", "t_", ",", "n1_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x2_", ",", "t_", ",", "n2_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x3_", ",", "t_", ",", "n3_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x4_", ",", "t_", ",", "n4_"}], "}"}]}], "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{"lhs___", ",", 
        RowBox[{"SubsuperscriptBox", "[", 
         RowBox[{"\"\<\[PartialD]\>\"", ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"SubscriptBox", "[", 
              RowBox[{"\"\<G\>\"", ",", "t_"}], "]"}], ",", "\"\<[\>\"", ",", 
             
             RowBox[{"RowBox", "[", 
              RowBox[{"{", 
               RowBox[{
               "x1_", ",", "\"\<,\>\"", ",", "x2_", ",", "\"\<,\>\"", ",", 
                "x3_", ",", "\"\<,\>\"", ",", "x4_"}], "}"}], "]"}], ",", 
             "\"\<]\>\""}], "}"}], "]"}], ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"\"\<(\>\"", ",", 
             RowBox[{"RowBox", "[", 
              RowBox[{"{", 
               RowBox[{
               "n1_", ",", "\"\<,\>\"", ",", "n2_", ",", "\"\<,\>\"", ",", 
                "n3_", ",", "\"\<,\>\"", ",", "n4_"}], "}"}], "]"}], ",", 
             "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", "f_", ",", "rhs___"}],
        "}"}], "]"}], ",", "StandardForm"}], "]"}], ":=", 
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{"lhs", ",", 
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<GaussianD\>\"", ",", "\"\<[\>\"", ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{"f", ",", "\"\<,\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{
                   "x1", ",", "\"\<,\>\"", ",", "t", ",", "\"\<,\>\"", ",", 
                    "n1"}], "}"}], "]"}], ",", "\"\<}\>\""}], "}"}], "]"}], 
              ",", "\"\<,\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{
                   "x2", ",", "\"\<,\>\"", ",", "t", ",", "\"\<,\>\"", ",", 
                    "n2"}], "}"}], "]"}], ",", "\"\<}\>\""}], "}"}], "]"}], 
              ",", "\"\<,\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{
                   "x3", ",", "\"\<,\>\"", ",", "t", ",", "\"\<,\>\"", ",", 
                    "n3"}], "}"}], "]"}], ",", "\"\<}\>\""}], "}"}], "]"}], 
              ",", "\"\<,\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{
                   "x4", ",", "\"\<,\>\"", ",", "t", ",", "\"\<,\>\"", ",", 
                    "n4"}], "}"}], "]"}], ",", "\"\<}\>\""}], "}"}], "]"}]}], 
             "}"}], "]"}], ",", "\"\<]\>\""}], "}"}], "]"}], ",", "rhs"}], 
       "}"}], "]"}], ",", "StandardForm"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{"GaussianD", "[", 
     RowBox[{"f_", ",", 
      RowBox[{"{", 
       RowBox[{"x1_", ",", "t_", ",", "n1_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x2_", ",", "t_", ",", "n2_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x3_", ",", "t_", ",", "n3_"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x4_", ",", "t_", ",", "n4_"}], "}"}]}], "]"}], ",", 
    "StandardForm"}], "]"}], ":=", 
  RowBox[{"RowBox", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"SubsuperscriptBox", "[", 
      RowBox[{"\"\<\[PartialD]\>\"", ",", 
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"SubscriptBox", "[", 
           RowBox[{"\"\<G\>\"", ",", 
            RowBox[{"MakeBoxes", "[", 
             RowBox[{"t", ",", "StandardForm"}], "]"}]}], "]"}], ",", 
          "\"\<[\>\"", ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"x1", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
             ",", 
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"x2", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
             ",", 
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"x3", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
             ",", 
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"x4", ",", "StandardForm"}], "]"}]}], "}"}], "]"}], 
          ",", "\"\<]\>\""}], "}"}], "]"}], ",", 
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<(\>\"", ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"n1", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
             ",", 
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"n2", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
             ",", 
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"n3", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
             ",", 
             RowBox[{"MakeBoxes", "[", 
              RowBox[{"n4", ",", "StandardForm"}], "]"}]}], "}"}], "]"}], 
          ",", "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", 
     RowBox[{"Parenthesize", "[", 
      RowBox[{"f", ",", "StandardForm", ",", "D"}], "]"}]}], "}"}], 
   "]"}]}]}], "PackageInput"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["GaussianDerivative", "Subsection"],

Cell[CellGroupData[{

Cell["Automatic Kernel Range", "Subsubsection"],

Cell["\<\
To ensure a given precision for Gaussian derivatives, one must provide a \
Gaussian kernel with a minimum range [-r,r].
If \[Epsilon] is the admissable error, the constraint for a continuous \
Gaussian kernel is\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubsuperscriptBox["\[Integral]", 
    RowBox[{"-", "r"}], "r"], " ", 
   RowBox[{
    RowBox[{"GaussianDKernel", "[", 
     RowBox[{"t", ",", "0", ",", "x"}], "]"}], 
    RowBox[{"\[DifferentialD]", "x"}]}]}], " ", "\[GreaterEqual]", " ", 
  RowBox[{"1", "-", "\[Epsilon]"}]}]], "Input",
 Evaluatable->False],

Cell["For n-th order derivative kernels this generalizes to ", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubsuperscriptBox["\[Integral]", 
    RowBox[{"-", "r"}], "r"], 
   RowBox[{
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"-", "x"}], ")"}], "n"], 
     RowBox[{"n", "!"}]], " ", 
    RowBox[{"GaussianDKernel", "[", 
     RowBox[{"t", ",", "n", ",", "x"}], "]"}], 
    RowBox[{"\[DifferentialD]", "x"}]}]}], " ", "\[GreaterEqual]", " ", 
  RowBox[{"1", "-", "\[Epsilon]"}]}]], "Input",
 Evaluatable->False],

Cell[TextData[{
 "Unfortunately, the above inequality cannot be solved for ",
 StyleBox["r", "Input"],
 " symbolically. Hence, we solve the inequality numerically for\n",
 StyleBox["t", "Input"],
 " = 1 and ",
 StyleBox["\[Epsilon]", "Input"],
 " = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["2", 
    RowBox[{"-", "m"}]], TraditionalForm]]],
 "with ",
 StyleBox["m", "Input"],
 " = 1,..., 32. Note, that t scales ",
 StyleBox["x", "Input"],
 " by ",
 Cell[BoxData[
  FormBox[
   SqrtBox["t"], TraditionalForm]], "Input",
  FontWeight->"Plain"],
 "and thus also ",
 StyleBox["r", "Input"],
 ". "
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RangeError", "[", "n_", "]"}], " ", ":=", 
  RowBox[{
   RowBox[{"RangeError", "[", "n", "]"}], "=", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", 
     RowBox[{"-", "r"}], "r"], 
    RowBox[{
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "x"}], ")"}], "n"], 
      RowBox[{"n", "!"}]], " ", 
     RowBox[{"GaussianDKernel", "[", 
      RowBox[{"1", ",", "n", ",", "x"}], "]"}], 
     RowBox[{"\[DifferentialD]", "x"}]}]}]}]}]], "Input"],

Cell["For the Gaussian kernel we obtain the explicit result", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"r", "/.", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"RangeError", "[", "0", "]"}], "\[Equal]", 
      RowBox[{"1", "-", 
       SuperscriptBox["2", 
        RowBox[{"-", "m"}]]}]}], ",", "r"}], "]"}], "\[LeftDoubleBracket]", 
   "1", "\[RightDoubleBracket]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"2", " ", 
  RowBox[{"InverseErf", "[", 
   RowBox[{"0", ",", 
    RowBox[{
     SuperscriptBox["2", 
      RowBox[{"-", "m"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["2", "m"]}], ")"}]}]}], "]"}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "A list of results for derivatives up the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["16", "th"], TraditionalForm]]],
 " order is generated by"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RangeErrorList", "[", "m_", "]"}], " ", ":=", " ", 
  RowBox[{"Rest", "[", 
   RowBox[{"FoldList", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"r", "/.", 
        RowBox[{"FindRoot", "[", 
         RowBox[{
          RowBox[{"Evaluate", "[", 
           RowBox[{
            RowBox[{"RangeError", "[", "#2", "]"}], " ", "\[Equal]", " ", 
            RowBox[{"1", " ", "-", " ", 
             SuperscriptBox["2", 
              RowBox[{"-", "m"}]]}]}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"r", ",", "#1"}], "}"}]}], "]"}]}], ")"}], "&"}], ",", 
     RowBox[{"2", " ", 
      RowBox[{"InverseErf", "[", 
       RowBox[{"0", ",", 
        RowBox[{
         SuperscriptBox["2", 
          RowBox[{"-", "m"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           SuperscriptBox["2", "m"]}], ")"}]}]}], "]"}]}], ",", 
     RowBox[{"Range", "[", 
      RowBox[{"0", ",", "16"}], "]"}]}], "]"}], "]"}]}]], "Input"],

Cell["In accordance with Zernickes formula we fit the results.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RangeErrorFunction", "[", "m_", "]"}], ":=", 
  SqrtBox[
   RowBox[{"Fit", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "16"}], "]"}], ",", 
        SuperscriptBox[
         RowBox[{"RangeErrorList", "[", "m", "]"}], "2"]}], "}"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"n", "+", "1"}], ",", " ", 
       RadicalBox[
        RowBox[{"n", "+", "1"}], "3"]}], "}"}], ",", "n"}], "]"}]]}]], "Input"],

Cell[TextData[{
 "Thus, for each ",
 StyleBox["m", "Input"],
 " we can generate a Gaussian kernel range function. "
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianKernelRange", "[", "m_", "]"}], " ", "=", " ", 
  RowBox[{"Compile", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"t", ",", "_Real"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "_Integer"}], "}"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "#"}], ",", "#"}], "}"}], "&"}], "[", 
     RowBox[{"Evaluate", "[", 
      RowBox[{"Ceiling", "[", 
       RowBox[{
        SqrtBox[
         RowBox[{"t", " ", 
          RowBox[{"\[Tau]", "/", "4"}], " "}]], 
        RowBox[{"RangeErrorFunction", "[", "m", "]"}]}], "]"}], "]"}], 
     "]"}]}], "]"}]}]], "Input",
 Evaluatable->False],

Cell[TextData[{
 " We do so explicitly for ",
 StyleBox["m", "Input"],
 " = 4, 8, 12,... , 52."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianKernelRange", "[", "4", "]"}], "=", 
  RowBox[{"Compile", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"t", ",", "_Real"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "_Integer"}], "}"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "#"}], ",", "#"}], "}"}], "&"}], "[", 
     RowBox[{"Ceiling", "[", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2.3243180666111423", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "n"}], ")"}]}], "-", 
          RowBox[{"0.9765965923097873", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "n"}], ")"}], "^", 
            RowBox[{"(", 
             RowBox[{"1", "/", "3"}], ")"}]}]}]}], ")"}], "*", "t", "*", 
        "\[Tau]"}], "]"}], "]"}], "]"}]}], "]"}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianKernelRange", "[", "8", "]"}], "=", 
  RowBox[{"Compile", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"t", ",", "_Real"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "_Integer"}], "}"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "#"}], ",", "#"}], "}"}], "&"}], "[", 
     RowBox[{"Ceiling", "[", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2.2224289812448683", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "n"}], ")"}]}], "+", 
          RowBox[{"1.6011247864558187", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "n"}], ")"}], "^", 
            RowBox[{"(", 
             RowBox[{"1", "/", "3"}], ")"}]}]}]}], ")"}], "*", "t", "*", 
        "\[Tau]"}], "]"}], "]"}], "]"}]}], "]"}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianKernelRange", "[", "12", "]"}], "=", 
  RowBox[{"Compile", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"t", ",", "_Real"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "_Integer"}], "}"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "#"}], ",", "#"}], "}"}], "&"}], "[", 
     RowBox[{"Ceiling", "[", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2.114376372864952", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "n"}], ")"}]}], "+", 
          RowBox[{"4.0288081480154725", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "n"}], ")"}], "^", 
            RowBox[{"(", 
             RowBox[{"1", "/", "3"}], ")"}]}]}]}], ")"}], "*", "t", "*", 
        "\[Tau]"}], "]"}], "]"}], "]"}]}], "]"}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianKernelRange", "[", "16", "]"}], "=", 
  RowBox[{"Compile", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"t", ",", "_Real"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "_Integer"}], "}"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "#"}], ",", "#"}], "}"}], "&"}], "[", 
     RowBox[{"Ceiling", "[", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1.998216846965191", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "n"}], ")"}]}], "+", 
          RowBox[{"6.392974885898669", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "n"}], ")"}], "^", 
            RowBox[{"(", 
             RowBox[{"1", "/", "3"}], ")"}]}]}]}], ")"}], "*", "t", "*", 
        "\[Tau]"}], "]"}], "]"}], "]"}]}], "]"}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianKernelRange", "[", "20", "]"}], "=", 
  RowBox[{"Compile", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"t", ",", "_Real"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "_Integer"}], "}"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "#"}], ",", "#"}], "}"}], "&"}], "[", 
     RowBox[{"Ceiling", "[", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1.874991609534614", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "n"}], ")"}]}], "+", 
          RowBox[{"8.723038909063387", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "n"}], ")"}], "^", 
            RowBox[{"(", 
             RowBox[{"1", "/", "3"}], ")"}]}]}]}], ")"}], "*", "t", "*", 
        "\[Tau]"}], "]"}], "]"}], "]"}]}], "]"}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianKernelRange", "[", "24", "]"}], "=", 
  RowBox[{"Compile", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"t", ",", "_Real"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "_Integer"}], "}"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "#"}], ",", "#"}], "}"}], "&"}], "[", 
     RowBox[{"Ceiling", "[", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1.7458525263268259", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "n"}], ")"}]}], "+", 
          RowBox[{"11.032362584249514", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "n"}], ")"}], "^", 
            RowBox[{"(", 
             RowBox[{"1", "/", "3"}], ")"}]}]}]}], ")"}], "*", "t", "*", 
        "\[Tau]"}], "]"}], "]"}], "]"}]}], "]"}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianKernelRange", "[", "28", "]"}], "=", 
  RowBox[{"Compile", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"t", ",", "_Real"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "_Integer"}], "}"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "#"}], ",", "#"}], "}"}], "&"}], "[", 
     RowBox[{"Ceiling", "[", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1.6117501067548536", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "n"}], ")"}]}], "+", 
          RowBox[{"13.328052128995822", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "n"}], ")"}], "^", 
            RowBox[{"(", 
             RowBox[{"1", "/", "3"}], ")"}]}]}]}], ")"}], "*", "t", "*", 
        "\[Tau]"}], "]"}], "]"}], "]"}]}], "]"}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianKernelRange", "[", "32", "]"}], "=", 
  RowBox[{"Compile", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"t", ",", "_Real"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "_Integer"}], "}"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "#"}], ",", "#"}], "}"}], "&"}], "[", 
     RowBox[{"Ceiling", "[", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1.473435732709178", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "n"}], ")"}]}], "+", 
          RowBox[{"15.61428837974991", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "n"}], ")"}], "^", 
            RowBox[{"(", 
             RowBox[{"1", "/", "3"}], ")"}]}]}]}], ")"}], "*", "t", "*", 
        "\[Tau]"}], "]"}], "]"}], "]"}]}], "]"}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianKernelRange", "[", "36", "]"}], "=", 
  RowBox[{"Compile", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"t", ",", "_Real"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "_Integer"}], "}"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "#"}], ",", "#"}], "}"}], "&"}], "[", 
     RowBox[{"Ceiling", "[", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1.3315035827972916", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "n"}], ")"}]}], "+", 
          RowBox[{"17.893710961739284", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "n"}], ")"}], "^", 
            RowBox[{"(", 
             RowBox[{"1", "/", "3"}], ")"}]}]}]}], ")"}], "*", "t", "*", 
        "\[Tau]"}], "]"}], "]"}], "]"}]}], "]"}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianKernelRange", "[", "40", "]"}], "=", 
  RowBox[{"Compile", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"t", ",", "_Real"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "_Integer"}], "}"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "#"}], ",", "#"}], "}"}], "&"}], "[", 
     RowBox[{"Ceiling", "[", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1.1864219273587364", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "n"}], ")"}]}], "+", 
          RowBox[{"20.168092531572174", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "n"}], ")"}], "^", 
            RowBox[{"(", 
             RowBox[{"1", "/", "3"}], ")"}]}]}]}], ")"}], "*", "t", "*", 
        "\[Tau]"}], "]"}], "]"}], "]"}]}], "]"}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianKernelRange", "[", "44", "]"}], "=", 
  RowBox[{"Compile", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"t", ",", "_Real"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "_Integer"}], "}"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "#"}], ",", "#"}], "}"}], "&"}], "[", 
     RowBox[{"Ceiling", "[", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"1.0385758971718777", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "n"}], ")"}]}], "+", 
          RowBox[{"22.438510420428443", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "n"}], ")"}], "^", 
            RowBox[{"(", 
             RowBox[{"1", "/", "3"}], ")"}]}]}]}], ")"}], "*", "t", "*", 
        "\[Tau]"}], "]"}], "]"}], "]"}]}], "]"}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianKernelRange", "[", "48", "]"}], "=", 
  RowBox[{"Compile", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"t", ",", "_Real"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "_Integer"}], "}"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "#"}], ",", "#"}], "}"}], "&"}], "[", 
     RowBox[{"Ceiling", "[", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"0.889875356726046", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "n"}], ")"}]}], "+", 
          RowBox[{"24.692137806054756", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "n"}], ")"}], "^", 
            RowBox[{"(", 
             RowBox[{"1", "/", "3"}], ")"}]}]}]}], ")"}], "*", "t", "*", 
        "\[Tau]"}], "]"}], "]"}], "]"}]}], "]"}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianKernelRange", "[", "52", "]"}], "=", 
  RowBox[{"Compile", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"t", ",", "_Real"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "_Integer"}], "}"}]}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "#"}], ",", "#"}], "}"}], "&"}], "[", 
     RowBox[{"Ceiling", "[", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"0.7367547195975274", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "n"}], ")"}]}], "+", 
          RowBox[{"26.829859007281208", "*", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "n"}], ")"}], "^", 
            RowBox[{"(", 
             RowBox[{"1", "/", "3"}], ")"}]}]}]}], ")"}], "*", "t", "*", 
        "\[Tau]"}], "]"}], "]"}], "]"}]}], "]"}]}]], "PackageInput"],

Cell["\<\
Earlier versions of this package used the formula of Zernicke for the upper \
bound of Gaussian width.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GaussianKernelRange", "=", " ", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "_Integer"}], "}"}]}], "}"}], ",", 
     RowBox[{"Ceiling", "[", 
      RowBox[{"4", " ", "*", " ", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"\[Tau]", " ", "t"}], "]"}], " ", "*", " ", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"n", "+", "2", "-", 
         RowBox[{"1.15", " ", 
          RadicalBox[
           RowBox[{"n", "+", "2"}], "3"]}]}], "]"}]}], "]"}]}], "]"}]}], 
  ";"}]], "Input",
 Evaluatable->False],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"GaussianDerivative", "::", "widthfail"}], "=", 
   "\"\<Insufficient kernel width for `1`-order differentiation.\>\""}], ";", 
  
  RowBox[{
   RowBox[{"GaussianDerivative", "::", "nowidth"}], "=", 
   "\"\<No kernel width specified.\>\""}], ";"}]], "PackageInput",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Automatic Minimal Scale", "Subsubsection"],

Cell["\<\
Scale is needed to regularize a discrete dataset. Here we determine the \
minimal scale needed to render correct derivative values for a given \
precision.\
\>", "Text"],

Cell["\<\
In Fourier space an n-th order Gaussian derivation is performed via  \
multiplication with\
\>", "Text"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]"}], ")"}], "n"], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "t"}], " ", 
     SuperscriptBox["\[Omega]", "2"]}]]}], 
  SqrtBox[
   RowBox[{"2", " ", "\[Pi]"}]]]], "Input",
 Evaluatable->False],

Cell["\<\
This Gaussian derivative kernel in Fourier space extends from -\[Infinity] to \
\[Infinity]. However, due to the discreteness of the data we are bounded by \
its Nyquist frequency. If we take the lattice constant of the data grid as 1, \
we cannot sample the data with frequencies higher than \[Pi]. Hence, we miss \
the values in Fourier space from \[Pi] to \[Infinity]. We calculate this \
error and determine the scale, with which this error is kept below a given \
precision threshold.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"error", "[", "n_", "]"}], " ", ":=", " ", 
  RowBox[{
   RowBox[{"error", "[", "n", "]"}], " ", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "\[Pi]"], 
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]"}], ")"}], "n"], 
          " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "t"}], " ", 
            SuperscriptBox["\[Omega]", "2"]}]]}], 
         SqrtBox[
          RowBox[{"2", " ", "\[Pi]"}]]], 
        RowBox[{"\[DifferentialD]", "\[Omega]"}]}]}], " ", ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "\[Infinity]"], 
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]"}], ")"}], "n"], 
          " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "t"}], " ", 
            SuperscriptBox["\[Omega]", "2"]}]]}], 
         SqrtBox[
          RowBox[{"2", " ", "\[Pi]"}]]], 
        RowBox[{"\[DifferentialD]", "\[Omega]"}]}]}], ")"}]}], 
    "]"}]}]}]], "Input"],

Cell[TextData[{
 "Here are the minimal scales ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]]],
 " for Gaussian derivatives of order ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]]],
 " from 0 through 16 to obtain a precision of ",
 Cell[BoxData[
  SuperscriptBox["2", 
   RowBox[{"-", "b"}]]]],
 " with ",
 Cell[BoxData[
  FormBox["b", TraditionalForm]]],
 " running from 4 to 52 in steps of 4."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"results", " ", "=", " ", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"MapIndexed", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"First", "[", "#2", "]"}], "-", "1"}], ",", 
          RowBox[{"t", "/.", 
           RowBox[{"FindRoot", "[", 
            RowBox[{
             RowBox[{"#1", "\[Equal]", 
              RowBox[{"1", "-", 
               SuperscriptBox["2", 
                RowBox[{"-", "b"}]]}]}], ",", 
             RowBox[{"{", 
              RowBox[{"t", ",", "1"}], "}"}]}], "]"}]}]}], "}"}], "&"}], ",", 
       
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"error", "[", "n", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "0", ",", "16"}], "}"}]}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"b", ",", "4", ",", "52", ",", "4"}], "}"}]}], "]"}]}], 
  ";"}]], "Input"],

Cell["\<\
For each precision we fit the terms of Zernicke's formula to these minmal \
scales.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Fit", "[", 
     RowBox[{"#", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", 
        RowBox[{"n", "+", "1"}], ",", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"n", "+", "1"}], ")"}], 
         RowBox[{"1", "/", "3"}]]}], "}"}], ",", "n"}], "]"}], "&"}], ",", 
   "results"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MinimalScale", "[", "4", "]"}], "=", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"n", ",", "_Integer"}], "}"}], "}"}], ",", 
     RowBox[{
      RowBox[{"-", "0.07225602550763996`"}], " ", "+", " ", 
      RowBox[{"0.1934994115318552`", "  ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", "n"}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], "+", 
      RowBox[{"0.05458391922630867`", "  ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "n"}], ")"}]}]}]}], "]"}]}], ";"}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MinimalScale", "[", "8", "]"}], "=", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"n", ",", "_Integer"}], "}"}], "}"}], ",", 
     RowBox[{"0.04813185222160912`", "\[InvisibleSpace] ", "+", " ", 
      RowBox[{"0.31489231691130615`", "  ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", "n"}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], "+", 
      RowBox[{"0.05841271321345174`", "  ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "n"}], ")"}]}]}]}], "]"}]}], ";"}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MinimalScale", "[", "12", "]"}], "=", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"n", ",", "_Integer"}], "}"}], "}"}], ",", 
     RowBox[{"0.23138720823850856`", " \[InvisibleSpace]", "+", 
      RowBox[{"0.3870206014942941`", "  ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", "n"}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], "+", 
      RowBox[{"0.06201023916198861`", "  ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "n"}], ")"}]}]}]}], "]"}]}], ";"}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MinimalScale", "[", "16", "]"}], "=", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"n", ",", "_Integer"}], "}"}], "}"}], ",", 
     RowBox[{"0.4427462125429202`", "\[InvisibleSpace] ", "+", 
      RowBox[{"0.43729757816428666`", "  ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", "n"}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], "+", 
      RowBox[{"0.06533784418156777`", "  ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "n"}], ")"}]}]}]}], "]"}]}], ";"}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MinimalScale", "[", "20", "]"}], "=", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"n", ",", "_Integer"}], "}"}], "}"}], ",", 
     RowBox[{"0.6700763376887527`", "\[InvisibleSpace] ", "+", 
      RowBox[{"0.47527046426284586`", "  ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", "n"}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], "+", 
      RowBox[{"0.06841700241661773`", "  ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "n"}], ")"}]}]}]}], "]"}]}], ";"}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MinimalScale", "[", "24", "]"}], "=", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"n", ",", "_Integer"}], "}"}], "}"}], ",", 
     RowBox[{"0.9076871517131073`", "\[InvisibleSpace] ", "+", 
      RowBox[{"0.5053978829196788`", "  ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", "n"}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], "+", 
      RowBox[{"0.07127851131749753`", "  ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "n"}], ")"}]}]}]}], "]"}]}], ";"}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MinimalScale", "[", "28", "]"}], "=", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"n", ",", "_Integer"}], "}"}], "}"}], ",", 
     RowBox[{"1.1524506471180527`", "\[InvisibleSpace] ", "+", 
      RowBox[{"0.5301181105158642`", "  ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", "n"}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], "+", 
      RowBox[{"0.07395088137222257`", "  ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "n"}], ")"}]}]}]}], "]"}]}], ";"}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MinimalScale", "[", "32", "]"}], "=", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"n", ",", "_Integer"}], "}"}], "}"}], ",", 
     RowBox[{"1.4024642991094307`", " \[InvisibleSpace]", "+", 
      RowBox[{"0.5509059382924002`", "  ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", "n"}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], "+", 
      RowBox[{"0.0764583548853869`", "  ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "n"}], ")"}]}]}]}], "]"}]}], ";"}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MinimalScale", "[", "36", "]"}], "=", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"n", ",", "_Integer"}], "}"}], "}"}], ",", 
     RowBox[{"1.656487038699375`", "\[InvisibleSpace] ", "+", 
      RowBox[{"0.568717809132497`", "  ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", "n"}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], "+", 
      RowBox[{"0.07882117438223667`", "  ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "n"}], ")"}]}]}]}], "]"}]}], ";"}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MinimalScale", "[", "40", "]"}], "=", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"n", ",", "_Integer"}], "}"}], "}"}], ",", 
     RowBox[{"1.9136820125603298`", "\[InvisibleSpace] ", "+", 
      RowBox[{"0.5841887192822285`", "  ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", "n"}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], "+", 
      RowBox[{"0.08105828273659765`", "  ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "n"}], ")"}]}]}]}], "]"}]}], ";"}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MinimalScale", "[", "44", "]"}], "=", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"n", ",", "_Integer"}], "}"}], "}"}], ",", 
     RowBox[{"2.1736973881589376`", "\[InvisibleSpace] ", "+", 
      RowBox[{"0.5976246623874925`", "  ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", "n"}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], "+", 
      RowBox[{"0.0831900868437959`", "  ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "n"}], ")"}]}]}]}], "]"}]}], ";"}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MinimalScale", "[", "48", "]"}], "=", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"n", ",", "_Integer"}], "}"}], "}"}], ",", 
     RowBox[{"2.442533291990515`", "\[InvisibleSpace] ", "+", 
      RowBox[{"0.6028349507086076`", "  ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", "n"}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], "+", 
      RowBox[{"0.08585656496350498`", "  ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "n"}], ")"}]}]}]}], "]"}]}], ";"}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MinimalScale", "[", "52", "]"}], "=", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"n", ",", "_Integer"}], "}"}], "}"}], ",", 
     RowBox[{"2.627515797245066`", "\[InvisibleSpace] ", "+", 
      RowBox[{"0.6649239314410514`", "  ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"1", "+", "n"}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], "+", 
      RowBox[{"0.08356758359896967`", "  ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "n"}], ")"}]}]}]}], "]"}]}], ";"}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"GaussianDerivative", "::", "scalefail"}], "=", 
   "\"\<Scale too small for `1`-order differentiation.\>\""}], 
  ";"}]], "PackageInput"],

Cell["\<\
The former approach for 12-bit precision to estimate the lower boumd of \
admissable scale paramterer values was:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MinimalScale", "=", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"n", ",", "_Integer"}], "}"}], "}"}], ",", 
     RowBox[{"Re", "[", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"n", "+", "1", "-", 
        RowBox[{"1.15", " ", 
         RadicalBox[
          RowBox[{"n", "+", "1"}], "3"]}]}], "]"}], "]"}]}], "]"}]}], 
  ";"}]], "Input",
 Evaluatable->False,
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Symbolical Implementation", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"GaussianDerivative", "[", 
     RowBox[{
      RowBox[{"tn", ":", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}], ".."}]}], ",", "opts___Rule"}], 
     "]"}], "[", "f_", "]"}], "=", "f"}], ";"}]], "PackageInput",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"GaussianDerivative", "[", 
    RowBox[{
     RowBox[{"tn", ":", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"_", ",", 
         RowBox[{"_Integer", "?", "Positive"}]}], "}"}], ".."}]}], ",", 
     "opts___Rule"}], "]"}], "[", "f_Symbol", "]"}], ":=", 
  RowBox[{"0", "/;", " ", 
   RowBox[{"MemberQ", "[", 
    RowBox[{
     RowBox[{"Attributes", "[", "f", "]"}], ",", "Constant"}], 
    "]"}]}]}]], "PackageInput",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"GaussianDerivative", "[", 
     RowBox[{
      RowBox[{"tns", ":", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0"}], "}"}], ".."}]}], ",", 
      "opts___Rule"}], "]"}], "[", "f_", "]"}], "=", "f"}], 
  ";"}]], "PackageInput",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"GaussianDerivative", "[", 
    RowBox[{
     RowBox[{"tns", ":", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"_", ",", 
         RowBox[{"_Integer", "?", "Positive"}], ",", "_Real"}], "}"}], 
       ".."}]}], ",", "opts___Rule"}], "]"}], "[", "f_Symbol", "]"}], ":=", 
  RowBox[{"0", "/;", " ", 
   RowBox[{"MemberQ", "[", 
    RowBox[{
     RowBox[{"Attributes", "[", "f", "]"}], ",", "Constant"}], 
    "]"}]}]}]], "PackageInput",
 InitializationCell->True],

Cell["Checking the GaussianD.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"GaussianDerivative", "[", 
    RowBox[{"tn__", ",", "opts___Rule"}], "]"}], "[", 
   RowBox[{"f", ":", 
    RowBox[{"_Symbol", "|", "_Function"}]}], "]"}], ":=", " ", 
  RowBox[{"Condition", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"FreeQ", "[", 
         RowBox[{"#", ",", "Slot"}], "]"}], ",", 
        RowBox[{"First", "[", "#", "]"}], ",", "#"}], "]"}], "&"}], "[", 
     RowBox[{
      RowBox[{"Evaluate", "[", 
       RowBox[{"GaussianD", "[", 
        RowBox[{
         RowBox[{"f", " ", "@@", " ", 
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{"Slot", "[", "i", "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"i", ",", 
              RowBox[{"Length", "[", 
               RowBox[{"{", "tn", "}"}], "]"}]}], "}"}]}], "]"}]}], ",", 
         RowBox[{"Sequence", " ", "@@", " ", 
          RowBox[{"MapIndexed", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Prepend", "[", 
              RowBox[{"#1", ",", 
               RowBox[{"Slot", "@@", "#2"}]}], "]"}], "&"}], ",", 
            RowBox[{"{", "tn", "}"}]}], "]"}]}], ",", "opts"}], " ", "]"}], 
       "]"}], "&"}], "]"}], ",", 
    RowBox[{
     RowBox[{"Stack", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"FreeQ", "[", 
           RowBox[{"#", ",", "Slot"}], "]"}], ",", 
          RowBox[{"First", "[", "#", "]"}], ",", "#"}], "]"}], "&"}], "[", 
       RowBox[{
        RowBox[{"Evaluate", "[", 
         RowBox[{"GaussianD", "[", 
          RowBox[{
           RowBox[{"f", " ", "@@", " ", 
            RowBox[{"Table", "[", 
             RowBox[{
              RowBox[{"Slot", "[", "i", "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"i", ",", 
                RowBox[{"Length", "[", 
                 RowBox[{"{", "tn", "}"}], "]"}]}], "}"}]}], "]"}]}], ",", 
           RowBox[{"Sequence", " ", "@@", " ", 
            RowBox[{"MapIndexed", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Prepend", "[", 
                RowBox[{"#1", ",", 
                 RowBox[{"Slot", "@@", "#2"}]}], "]"}], "&"}], ",", 
              RowBox[{"{", "tn", "}"}]}], "]"}]}], " ", ",", "opts"}], "]"}], 
         "]"}], "&"}], "]"}], "]"}], "===", 
     RowBox[{"{", "}"}]}]}], "]"}]}]], "PackageInput"],

Cell["Old Code:", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"GaussianDerivative", "[", 
    RowBox[{
     RowBox[{"tn", ":", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"_", ",", 
         RowBox[{"_Integer", ":", "0"}]}], "}"}], ".."}]}], ",", " ", 
     "opts___Rule"}], "]"}], "[", "img_Symbol", "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"result", ",", "ts", ",", "ns", ",", "\[IndentingNewLine]", 
      RowBox[{"xs", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Unique", "[", "\"\<x\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"Length", "[", 
           RowBox[{"{", "tn", "}"}], "]"}], "}"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"\[Omega]s", "=", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Unique", "[", "\"\<\[Omega]\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"Length", "[", 
           RowBox[{"{", "tn", "}"}], "]"}], "}"}]}], "]"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"ys", "=", " ", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"Unique", "[", "\"\<y\>\"", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"Length", "[", 
           RowBox[{"{", "tn", "}"}], "]"}], "}"}]}], "]"}]}]}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Evaluate", "[", 
        RowBox[{"result", " ", "/.", " ", 
         RowBox[{"Thread", "[", 
          RowBox[{"ys", " ", "\[Rule]", " ", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Slot", "[", "i", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"i", ",", 
               RowBox[{"Length", "[", "ys", "]"}]}], "}"}]}], "]"}]}], 
          "]"}]}], "]"}], "&"}], ")"}], " ", "/;", " ", "\[IndentingNewLine]", 
     RowBox[{"If", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"FreeQ", "[", 
        RowBox[{
         RowBox[{"result", "=", " ", 
          RowBox[{"FourierTransform", "[", 
           RowBox[{
            RowBox[{"Apply", "[", 
             RowBox[{"img", ",", "xs"}], "]"}], ",", "xs", ",", "\[Omega]s"}],
            "]"}]}], ",", "FourierTransform"}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{"ts", ",", "ns"}], "}"}], "=", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", "tn", "}"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"FreeQ", "[", 
         RowBox[{
          RowBox[{"result", "=", "  ", 
           RowBox[{"InverseFourierTransform", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Apply", "[", 
               RowBox[{"Times", ",", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "I"}], "  ", "\[Omega]s"}], ")"}], "^", 
                 "ns"}]}], "]"}], " ", 
              RowBox[{"Exp", "[", 
               RowBox[{"-", 
                RowBox[{"ts", ".", 
                 RowBox[{"(", " ", 
                  RowBox[{"\[Omega]s", "^", "2"}], ")"}]}]}], "]"}], "  ", 
              "result"}], ",", "\[Omega]s", ",", "ys"}], "]"}]}], ",", 
          "InverseFourierTransform"}], "]"}]}], ",", "\[IndentingNewLine]", 
       "False"}], "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Numerical Implementation", "Subsubsection"],

Cell["\<\
The GaussianDerivative checks if the image and parameters allow numeric \
differentiation and calls up the apporpriate Method.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"GaussianDerivative", "[", 
    RowBox[{
     RowBox[{"tn", ":", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"_", "?", "NumericQ"}], ",", 
         RowBox[{"_Integer", ":", "0"}]}], "}"}], ".."}]}], ",", " ", 
     "opts___Rule"}], "]"}], "[", 
   RowBox[{"img_", "?", "ImageQ"}], "]"}], ":=", 
  RowBox[{"Image", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"GaussianDerivative", "[", 
      RowBox[{"tn", ",", "opts"}], "]"}], "[", 
     RowBox[{"ImageData", "[", 
      RowBox[{"img", ",", 
       RowBox[{"Interleaving", "\[Rule]", " ", "True"}]}], "]"}], "]"}], ",", 
    
    RowBox[{"Sequence", "@@", 
     RowBox[{"Options", "[", "img", "]"}]}]}], "]"}]}]], "PackageInput"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"GaussianDerivative", "::", "nomethod"}], " ", "=", " ", 
    "\"\<Derivation Method `1` not implemented!\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GaussianDerivative", "[", 
    RowBox[{
     RowBox[{"tn", ":", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"_", "?", "NumericQ"}], ",", 
         RowBox[{"_Integer", ":", "0"}]}], "}"}], ".."}]}], ",", " ", 
     "opts___Rule"}], "]"}], "[", "img_List", "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Method", " ", "/.", " ", 
       RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
      RowBox[{"Options", "[", "GaussianDerivative", "]"}]}], ",", 
     "\[IndentingNewLine]", "Convolve", ",", " ", 
     RowBox[{
      RowBox[{"ListConvolveGaussianDerivative", "[", 
       RowBox[{"tn", ",", "opts"}], "]"}], "[", "img", "]"}], ",", 
     "\[IndentingNewLine]", "Fourier", ",", 
     RowBox[{
      RowBox[{"FourierGaussianDerivative", "[", 
       RowBox[{
        RowBox[{"Apply", "[", 
         RowBox[{"Sequence", ",", 
          RowBox[{"Reverse", "[", 
           RowBox[{"{", "tn", "}"}], "]"}]}], "]"}], ",", "opts"}], "]"}], 
      "[", "img", "]"}], ",", "\[IndentingNewLine]", "_", ",", 
     RowBox[{
      RowBox[{"Message", "[", 
       RowBox[{
        RowBox[{"GaussianDerivative", "::", "nomethod"}], ",", "Method"}], 
       "]"}], ";", 
      RowBox[{"Throw", "[", "$Failed", "]"}]}]}], "\[IndentingNewLine]", 
    "]"}], "/;", 
   RowBox[{
    RowBox[{"TensorRank", "[", "img", "]"}], "\[GreaterEqual]", 
    RowBox[{"Length", "[", 
     RowBox[{"{", "tn", "}"}], "]"}]}]}]}]}], "PackageInput",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"GaussianDerivative", "[", 
    RowBox[{
     RowBox[{"tns", ":", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"_", "?", "NumericQ"}], ",", "_Integer", ",", 
         RowBox[{"_Real", "|", "_Rational", "|", "_Integer"}]}], "}"}], 
       ".."}]}], ",", " ", "opts___Rule"}], "]"}], "[", 
   RowBox[{"img_", "?", "ImageQ"}], "]"}], ":=", 
  RowBox[{"Image", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"GaussianDerivative", "[", 
      RowBox[{"tns", ",", "opts"}], "]"}], "[", 
     RowBox[{"ImageData", "[", 
      RowBox[{"img", ",", 
       RowBox[{"Interleaving", "\[Rule]", " ", "True"}]}], "]"}], "]"}], ",", 
    
    RowBox[{"Sequence", "@@", 
     RowBox[{"Options", "[", "img", "]"}]}]}], "]"}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"GaussianDerivative", "[", 
    RowBox[{
     RowBox[{"tns", ":", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"_", "?", "NumericQ"}], ",", "_Integer", ",", 
         RowBox[{"_Real", "|", "_Rational", "|", "_Integer"}]}], "}"}], 
       ".."}]}], ",", " ", "opts___Rule"}], "]"}], "[", "img_List", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Method", " ", "/.", " ", 
       RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
      RowBox[{"Options", "[", "GaussianDerivative", "]"}]}], ",", 
     "\[IndentingNewLine]", "Convolve", ",", " ", 
     RowBox[{
      RowBox[{"ListConvolveGaussianShiftDerivative", "[", 
       RowBox[{"tns", ",", "opts"}], "]"}], "[", "img", "]"}], ",", 
     "\[IndentingNewLine]", "Fourier", ",", 
     RowBox[{
      RowBox[{"FourierGaussianShiftDerivative", "[", 
       RowBox[{
        RowBox[{"Apply", "[", 
         RowBox[{"Sequence", ",", 
          RowBox[{"Reverse", "[", 
           RowBox[{"{", "tns", "}"}], "]"}]}], "]"}], ",", "opts"}], "]"}], 
      "[", "img", "]"}], ",", "\[IndentingNewLine]", "_", ",", 
     RowBox[{
      RowBox[{"Message", "[", 
       RowBox[{
        RowBox[{"GaussianDerivative", "::", "nomethod"}], ",", "Method"}], 
       "]"}], ";", 
      RowBox[{"Throw", "[", "$Failed", "]"}]}]}], "\[IndentingNewLine]", 
    "]"}], "/;", 
   RowBox[{
    RowBox[{"TensorRank", "[", "img", "]"}], "\[GreaterEqual]", 
    RowBox[{"Length", "[", 
     RowBox[{"{", "tns", "}"}], "]"}]}]}]}]], "PackageInput",
 InitializationCell->True],

Cell["ListConvolve Method", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"GaussianDerivative", "::", "noboundopt"}], "=", 
   "\"\<Invalid or undefined ImageBoundary option.\>\""}], 
  ";"}]], "PackageInput",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"GaussianKernelInterval", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", "_", ",", 
     RowBox[{"rangeopt_:", "Automatic"}]}], "]"}], " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1"}], ",", "1"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"GaussianKernelInterval", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "_"}], "}"}], ",", "_", ",", 
      RowBox[{"rangeopt_:", "Automatic"}]}], "]"}], " ", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1"}], ",", "1"}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GaussianKernelInterval", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"t_", ",", "n_", ",", 
       RowBox[{"s_:", "0"}]}], "}"}], ",", "bits_", ",", 
     RowBox[{"rangeopt_:", "Automatic"}]}], "]"}], " ", ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"t", "\[LessEqual]", "0"}], ",", 
       RowBox[{
        RowBox[{"Message", "[", 
         RowBox[{
          RowBox[{"GaussianDerivative", "::", "scalefail"}], ",", "n"}], 
         "]"}], ";", " ", 
        RowBox[{"Throw", "[", "$Failed", "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"t", "<", 
        RowBox[{
         RowBox[{"MinimalScale", "[", "bits", "]"}], "[", "n", "]"}]}], ",", 
       RowBox[{"Message", "[", 
        RowBox[{
         RowBox[{"GaussianDerivative", "::", "scalefail"}], ",", "n"}], 
        "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"Switch", "[", "\[IndentingNewLine]", 
      RowBox[{"rangeopt", ",", "\[IndentingNewLine]", "Automatic", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"GaussianKernelRange", "[", "bits", "]"}], "[", 
         RowBox[{"t", ",", "n"}], "]"}], "+", 
        RowBox[{"Floor", "[", "s", "]"}]}], ",", "\[IndentingNewLine]", 
       "Infinity", ",", 
       RowBox[{"Floor", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "}"}], "*", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"-", "\[Tau]"}], " ", "t", "*", 
            RowBox[{"Log", "[", "$MinMachineNumber", "]"}]}], "]"}]}], "+", 
         "s"}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "Infinity"}], ",", "Infinity"}], "}"}], ",", 
       RowBox[{"Floor", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "}"}], "*", 
          RowBox[{"Sqrt", "[", 
           RowBox[{
            RowBox[{"-", "\[Tau]"}], " ", "t", "*", 
            RowBox[{"Log", "[", "$MinMachineNumber", "]"}]}], "]"}]}], "+", 
         "s"}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"_Integer", ",", "Infinity"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"rangeopt", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", " ", 
         RowBox[{"Floor", "[", 
          RowBox[{
           RowBox[{"Sqrt", "[", 
            RowBox[{
             RowBox[{"-", "\[Tau]"}], " ", "t", "*", 
             RowBox[{"Log", "[", "$MinMachineNumber", "]"}]}], "]"}], "+", 
           "s"}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "Infinity"}], ",", "_Integer"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Floor", "[", 
           RowBox[{
            RowBox[{"Sqrt", "[", 
             RowBox[{
              RowBox[{"-", "\[Tau]"}], " ", "t", "*", 
              RowBox[{"Log", "[", "$MinMachineNumber", "]"}]}], "]"}], "-", 
            "s"}], "]"}]}], ",", 
         RowBox[{"rangeopt", "[", 
          RowBox[{"[", "2", "]"}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"_Integer", ",", "_Integer"}], "}"}], ",", "rangeopt", ",", 
       "\[IndentingNewLine]", "_", ",", 
       RowBox[{
        RowBox[{"Message", "[", 
         RowBox[{"GaussianDerivative", "::", "nowidth"}], "]"}], ";", " ", 
        RowBox[{"Throw", "[", "$Failed", "]"}]}]}], "\[IndentingNewLine]", 
      "]"}]}], ")"}]}], ";"}]}], "PackageInput",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ListConvolveGaussianDerivative1D", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"kmin_", ",", "kmax_"}], "}"}], ",", "boundaryopt_"}], "}"}],
       ",", "img_", ",", " ", "depth_", ",", "opts___"}], "]"}], "=", "img"}],
    ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ListConvolveGaussianDerivative1D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t_", ",", "n_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"kmin_", ",", "kmax_"}], "}"}], ",", "boundaryopt_"}], "}"}], 
     ",", "img_", ",", " ", "depth_", ",", "opts___"}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"kern", "=", 
       RowBox[{"Nest", "[", 
        RowBox[{"List", ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"NGaussianDKernel", "[", "n", "]"}], "[", 
            RowBox[{"t", ",", "x"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "kmin", ",", "kmax"}], "}"}]}], "]"}], ",", 
         RowBox[{"depth", "-", "1"}]}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Switch", "[", "\[IndentingNewLine]", 
      RowBox[{
      "boundaryopt", ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       "Cyclic", ",", "\[IndentingNewLine]", 
       RowBox[{"ListConvolve", "[", 
        RowBox[{"kern", ",", "img", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"PadLeft", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "kmin"}], "+", "1"}], "}"}], ",", "depth", ",", 
             "1"}], "]"}], ",", 
           RowBox[{"PadLeft", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "kmax"}], "-", "1"}], "}"}], ",", "depth", ",", 
             "1"}], "]"}]}], "}"}]}], "]"}], " ", ",", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", "Truncate", ",", "\[IndentingNewLine]", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"AttachFrame1D", "[", 
           RowBox[{"#", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "kmin"}], ",", "kmax"}], "}"}]}], "]"}], "&"}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"ListConvolve", "[", 
          RowBox[{"kern", ",", "img", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"PadLeft", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"-", "1"}], "}"}], ",", "depth", ",", "1"}], "]"}], 
             ",", 
             RowBox[{"PadLeft", "[", 
              RowBox[{
               RowBox[{"{", "1", "}"}], ",", "depth", ",", "1"}], "]"}]}], 
            "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"depth", "-", "1"}], "}"}]}], " ", "]"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"_", "?", "NumericQ"}], ",", "\[IndentingNewLine]", 
       RowBox[{"ListConvolve", "[", 
        RowBox[{"kern", ",", "img", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"PadLeft", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "kmin"}], "+", "1"}], "}"}], ",", "depth", ",", 
             "1"}], "]"}], ",", 
           RowBox[{"PadLeft", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "kmax"}], "-", "1"}], "}"}], ",", "depth", ",", 
             "1"}], "]"}]}], "}"}], ",", 
         RowBox[{"N", "[", "boundaryopt", "]"}]}], "]"}], " ", ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", "Constant", ",", 
       "\[IndentingNewLine]", 
       RowBox[{"ListConvolve", "[", 
        RowBox[{"kern", ",", 
         RowBox[{"ImageFrame1D", "[", 
          RowBox[{"img", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "kmin"}], ",", "kmax"}], "}"}], ",", "depth", ",",
              " ", "Constant"}], "}"}]}], "]"}]}], "]"}], " ", ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", "Reflective", ",", 
       "\[IndentingNewLine]", 
       RowBox[{"ListConvolve", "[", 
        RowBox[{"kern", ",", 
         RowBox[{"ImageFrame1D", "[", 
          RowBox[{"img", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "kmin"}], ",", "kmax"}], "}"}], ",", "depth", ",",
              " ", "Reflective"}], "}"}]}], "]"}]}], "]"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", "_", ",", 
       RowBox[{
        RowBox[{"Message", "[", 
         RowBox[{"GaussianDerivative", "::", "noboundopt"}], "]"}], ";", " ", 
        
        RowBox[{"Throw", "[", "$Failed", "]"}]}]}], "\[IndentingNewLine]", 
      "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ListConvolveGaussianDerivative", "[", 
    RowBox[{"tn__List", ",", "opts___Rule"}], "]"}], "[", "img_List", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{"Catch", "[", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"dim", "=", 
        RowBox[{"TensorRank", "[", "img", "]"}]}], ",", 
       RowBox[{"nn", "=", 
        RowBox[{"Length", "[", 
         RowBox[{"{", "tn", "}"}], "]"}]}], ",", "dimrot", ",", 
       "\[IndentingNewLine]", 
       RowBox[{"bounds", " ", "=", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"ImageBoundary", " ", "/.", " ", 
           RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
          RowBox[{"Options", "[", "GaussianDerivative", "]"}]}], ")"}]}], ",",
        "\[IndentingNewLine]", 
       RowBox[{"kernrange", " ", "=", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"KernelRange", " ", "/.", " ", 
           RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
          RowBox[{"Options", "[", "GaussianDerivative", "]"}]}], ")"}]}], ",",
        "\[IndentingNewLine]", 
       RowBox[{"kernpbits", " ", "=", " ", 
        RowBox[{"Min", "[", 
         RowBox[{"52", ",", 
          RowBox[{"Max", "[", 
           RowBox[{"4", ",", 
            RowBox[{"4", "*", 
             RowBox[{"Ceiling", "[", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"Log", "[", 
                RowBox[{"2", ",", 
                 RowBox[{"10", "^", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"WorkingPrecision", " ", "/.", " ", 
                    RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
                    RowBox[{"Options", "[", "GaussianDerivative", "]"}]}], 
                   ")"}]}]}], "\[IndentingNewLine]", "]"}], "/", "4"}], 
              "]"}]}]}], "]"}]}], "]"}]}]}], "\[IndentingNewLine]", "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"If", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"dim", " ", "===", " ", "nn"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"dimrot", "=", 
         RowBox[{"RotateLeft", "[", 
          RowBox[{"Range", "[", "nn", "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Fold", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"ListConvolveGaussianDerivative1D", "[", 
            RowBox[{"#2", ",", 
             RowBox[{"Transpose", "[", 
              RowBox[{"#1", ",", "dimrot"}], "]"}], ",", "dim", ",", "opts"}],
             "]"}], "&"}], ",", "\[IndentingNewLine]", "img", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"{", 
              RowBox[{"#", ",", 
               RowBox[{"GaussianKernelInterval", "[", 
                RowBox[{"#", ",", "kernpbits", ",", "kernrange"}], "]"}], ",",
                "bounds"}], "}"}], "&"}], ",", 
            RowBox[{"RotateLeft", "[", 
             RowBox[{"{", "tn", "}"}], "]"}]}], "]"}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"dimrot", "=", 
         RowBox[{"Join", "[", 
          RowBox[{
           RowBox[{"Range", "[", 
            RowBox[{"1", ",", 
             RowBox[{"dim", "-", "nn"}]}], "]"}], ",", 
           RowBox[{"RotateLeft", "[", 
            RowBox[{"Range", "[", 
             RowBox[{
              RowBox[{"dim", "-", "nn", "+", "1"}], ",", "dim"}], "]"}], 
            "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"Transpose", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Fold", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"ListConvolveGaussianDerivative1D", "[", 
              RowBox[{"#2", ",", 
               RowBox[{"Transpose", "[", 
                RowBox[{"#1", ",", "dimrot"}], "]"}], ",", "dim", ",", 
               "opts"}], "]"}], "&"}], ",", "\[IndentingNewLine]", 
            RowBox[{"Transpose", "[", 
             RowBox[{"img", ",", 
              RowBox[{"Join", "[", 
               RowBox[{
                RowBox[{"Range", "[", 
                 RowBox[{
                  RowBox[{"dim", "-", "nn", "+", "1"}], ",", "dim"}], "]"}], 
                ",", 
                RowBox[{"Range", "[", 
                 RowBox[{"1", ",", 
                  RowBox[{"dim", "-", "nn"}]}], "]"}]}], "]"}]}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Map", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{"#", ",", 
                 RowBox[{"GaussianKernelInterval", "[", 
                  RowBox[{"#", ",", "kernpbits", ",", "kernrange"}], "]"}], 
                 ",", "bounds"}], "}"}], "&"}], ",", 
              RowBox[{"RotateLeft", "[", 
               RowBox[{"{", "tn", "}"}], "]"}]}], "]"}]}], 
           "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"Range", "[", 
             RowBox[{
              RowBox[{"nn", "+", "1"}], ",", "dim"}], "]"}], ",", 
            RowBox[{"Range", "[", 
             RowBox[{"1", ",", "nn"}], "]"}]}], "]"}]}], 
         "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
    "\[IndentingNewLine]", "]"}], "]"}]}]}], "PackageInput",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ListConvolveGaussianShiftDerivative1D", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", 
          RowBox[{"0", "|", "0.0"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"kmin_", ",", "kmax_"}], "}"}], ",", "boundaryopt_"}], "}"}],
       ",", "img_", ",", " ", "depth_", ",", "opts___"}], "]"}], "=", "img"}],
    ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ListConvolveGaussianShiftDerivative1D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t_", ",", "n_", ",", "s_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"kmin_", ",", "kmax_"}], "}"}], ",", "boundaryopt_"}], "}"}], 
     ",", "img_", ",", " ", "depth_", ",", "opts___"}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"kern", "=", 
       RowBox[{"Nest", "[", 
        RowBox[{"List", ",", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"NGaussianDKernel", "[", "n", "]"}], "[", 
            RowBox[{"t", ",", 
             RowBox[{"x", "-", 
              RowBox[{"t", " ", "s"}]}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "kmin", ",", "kmax"}], "}"}]}], "]"}], ",", 
         RowBox[{"depth", "-", "1"}]}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Switch", "[", "\[IndentingNewLine]", 
      RowBox[{
      "boundaryopt", ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       "Cyclic", ",", "\[IndentingNewLine]", 
       RowBox[{"ListConvolve", "[", 
        RowBox[{"kern", ",", "img", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"PadLeft", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "kmin"}], "+", "1"}], "}"}], ",", "depth", ",", 
             "1"}], "]"}], ",", 
           RowBox[{"PadLeft", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "kmax"}], "-", "1"}], "}"}], ",", "depth", ",", 
             "1"}], "]"}]}], "}"}]}], "]"}], " ", ",", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", "Truncate", ",", "\[IndentingNewLine]", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"AttachFrame1D", "[", 
           RowBox[{"#", ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "kmin"}], ",", "kmax"}], "}"}]}], "]"}], "&"}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"ListConvolve", "[", 
          RowBox[{"kern", ",", "img", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"PadLeft", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"-", "1"}], "}"}], ",", "depth", ",", "1"}], "]"}], 
             ",", 
             RowBox[{"PadLeft", "[", 
              RowBox[{
               RowBox[{"{", "1", "}"}], ",", "depth", ",", "1"}], "]"}]}], 
            "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"depth", "-", "1"}], "}"}]}], " ", "]"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"_", "?", "NumericQ"}], ",", "\[IndentingNewLine]", 
       RowBox[{"ListConvolve", "[", 
        RowBox[{"kern", ",", "img", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"PadLeft", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "kmin"}], "+", "1"}], "}"}], ",", "depth", ",", 
             "1"}], "]"}], ",", 
           RowBox[{"PadLeft", "[", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "kmax"}], "-", "1"}], "}"}], ",", "depth", ",", 
             "1"}], "]"}]}], "}"}], ",", 
         RowBox[{"N", "[", "boundaryopt", "]"}]}], "]"}], " ", ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", "Constant", ",", 
       "\[IndentingNewLine]", 
       RowBox[{"ListConvolve", "[", 
        RowBox[{"kern", ",", 
         RowBox[{"ImageFrame1D", "[", 
          RowBox[{"img", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "kmin"}], ",", "kmax"}], "}"}], ",", "depth", ",",
              " ", "Constant"}], "}"}]}], "]"}]}], "]"}], " ", ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", "Reflective", ",", 
       "\[IndentingNewLine]", 
       RowBox[{"ListConvolve", "[", 
        RowBox[{"kern", ",", 
         RowBox[{"ImageFrame1D", "[", 
          RowBox[{"img", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "kmin"}], ",", "kmax"}], "}"}], ",", "depth", ",",
              " ", "Reflective"}], "}"}]}], "]"}]}], "]"}], ",", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", "_", ",", 
       RowBox[{
        RowBox[{"Message", "[", 
         RowBox[{"GaussianDerivative", "::", "noboundopt"}], "]"}], ";", " ", 
        
        RowBox[{"Throw", "[", "$Failed", "]"}]}]}], "\[IndentingNewLine]", 
      "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ListConvolveGaussianShiftDerivative", "[", 
    RowBox[{"tns__List", ",", "opts___Rule"}], "]"}], "[", "img_List", "]"}], 
  ":=", "\[IndentingNewLine]", 
  RowBox[{"Catch", "[", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"dim", "=", 
        RowBox[{"TensorRank", "[", "img", "]"}]}], ",", 
       RowBox[{"nn", "=", 
        RowBox[{"Length", "[", 
         RowBox[{"{", "tns", "}"}], "]"}]}], ",", "dimrot", ",", 
       "\[IndentingNewLine]", 
       RowBox[{"bounds", " ", "=", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"ImageBoundary", " ", "/.", " ", 
           RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
          RowBox[{"Options", "[", "GaussianDerivative", "]"}]}], ")"}]}], ",",
        "\[IndentingNewLine]", 
       RowBox[{"kernrange", " ", "=", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"KernelRange", " ", "/.", " ", 
           RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
          RowBox[{"Options", "[", "GaussianDerivative", "]"}]}], ")"}]}], ",",
        "\[IndentingNewLine]", 
       RowBox[{"kernpbits", " ", "=", " ", 
        RowBox[{"Min", "[", 
         RowBox[{"52", ",", 
          RowBox[{"Max", "[", 
           RowBox[{"4", ",", 
            RowBox[{"4", "*", 
             RowBox[{"Ceiling", "[", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"Log", "[", 
                RowBox[{"2", ",", 
                 RowBox[{"10", "^", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"WorkingPrecision", " ", "/.", " ", 
                    RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
                    RowBox[{"Options", "[", "GaussianDerivative", "]"}]}], 
                   ")"}]}]}], "\[IndentingNewLine]", "]"}], "/", "4"}], 
              "]"}]}]}], "]"}]}], "]"}]}]}], "\[IndentingNewLine]", "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"If", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"dim", " ", "===", " ", "nn"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"dimrot", "=", 
         RowBox[{"RotateLeft", "[", 
          RowBox[{"Range", "[", "nn", "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Fold", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"ListConvolveGaussianShiftDerivative1D", "[", 
            RowBox[{"#2", ",", 
             RowBox[{"Transpose", "[", 
              RowBox[{"#1", ",", "dimrot"}], "]"}], ",", "dim", ",", "opts"}],
             "]"}], "&"}], ",", "\[IndentingNewLine]", "img", ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"{", 
              RowBox[{"#", ",", 
               RowBox[{"GaussianKernelInterval", "[", 
                RowBox[{"#", ",", "kernpbits", ",", "kernrange"}], "]"}], ",",
                "bounds"}], "}"}], "&"}], ",", 
            RowBox[{"RotateLeft", "[", 
             RowBox[{"{", "tns", "}"}], "]"}]}], "]"}]}], "]"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"dimrot", "=", 
         RowBox[{"Join", "[", 
          RowBox[{
           RowBox[{"Range", "[", 
            RowBox[{"1", ",", 
             RowBox[{"dim", "-", "nn"}]}], "]"}], ",", 
           RowBox[{"RotateLeft", "[", 
            RowBox[{"Range", "[", 
             RowBox[{
              RowBox[{"dim", "-", "nn", "+", "1"}], ",", "dim"}], "]"}], 
            "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"Transpose", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Fold", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"ListConvolveGaussianShiftDerivative1D", "[", 
              RowBox[{"#2", ",", 
               RowBox[{"Transpose", "[", 
                RowBox[{"#1", ",", "dimrot"}], "]"}], ",", "dim", ",", 
               "opts"}], "]"}], "&"}], ",", "\[IndentingNewLine]", 
            RowBox[{"Transpose", "[", 
             RowBox[{"img", ",", 
              RowBox[{"Join", "[", 
               RowBox[{
                RowBox[{"Range", "[", 
                 RowBox[{
                  RowBox[{"dim", "-", "nn", "+", "1"}], ",", "dim"}], "]"}], 
                ",", 
                RowBox[{"Range", "[", 
                 RowBox[{"1", ",", 
                  RowBox[{"dim", "-", "nn"}]}], "]"}]}], "]"}]}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Map", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"{", 
                RowBox[{"#", ",", 
                 RowBox[{"GaussianKernelInterval", "[", 
                  RowBox[{"#", ",", "kernpbits", ",", "kernrange"}], "]"}], 
                 ",", "bounds"}], "}"}], "&"}], ",", 
              RowBox[{"RotateLeft", "[", 
               RowBox[{"{", "tns", "}"}], "]"}]}], "]"}]}], 
           "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"Range", "[", 
             RowBox[{
              RowBox[{"nn", "+", "1"}], ",", "dim"}], "]"}], ",", 
            RowBox[{"Range", "[", 
             RowBox[{"1", ",", "nn"}], "]"}]}], "]"}]}], 
         "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
    "\[IndentingNewLine]", "]"}], "]"}]}]}], "PackageInput",
 InitializationCell->True],

Cell["Fourier Method", "Text"],

Cell[TextData[{
 "NFourierGaussianDKernelList[] renders the Fourier transformed kernel scaled \
by factor ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "\[ImaginaryI]"}], ")"}], "n"], TraditionalForm]]],
 StyleBox[" ", "InlineFormula"],
 Cell[BoxData[
  FormBox[
   SqrtBox["r"], TraditionalForm]]],
 ". This way the kernel remains real and the multiplication with the Fourier \
transformed image is performed twice as fast. The complex scaling is applied \
separately at a later stage. The Fourier transformed Gaussian derivative \
kernel is capped by ",
 StyleBox["10.^($MachinePrecision-3)", "Input"],
 " so that numerical instabilities for negative ",
 StyleBox["t", "Input"],
 " do not occur."
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
   "NFourierGaussianDKernelList", " ", "=", " ", "\[IndentingNewLine]", 
    RowBox[{"Compile", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", "_Real"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "_Integer"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", "_Integer"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"Join", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"n", "===", "0"}], ",", "1", ",", "0"}], "]"}], "}"}], 
          ",", "#", ",", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"-", "1"}], ")"}], "^", "n"}], "  ", 
           RowBox[{"Reverse", "[", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"EvenQ", "[", "r", "]"}], ",", 
              RowBox[{"Drop", "[", 
               RowBox[{"#", ",", 
                RowBox[{"-", "1"}]}], "]"}], ",", "#"}], "]"}], "]"}]}]}], 
         "]"}], "&"}], "[", 
       RowBox[{"With", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"stepsize", " ", "=", 
           RowBox[{"2.", 
            RowBox[{"Pi", "/", "r"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"(", "omega", ")"}], "^", "n"}], " ", "*", " ", 
            RowBox[{"Exp", "[", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{"omega", "^", "2"}]}], " ", "\[Tau]", " ", 
              RowBox[{"t", "/", "4"}]}], "]"}]}], ",", 
           RowBox[{"{", 
            RowBox[{
            "omega", ",", "stepsize", ",", " ", "Pi", ",", "stepsize"}], 
            "}"}]}], "]"}]}], "\[IndentingNewLine]", "]"}], 
       "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"omega", ",", "_Real"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"stepsize", ",", "_Real"}], "}"}]}], "}"}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FourierGaussianDerivative", "[", 
    RowBox[{"tn__List", ",", " ", "opts___Rule"}], "]"}], "[", "img_List", 
   "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"dim", "=", 
       RowBox[{"TensorRank", "[", "img", "]"}]}], ",", "\[IndentingNewLine]", 
      
      RowBox[{"nn", "=", 
       RowBox[{"Length", "[", 
        RowBox[{"{", "tn", "}"}], "]"}]}], ",", "\[IndentingNewLine]", "kern",
       ",", "norm", ",", "res"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"kern", " ", "=", " ", "\[IndentingNewLine]", 
      RowBox[{"Apply", "[", "\[IndentingNewLine]", 
       RowBox[{"FastOuterTimes", ",", "\[IndentingNewLine]", 
        RowBox[{"Apply", "[", "\[IndentingNewLine]", 
         RowBox[{"NFourierGaussianDKernelList", ",", "\[IndentingNewLine]", 
          RowBox[{"Transpose", "[", 
           RowBox[{"Append", "[", 
            RowBox[{
             RowBox[{"Transpose", "[", 
              RowBox[{"{", "tn", "}"}], "]"}], ",", 
             RowBox[{"res", "=", 
              RowBox[{"Take", "[", 
               RowBox[{
                RowBox[{"Dimensions", "[", "img", "]"}], ",", "nn"}], 
               "]"}]}]}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", "1", "}"}]}], "\[IndentingNewLine]", "]"}]}], 
       "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Not", "[", 
         RowBox[{"Apply", "[", 
          RowBox[{"And", ",", 
           RowBox[{"Positive", "[", 
            RowBox[{
             RowBox[{"Transpose", "[", 
              RowBox[{"{", "tn", "}"}], "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "]"}], "]"}], " ", "&&",
         " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Max", "[", "kern", "]"}], ">", 
          RowBox[{"10.", "^", 
           RowBox[{"(", 
            RowBox[{"$MachinePrecision", "-", "3"}], ")"}]}]}], ")"}]}], ",", 
       
       RowBox[{"kern", "=", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", 
            RowBox[{"#", ",", 
             RowBox[{"10.", "^", 
              RowBox[{"(", 
               RowBox[{"$MachinePrecision", "-", "3"}], ")"}]}]}], "]"}], 
           "&"}], ",", "kern", ",", 
          RowBox[{"{", 
           RowBox[{"-", "1"}], "}"}]}], "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"norm", " ", "=", " ", 
      RowBox[{"Apply", "[", 
       RowBox[{"Times", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"-", "I"}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Transpose", "[", 
            RowBox[{"{", "tn", "}"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], ")"}]}]}], "]"}]}], " ", ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"dim", " ", "===", " ", "nn"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Chop", "[", 
        RowBox[{"Re", "[", 
         RowBox[{"InverseFourier", "[", 
          RowBox[{"norm", " ", "*", " ", "kern", " ", "*", " ", 
           RowBox[{"Fourier", "[", "img", "]"}]}], "]"}], "]"}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Transpose", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Map", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"Chop", "[", 
             RowBox[{"Re", "[", 
              RowBox[{"InverseFourier", "[", 
               RowBox[{"norm", "*", " ", "kern", " ", "*", " ", 
                RowBox[{"Fourier", "[", "#", "]"}]}], "]"}], "]"}], "]"}], 
            "&"}], ",", "\[IndentingNewLine]", 
           RowBox[{"Transpose", "[", 
            RowBox[{"img", ",", 
             RowBox[{"Join", "[", 
              RowBox[{
               RowBox[{"Range", "[", 
                RowBox[{
                 RowBox[{"dim", "-", "nn", "+", "1"}], ",", "dim"}], "]"}], 
               ",", 
               RowBox[{"Range", "[", 
                RowBox[{"1", ",", 
                 RowBox[{"dim", "-", "nn"}]}], "]"}]}], "]"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"dim", "-", "nn"}], "}"}]}], "\[IndentingNewLine]", "]"}],
          ",", "\[IndentingNewLine]", 
         RowBox[{"Join", "[", 
          RowBox[{
           RowBox[{"Range", "[", 
            RowBox[{
             RowBox[{"nn", "+", "1"}], ",", "dim"}], "]"}], ",", 
           RowBox[{"Range", "[", 
            RowBox[{"1", ",", "nn"}], "]"}]}], "]"}]}], "\[IndentingNewLine]",
         "]"}]}], "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]}], "PackageInput",
 InitializationCell->True],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
   "NFourierGaussianShiftDKernelList", " ", "=", "  ", "\[IndentingNewLine]", 
    
    RowBox[{"Compile", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", "_Real"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "_Integer"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"s", ",", "_Real"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", "_Integer"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"n", "===", "0"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Exp", "[", 
            RowBox[{
             RowBox[{"-", "#"}], "*", 
             RowBox[{"(", 
              RowBox[{"#", "-", 
               RowBox[{"\[ImaginaryI]", " ", "s"}]}], ")"}], " ", "\[Tau]", 
             " ", 
             RowBox[{"t", "/", "4"}]}], "]"}], "&"}], ",", 
          RowBox[{
           RowBox[{"N", "[", 
            FractionBox[
             RowBox[{"2", "\[Pi]"}], "r"], " ", "]"}], 
           RowBox[{"Join", "[", 
            RowBox[{
             RowBox[{"Range", "[", 
              RowBox[{"0", ",", 
               RowBox[{"Quotient", "[", 
                RowBox[{"r", ",", "2"}], "]"}]}], "]"}], ",", 
             RowBox[{"Range", "[", 
              RowBox[{
               RowBox[{"1", "+", 
                RowBox[{"Quotient", "[", 
                 RowBox[{
                  RowBox[{"-", "r"}], ",", "2"}], "]"}]}], ",", 
               RowBox[{"-", "1"}]}], "]"}]}], "]"}]}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"(", "#", ")"}], "^", "n"}], " ", "*", " ", 
            RowBox[{"Exp", "[", 
             RowBox[{
              RowBox[{"-", "#"}], "*", 
              RowBox[{"(", 
               RowBox[{"#", "-", 
                RowBox[{"\[ImaginaryI]", " ", "s"}]}], ")"}], " ", "\[Tau]", 
              " ", 
              RowBox[{"t", "/", "4"}]}], "]"}]}], "&"}], ",", 
          RowBox[{
           RowBox[{"N", "[", 
            FractionBox[
             RowBox[{"2", "\[Pi]"}], "r"], " ", "]"}], 
           RowBox[{"Join", "[", 
            RowBox[{
             RowBox[{"Range", "[", 
              RowBox[{"0", ",", 
               RowBox[{"Quotient", "[", 
                RowBox[{"r", ",", "2"}], "]"}]}], "]"}], ",", 
             RowBox[{"Range", "[", 
              RowBox[{
               RowBox[{"1", "+", 
                RowBox[{"Quotient", "[", 
                 RowBox[{
                  RowBox[{"-", "r"}], ",", "2"}], "]"}]}], ",", 
               RowBox[{"-", "1"}]}], "]"}]}], "]"}]}]}], "]"}]}], 
       "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FourierGaussianShiftDerivative", "[", 
    RowBox[{"tns__List", ",", " ", "opts___Rule"}], "]"}], "[", "img_List", 
   "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"dim", "=", 
       RowBox[{"TensorRank", "[", "img", "]"}]}], ",", "\[IndentingNewLine]", 
      
      RowBox[{"nn", "=", 
       RowBox[{"Length", "[", 
        RowBox[{"{", "tns", "}"}], "]"}]}], ",", "\[IndentingNewLine]", 
      "kern", ",", "norm", ",", "res"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"kern", " ", "=", " ", "\[IndentingNewLine]", 
      RowBox[{"Apply", "[", "\[IndentingNewLine]", 
       RowBox[{"FastOuterTimes", ",", "\[IndentingNewLine]", 
        RowBox[{"Apply", "[", "\[IndentingNewLine]", 
         RowBox[{
         "NFourierGaussianShiftDKernelList", ",", "\[IndentingNewLine]", 
          RowBox[{"Transpose", "[", 
           RowBox[{"Append", "[", 
            RowBox[{
             RowBox[{"Transpose", "[", 
              RowBox[{"{", "tns", "}"}], "]"}], ",", 
             RowBox[{"res", "=", 
              RowBox[{"Take", "[", 
               RowBox[{
                RowBox[{"Dimensions", "[", "img", "]"}], ",", "nn"}], 
               "]"}]}]}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"{", "1", "}"}]}], "\[IndentingNewLine]", "]"}]}], 
       "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Not", "[", 
         RowBox[{"Apply", "[", 
          RowBox[{"And", ",", 
           RowBox[{"Positive", "[", 
            RowBox[{
             RowBox[{"Transpose", "[", 
              RowBox[{"{", "tns", "}"}], "]"}], "[", 
             RowBox[{"[", "1", "]"}], "]"}], "]"}]}], "]"}], "]"}], " ", "&&",
         " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Max", "[", "kern", "]"}], ">", 
          RowBox[{"10.", "^", 
           RowBox[{"(", 
            RowBox[{"$MachinePrecision", "-", "3"}], ")"}]}]}], ")"}]}], ",", 
       
       RowBox[{"kern", "=", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Min", "[", 
            RowBox[{"#", ",", 
             RowBox[{"10.", "^", 
              RowBox[{"(", 
               RowBox[{"$MachinePrecision", "-", "3"}], ")"}]}]}], "]"}], 
           "&"}], ",", "kern", ",", 
          RowBox[{"{", 
           RowBox[{"-", "1"}], "}"}]}], "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"norm", " ", "=", " ", 
      RowBox[{"Apply", "[", 
       RowBox[{"Times", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"-", "I"}], ")"}], "^", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"Transpose", "[", 
            RowBox[{"{", "tns", "}"}], "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}], ")"}]}]}], "]"}]}], " ", ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"dim", " ", "===", " ", "nn"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Chop", "[", 
        RowBox[{"Re", "[", 
         RowBox[{"InverseFourier", "[", 
          RowBox[{"norm", " ", "*", " ", "kern", " ", "*", " ", 
           RowBox[{"Fourier", "[", "img", "]"}]}], "]"}], "]"}], "]"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Transpose", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Map", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"Chop", "[", 
             RowBox[{"Re", "[", 
              RowBox[{"InverseFourier", "[", 
               RowBox[{"norm", "*", " ", "kern", " ", "*", " ", 
                RowBox[{"Fourier", "[", "#", "]"}]}], "]"}], "]"}], "]"}], 
            "&"}], ",", "\[IndentingNewLine]", 
           RowBox[{"Transpose", "[", 
            RowBox[{"img", ",", 
             RowBox[{"Join", "[", 
              RowBox[{
               RowBox[{"Range", "[", 
                RowBox[{
                 RowBox[{"dim", "-", "nn", "+", "1"}], ",", "dim"}], "]"}], 
               ",", 
               RowBox[{"Range", "[", 
                RowBox[{"1", ",", 
                 RowBox[{"dim", "-", "nn"}]}], "]"}]}], "]"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"dim", "-", "nn"}], "}"}]}], "\[IndentingNewLine]", "]"}],
          ",", "\[IndentingNewLine]", 
         RowBox[{"Join", "[", 
          RowBox[{
           RowBox[{"Range", "[", 
            RowBox[{
             RowBox[{"nn", "+", "1"}], ",", "dim"}], "]"}], ",", 
           RowBox[{"Range", "[", 
            RowBox[{"1", ",", "nn"}], "]"}]}], "]"}]}], "\[IndentingNewLine]",
         "]"}]}], "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]}], "PackageInput"]
}, Closed]],

Cell[CellGroupData[{

Cell["GaussianDerivative Input Notation", "Subsubsection"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     SubscriptBox["f_", 
      SubscriptBox["G", "t_"]],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{
      RowBox[{"GaussianDerivative", "[", 
       RowBox[{"{", 
        RowBox[{"t_", ",", "0"}], "}"}], "]"}], "[", "f_", "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"GaussianDerivative", " ", "Input", " ", "Notation"}], " ", "*)"}],
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"SubscriptBox", "[", 
       RowBox[{"f_", ",", 
        RowBox[{"SubscriptBox", "[", 
         RowBox[{"\"\<G\>\"", ",", "t_"}], "]"}]}], "]"}], ",", 
      "StandardForm"}], "]"}], ":=", 
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<GaussianDerivative\>\"", ",", "\"\<[\>\"", ",", 
            RowBox[{"RowBox", "[", 
             RowBox[{"{", 
              RowBox[{"\"\<{\>\"", ",", 
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{"t", ",", "\"\<,\>\"", ",", "\"\<0\>\""}], "}"}], 
                "]"}], ",", "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<]\>\""}], 
           "}"}], "]"}], ",", "\"\<[\>\"", ",", "f", ",", "\"\<]\>\""}], 
        "}"}], "]"}], ",", "StandardForm"}], "]"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MakeBoxes", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"GaussianDerivative", "[", 
        RowBox[{"{", 
         RowBox[{"t_", ",", "0"}], "}"}], "]"}], "[", "f_", "]"}], ",", 
      "StandardForm"}], "]"}], ":=", 
    RowBox[{"SubscriptBox", "[", 
     RowBox[{
      RowBox[{"MakeBoxes", "[", 
       RowBox[{"f", ",", "StandardForm"}], "]"}], ",", 
      RowBox[{"SubscriptBox", "[", 
       RowBox[{"\"\<G\>\"", ",", 
        RowBox[{"MakeBoxes", "[", 
         RowBox[{"t", ",", "StandardForm"}], "]"}]}], "]"}]}], 
     "]"}]}]}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     SubsuperscriptBox["f_", 
      SubscriptBox["G", "t_"], "\[Prime]",
      MultilineFunction->None],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{
      RowBox[{"GaussianDerivative", "[", 
       RowBox[{"{", 
        RowBox[{"t_", ",", "1"}], "}"}], "]"}], "[", "f_", "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"SubsuperscriptBox", "[", 
      RowBox[{"f_", ",", 
       RowBox[{"SubscriptBox", "[", 
        RowBox[{"\"\<G\>\"", ",", "t_"}], "]"}], ",", "\"\<\[Prime]\>\""}], 
      "]"}], ",", "StandardForm"}], "]"}], ":=", 
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<GaussianDerivative\>\"", ",", "\"\<[\>\"", ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{"\"\<{\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"t", ",", "\"\<,\>\"", ",", "\"\<1\>\""}], "}"}], 
               "]"}], ",", "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<]\>\""}], 
          "}"}], "]"}], ",", "\"\<[\>\"", ",", "f", ",", "\"\<]\>\""}], "}"}],
       "]"}], ",", "StandardForm"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"GaussianDerivative", "[", 
      RowBox[{"{", 
       RowBox[{"t_", ",", "1"}], "}"}], "]"}], "[", "f_", "]"}], ",", 
    "StandardForm"}], "]"}], ":=", 
  RowBox[{"SubsuperscriptBox", "[", 
   RowBox[{
    RowBox[{"MakeBoxes", "[", 
     RowBox[{"f", ",", "StandardForm"}], "]"}], ",", 
    RowBox[{"SubscriptBox", "[", 
     RowBox[{"\"\<G\>\"", ",", 
      RowBox[{"MakeBoxes", "[", 
       RowBox[{"t", ",", "StandardForm"}], "]"}]}], "]"}], ",", 
    "\"\<\[Prime]\>\"", ",", 
    RowBox[{"MultilineFunction", "\[Rule]", "None"}]}], 
   "]"}]}]}], "PackageInput"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     SubsuperscriptBox["f_", 
      SubscriptBox["G", "t_"], "\[Prime]\[Prime]",
      MultilineFunction->None],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{
      RowBox[{"GaussianDerivative", "[", 
       RowBox[{"{", 
        RowBox[{"t_", ",", "2"}], "}"}], "]"}], "[", "f_", "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"SubsuperscriptBox", "[", 
      RowBox[{"f_", ",", 
       RowBox[{"SubscriptBox", "[", 
        RowBox[{"\"\<G\>\"", ",", "t_"}], "]"}], ",", 
       "\"\<\[Prime]\[Prime]\>\""}], "]"}], ",", "StandardForm"}], "]"}], ":=", 
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<GaussianDerivative\>\"", ",", "\"\<[\>\"", ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{"\"\<{\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"t", ",", "\"\<,\>\"", ",", "\"\<2\>\""}], "}"}], 
               "]"}], ",", "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<]\>\""}], 
          "}"}], "]"}], ",", "\"\<[\>\"", ",", "f", ",", "\"\<]\>\""}], "}"}],
       "]"}], ",", "StandardForm"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"GaussianDerivative", "[", 
      RowBox[{"{", 
       RowBox[{"t_", ",", "2"}], "}"}], "]"}], "[", "f_", "]"}], ",", 
    "StandardForm"}], "]"}], ":=", 
  RowBox[{"SubsuperscriptBox", "[", 
   RowBox[{
    RowBox[{"MakeBoxes", "[", 
     RowBox[{"f", ",", "StandardForm"}], "]"}], ",", 
    RowBox[{"SubscriptBox", "[", 
     RowBox[{"\"\<G\>\"", ",", 
      RowBox[{"MakeBoxes", "[", 
       RowBox[{"t", ",", "StandardForm"}], "]"}]}], "]"}], ",", 
    "\"\<\[Prime]\[Prime]\>\"", ",", 
    RowBox[{"MultilineFunction", "\[Rule]", "None"}]}], 
   "]"}]}]}], "PackageInput"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     SubsuperscriptBox["f_", 
      SubscriptBox["G", "t_"], 
      RowBox[{"(", "n_", ")"}]],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{
      RowBox[{"GaussianDerivative", "[", 
       RowBox[{"{", 
        RowBox[{"t_", ",", "n_"}], "}"}], "]"}], "[", "f_", "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"SubsuperscriptBox", "[", 
      RowBox[{"f_", ",", 
       RowBox[{"SubscriptBox", "[", 
        RowBox[{"\"\<G\>\"", ",", "t_"}], "]"}], ",", 
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<(\>\"", ",", "n_", ",", "\"\<)\>\""}], "}"}], "]"}]}], 
      "]"}], ",", "StandardForm"}], "]"}], ":=", 
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<GaussianDerivative\>\"", ",", "\"\<[\>\"", ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{"\"\<{\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"t", ",", "\"\<,\>\"", ",", "n"}], "}"}], "]"}], ",", 
              "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<]\>\""}], "}"}], "]"}], 
        ",", "\"\<[\>\"", ",", "f", ",", "\"\<]\>\""}], "}"}], "]"}], ",", 
     "StandardForm"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"GaussianDerivative", "[", 
      RowBox[{"{", 
       RowBox[{"t_", ",", "n_"}], "}"}], "]"}], "[", "f_", "]"}], ",", 
    "StandardForm"}], "]"}], ":=", 
  RowBox[{"SubsuperscriptBox", "[", 
   RowBox[{
    RowBox[{"MakeBoxes", "[", 
     RowBox[{"f", ",", "StandardForm"}], "]"}], ",", 
    RowBox[{"SubscriptBox", "[", 
     RowBox[{"\"\<G\>\"", ",", 
      RowBox[{"MakeBoxes", "[", 
       RowBox[{"t", ",", "StandardForm"}], "]"}]}], "]"}], ",", 
    RowBox[{"RowBox", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<(\>\"", ",", 
       RowBox[{"MakeBoxes", "[", 
        RowBox[{"n", ",", "StandardForm"}], "]"}], ",", "\"\<)\>\""}], "}"}], 
     "]"}]}], "]"}]}]}], "PackageInput"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     SubscriptBox["f_", 
      SubscriptBox["G", 
       RowBox[{"t1_", ",", "t2_"}]]],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{
      RowBox[{"GaussianDerivative", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t1_", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t2_", ",", "0"}], "}"}]}], "]"}], "[", "f_", "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"SubscriptBox", "[", 
      RowBox[{"f_", ",", 
       RowBox[{"SubscriptBox", "[", 
        RowBox[{"\"\<G\>\"", ",", 
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{"t1_", ",", "\"\<,\>\"", ",", "t2_"}], "}"}], "]"}]}], 
        "]"}]}], "]"}], ",", "StandardForm"}], "]"}], ":=", 
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<GaussianDerivative\>\"", ",", "\"\<[\>\"", ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{"t1", ",", "\"\<,\>\"", ",", "\"\<0\>\""}], "}"}], 
                  "]"}], ",", "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<,\>\"", 
              ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{"t2", ",", "\"\<,\>\"", ",", "\"\<0\>\""}], "}"}], 
                  "]"}], ",", "\"\<}\>\""}], "}"}], "]"}]}], "}"}], "]"}], 
           ",", "\"\<]\>\""}], "}"}], "]"}], ",", "\"\<[\>\"", ",", "f", ",", 
        "\"\<]\>\""}], "}"}], "]"}], ",", "StandardForm"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"GaussianDerivative", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t1_", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t2_", ",", "0"}], "}"}]}], "]"}], "[", "f_", "]"}], ",", 
    "StandardForm"}], "]"}], ":=", 
  RowBox[{"SubscriptBox", "[", 
   RowBox[{
    RowBox[{"MakeBoxes", "[", 
     RowBox[{"f", ",", "StandardForm"}], "]"}], ",", 
    RowBox[{"SubscriptBox", "[", 
     RowBox[{"\"\<G\>\"", ",", 
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"MakeBoxes", "[", 
          RowBox[{"t1", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", ",", 
         RowBox[{"MakeBoxes", "[", 
          RowBox[{"t2", ",", "StandardForm"}], "]"}]}], "}"}], "]"}]}], 
     "]"}]}], "]"}]}]}], "PackageInput"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     SubsuperscriptBox["f_", 
      SubscriptBox["G", 
       RowBox[{"t1_", ",", "t2_"}]], 
      RowBox[{"(", 
       RowBox[{"n1_", ",", "n2_"}], ")"}]],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{
      RowBox[{"GaussianDerivative", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t1_", ",", "n1_"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t2_", ",", "n2_"}], "}"}]}], "]"}], "[", "f_", "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"SubsuperscriptBox", "[", 
      RowBox[{"f_", ",", 
       RowBox[{"SubscriptBox", "[", 
        RowBox[{"\"\<G\>\"", ",", 
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{"t1_", ",", "\"\<,\>\"", ",", "t2_"}], "}"}], "]"}]}], 
        "]"}], ",", 
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<(\>\"", ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"n1_", ",", "\"\<,\>\"", ",", "n2_"}], "}"}], "]"}], ",", 
          "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", "StandardForm"}], "]"}], 
   ":=", 
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<GaussianDerivative\>\"", ",", "\"\<[\>\"", ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{"t1", ",", "\"\<,\>\"", ",", "n1"}], "}"}], "]"}], 
                 ",", "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<,\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{"t2", ",", "\"\<,\>\"", ",", "n2"}], "}"}], "]"}], 
                 ",", "\"\<}\>\""}], "}"}], "]"}]}], "}"}], "]"}], ",", 
           "\"\<]\>\""}], "}"}], "]"}], ",", "\"\<[\>\"", ",", "f", ",", 
        "\"\<]\>\""}], "}"}], "]"}], ",", "StandardForm"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"GaussianDerivative", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t1_", ",", "n1_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t2_", ",", "n2_"}], "}"}]}], "]"}], "[", "f_", "]"}], ",", 
    "StandardForm"}], "]"}], ":=", 
  RowBox[{"SubsuperscriptBox", "[", 
   RowBox[{
    RowBox[{"MakeBoxes", "[", 
     RowBox[{"f", ",", "StandardForm"}], "]"}], ",", 
    RowBox[{"SubscriptBox", "[", 
     RowBox[{"\"\<G\>\"", ",", 
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"MakeBoxes", "[", 
          RowBox[{"t1", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", ",", 
         RowBox[{"MakeBoxes", "[", 
          RowBox[{"t2", ",", "StandardForm"}], "]"}]}], "}"}], "]"}]}], "]"}],
     ",", 
    RowBox[{"RowBox", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<(\>\"", ",", 
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"MakeBoxes", "[", 
           RowBox[{"n1", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", ",", 
          
          RowBox[{"MakeBoxes", "[", 
           RowBox[{"n2", ",", "StandardForm"}], "]"}]}], "}"}], "]"}], ",", 
       "\"\<)\>\""}], "}"}], "]"}]}], "]"}]}]}], "PackageInput"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     SubscriptBox["f_", 
      SubscriptBox["G", "t_"]],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{
      RowBox[{"GaussianDerivative", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t_", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t_", ",", "0"}], "}"}]}], "]"}], "[", "f_", "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"SubscriptBox", "[", 
      RowBox[{"f_", ",", 
       RowBox[{"SubscriptBox", "[", 
        RowBox[{"\"\<G\>\"", ",", "t_"}], "]"}]}], "]"}], ",", 
     "StandardForm"}], "]"}], ":=", 
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<GaussianDerivative\>\"", ",", "\"\<[\>\"", ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{"t", ",", "\"\<,\>\"", ",", "\"\<0\>\""}], "}"}], 
                  "]"}], ",", "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<,\>\"", 
              ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{"t", ",", "\"\<,\>\"", ",", "\"\<0\>\""}], "}"}], 
                  "]"}], ",", "\"\<}\>\""}], "}"}], "]"}]}], "}"}], "]"}], 
           ",", "\"\<]\>\""}], "}"}], "]"}], ",", "\"\<[\>\"", ",", "f", ",", 
        "\"\<]\>\""}], "}"}], "]"}], ",", "StandardForm"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"GaussianDerivative", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t_", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t_", ",", "0"}], "}"}]}], "]"}], "[", "f_", "]"}], ",", 
    "StandardForm"}], "]"}], ":=", 
  RowBox[{"SubscriptBox", "[", 
   RowBox[{
    RowBox[{"MakeBoxes", "[", 
     RowBox[{"f", ",", "StandardForm"}], "]"}], ",", 
    RowBox[{"SubscriptBox", "[", 
     RowBox[{"\"\<G\>\"", ",", 
      RowBox[{"MakeBoxes", "[", 
       RowBox[{"t", ",", "StandardForm"}], "]"}]}], "]"}]}], 
   "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     SubsuperscriptBox["f_", 
      SubscriptBox["G", "t_"], 
      RowBox[{"(", 
       RowBox[{"n1_", ",", "n2_"}], ")"}]],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{
      RowBox[{"GaussianDerivative", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t_", ",", "n1_"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t_", ",", "n2_"}], "}"}]}], "]"}], "[", "f_", "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"SubsuperscriptBox", "[", 
      RowBox[{"f_", ",", 
       RowBox[{"SubscriptBox", "[", 
        RowBox[{"\"\<G\>\"", ",", "t_"}], "]"}], ",", 
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<(\>\"", ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{"n1_", ",", "\"\<,\>\"", ",", "n2_"}], "}"}], "]"}], ",", 
          "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", "StandardForm"}], "]"}], 
   ":=", 
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<GaussianDerivative\>\"", ",", "\"\<[\>\"", ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{"t", ",", "\"\<,\>\"", ",", "n1"}], "}"}], "]"}], 
                 ",", "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<,\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{"t", ",", "\"\<,\>\"", ",", "n2"}], "}"}], "]"}], 
                 ",", "\"\<}\>\""}], "}"}], "]"}]}], "}"}], "]"}], ",", 
           "\"\<]\>\""}], "}"}], "]"}], ",", "\"\<[\>\"", ",", "f", ",", 
        "\"\<]\>\""}], "}"}], "]"}], ",", "StandardForm"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"GaussianDerivative", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t_", ",", "n1_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t_", ",", "n2_"}], "}"}]}], "]"}], "[", "f_", "]"}], ",", 
    "StandardForm"}], "]"}], ":=", 
  RowBox[{"SubsuperscriptBox", "[", 
   RowBox[{
    RowBox[{"MakeBoxes", "[", 
     RowBox[{"f", ",", "StandardForm"}], "]"}], ",", 
    RowBox[{"SubscriptBox", "[", 
     RowBox[{"\"\<G\>\"", ",", 
      RowBox[{"MakeBoxes", "[", 
       RowBox[{"t", ",", "StandardForm"}], "]"}]}], "]"}], ",", 
    RowBox[{"RowBox", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<(\>\"", ",", 
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"MakeBoxes", "[", 
           RowBox[{"n1", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", ",", 
          
          RowBox[{"MakeBoxes", "[", 
           RowBox[{"n2", ",", "StandardForm"}], "]"}]}], "}"}], "]"}], ",", 
       "\"\<)\>\""}], "}"}], "]"}]}], "]"}]}]}], "PackageInput"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     SubscriptBox["f_", 
      SubscriptBox["G", 
       RowBox[{"t1_", ",", "t2_", ",", "t3_"}]]],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{
      RowBox[{"GaussianDerivative", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t1_", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t2_", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t3_", ",", "0"}], "}"}]}], "]"}], "[", "f_", "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"SubscriptBox", "[", 
      RowBox[{"f_", ",", 
       RowBox[{"SubscriptBox", "[", 
        RowBox[{"\"\<G\>\"", ",", 
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{
           "t1_", ",", "\"\<,\>\"", ",", "t2_", ",", "\"\<,\>\"", ",", 
            "t3_"}], "}"}], "]"}]}], "]"}]}], "]"}], ",", "StandardForm"}], 
    "]"}], ":=", 
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<GaussianDerivative\>\"", ",", "\"\<[\>\"", ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{"t1", ",", "\"\<,\>\"", ",", "\"\<0\>\""}], "}"}], 
                  "]"}], ",", "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<,\>\"", 
              ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{"t2", ",", "\"\<,\>\"", ",", "\"\<0\>\""}], "}"}], 
                  "]"}], ",", "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<,\>\"", 
              ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{"t3", ",", "\"\<,\>\"", ",", "\"\<0\>\""}], "}"}], 
                  "]"}], ",", "\"\<}\>\""}], "}"}], "]"}]}], "}"}], "]"}], 
           ",", "\"\<]\>\""}], "}"}], "]"}], ",", "\"\<[\>\"", ",", "f", ",", 
        "\"\<]\>\""}], "}"}], "]"}], ",", "StandardForm"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"GaussianDerivative", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t1_", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t2_", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t3_", ",", "0"}], "}"}]}], "]"}], "[", "f_", "]"}], ",", 
    "StandardForm"}], "]"}], ":=", 
  RowBox[{"SubscriptBox", "[", 
   RowBox[{
    RowBox[{"MakeBoxes", "[", 
     RowBox[{"f", ",", "StandardForm"}], "]"}], ",", 
    RowBox[{"SubscriptBox", "[", 
     RowBox[{"\"\<G\>\"", ",", 
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"MakeBoxes", "[", 
          RowBox[{"t1", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", ",", 
         RowBox[{"MakeBoxes", "[", 
          RowBox[{"t2", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", ",", 
         RowBox[{"MakeBoxes", "[", 
          RowBox[{"t3", ",", "StandardForm"}], "]"}]}], "}"}], "]"}]}], 
     "]"}]}], "]"}]}]}], "PackageInput"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     SubsuperscriptBox["f_", 
      SubscriptBox["G", 
       RowBox[{"t1_", ",", "t2_", ",", "t3_"}]], 
      RowBox[{"(", 
       RowBox[{"n1_", ",", "n2_", ",", "n3_"}], ")"}]],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{
      RowBox[{"GaussianDerivative", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t1_", ",", "n1_"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t2_", ",", "n2_"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t3_", ",", "n3_"}], "}"}]}], "]"}], "[", "f_", "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"SubsuperscriptBox", "[", 
      RowBox[{"f_", ",", 
       RowBox[{"SubscriptBox", "[", 
        RowBox[{"\"\<G\>\"", ",", 
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{
           "t1_", ",", "\"\<,\>\"", ",", "t2_", ",", "\"\<,\>\"", ",", 
            "t3_"}], "}"}], "]"}]}], "]"}], ",", 
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<(\>\"", ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{
            "n1_", ",", "\"\<,\>\"", ",", "n2_", ",", "\"\<,\>\"", ",", 
             "n3_"}], "}"}], "]"}], ",", "\"\<)\>\""}], "}"}], "]"}]}], "]"}],
      ",", "StandardForm"}], "]"}], ":=", 
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<GaussianDerivative\>\"", ",", "\"\<[\>\"", ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{"t1", ",", "\"\<,\>\"", ",", "n1"}], "}"}], "]"}], 
                 ",", "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<,\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{"t2", ",", "\"\<,\>\"", ",", "n2"}], "}"}], "]"}], 
                 ",", "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<,\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{"t3", ",", "\"\<,\>\"", ",", "n3"}], "}"}], "]"}], 
                 ",", "\"\<}\>\""}], "}"}], "]"}]}], "}"}], "]"}], ",", 
           "\"\<]\>\""}], "}"}], "]"}], ",", "\"\<[\>\"", ",", "f", ",", 
        "\"\<]\>\""}], "}"}], "]"}], ",", "StandardForm"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"GaussianDerivative", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t1_", ",", "n1_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t2_", ",", "n2_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t3_", ",", "n3_"}], "}"}]}], "]"}], "[", "f_", "]"}], ",", 
    "StandardForm"}], "]"}], ":=", 
  RowBox[{"SubsuperscriptBox", "[", 
   RowBox[{
    RowBox[{"MakeBoxes", "[", 
     RowBox[{"f", ",", "StandardForm"}], "]"}], ",", 
    RowBox[{"SubscriptBox", "[", 
     RowBox[{"\"\<G\>\"", ",", 
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"MakeBoxes", "[", 
          RowBox[{"t1", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", ",", 
         RowBox[{"MakeBoxes", "[", 
          RowBox[{"t2", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", ",", 
         RowBox[{"MakeBoxes", "[", 
          RowBox[{"t3", ",", "StandardForm"}], "]"}]}], "}"}], "]"}]}], "]"}],
     ",", 
    RowBox[{"RowBox", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<(\>\"", ",", 
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"MakeBoxes", "[", 
           RowBox[{"n1", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", ",", 
          
          RowBox[{"MakeBoxes", "[", 
           RowBox[{"n2", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", ",", 
          
          RowBox[{"MakeBoxes", "[", 
           RowBox[{"n3", ",", "StandardForm"}], "]"}]}], "}"}], "]"}], ",", 
       "\"\<)\>\""}], "}"}], "]"}]}], "]"}]}]}], "PackageInput"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     SubscriptBox["f_", 
      SubscriptBox["G", "t_"]],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{
      RowBox[{"GaussianDerivative", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t_", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t_", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t_", ",", "0"}], "}"}]}], "]"}], "[", "f_", "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"SubscriptBox", "[", 
      RowBox[{"f_", ",", 
       RowBox[{"SubscriptBox", "[", 
        RowBox[{"\"\<G\>\"", ",", "t_"}], "]"}]}], "]"}], ",", 
     "StandardForm"}], "]"}], ":=", 
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<GaussianDerivative\>\"", ",", "\"\<[\>\"", ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{"t", ",", "\"\<,\>\"", ",", "\"\<0\>\""}], "}"}], 
                  "]"}], ",", "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<,\>\"", 
              ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{"t", ",", "\"\<,\>\"", ",", "\"\<0\>\""}], "}"}], 
                  "]"}], ",", "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<,\>\"", 
              ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{"t", ",", "\"\<,\>\"", ",", "\"\<0\>\""}], "}"}], 
                  "]"}], ",", "\"\<}\>\""}], "}"}], "]"}]}], "}"}], "]"}], 
           ",", "\"\<]\>\""}], "}"}], "]"}], ",", "\"\<[\>\"", ",", "f", ",", 
        "\"\<]\>\""}], "}"}], "]"}], ",", "StandardForm"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"GaussianDerivative", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t_", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t_", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t_", ",", "0"}], "}"}]}], "]"}], "[", "f_", "]"}], ",", 
    "StandardForm"}], "]"}], ":=", 
  RowBox[{"SubscriptBox", "[", 
   RowBox[{
    RowBox[{"MakeBoxes", "[", 
     RowBox[{"f", ",", "StandardForm"}], "]"}], ",", 
    RowBox[{"SubscriptBox", "[", 
     RowBox[{"\"\<G\>\"", ",", 
      RowBox[{"MakeBoxes", "[", 
       RowBox[{"t", ",", "StandardForm"}], "]"}]}], "]"}]}], 
   "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     SubsuperscriptBox["f_", 
      SubscriptBox["G", "t_"], 
      RowBox[{"(", 
       RowBox[{"n1_", ",", "n2_", ",", "n3_"}], ")"}]],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{
      RowBox[{"GaussianDerivative", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t_", ",", "n1_"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t_", ",", "n2_"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t_", ",", "n3_"}], "}"}]}], "]"}], "[", "f_", "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"SubsuperscriptBox", "[", 
      RowBox[{"f_", ",", 
       RowBox[{"SubscriptBox", "[", 
        RowBox[{"\"\<G\>\"", ",", "t_"}], "]"}], ",", 
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{"\"\<(\>\"", ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{
            "n1_", ",", "\"\<,\>\"", ",", "n2_", ",", "\"\<,\>\"", ",", 
             "n3_"}], "}"}], "]"}], ",", "\"\<)\>\""}], "}"}], "]"}]}], "]"}],
      ",", "StandardForm"}], "]"}], ":=", 
   RowBox[{"MakeExpression", "[", 
    RowBox[{
     RowBox[{"RowBox", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<GaussianDerivative\>\"", ",", "\"\<[\>\"", ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{"t", ",", "\"\<,\>\"", ",", "n1"}], "}"}], "]"}], 
                 ",", "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<,\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{"t", ",", "\"\<,\>\"", ",", "n2"}], "}"}], "]"}], 
                 ",", "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<,\>\"", ",", 
              RowBox[{"RowBox", "[", 
               RowBox[{"{", 
                RowBox[{"\"\<{\>\"", ",", 
                 RowBox[{"RowBox", "[", 
                  RowBox[{"{", 
                   RowBox[{"t", ",", "\"\<,\>\"", ",", "n3"}], "}"}], "]"}], 
                 ",", "\"\<}\>\""}], "}"}], "]"}]}], "}"}], "]"}], ",", 
           "\"\<]\>\""}], "}"}], "]"}], ",", "\"\<[\>\"", ",", "f", ",", 
        "\"\<]\>\""}], "}"}], "]"}], ",", "StandardForm"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MakeBoxes", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"GaussianDerivative", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t_", ",", "n1_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t_", ",", "n2_"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"t_", ",", "n3_"}], "}"}]}], "]"}], "[", "f_", "]"}], ",", 
    "StandardForm"}], "]"}], ":=", 
  RowBox[{"SubsuperscriptBox", "[", 
   RowBox[{
    RowBox[{"MakeBoxes", "[", 
     RowBox[{"f", ",", "StandardForm"}], "]"}], ",", 
    RowBox[{"SubscriptBox", "[", 
     RowBox[{"\"\<G\>\"", ",", 
      RowBox[{"MakeBoxes", "[", 
       RowBox[{"t", ",", "StandardForm"}], "]"}]}], "]"}], ",", 
    RowBox[{"RowBox", "[", 
     RowBox[{"{", 
      RowBox[{"\"\<(\>\"", ",", 
       RowBox[{"RowBox", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"MakeBoxes", "[", 
           RowBox[{"n1", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", ",", 
          
          RowBox[{"MakeBoxes", "[", 
           RowBox[{"n2", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", ",", 
          
          RowBox[{"MakeBoxes", "[", 
           RowBox[{"n3", ",", "StandardForm"}], "]"}]}], "}"}], "]"}], ",", 
       "\"\<)\>\""}], "}"}], "]"}]}], "]"}]}]}], "PackageInput"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     SubscriptBox["f_", 
      SubscriptBox["G", 
       RowBox[{"t1_", ",", "t2_", ",", "t3_", ",", "t4_"}]]],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{
      RowBox[{"GaussianDerivative", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t1_", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t2_", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t3_", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t4_", ",", "0"}], "}"}]}], "]"}], "[", "f_", "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"SubscriptBox", "[", 
       RowBox[{"f_", ",", 
        RowBox[{"SubscriptBox", "[", 
         RowBox[{"\"\<G\>\"", ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{
            "t1_", ",", "\"\<,\>\"", ",", "t2_", ",", "\"\<,\>\"", ",", "t3_",
              ",", "\"\<,\>\"", ",", "t4_"}], "}"}], "]"}]}], "]"}]}], "]"}], 
      ",", "StandardForm"}], "]"}], ":=", 
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<GaussianDerivative\>\"", ",", "\"\<[\>\"", ",", 
            RowBox[{"RowBox", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<{\>\"", ",", 
                  RowBox[{"RowBox", "[", 
                   RowBox[{"{", 
                    RowBox[{"t1", ",", "\"\<,\>\"", ",", "\"\<0\>\""}], "}"}],
                    "]"}], ",", "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<,\>\"",
                ",", 
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<{\>\"", ",", 
                  RowBox[{"RowBox", "[", 
                   RowBox[{"{", 
                    RowBox[{"t2", ",", "\"\<,\>\"", ",", "\"\<0\>\""}], "}"}],
                    "]"}], ",", "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<,\>\"",
                ",", 
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<{\>\"", ",", 
                  RowBox[{"RowBox", "[", 
                   RowBox[{"{", 
                    RowBox[{"t3", ",", "\"\<,\>\"", ",", "\"\<0\>\""}], "}"}],
                    "]"}], ",", "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<,\>\"",
                ",", 
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<{\>\"", ",", 
                  RowBox[{"RowBox", "[", 
                   RowBox[{"{", 
                    RowBox[{"t4", ",", "\"\<,\>\"", ",", "\"\<0\>\""}], "}"}],
                    "]"}], ",", "\"\<}\>\""}], "}"}], "]"}]}], "}"}], "]"}], 
            ",", "\"\<]\>\""}], "}"}], "]"}], ",", "\"\<[\>\"", ",", "f", 
         ",", "\"\<]\>\""}], "}"}], "]"}], ",", "StandardForm"}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MakeBoxes", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"GaussianDerivative", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"t1_", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t2_", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t3_", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t4_", ",", "0"}], "}"}]}], "]"}], "[", "f_", "]"}], ",", 
      "StandardForm"}], "]"}], ":=", 
    RowBox[{"SubscriptBox", "[", 
     RowBox[{
      RowBox[{"MakeBoxes", "[", 
       RowBox[{"f", ",", "StandardForm"}], "]"}], ",", 
      RowBox[{"SubscriptBox", "[", 
       RowBox[{"\"\<G\>\"", ",", 
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"MakeBoxes", "[", 
            RowBox[{"t1", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", ",", 
           RowBox[{"MakeBoxes", "[", 
            RowBox[{"t2", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", ",", 
           RowBox[{"MakeBoxes", "[", 
            RowBox[{"t3", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", ",", 
           RowBox[{"MakeBoxes", "[", 
            RowBox[{"t4", ",", "StandardForm"}], "]"}]}], "}"}], "]"}]}], 
       "]"}]}], "]"}]}]}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     SubsuperscriptBox["f_", 
      SubscriptBox["G", 
       RowBox[{"t1_", ",", "t2_", ",", "t3_", ",", "t4_"}]], 
      RowBox[{"(", 
       RowBox[{"n1_", ",", "n2_", ",", "n3_", ",", "n4_"}], ")"}]],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{
      RowBox[{"GaussianDerivative", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t1_", ",", "n1_"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t2_", ",", "n2_"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t3_", ",", "n3_"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t4_", ",", "n4_"}], "}"}]}], "]"}], "[", "f_", "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"SubsuperscriptBox", "[", 
       RowBox[{"f_", ",", 
        RowBox[{"SubscriptBox", "[", 
         RowBox[{"\"\<G\>\"", ",", 
          RowBox[{"RowBox", "[", 
           RowBox[{"{", 
            RowBox[{
            "t1_", ",", "\"\<,\>\"", ",", "t2_", ",", "\"\<,\>\"", ",", "t3_",
              ",", "\"\<,\>\"", ",", "t4_"}], "}"}], "]"}]}], "]"}], ",", 
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<(\>\"", ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{
             "n1_", ",", "\"\<,\>\"", ",", "n2_", ",", "\"\<,\>\"", ",", 
              "n3_", ",", "\"\<,\>\"", ",", "n4_"}], "}"}], "]"}], ",", 
           "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", "StandardForm"}], "]"}],
     ":=", 
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<GaussianDerivative\>\"", ",", "\"\<[\>\"", ",", 
            RowBox[{"RowBox", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<{\>\"", ",", 
                  RowBox[{"RowBox", "[", 
                   RowBox[{"{", 
                    RowBox[{"t1", ",", "\"\<,\>\"", ",", "n1"}], "}"}], "]"}],
                   ",", "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<,\>\"", ",", 
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<{\>\"", ",", 
                  RowBox[{"RowBox", "[", 
                   RowBox[{"{", 
                    RowBox[{"t2", ",", "\"\<,\>\"", ",", "n2"}], "}"}], "]"}],
                   ",", "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<,\>\"", ",", 
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<{\>\"", ",", 
                  RowBox[{"RowBox", "[", 
                   RowBox[{"{", 
                    RowBox[{"t3", ",", "\"\<,\>\"", ",", "n3"}], "}"}], "]"}],
                   ",", "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<,\>\"", ",", 
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<{\>\"", ",", 
                  RowBox[{"RowBox", "[", 
                   RowBox[{"{", 
                    RowBox[{"t4", ",", "\"\<,\>\"", ",", "n4"}], "}"}], "]"}],
                   ",", "\"\<}\>\""}], "}"}], "]"}]}], "}"}], "]"}], ",", 
            "\"\<]\>\""}], "}"}], "]"}], ",", "\"\<[\>\"", ",", "f", ",", 
         "\"\<]\>\""}], "}"}], "]"}], ",", "StandardForm"}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MakeBoxes", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"GaussianDerivative", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"t1_", ",", "n1_"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t2_", ",", "n2_"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t3_", ",", "n3_"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t4_", ",", "n4_"}], "}"}]}], "]"}], "[", "f_", "]"}], ",", 
      "StandardForm"}], "]"}], ":=", 
    RowBox[{"SubsuperscriptBox", "[", 
     RowBox[{
      RowBox[{"MakeBoxes", "[", 
       RowBox[{"f", ",", "StandardForm"}], "]"}], ",", 
      RowBox[{"SubscriptBox", "[", 
       RowBox[{"\"\<G\>\"", ",", 
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"MakeBoxes", "[", 
            RowBox[{"t1", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", ",", 
           RowBox[{"MakeBoxes", "[", 
            RowBox[{"t2", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", ",", 
           RowBox[{"MakeBoxes", "[", 
            RowBox[{"t3", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", ",", 
           RowBox[{"MakeBoxes", "[", 
            RowBox[{"t4", ",", "StandardForm"}], "]"}]}], "}"}], "]"}]}], 
       "]"}], ",", 
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{"\"\<(\>\"", ",", 
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"MakeBoxes", "[", 
             RowBox[{"n1", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
            ",", 
            RowBox[{"MakeBoxes", "[", 
             RowBox[{"n2", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
            ",", 
            RowBox[{"MakeBoxes", "[", 
             RowBox[{"n3", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
            ",", 
            RowBox[{"MakeBoxes", "[", 
             RowBox[{"n4", ",", "StandardForm"}], "]"}]}], "}"}], "]"}], ",", 
         "\"\<)\>\""}], "}"}], "]"}]}], "]"}]}]}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     SubscriptBox["f_", 
      SubscriptBox["G", "t_"]],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{
      RowBox[{"GaussianDerivative", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t_", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t_", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t_", ",", "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t_", ",", "0"}], "}"}]}], "]"}], "[", "f_", "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"SubscriptBox", "[", 
       RowBox[{"f_", ",", 
        RowBox[{"SubscriptBox", "[", 
         RowBox[{"\"\<G\>\"", ",", "t_"}], "]"}]}], "]"}], ",", 
      "StandardForm"}], "]"}], ":=", 
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<GaussianDerivative\>\"", ",", "\"\<[\>\"", ",", 
            RowBox[{"RowBox", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<{\>\"", ",", 
                  RowBox[{"RowBox", "[", 
                   RowBox[{"{", 
                    RowBox[{"t", ",", "\"\<,\>\"", ",", "\"\<0\>\""}], "}"}], 
                   "]"}], ",", "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<,\>\"", 
               ",", 
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<{\>\"", ",", 
                  RowBox[{"RowBox", "[", 
                   RowBox[{"{", 
                    RowBox[{"t", ",", "\"\<,\>\"", ",", "\"\<0\>\""}], "}"}], 
                   "]"}], ",", "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<,\>\"", 
               ",", 
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<{\>\"", ",", 
                  RowBox[{"RowBox", "[", 
                   RowBox[{"{", 
                    RowBox[{"t", ",", "\"\<,\>\"", ",", "\"\<0\>\""}], "}"}], 
                   "]"}], ",", "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<,\>\"", 
               ",", 
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<{\>\"", ",", 
                  RowBox[{"RowBox", "[", 
                   RowBox[{"{", 
                    RowBox[{"t", ",", "\"\<,\>\"", ",", "\"\<0\>\""}], "}"}], 
                   "]"}], ",", "\"\<}\>\""}], "}"}], "]"}]}], "}"}], "]"}], 
            ",", "\"\<]\>\""}], "}"}], "]"}], ",", "\"\<[\>\"", ",", "f", 
         ",", "\"\<]\>\""}], "}"}], "]"}], ",", "StandardForm"}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MakeBoxes", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"GaussianDerivative", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"t_", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t_", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t_", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t_", ",", "0"}], "}"}]}], "]"}], "[", "f_", "]"}], ",", 
      "StandardForm"}], "]"}], ":=", 
    RowBox[{"SubscriptBox", "[", 
     RowBox[{
      RowBox[{"MakeBoxes", "[", 
       RowBox[{"f", ",", "StandardForm"}], "]"}], ",", 
      RowBox[{"SubscriptBox", "[", 
       RowBox[{"\"\<G\>\"", ",", 
        RowBox[{"MakeBoxes", "[", 
         RowBox[{"t", ",", "StandardForm"}], "]"}]}], "]"}]}], 
     "]"}]}]}]}]], "Input"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Notation", "[", 
   RowBox[{
    TagBox[
     SubsuperscriptBox["f_", 
      SubscriptBox["G", "t_"], 
      RowBox[{"(", 
       RowBox[{"n1_", ",", "n2_", ",", "n3_", ",", "n4_"}], ")"}]],
     "NotationTemplateTag"], " ", "\[DoubleLongLeftRightArrow]", " ", 
    TagBox[
     RowBox[{
      RowBox[{"GaussianDerivative", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t_", ",", "n1_"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t_", ",", "n2_"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t_", ",", "n3_"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"t_", ",", "n4_"}], "}"}]}], "]"}], "[", "f_", "]"}],
     "NotationTemplateTag"]}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"SubsuperscriptBox", "[", 
       RowBox[{"f_", ",", 
        RowBox[{"SubscriptBox", "[", 
         RowBox[{"\"\<G\>\"", ",", "t_"}], "]"}], ",", 
        RowBox[{"RowBox", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<(\>\"", ",", 
           RowBox[{"RowBox", "[", 
            RowBox[{"{", 
             RowBox[{
             "n1_", ",", "\"\<,\>\"", ",", "n2_", ",", "\"\<,\>\"", ",", 
              "n3_", ",", "\"\<,\>\"", ",", "n4_"}], "}"}], "]"}], ",", 
           "\"\<)\>\""}], "}"}], "]"}]}], "]"}], ",", "StandardForm"}], "]"}],
     ":=", 
    RowBox[{"MakeExpression", "[", 
     RowBox[{
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{"\"\<GaussianDerivative\>\"", ",", "\"\<[\>\"", ",", 
            RowBox[{"RowBox", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<{\>\"", ",", 
                  RowBox[{"RowBox", "[", 
                   RowBox[{"{", 
                    RowBox[{"t", ",", "\"\<,\>\"", ",", "n1"}], "}"}], "]"}], 
                  ",", "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<,\>\"", ",", 
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<{\>\"", ",", 
                  RowBox[{"RowBox", "[", 
                   RowBox[{"{", 
                    RowBox[{"t", ",", "\"\<,\>\"", ",", "n2"}], "}"}], "]"}], 
                  ",", "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<,\>\"", ",", 
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<{\>\"", ",", 
                  RowBox[{"RowBox", "[", 
                   RowBox[{"{", 
                    RowBox[{"t", ",", "\"\<,\>\"", ",", "n3"}], "}"}], "]"}], 
                  ",", "\"\<}\>\""}], "}"}], "]"}], ",", "\"\<,\>\"", ",", 
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<{\>\"", ",", 
                  RowBox[{"RowBox", "[", 
                   RowBox[{"{", 
                    RowBox[{"t", ",", "\"\<,\>\"", ",", "n4"}], "}"}], "]"}], 
                  ",", "\"\<}\>\""}], "}"}], "]"}]}], "}"}], "]"}], ",", 
            "\"\<]\>\""}], "}"}], "]"}], ",", "\"\<[\>\"", ",", "f", ",", 
         "\"\<]\>\""}], "}"}], "]"}], ",", "StandardForm"}], "]"}]}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MakeBoxes", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"GaussianDerivative", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"t_", ",", "n1_"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t_", ",", "n2_"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t_", ",", "n3_"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"t_", ",", "n4_"}], "}"}]}], "]"}], "[", "f_", "]"}], ",", 
      "StandardForm"}], "]"}], ":=", 
    RowBox[{"SubsuperscriptBox", "[", 
     RowBox[{
      RowBox[{"MakeBoxes", "[", 
       RowBox[{"f", ",", "StandardForm"}], "]"}], ",", 
      RowBox[{"SubscriptBox", "[", 
       RowBox[{"\"\<G\>\"", ",", 
        RowBox[{"MakeBoxes", "[", 
         RowBox[{"t", ",", "StandardForm"}], "]"}]}], "]"}], ",", 
      RowBox[{"RowBox", "[", 
       RowBox[{"{", 
        RowBox[{"\"\<(\>\"", ",", 
         RowBox[{"RowBox", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"MakeBoxes", "[", 
             RowBox[{"n1", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
            ",", 
            RowBox[{"MakeBoxes", "[", 
             RowBox[{"n2", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
            ",", 
            RowBox[{"MakeBoxes", "[", 
             RowBox[{"n3", ",", "StandardForm"}], "]"}], ",", "\"\<,\>\"", 
            ",", 
            RowBox[{"MakeBoxes", "[", 
             RowBox[{"n4", ",", "StandardForm"}], "]"}]}], "}"}], "]"}], ",", 
         "\"\<)\>\""}], "}"}], "]"}]}], "]"}]}]}]}]], "PackageInput"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["GaussianDerivativeJet", "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"JetIndex", "[", 
     RowBox[{"n_", ",", "1"}], "]"}], "=", 
    RowBox[{"{", 
     RowBox[{"{", "n", "}"}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"JetIndex", "[", 
    RowBox[{"n_", ",", "d_"}], "]"}], ":=", 
   RowBox[{"Join", "@@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Prepend", "[", 
          RowBox[{"#", ",", 
           RowBox[{"n", "-", "k"}]}], "]"}], "&"}], ",", 
        RowBox[{"JetIndex", "[", 
         RowBox[{"k", ",", 
          RowBox[{"d", "-", "1"}]}], "]"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "0", ",", "n"}], "}"}]}], "]"}]}]}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"GaussianDerivativeJet", "[", 
     RowBox[{"t_", ",", "n_"}], "]"}], "[", 
    RowBox[{"img_", "?", "ImageQ"}], "]"}], " ", ":=", " ", 
   RowBox[{"Apply", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"GaussianDerivative", "[", "##", "]"}], "[", 
       RowBox[{"ImageData", "[", 
        RowBox[{"img", ",", 
         RowBox[{"Interleaving", "\[Rule]", " ", "True"}]}], "]"}], "]"}], 
      "&"}], ",", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", "#"}], "}"}], "&"}], ",", 
       RowBox[{"JetIndex", "[", 
        RowBox[{"n", ",", "2"}], "]"}], ",", 
       RowBox[{"{", "2", "}"}]}], "]"}], ",", 
     RowBox[{"{", "1", "}"}]}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GaussianDerivativeJet", "[", 
    RowBox[{"t_", ",", "n_"}], "]"}], "[", "img_List", "]"}], " ", ":=", " ", 
  
  RowBox[{"Apply", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"GaussianDerivative", "[", "##", "]"}], "[", "img", "]"}], 
     "&"}], ",", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t", ",", "#"}], "}"}], "&"}], ",", 
      RowBox[{"JetIndex", "[", 
       RowBox[{"n", ",", 
        RowBox[{"ArrayDepth", "[", "img", "]"}]}], "]"}], ",", 
      RowBox[{"{", "2", "}"}]}], "]"}], ",", 
    RowBox[{"{", "1", "}"}]}], "]"}]}]}], "PackageInput"]
}, Closed]],

Cell[CellGroupData[{

Cell["GaussianDerivativeAt", "Subsection"],

Cell[CellGroupData[{

Cell["Numerical Implementation", "Subsubsection"],

Cell["\<\
The GaussianDerivative checks if the image and parameters allow numeric \
differentiation at one or several locations in scale space.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"GaussianDerivativeAt", "[", 
     RowBox[{
      RowBox[{"tnp", ":", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"_", "?", "NumericQ"}], ",", 
          RowBox[{"_", "?", "NumericQ"}], ",", 
          RowBox[{"_Integer", ":", "0"}]}], "}"}], ".."}]}], ",", " ", 
      "opts___Rule"}], "]"}], "[", "img_List", "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Catch", "[", 
     RowBox[{"Module", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"bounds", " ", "=", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ImageBoundary", " ", "/.", " ", 
             RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
            RowBox[{"Options", "[", "GaussianDerivativeAt", "]"}]}], ")"}]}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"kernrange", " ", "=", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"KernelRange", " ", "/.", " ", 
             RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
            RowBox[{"Options", "[", "GaussianDerivativeAt", "]"}]}], ")"}]}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"kernpbits", " ", "=", " ", 
          RowBox[{"Min", "[", 
           RowBox[{"52", ",", 
            RowBox[{"Max", "[", 
             RowBox[{"4", ",", 
              RowBox[{"4", "*", 
               RowBox[{"Ceiling", "[", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"Log", "[", 
                  RowBox[{"2", ",", 
                   RowBox[{"10", "^", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"WorkingPrecision", " ", "/.", " ", 
                    RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
                    RowBox[{"Options", "[", "GaussianDerivativeAt", "]"}]}], 
                    ")"}]}]}], "\[IndentingNewLine]", "]"}], "/", "4"}], 
                "]"}]}]}], "]"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{"tnpList", "=", 
          RowBox[{"Reverse", "[", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"PadRight", "[", 
               RowBox[{"#", ",", "3"}], "]"}], "&"}], ",", 
             RowBox[{"{", "tnp", "}"}]}], "]"}], "]"}]}], ",", 
         "\[IndentingNewLine]", "positions", ",", "intervals", ",", 
         "frameWidth", ",", "offsets", ",", "framedImage", ",", "x"}], 
        "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"positions", " ", "=", " ", 
         RowBox[{"tnpList", "\[LeftDoubleBracket]", 
          RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"intervals", "=", 
         RowBox[{"Map", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"GaussianKernelInterval", "[", 
             RowBox[{
              RowBox[{"Rest", "[", "#", "]"}], ",", "kernpbits", ",", 
              "kernrange"}], "]"}], "&"}], ",", "\[IndentingNewLine]", 
           "tnpList", ",", 
           RowBox[{"{", "1", "}"}]}], "\[IndentingNewLine]", "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"frameWidth", "=", 
         RowBox[{"Transpose", "[", 
          RowBox[{"Apply", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"1", "-", 
                RowBox[{"Map", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Min", "[", 
                    RowBox[{"1", ",", "#"}], "]"}], "&"}], ",", "#1"}], 
                 "]"}]}], ",", "\[IndentingNewLine]", 
               RowBox[{"MapThread", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"Max", "[", 
                    RowBox[{"#1", ",", "#2"}], "]"}], "-", "#2"}], ")"}], 
                  "&"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"#2", ",", 
                   RowBox[{"Take", "[", 
                    RowBox[{
                    RowBox[{"Dimensions", "[", "img", "]"}], ",", 
                    RowBox[{"Length", "[", "#2", "]"}]}], "]"}]}], "}"}]}], 
                "]"}]}], "}"}], "&"}], ",", "\[IndentingNewLine]", 
            RowBox[{"Transpose", "[", 
             RowBox[{
              RowBox[{"Round", "[", "positions", "]"}], "+", "intervals"}], 
             "]"}]}], "\[IndentingNewLine]", "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"offsets", " ", "=", " ", 
         RowBox[{"frameWidth", "\[LeftDoubleBracket]", 
          RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"framedImage", " ", "=", " ", 
         RowBox[{"ImageFrame", "[", 
          RowBox[{"img", ",", "frameWidth", ",", 
           RowBox[{"ImageBoundary", "\[Rule]", " ", "bounds"}]}], "]"}]}], 
        ";", "\[IndentingNewLine]", 
        RowBox[{"Fold", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"Dot", "[", 
            RowBox[{"#2", ",", "#1"}], "]"}], "&"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"Apply", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Take", "[", 
              RowBox[{"framedImage", ",", "##"}], "]"}], "&"}], ",", 
            RowBox[{
             RowBox[{"Round", "[", "positions", "]"}], " ", "+", " ", 
             "offsets", "+", "intervals"}]}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"MapThread", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"Table", "[", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{"NGaussianDKernel", "[", 
                 RowBox[{"Last", "[", "#1", "]"}], "]"}], "[", 
                RowBox[{
                 RowBox[{"#1", "\[LeftDoubleBracket]", 
                  RowBox[{"-", "2"}], "\[RightDoubleBracket]"}], ",", "x"}], 
                "]"}], ",", 
               RowBox[{"Evaluate", "[", 
                RowBox[{"Join", "[", 
                 RowBox[{
                  RowBox[{"{", "x", "}"}], ",", 
                  RowBox[{
                   RowBox[{"Reverse", "[", "#2", "]"}], "+", 
                   RowBox[{"First", "[", "#1", "]"}], "-", 
                   RowBox[{"Round", "[", 
                    RowBox[{"First", "[", "#1", "]"}], "]"}]}], ",", 
                  RowBox[{"{", 
                   RowBox[{"-", "1"}], "}"}]}], "]"}], "]"}]}], 
              "\[IndentingNewLine]", "]"}], "&"}], ",", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{"tnpList", ",", "intervals"}], "}"}]}], 
           "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}]}], 
      "\[IndentingNewLine]", "]"}], "]"}], "/;", 
    RowBox[{
     RowBox[{"TensorRank", "[", "img", "]"}], "\[GreaterEqual]", 
     RowBox[{"Length", "[", 
      RowBox[{"{", "tnp", "}"}], "]"}]}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"GaussianDerivativeAt", "[", 
    RowBox[{
     RowBox[{"tnps", ":", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"_", "?", "NumericQ"}], ",", 
           RowBox[{"_", "?", "NumericQ"}], ",", 
           RowBox[{"_Integer", ":", "0"}]}], "}"}], ".."}], "}"}], ".."}]}], 
     ",", " ", "opts___Rule"}], "]"}], "[", "img_List", "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Catch", "[", 
    RowBox[{"Module", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"bounds", " ", "=", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"ImageBoundary", " ", "/.", " ", 
            RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
           RowBox[{"Options", "[", "GaussianDerivativeAt", "]"}]}], ")"}]}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"kernrange", " ", "=", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"KernelRange", " ", "/.", " ", 
            RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
           RowBox[{"Options", "[", "GaussianDerivativeAt", "]"}]}], ")"}]}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"kernpbits", " ", "=", " ", 
         RowBox[{"Min", "[", 
          RowBox[{"52", ",", 
           RowBox[{"Max", "[", 
            RowBox[{"4", ",", 
             RowBox[{"4", "*", 
              RowBox[{"Ceiling", "[", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{"Log", "[", 
                 RowBox[{"2", ",", 
                  RowBox[{"10", "^", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"WorkingPrecision", " ", "/.", " ", 
                    RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
                    RowBox[{"Options", "[", "GaussianDerivativeAt", "]"}]}], 
                    ")"}]}]}], "\[IndentingNewLine]", "]"}], "/", "4"}], 
               "]"}]}]}], "]"}]}], "]"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{"tnpList", "=", 
         RowBox[{"Map", "[", 
          RowBox[{"Reverse", ",", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"PadRight", "[", 
               RowBox[{"#", ",", "3"}], "]"}], "&"}], ",", 
             RowBox[{"{", "tnps", "}"}], ",", 
             RowBox[{"{", "2", "}"}]}], "]"}]}], "]"}]}], ",", 
        "\[IndentingNewLine]", "positions", ",", "intervals", ",", 
        "frameWidth", ",", "offsets", ",", "framedImage", ",", "x"}], 
       "\[IndentingNewLine]", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"positions", " ", "=", " ", 
        RowBox[{"tnpList", "\[LeftDoubleBracket]", 
         RowBox[{"All", ",", "All", ",", "1"}], "\[RightDoubleBracket]"}]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"intervals", "=", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"GaussianKernelInterval", "[", 
            RowBox[{
             RowBox[{"Rest", "[", "#", "]"}], ",", "kernpbits", ",", 
             "kernrange"}], "]"}], "&"}], ",", "tnpList", ",", 
          RowBox[{"{", "2", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"frameWidth", "=", 
        RowBox[{
         RowBox[{
          RowBox[{"MapThread", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"1", "-", 
                RowBox[{"Min", "[", 
                 RowBox[{"1", ",", 
                  RowBox[{"First", "[", "#1", "]"}]}], "]"}]}], ",", 
               RowBox[{
                RowBox[{"Max", "[", 
                 RowBox[{
                  RowBox[{"Last", "[", "#1", "]"}], ",", "#2"}], "]"}], "-", 
                "#2"}]}], "}"}], "&"}], ",", 
            RowBox[{"{", 
             RowBox[{"#", ",", 
              RowBox[{"Take", "[", 
               RowBox[{
                RowBox[{"Dimensions", "[", "img", "]"}], ",", 
                RowBox[{"Length", "[", "#", "]"}]}], "]"}]}], "}"}]}], 
           "\[IndentingNewLine]", "]"}], "&"}], "[", 
         RowBox[{"PseudoTranspose", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Round", "[", "positions", "]"}], "+", "intervals"}], ",", 
           RowBox[{"{", 
            RowBox[{"3", ",", "1", ",", "2"}], "}"}]}], "]"}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"offsets", " ", "=", " ", 
        RowBox[{"frameWidth", "\[LeftDoubleBracket]", 
         RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"framedImage", " ", "=", " ", 
        RowBox[{"ImageFrame", "[", 
         RowBox[{"img", ",", "frameWidth", ",", 
          RowBox[{"ImageBoundary", "\[Rule]", " ", "bounds"}]}], "]"}]}], ";",
        "\[IndentingNewLine]", 
       RowBox[{"MapThread", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"Fold", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Dot", "[", 
              RowBox[{"#2", ",", "#1"}], "]"}], "&"}], ",", 
            RowBox[{"Apply", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Take", "[", 
                RowBox[{"framedImage", ",", "##"}], "]"}], "&"}], ",", "#1"}],
              "]"}], ",", "#2"}], "]"}], "&"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"Map", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"#", " ", "+", " ", "offsets"}], ")"}], "&"}], ",", 
              RowBox[{"Round", "[", "positions", "]"}]}], "]"}], "+", 
            "intervals"}], ",", "\[IndentingNewLine]", 
           RowBox[{"MapThread", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"Table", "[", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{
                 RowBox[{"NGaussianDKernel", "[", 
                  RowBox[{"Last", "[", "#1", "]"}], "]"}], "[", 
                 RowBox[{
                  RowBox[{"#1", "[", 
                   RowBox[{"[", 
                    RowBox[{"-", "2"}], "]"}], "]"}], ",", "x"}], "]"}], ",", 
                "\[IndentingNewLine]", 
                RowBox[{"Evaluate", "[", 
                 RowBox[{"Join", "[", 
                  RowBox[{
                   RowBox[{"{", "x", "}"}], ",", 
                   RowBox[{
                    RowBox[{"Reverse", "[", "#2", "]"}], "+", 
                    RowBox[{"First", "[", "#1", "]"}], "-", 
                    RowBox[{"Round", "[", 
                    RowBox[{"First", "[", "#1", "]"}], "]"}]}], ",", 
                   RowBox[{"{", 
                    RowBox[{"-", "1"}], "}"}]}], "]"}], "]"}]}], 
               "\[IndentingNewLine]", "]"}], "&"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"{", 
              RowBox[{"tnpList", ",", "intervals"}], "}"}], ",", "2"}], 
            "\[IndentingNewLine]", "]"}]}], "}"}]}], "\[IndentingNewLine]", 
        "]"}]}]}], "\[IndentingNewLine]", "]"}], "]"}], "/;", 
   RowBox[{"Apply", "[", 
    RowBox[{"And", ",", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"TensorRank", "[", "img", "]"}], "\[GreaterEqual]", 
          RowBox[{"Length", "[", "#", "]"}]}], ")"}], "&"}], ",", 
       RowBox[{"{", "tnps", "}"}]}], "]"}]}], "]"}]}]}]}], "PackageInput",
 InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Local Maximum Mask", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"LocalMaximumMask", "[", 
    RowBox[{
     RowBox[{"img_", "?", "ImageQ"}], ",", 
     RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], ":=", 
   RowBox[{"Image", "[", 
    RowBox[{
     RowBox[{"LocalMaximumMask", "[", 
      RowBox[{
       RowBox[{"ImageData", "[", "img", "]"}], ",", "opts"}], "]"}], ",", 
     "\"\<Bit\>\""}], "]"}]}], ";"}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"LocalMaximumMask", "[", 
   RowBox[{"img_", ",", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], " ", ":=", " ", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Map", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Position", "[", 
          RowBox[{"#", ",", 
           RowBox[{"Max", "[", "#", "]"}]}], "]"}], "===", 
         RowBox[{"{", 
          RowBox[{"{", "2", "}"}], "}"}]}], ",", "1", ",", "0"}], "]"}], 
      "&"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Partition", "[", 
      RowBox[{
       RowBox[{"ImageFrame", "[", 
        RowBox[{"img", ",", "1", ",", 
         RowBox[{"ImageBoundary", "->", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ImageBoundary", " ", "/.", " ", 
             RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
            RowBox[{"Options", "[", "LocalMaximumMask", "]"}]}], ")"}]}]}], 
        "]"}], ",", "3", ",", "1"}], "]"}]}], "\[IndentingNewLine]", "]"}], "/;",
    " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "1"}]}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"LocalMaximumMask", "[", 
   RowBox[{"img_", ",", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], " ", ":=", " ", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Map", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Position", "[", 
          RowBox[{"#", ",", 
           RowBox[{"Max", "[", "#", "]"}]}], "]"}], "===", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"2", ",", "2"}], "}"}], "}"}]}], ",", "1", ",", "0"}], 
       "]"}], "&"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Partition", "[", 
      RowBox[{
       RowBox[{"ImageFrame", "[", 
        RowBox[{"img", ",", "1", ",", 
         RowBox[{"ImageBoundary", "->", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ImageBoundary", " ", "/.", " ", 
             RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
            RowBox[{"Options", "[", "LocalMaximumMask", "]"}]}], ")"}]}]}], 
        "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", "2", "}"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "2"}]}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"LocalMaximumMask", "[", 
   RowBox[{"img_", ",", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], " ", ":=", " ", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Map", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Position", "[", 
          RowBox[{"#", ",", 
           RowBox[{"Max", "[", "#", "]"}]}], "]"}], "===", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"2", ",", "2", ",", "2"}], "}"}], "}"}]}], ",", "1", ",", 
        "0"}], "]"}], "&"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Partition", "[", 
      RowBox[{
       RowBox[{"ImageFrame", "[", 
        RowBox[{"img", ",", "1", ",", 
         RowBox[{"ImageBoundary", "->", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ImageBoundary", " ", "/.", " ", 
             RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
            RowBox[{"Options", "[", "LocalMaximumMask", "]"}]}], ")"}]}]}], 
        "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", "3", "}"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"LocalMaximumMask", "[", 
   RowBox[{"img_", ",", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], " ", ":=", " ", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"n", "=", 
        RowBox[{"ArrayDepth", "[", "img", "]"}]}], ",", "p"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"p", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{"Table", "[", 
         RowBox[{"2", ",", 
          RowBox[{"{", "n", "}"}]}], "]"}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Map", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Position", "[", 
             RowBox[{"#", ",", 
              RowBox[{"Max", "[", "#", "]"}]}], "]"}], "===", "p"}], ",", "1",
            ",", "0"}], "]"}], "&"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Partition", "[", 
         RowBox[{
          RowBox[{"ImageFrame", "[", 
           RowBox[{"img", ",", "1", ",", 
            RowBox[{"ImageBoundary", "->", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"ImageBoundary", " ", "/.", " ", 
                RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
               RowBox[{"Options", "[", "LocalMaximumMask", "]"}]}], ")"}]}]}],
            "]"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", "n", "}"}]}], "]"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{"1", ",", 
            RowBox[{"{", "n", "}"}]}], "]"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", "n", "}"}]}], "\[IndentingNewLine]", "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], ">", "3"}]}]}]], "PackageInput"]
}, Closed]],

Cell[CellGroupData[{

Cell["Local Minimum Mask", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"LocalMinimumMask", "[", 
    RowBox[{
     RowBox[{"img_", "?", "ImageQ"}], ",", 
     RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], ":=", 
   RowBox[{"Image", "[", 
    RowBox[{
     RowBox[{"LocalMinimumMask", "[", 
      RowBox[{
       RowBox[{"ImageData", "[", "img", "]"}], ",", "opts"}], "]"}], ",", 
     "\"\<Bit\>\""}], "]"}]}], ";"}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"LocalMinimumMask", "[", 
   RowBox[{"img_", ",", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], " ", ":=", " ", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Map", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Position", "[", 
          RowBox[{"#", ",", 
           RowBox[{"Min", "[", "#", "]"}]}], "]"}], "===", 
         RowBox[{"{", 
          RowBox[{"{", "2", "}"}], "}"}]}], ",", "1", ",", "0"}], "]"}], 
      "&"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Partition", "[", 
      RowBox[{
       RowBox[{"ImageFrame", "[", 
        RowBox[{"img", ",", "1", ",", 
         RowBox[{"ImageBoundary", "->", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ImageBoundary", " ", "/.", " ", 
             RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
            RowBox[{"Options", "[", "LocalMinimumMask", "]"}]}], ")"}]}]}], 
        "]"}], ",", "3", ",", "1"}], "]"}]}], "\[IndentingNewLine]", "]"}], "/;",
    " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "1"}]}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"LocalMinimumMask", "[", 
   RowBox[{"img_", ",", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], " ", ":=", " ", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Map", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Position", "[", 
          RowBox[{"#", ",", 
           RowBox[{"Min", "[", "#", "]"}]}], "]"}], "===", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"2", ",", "2"}], "}"}], "}"}]}], ",", "1", ",", "0"}], 
       "]"}], "&"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Partition", "[", 
      RowBox[{
       RowBox[{"ImageFrame", "[", 
        RowBox[{"img", ",", "1", ",", 
         RowBox[{"ImageBoundary", "->", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ImageBoundary", " ", "/.", " ", 
             RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
            RowBox[{"Options", "[", "LocalMinimumMask", "]"}]}], ")"}]}]}], 
        "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", "2", "}"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "2"}]}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"LocalMinimumMask", "[", 
   RowBox[{"img_", ",", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], " ", ":=", " ", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Map", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Position", "[", 
          RowBox[{"#", ",", 
           RowBox[{"Min", "[", "#", "]"}]}], "]"}], "===", 
         RowBox[{"{", 
          RowBox[{"{", 
           RowBox[{"2", ",", "2", ",", "2"}], "}"}], "}"}]}], ",", "1", ",", 
        "0"}], "]"}], "&"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Partition", "[", 
      RowBox[{
       RowBox[{"ImageFrame", "[", 
        RowBox[{"img", ",", "1", ",", 
         RowBox[{"ImageBoundary", "->", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"ImageBoundary", " ", "/.", " ", 
             RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
            RowBox[{"Options", "[", "LocalMinimumMask", "]"}]}], ")"}]}]}], 
        "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", "3", "}"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"LocalMinimumMask", "[", 
   RowBox[{"img_", ",", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], " ", ":=", " ", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"n", "=", 
        RowBox[{"ArrayDepth", "[", "img", "]"}]}], ",", "p"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"p", " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{"Table", "[", 
         RowBox[{"2", ",", 
          RowBox[{"{", "n", "}"}]}], "]"}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Map", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Position", "[", 
             RowBox[{"#", ",", 
              RowBox[{"Min", "[", "#", "]"}]}], "]"}], "===", "p"}], ",", "1",
            ",", "0"}], "]"}], "&"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Partition", "[", 
         RowBox[{
          RowBox[{"ImageFrame", "[", 
           RowBox[{"img", ",", "1", ",", 
            RowBox[{"ImageBoundary", "->", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"ImageBoundary", " ", "/.", " ", 
                RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
               RowBox[{"Options", "[", "LocalMinimumMask", "]"}]}], ")"}]}]}],
            "]"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{"3", ",", 
            RowBox[{"{", "n", "}"}]}], "]"}], ",", 
          RowBox[{"Table", "[", 
           RowBox[{"1", ",", 
            RowBox[{"{", "n", "}"}]}], "]"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"{", "n", "}"}]}], "\[IndentingNewLine]", "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], ">", "3"}]}]}]], "PackageInput"]
}, Closed]],

Cell[CellGroupData[{

Cell["ThresholdFilter", "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ThresholdFilter", "[", 
    RowBox[{"img_", "?", "ImageQ"}], "]"}], ":=", 
   RowBox[{"Image", "[", 
    RowBox[{
     RowBox[{"ThresholdFilter", "[", 
      RowBox[{"ImageData", "[", "img", "]"}], "]"}], ",", 
     RowBox[{"Sequence", "@@", 
      RowBox[{"Options", "[", "img", "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ThresholdFilter", "[", "c_", "]"}], "[", 
   RowBox[{"img_", "?", "ImageQ"}], "]"}], ":=", 
  RowBox[{"Image", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ThresholdFilter", "[", "c", "]"}], "[", 
     RowBox[{"ImageData", "[", "img", "]"}], "]"}], ",", 
    RowBox[{"Sequence", "@@", 
     RowBox[{"Options", "[", "img", "]"}]}]}], "]"}]}]}], "PackageInput"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ThresholdFilter", "[", "img_List", "]"}], "=", " ", 
   RowBox[{"img", " ", 
    RowBox[{"UnitStep", "[", "img", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ThresholdFilter", "[", "c_", "]"}], "[", "img_List", "]"}], ":=",
    " ", 
   RowBox[{"img", " ", 
    RowBox[{"UnitStep", "[", 
     RowBox[{"img", "-", "c"}], "]"}]}]}], ";"}]}], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Utility Functions", "Subsection"],

Cell["\<\
A utility function to speed up outer multiplications by a factor 15 compared \
to Outer[].\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"FastOuterTimes", "[", 
    RowBox[{"x_List", ",", "y__List"}], "]"}], " ", ":=", " ", 
   RowBox[{"Fold", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"With", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"v", "=", "#2"}], "}"}], ",", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Times", "[", 
            RowBox[{"#", ",", "v"}], "]"}], "&"}], ",", "#1", ",", 
          RowBox[{"{", 
           RowBox[{"TensorRank", "[", "#1", "]"}], "}"}]}], "]"}]}], "]"}], 
      "&"}], ",", "x", ",", 
     RowBox[{"{", "y", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FastOuterTimes", "[", "x_List", "]"}], " ", "=", " ", "x"}], 
  ";"}]}], "PackageInput"],

Cell["\<\
A transpose function that can handle matrices with varying row length.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"PseudoTranspose", "[", 
    RowBox[{"expr", ":", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "__", "}"}], ".."}], "}"}]}], "]"}], " ", ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"DeleteCases", "[", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"PadRight", "[", 
       RowBox[{"expr", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Length", "[", "expr", "]"}], ",", 
          RowBox[{"Max", "[", 
           RowBox[{"Map", "[", 
            RowBox[{"Length", ",", "expr"}], "]"}], "]"}]}], "}"}], ",", 
        "Null"}], "]"}], "]"}], ",", "Null", ",", 
     RowBox[{"{", "2", "}"}]}], "]"}]}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PseudoTranspose", "[", 
   RowBox[{
    RowBox[{"expr", ":", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "__", "}"}], ".."}], "}"}]}], ",", "perm_List"}], "]"}], 
  " ", ":=", "\[IndentingNewLine]", 
  RowBox[{"With", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"dim", "=", 
      RowBox[{"Drop", "[", 
       RowBox[{
        RowBox[{"NestWhileList", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Max", "[", 
            RowBox[{"Map", "[", 
             RowBox[{"Length", ",", "expr", ",", 
              RowBox[{"{", 
               RowBox[{"i", "++"}], "}"}]}], "]"}], "]"}], "&"}], ",", 
          RowBox[{
           RowBox[{"i", "=", "1"}], ";", 
           RowBox[{"Length", "[", "expr", "]"}]}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"#", ">", "0"}], ")"}], "&"}]}], "]"}], ",", 
        RowBox[{"-", "1"}]}], "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Length", "[", "perm", "]"}], ">", 
        RowBox[{"Length", "[", "dim", "]"}]}], ",", " ", 
       RowBox[{
        RowBox[{"Message", "[", 
         RowBox[{
          RowBox[{"Transpose", "::", "tperm"}], ",", "perm"}], "]"}], ";", 
        RowBox[{"Return", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"DeleteCases", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{
         RowBox[{"PadRight", "[", 
          RowBox[{"expr", ",", "dim", ",", "Null"}], "]"}], ",", "perm"}], 
        "]"}], ",", 
       RowBox[{"Null", "|", 
        RowBox[{"{", 
         RowBox[{"Null", ".."}], "}"}]}], ",", 
       RowBox[{"Length", "[", "perm", "]"}]}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]}], "PackageInput"],

Cell["\<\
Attaching a frame of specified value and thickness around an image.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"AttachFrame1D", "[", 
   RowBox[{"data_List", ",", 
    RowBox[{"{", 
     RowBox[{"widthleft_Integer", ",", "widthright_Integer"}], "}"}]}], "]"}],
   " ", ":=", "\[IndentingNewLine]", 
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"widthleft", "==", "widthright"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{"#", ",", "data", ",", "#"}], "]"}], "&"}], "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", 
         RowBox[{"{", "widthleft", "}"}], ",", "##"}], "]"}], "&"}], "@@", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"Dimensions", "[", 
         RowBox[{"First", "[", "data", "]"}], "]"}], "}"}], "]"}]}], "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "widthleft", "}"}], ",", "##"}], "]"}], ",", "data", 
        ",", 
        RowBox[{"Table", "[", 
         RowBox[{"0", ",", 
          RowBox[{"{", "widthright", "}"}], ",", "##"}], "]"}]}], "]"}], 
      "&"}], "@@", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"Dimensions", "[", 
        RowBox[{"First", "[", "data", "]"}], "]"}], "}"}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "PackageInput"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Closing Package", "Section"],

Cell["Closing the package and locking all the symbols.", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"End", "[", "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetAttributes", "[", 
   RowBox[{
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
     "G", ",", "\[IndentingNewLine]", "NGaussianKernel", ",", 
      "\[IndentingNewLine]", "GaussianKernel", ",", "\[IndentingNewLine]", 
      "AngularGaussianKernel", ",", "\[IndentingNewLine]", "NGaussianDKernel",
       ",", "\[IndentingNewLine]", "GaussianDKernel", ",", 
      "\[IndentingNewLine]", "GaussianD", ",", "\[IndentingNewLine]", 
      "GaussianBlur", ",", "\[IndentingNewLine]", "GaussianDerivative", ",", 
      "\[IndentingNewLine]", "GaussianDerivativeJet", ",", 
      "\[IndentingNewLine]", "GaussianDerivativeAt", ",", 
      "\[IndentingNewLine]", "LocalMinimumMask", ",", "\[IndentingNewLine]", 
      "LocalMaximumMask", ",", "\[IndentingNewLine]", "ThresholdFilter", ",", 
      "\[IndentingNewLine]", "ScaleTToSigma", ",", "\[IndentingNewLine]", 
      "SigmaToScaleT", ",", "\[IndentingNewLine]", "Method", ",", 
      "\[IndentingNewLine]", "KernelRange", ",", "\[IndentingNewLine]", 
      "ImageBoundary", ",", "\[IndentingNewLine]", "Convolve", ",", 
      "\[IndentingNewLine]", "Fourier", ",", "\[IndentingNewLine]", "Cyclic", 
      ",", "\[IndentingNewLine]", "Truncate", ",", "\[IndentingNewLine]", 
      "Reflective"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"Protected", ",", " ", "ReadProtected"}], "}"}]}], 
   "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{"EndPackage", "[", "]"}]}], "PackageInput",
 InitializationCell->True]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowSize->{1015, 752},
WindowMargins->{{57, Automatic}, {Automatic, 0}},
Visible->True,
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
ShowSelection->True,
InputAliases->{"intt" -> RowBox[{"\[Integral]", 
     RowBox[{"\[SelectionPlaceholder]", 
       RowBox[{"\[DifferentialD]", "\[Placeholder]"}]}]}], "dintt" -> 
  RowBox[{
     SubsuperscriptBox[
     "\[Integral]", "\[SelectionPlaceholder]", "\[Placeholder]"], 
     RowBox[{"\[Placeholder]", 
       RowBox[{"\[DifferentialD]", "\[Placeholder]"}]}]}], "sumt" -> RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
      "\[Placeholder]"], "\[Placeholder]"}], "prodt" -> RowBox[{
     UnderoverscriptBox["\[Product]", 
      RowBox[{"\[SelectionPlaceholder]", "=", "\[Placeholder]"}], 
      "\[Placeholder]"], "\[Placeholder]"}], "dt" -> RowBox[{
     SubscriptBox["\[PartialD]", "\[Placeholder]"], " ", 
     "\[SelectionPlaceholder]"}], "notation" -> RowBox[{"Notation", "[", 
     RowBox[{
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> "NotationTemplateStyle"],
        " ", "\[DoubleLongLeftRightArrow]", " ", 
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> 
        "NotationTemplateStyle"]}], "]"}], "notation>" -> 
  RowBox[{"Notation", "[", 
     RowBox[{
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> "NotationTemplateStyle"],
        " ", "\[DoubleLongRightArrow]", " ", 
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> 
        "NotationTemplateStyle"]}], "]"}], "notation<" -> 
  RowBox[{"Notation", "[", 
     RowBox[{
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> "NotationTemplateStyle"],
        " ", "\[DoubleLongLeftArrow]", " ", 
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> 
        "NotationTemplateStyle"]}], "]"}], "symb" -> RowBox[{"Symbolize", "[", 
     TagBox[
     "\[Placeholder]", NotationBoxTag, TagStyle -> "NotationTemplateStyle"], 
     "]"}], "infixnotation" -> RowBox[{"InfixNotation", "[", 
     RowBox[{
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> "NotationTemplateStyle"],
        ",", "\[Placeholder]"}], "]"}], "addia" -> 
  RowBox[{"AddInputAlias", "[", 
     RowBox[{"\"\[Placeholder]\"", "\[Rule]", 
       TagBox[
       "\[Placeholder]", NotationBoxTag, TagStyle -> 
        "NotationTemplateStyle"]}], "]"}], "pattwraper" -> 
  TagBox["\[Placeholder]", NotationPatternTag, TagStyle -> 
    "NotationPatternWrapperStyle"], "madeboxeswraper" -> 
  TagBox["\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
    "NotationMadeBoxesWrapperStyle"]},
TrackCellChangeTimes->False,
Magnification->1.5,
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (November 7, \
2010)",
StyleDefinitions->"PackageNotebook.nb",
PrivateNotebookOptions -> {"NotebookAuthor" -> ""}
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 44, 0, 144, "Title"],
Cell[614, 24, 100, 4, 118, "Subsubtitle"],
Cell[717, 30, 27, 0, 39, "Text"],
Cell[CellGroupData[{
Cell[769, 34, 25, 0, 72, "Section"],
Cell[797, 36, 934, 24, 291, "PackageInput"],
Cell[1734, 62, 128, 3, 39, "Text"],
Cell[1865, 67, 7699, 176, 1441, "PackageInput",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[9601, 248, 32, 0, 72, "Section"],
Cell[9636, 250, 92, 2, 39, "Text"],
Cell[9731, 254, 1188, 26, 359, "Input"],
Cell[10922, 282, 339, 6, 153, "PackageInput"],
Cell[11264, 290, 1260, 20, 636, "PackageInput",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[12561, 315, 42, 0, 72, "Section"],
Cell[12606, 317, 19142, 423, 5926, "PackageInput",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[31785, 745, 31, 0, 72, "Section"],
Cell[31819, 747, 60, 0, 39, "Text"],
Cell[31882, 749, 108, 2, 60, "PackageInput",
 InitializationCell->True],
Cell[31993, 753, 97, 2, 39, "Text"],
Cell[32093, 757, 1335, 34, 291, "PackageInput"],
Cell[CellGroupData[{
Cell[33453, 795, 37, 0, 63, "Subsection"],
Cell[33493, 797, 497, 16, 43921, "Text"],
Cell[33993, 815, 722, 20, 66642, "PackageInput",
 InitializationCell->True],
Cell[34718, 837, 26, 0, 15585, "Input"],
Cell[34747, 839, 164, 4, 29890, "PackageInput"],
Cell[34914, 845, 180, 4, 28747, "PackageInput"],
Cell[CellGroupData[{
Cell[35119, 853, 47, 0, 24603, "Subsubsection"],
Cell[35169, 855, 118, 3, 16816, "Text"],
Cell[35290, 860, 2132, 62, 139077, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[37459, 927, 48, 0, 14761, "Subsubsection"],
Cell[37510, 929, 1425, 43, 108663, "PackageInput",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[38972, 977, 56, 0, 24603, "Subsubsection"],
Cell[39031, 979, 1194, 34, 98113, "PackageInput",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[40262, 1018, 54, 0, 24603, "Subsubsection"],
Cell[40319, 1020, 301, 9, 16402, "Input"],
Cell[40623, 1031, 1576, 42, 107941, "PackageInput",
 InitializationCell->True],
Cell[42202, 1075, 273, 8, 16402, "Input"],
Cell[42478, 1085, 1300, 37, 77820, "PackageInput",
 InitializationCell->True],
Cell[43781, 1124, 355, 11, 19165, "Input"],
Cell[44139, 1137, 1789, 49, 128002, "PackageInput"],
Cell[45931, 1188, 326, 10, 19165, "Input"],
Cell[46260, 1200, 1474, 41, 77820, "PackageInput"],
Cell[47737, 1243, 384, 12, 19165, "Input"],
Cell[48124, 1257, 2092, 56, 128002, "PackageInput"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[50265, 1319, 45, 0, 37, "Subsection"],
Cell[CellGroupData[{
Cell[50335, 1323, 48, 0, 2160, "Subsubsection"],
Cell[50386, 1325, 887, 26, 8061, "PackageInput",
 InitializationCell->True]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[51322, 1357, 48, 0, 37, "Subsection"],
Cell[51373, 1359, 152, 4, 2296, "PackageInput",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[51550, 1367, 47, 0, 2160, "Subsubsection"],
Cell[51600, 1369, 456, 15, 3552, "Text"],
Cell[52059, 1386, 312, 7, 4923, "Input"],
Cell[52374, 1395, 471, 21, 2322, "Text"],
Cell[52848, 1418, 1291, 40, 4515, "Input"],
Cell[54142, 1460, 1379, 44, 4860, "Input"],
Cell[CellGroupData[{
Cell[55546, 1508, 111, 3, 1369, "Input"],
Cell[55660, 1513, 55, 0, 1369, "Output"]
}, Open  ]],
Cell[55730, 1516, 177, 6, 1477, "Text"],
Cell[55910, 1524, 21035, 622, 60831, "PackageInput",
 InitializationCell->True],
Cell[76948, 2148, 126, 3, 1477, "Text"],
Cell[77077, 2153, 1646, 48, 11389, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[78760, 2206, 48, 0, 1296, "Subsubsection"],
Cell[78811, 2208, 257, 5, 26973, "Text"],
Cell[79071, 2215, 3343, 97, 179362, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[82451, 2317, 56, 0, 1296, "Subsubsection"],
Cell[82510, 2319, 5025, 135, 372957, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[87572, 2459, 55, 0, 1296, "Subsubsection"],
Cell[87630, 2461, 385, 11, 16402, "Input"],
Cell[88018, 2474, 1722, 45, 107941, "PackageInput",
 InitializationCell->True],
Cell[89743, 2521, 413, 12, 19381, "Input"],
Cell[90159, 2535, 1758, 46, 107941, "PackageInput"],
Cell[91920, 2583, 401, 12, 16402, "Input"],
Cell[92324, 2597, 1585, 41, 87661, "PackageInput"],
Cell[93912, 2640, 421, 12, 19381, "Input"],
Cell[94336, 2654, 1776, 46, 107941, "PackageInput"],
Cell[96115, 2702, 453, 15, 19165, "Input"],
Cell[96571, 2719, 2092, 54, 108501, "PackageInput"],
Cell[98666, 2775, 474, 15, 22618, "Input"],
Cell[99143, 2792, 2272, 59, 128488, "PackageInput"],
Cell[101418, 2853, 513, 17, 19165, "Input"],
Cell[101934, 2872, 2679, 70, 168853, "PackageInput"],
Cell[104616, 2944, 533, 17, 22618, "Input"],
Cell[105152, 2963, 2893, 71, 158788, "PackageInput"],
Cell[108048, 3036, 563, 18, 22618, "Input"],
Cell[108614, 3056, 3219, 79, 168853, "PackageInput"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[111882, 3141, 34, 0, 37, "Subsection"],
Cell[111919, 3143, 484, 14, 1822, "PackageInput"],
Cell[112406, 3159, 189, 6, 1066, "PackageInput"],
Cell[112598, 3167, 515, 16, 1440, "PackageInput"],
Cell[113116, 3185, 636, 19, 1842, "PackageInput"]
}, Closed]],
Cell[CellGroupData[{
Cell[113789, 3209, 31, 0, 37, "Subsection"],
Cell[CellGroupData[{
Cell[113845, 3213, 50, 0, 3240, "Subsubsection"],
Cell[113898, 3215, 190, 5, 3444, "PackageInput",
 InitializationCell->True],
Cell[114091, 3222, 77, 1, 2215, "Text"],
Cell[114171, 3225, 155, 3, 2215, "Text"],
Cell[114329, 3230, 486, 14, 4923, "PackageInput"],
Cell[114818, 3246, 171, 3, 3552, "Text"],
Cell[114992, 3251, 399, 12, 3444, "PackageInput"],
Cell[115394, 3265, 178, 3, 3552, "Text"],
Cell[115575, 3270, 255, 6, 6148, "PackageInput"],
Cell[115833, 3278, 531, 16, 4923, "PackageInput"],
Cell[116367, 3296, 70, 1, 2215, "Text"],
Cell[116440, 3299, 188, 4, 3552, "Text"],
Cell[116631, 3305, 870, 27, 6318, "PackageInput"],
Cell[117504, 3334, 70, 1, 2215, "Text"],
Cell[117577, 3337, 94, 2, 2215, "Text"],
Cell[117674, 3341, 551, 16, 6318, "PackageInput",
 InitializationCell->True],
Cell[118228, 3359, 27, 0, 2215, "Text"],
Cell[118258, 3361, 746, 24, 6246, "PackageInput",
 InitializationCell->True],
Cell[119007, 3387, 34, 0, 2215, "Text"],
Cell[119044, 3389, 474, 14, 4860, "PackageInput",
 InitializationCell->True],
Cell[119521, 3405, 156, 3, 3552, "Text"],
Cell[119680, 3410, 1002, 30, 7627, "PackageInput",
 InitializationCell->True],
Cell[120685, 3442, 31, 0, 2215, "Text"],
Cell[120719, 3444, 436, 12, 4860, "PackageInput",
 InitializationCell->True],
Cell[121158, 3458, 71, 0, 2215, "Text"],
Cell[121232, 3460, 2428, 70, 19165, "PackageInput"],
Cell[123663, 3532, 71, 1, 2215, "Text"],
Cell[123737, 3535, 161, 3, 3552, "Text"],
Cell[123901, 3540, 291, 7, 4828, "Text"],
Cell[124195, 3549, 2999, 90, 11895, "PackageInput"],
Cell[127197, 3641, 6100, 174, 15216, "PackageInput"],
Cell[133300, 3817, 40, 0, 2215, "Text"],
Cell[133343, 3819, 995, 32, 7930, "PackageInput"],
Cell[134341, 3853, 4390, 128, 13123, "PackageInput"],
Cell[138734, 3983, 38, 0, 2215, "Text"],
Cell[138775, 3985, 1313, 41, 9598, "PackageInput"],
Cell[140091, 4028, 775, 25, 8547, "PackageInput"],
Cell[140869, 4055, 86, 2, 2215, "Text"],
Cell[140958, 4059, 372, 10, 4860, "PackageInput"],
Cell[141333, 4071, 1153, 38, 11319, "PackageInput"],
Cell[142489, 4111, 777, 25, 7836, "PackageInput"],
Cell[143269, 4138, 681, 22, 7593, "PackageInput"],
Cell[143953, 4162, 32, 0, 2215, "Text"],
Cell[143988, 4164, 1620, 50, 10935, "PackageInput"],
Cell[145611, 4216, 1615, 50, 10935, "PackageInput"],
Cell[147229, 4268, 1659, 50, 10935, "PackageInput"],
Cell[148891, 4320, 74, 1, 2215, "Text"],
Cell[148968, 4323, 54, 0, 2215, "Text"],
Cell[149025, 4325, 1548, 42, 16978, "PackageInput",
 InitializationCell->True],
Cell[150576, 4369, 47, 0, 2215, "Text"],
Cell[150626, 4371, 542, 17, 4923, "PackageInput",
 InitializationCell->True],
Cell[151171, 4390, 65, 0, 2215, "Text"],
Cell[151239, 4392, 1878, 49, 17059, "PackageInput"],
Cell[153120, 4443, 209, 4, 3552, "Text"],
Cell[153332, 4449, 5562, 139, 45990, "PackageInput",
 InitializationCell->True],
Cell[158897, 4590, 50, 0, 2215, "Text"],
Cell[158950, 4592, 1201, 36, 8911, "PackageInput",
 InitializationCell->True],
Cell[160154, 4630, 1222, 35, 8979, "PackageInput",
 InitializationCell->True],
Cell[161379, 4667, 52, 0, 2215, "Text"],
Cell[161434, 4669, 1480, 45, 10296, "PackageInput",
 InitializationCell->True],
Cell[162917, 4716, 1503, 44, 10360, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[164457, 4765, 49, 0, 1944, "Subsubsection"],
Cell[164509, 4767, 478, 15, 22855, "Input"],
Cell[164990, 4784, 2693, 69, 198580, "PackageInput"],
Cell[167686, 4855, 518, 16, 22855, "Input"],
Cell[168207, 4873, 2827, 75, 158788, "PackageInput"],
Cell[171037, 4950, 701, 21, 35065, "Input"],
Cell[171741, 4973, 4486, 114, 344391, "PackageInput"],
Cell[176230, 5089, 666, 20, 35065, "Input"],
Cell[176899, 5111, 4085, 105, 314172, "PackageInput"],
Cell[180987, 5218, 820, 23, 35065, "Input"],
Cell[181810, 5243, 5551, 139, 405648, "PackageInput"],
Cell[187364, 5384, 772, 22, 35065, "Input"],
Cell[188139, 5408, 4956, 126, 359689, "PackageInput"],
Cell[193098, 5536, 939, 25, 61447, "Input"],
Cell[194040, 5563, 6564, 160, 466033, "PackageInput"],
Cell[200607, 5725, 878, 24, 61447, "Input"],
Cell[201488, 5751, 5780, 143, 420358, "PackageInput"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[207317, 5900, 40, 0, 37, "Subsection"],
Cell[CellGroupData[{
Cell[207382, 5904, 47, 0, 127, "Subsubsection"],
Cell[207432, 5906, 235, 5, 2368, "Text"],
Cell[207670, 5913, 346, 10, 2322, "Input",
 Evaluatable->False],
Cell[208019, 5925, 70, 0, 1477, "Text"],
Cell[208092, 5927, 472, 15, 2524, "Input",
 Evaluatable->False],
Cell[208567, 5944, 611, 24, 2601, "Text"],
Cell[209181, 5970, 512, 16, 2524, "Input"],
Cell[209696, 5988, 69, 0, 1477, "Text"],
Cell[CellGroupData[{
Cell[209790, 5992, 333, 10, 1683, "Input"],
Cell[210126, 6004, 290, 10, 1702, "Output"]
}, Open  ]],
Cell[210431, 6017, 176, 6, 1639, "Text"],
Cell[210610, 6025, 1029, 30, 3687, "Input"],
Cell[211642, 6057, 72, 0, 1477, "Text"],
Cell[211717, 6059, 555, 17, 3856, "Input"],
Cell[212275, 6078, 127, 4, 1477, "Text"],
Cell[212405, 6084, 732, 24, 4402, "Input",
 Evaluatable->False],
Cell[213140, 6110, 107, 4, 1477, "Text"],
Cell[213250, 6116, 972, 30, 6772, "PackageInput"],
Cell[214225, 6148, 972, 30, 6772, "PackageInput"],
Cell[215200, 6180, 972, 30, 5905, "PackageInput"],
Cell[216175, 6212, 971, 30, 5905, "PackageInput"],
Cell[217149, 6244, 971, 30, 5905, "PackageInput"],
Cell[218123, 6276, 973, 30, 6772, "PackageInput"],
Cell[219099, 6308, 973, 30, 6772, "PackageInput"],
Cell[220075, 6340, 971, 30, 5905, "PackageInput"],
Cell[221049, 6372, 973, 30, 6772, "PackageInput"],
Cell[222025, 6404, 973, 30, 6772, "PackageInput"],
Cell[223001, 6436, 973, 30, 6772, "PackageInput"],
Cell[223977, 6468, 972, 30, 5905, "PackageInput"],
Cell[224952, 6500, 973, 30, 6772, "PackageInput"],
Cell[225928, 6532, 126, 3, 1477, "Text"],
Cell[226057, 6537, 684, 21, 3694, "Input",
 Evaluatable->False],
Cell[226744, 6560, 339, 9, 4099, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[227120, 6574, 48, 0, 76, "Subsubsection"],
Cell[227171, 6576, 179, 4, 16816, "Text"],
Cell[227353, 6582, 114, 3, 16816, "Text"],
Cell[227470, 6587, 367, 13, 34965, "Input",
 Evaluatable->False],
Cell[227840, 6602, 513, 8, 36661, "Text"],
Cell[228356, 6612, 1395, 43, 35065, "Input"],
Cell[229754, 6657, 414, 15, 18207, "Text"],
Cell[230171, 6674, 949, 29, 32197, "Input"],
Cell[231123, 6705, 107, 3, 16816, "Text"],
Cell[231233, 6710, 391, 13, 19381, "Input"],
Cell[231627, 6725, 616, 18, 43120, "PackageInput"],
Cell[232246, 6745, 612, 17, 43120, "PackageInput"],
Cell[232861, 6764, 607, 17, 43120, "PackageInput"],
Cell[233471, 6783, 607, 17, 43120, "PackageInput"],
Cell[234081, 6802, 607, 17, 43120, "PackageInput"],
Cell[234691, 6821, 606, 17, 43120, "PackageInput"],
Cell[235300, 6840, 606, 17, 43120, "PackageInput"],
Cell[235909, 6859, 605, 17, 43120, "PackageInput"],
Cell[236517, 6878, 604, 17, 43120, "PackageInput"],
Cell[237124, 6897, 606, 17, 43120, "PackageInput"],
Cell[237733, 6916, 605, 17, 43120, "PackageInput"],
Cell[238341, 6935, 605, 17, 43120, "PackageInput"],
Cell[238949, 6954, 605, 17, 43120, "PackageInput"],
Cell[239557, 6973, 184, 5, 26151, "PackageInput"],
Cell[239744, 6980, 137, 3, 16816, "Text"],
Cell[239884, 6985, 472, 16, 24441, "Input",
 Evaluatable->False,
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[240393, 7006, 50, 0, 76, "Subsubsection"],
Cell[240446, 7008, 331, 11, 3552, "PackageInput",
 InitializationCell->True],
Cell[240780, 7021, 498, 16, 4860, "PackageInput",
 InitializationCell->True],
Cell[241281, 7039, 346, 12, 3552, "PackageInput",
 InitializationCell->True],
Cell[241630, 7053, 515, 16, 4923, "PackageInput",
 InitializationCell->True],
Cell[242148, 7071, 39, 0, 2215, "Text"],
Cell[242190, 7073, 2434, 67, 12912, "PackageInput"],
Cell[244627, 7142, 25, 0, 2215, "Text"],
Cell[244655, 7144, 3466, 93, 22051, "Input",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[248158, 7242, 49, 0, 76, "Subsubsection"],
Cell[248210, 7244, 150, 3, 87, "Text"],
Cell[248363, 7249, 753, 23, 297, "PackageInput"],
Cell[249119, 7274, 1832, 50, 607, "PackageInput",
 InitializationCell->True],
Cell[250954, 7326, 796, 23, 298, "PackageInput"],
Cell[251753, 7351, 1667, 44, 559, "PackageInput",
 InitializationCell->True],
Cell[253423, 7397, 35, 0, 87, "Text"],
Cell[253461, 7399, 208, 6, 135, "PackageInput",
 InitializationCell->True],
Cell[253672, 7407, 4461, 122, 1084, "PackageInput",
 InitializationCell->True],
Cell[258136, 7531, 10747, 268, 3412, "PackageInput",
 InitializationCell->True],
Cell[268886, 7801, 10899, 271, 3514, "PackageInput",
 InitializationCell->True],
Cell[279788, 8074, 30, 0, 87, "Text"],
Cell[279821, 8076, 748, 20, 253, "Text"],
Cell[280572, 8098, 7186, 188, 2317, "PackageInput",
 InitializationCell->True],
Cell[287761, 8288, 7879, 206, 2610, "PackageInput"]
}, Closed]],
Cell[CellGroupData[{
Cell[295677, 8499, 58, 0, 76, "Subsubsection"],
Cell[295738, 8501, 413, 13, 4711, "Input"],
Cell[296154, 8516, 1794, 48, 27310, "PackageInput"],
Cell[297951, 8566, 461, 14, 4711, "Input"],
Cell[298415, 8582, 1697, 46, 25285, "PackageInput"],
Cell[300115, 8630, 469, 14, 4711, "Input"],
Cell[300587, 8646, 1714, 46, 98050, "PackageInput"],
Cell[302304, 8694, 452, 14, 22855, "Input"],
Cell[302759, 8710, 1912, 52, 107941, "PackageInput"],
Cell[304674, 8764, 536, 17, 23847, "Input"],
Cell[305213, 8783, 2478, 66, 118005, "PackageInput"],
Cell[307694, 8851, 609, 19, 22855, "Input"],
Cell[308306, 8872, 3170, 85, 138538, "PackageInput"],
Cell[311479, 8959, 503, 16, 23847, "Input"],
Cell[311985, 8977, 2133, 58, 97350, "Input"],
Cell[314121, 9037, 576, 18, 22855, "Input"],
Cell[314700, 9057, 2823, 75, 128488, "PackageInput"],
Cell[317526, 9134, 619, 19, 23847, "Input"],
Cell[318148, 9155, 3072, 80, 158328, "PackageInput"],
Cell[321223, 9237, 706, 21, 34282, "Input"],
Cell[321932, 9260, 3913, 101, 283702, "PackageInput"],
Cell[325848, 9363, 573, 18, 35770, "Input"],
Cell[326424, 9383, 2560, 68, 161218, "Input"],
Cell[328987, 9453, 660, 20, 34282, "Input"],
Cell[329650, 9475, 3404, 88, 238182, "PackageInput"],
Cell[333057, 9565, 702, 21, 35770, "Input"],
Cell[333762, 9588, 3786, 93, 252253, "PackageInput"],
Cell[337551, 9683, 803, 23, 11440, "Input"],
Cell[338357, 9708, 4814, 117, 47367, "PackageInput"],
Cell[343174, 9827, 643, 20, 4711, "Input"],
Cell[343820, 9849, 3104, 79, 27204, "Input"],
Cell[346927, 9930, 744, 22, 11440, "Input"],
Cell[347674, 9954, 4133, 102, 41310, "PackageInput"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[351856, 10062, 43, 0, 37, "Subsection"],
Cell[351902, 10064, 2334, 73, 1723, "PackageInput"]
}, Closed]],
Cell[CellGroupData[{
Cell[354273, 10142, 42, 0, 37, "Subsection"],
Cell[CellGroupData[{
Cell[354340, 10146, 49, 0, 3240, "Subsubsection"],
Cell[354392, 10148, 157, 3, 5328, "Text"],
Cell[354552, 10153, 14852, 355, 144847, "PackageInput",
 InitializationCell->True]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[369453, 10514, 40, 0, 37, "Subsection"],
Cell[369496, 10516, 409, 12, 2160, "PackageInput"],
Cell[369908, 10530, 1170, 32, 5122, "PackageInput"],
Cell[371081, 10564, 1372, 37, 5698, "PackageInput"],
Cell[372456, 10603, 1409, 38, 5698, "PackageInput"],
Cell[373868, 10643, 1934, 52, 8061, "PackageInput"]
}, Closed]],
Cell[CellGroupData[{
Cell[375839, 10700, 40, 0, 37, "Subsection"],
Cell[375882, 10702, 409, 12, 2160, "PackageInput"],
Cell[376294, 10716, 1170, 32, 5122, "PackageInput"],
Cell[377467, 10750, 1372, 37, 5698, "PackageInput"],
Cell[378842, 10789, 1409, 38, 5698, "PackageInput"],
Cell[380254, 10829, 1934, 52, 8061, "PackageInput"]
}, Closed]],
Cell[CellGroupData[{
Cell[382225, 10886, 37, 0, 37, "Subsection"],
Cell[382265, 10888, 774, 22, 132, "PackageInput"],
Cell[383042, 10912, 446, 13, 86, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[383525, 10930, 39, 0, 63, "Subsection"],
Cell[383567, 10932, 114, 3, 438, "Text"],
Cell[383684, 10937, 792, 24, 1234, "PackageInput"],
Cell[384479, 10963, 94, 2, 438, "Text"],
Cell[384576, 10967, 2536, 73, 3876, "PackageInput"],
Cell[387115, 11042, 91, 2, 438, "Text"],
Cell[387209, 11046, 1397, 40, 2277, "PackageInput"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[388655, 11092, 34, 0, 72, "Section"],
Cell[388692, 11094, 64, 0, 39, "Text"],
Cell[388759, 11096, 1639, 29, 751, "PackageInput",
 InitializationCell->True]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
