(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    378875,      10508]
NotebookOptionsPosition[    376027,      10421]
NotebookOutlinePosition[    376628,      10444]
CellTagsIndexPosition[    376585,      10441]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Image Derivative Package", "Title"],

Cell["\<\
Markus van Almsick
Technische Universiteit Eindhoven
\[Copyright]2009\
\>", "Subsubtitle"],

Cell[CellGroupData[{

Cell["Prefix", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "TimeSamp", " ", "for", " ", "Package", " ", "Version", " ", "Control"}], 
   " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Unprotect", "[", "TimeStamp", "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"TimeStamp", "::", "usage"}], "=", 
     "\"\<TimeStamp[context] should be set to a Date[]-List indicating the \
version of the corresponding package.\>\""}], ";"}], "\[IndentingNewLine]", 
   "\n", 
   RowBox[{
    RowBox[{
    "TimeStamp", "[", "\"\<MathVisionTools`ImageDerivative`\>\"", "]"}], "=", 
    
    RowBox[{"{", 
     RowBox[{"2010", ",", "9", ",", "7", ",", "17", ",", "38", ",", "0"}], 
     "}"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Protect", "[", "TimeStamp", "]"}], ";"}]}]}]], "PackageInput",
 CellChangeTimes->{{3.492862722564891*^9, 3.492862739080833*^9}}],

Cell["\<\
The preamble of the package containing all kinds of remarks about authorship, \
contence, and copyright.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Name", ":", "MathVisionTools`ImageDerivative`"}]}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Author", ":", 
     RowBox[{"Markus", " ", "van", " ", "Almsick"}]}]}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Email", " ", 
     RowBox[{"address", ":", 
      RowBox[{"M", ".", "v", ".", 
       RowBox[{"Almsick", "@", "tue"}], ".", "nl"}]}]}]}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Context", ":", "MathVisionTools`ImageDerivative`"}]}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Package", " ", 
     RowBox[{"Version", ":", "1.0"}]}]}], "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Mathematica", " ", 
     RowBox[{"Version", ":", "7"}]}]}], "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"Copyright", ":", 
      RowBox[{"Copyright", " ", "2009"}]}]}], ",", " ", 
    RowBox[{"Technische", " ", "Universiteit", " ", "Eindhoven"}]}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Title", ":", 
     RowBox[{"Image", " ", "Derivative"}]}]}], "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Summary", ":", 
     RowBox[{
      RowBox[{
      "This", " ", "package", " ", "implements", " ", "the", " ", 
       "derivation", " ", "of", " ", "images", " ", "via", " ", "B"}], "-", 
      RowBox[{"spline", " ", "interpolation"}]}]}]}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"Keywords", ":", "Interpolation"}]}], ",", " ", "BSpline", ",", 
    " ", "Derivative"}], "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Requirements", ":", "None"}]}], "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Source", ":", "None"}]}], "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"History", ":", 
      RowBox[{
      "Version", " ", "1.0", " ", "by", " ", "Markus", " ", "van", " ", 
       "Almsick"}]}]}], ",", " ", 
    RowBox[{"December", " ", "2009"}]}], "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Limitations", ":", " ", 
     RowBox[{
      RowBox[{"Only", " ", "odd", " ", "B"}], "-", 
      RowBox[{
      "spline", " ", "orders", " ", "up", " ", "to", " ", "9", "th", " ", 
       "order", " ", 
       RowBox[{"supported", "."}]}]}]}]}], "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Discussion", ":"}]}], "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"To", " ", 
     RowBox[{"do", ":"}]}]}], "*)"}]}]], "PackageInput",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Begin Package", "Section"],

Cell["\<\
Declaring the package and unlocking all symbols defined in the code.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"BeginPackage", "[", 
   RowBox[{"\"\<MathVisionTools`ImageDerivative`\>\"", ",", " ", 
    RowBox[{"{", 
     RowBox[{
     "\"\<MathVisionTools`ImageInterpolation`\>\"", ",", 
      "\"\<MathVisionTools`Common`MathVisionToolsCommon`\>\""}], "}"}]}], 
   "]"}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{"Unprotect", "[", "\[IndentingNewLine]", "ImageDerivative", 
  "\[IndentingNewLine]", "]"}]}], "PackageInput",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Online Help and Options", "Section"],

Cell[BoxData["\<\"\\!\\(\\*FormBox[FormBox[\\n  RowBox[{\\n   RowBox[{\\n    \
RowBox[{\\n     RowBox[{\\\"ImageDerivative\\\", \\\"[\\\", \\n      \
RowBox[{SubscriptBox[\\\"n\\\", \\\"1\\\"], \\\",\\\", \
SubscriptBox[\\\"n\\\", \\\"2\\\"], \\\",\\\", \\\"\[Ellipsis]\\\"}], \\\"]\\\
\"}], \\\"[\\\", \\n     \
StyleBox[\\\"image\\\",\\nFontSlant->\\\"Italic\\\"], \\\"]\\\"}], \\\" \\\", \
\\\"generates\\\", \\\" \\\", \\\"an\\\", \\\" \\\", \\\"image\\\", \\\" \
\\\", \\\"array\\\", \\\" \\\", \\\"obtained\\\", \\\" \\\", \\\"from\\\", \\\
\" \\\", \\n    StyleBox[\\\"image\\\",\\nFontSlant->\\\"Italic\\\"], \\\" \\\
\", \\\"by\\\", \\\" \\\", \\\"differentiating\\\", \\\" \\\", \
SubscriptBox[\\\"n\\\", \\\"1\\\"], \\\" \\\", \\\"times\\\", \\\" \\\", \
\\\"with\\\", \\\" \\\", \\\"respect\\\", \\\" \\\", \\\"to\\\", \\\" \\\", \
\\\"the\\\", \\\" \\\", \\\"first\\\", \\\" \\\", \\\"dimension\\\"}], \
\\\",\\\", \\\" \\\", \\n   RowBox[{SubscriptBox[\\\"n\\\", \\\"2\\\"], \\\" \
\\\", \\\"times\\\", \\\" \\\", \\\"with\\\", \\\" \\\", \\\"respect\\\", \
\\\" \\\", \\\"to\\\", \\\" \\\", \\\"the\\\", \\\" \\\", \\\"second\\\", \
\\\" \\\", \\\"dimension\\\"}], \\\",\\\", \\\" \\\", \\n   RowBox[{\\n    \
RowBox[{\\\"and\\\", \\\" \\\", \\\"so\\\", \\\" \\\", \\n     RowBox[{\\\"on\
\\\", \\\".\\\", \\\" \\\", \\\"The\\\"}], \\\" \\\", \\\"derivatives\\\", \\\
\" \\\", \\\"are\\\", \\\" \\\", \\\"formed\\\", \\\" \\\", \\\"via\\\", \\\" \
\\\", \\\"interpolating\\\", \\\" \\\", \\\"B\\\"}], \\\"-\\\", \\n    \
RowBox[{\\\"spline\\\", \\\" \\\", \\\"of\\\", \\\" \\\", \\\"odd\\\", \\\" \
\\\", \\n     RowBox[{\\\"order\\\", \\\".\\\", \\\" \\\", \\\"Their\\\"}], \
\\\" \\\", \\\"order\\\", \\\" \\\", \\\"can\\\", \\\" \\\", \\\"be\\\", \\\" \
\\\", \\\"set\\\", \\\" \\\", \\\"by\\\", \\\" \\\", \\\"the\\\", \\\" \\\", \
\\\"option\\\", \\\" \\\", \\n     RowBox[{\\n      \
StyleBox[\\\"InterpolationOrder\\\", \\\"MR\\\"], \\\".\\\", \\\" \\\", \
\\\"The\\\"}], \\\" \\\", \\\"option\\\", \\\" \\\", \\n     \
StyleBox[\\\"ImageBoundary\\\", \\\"MR\\\"], \\\" \\\", \\\"is\\\", \\\" \
\\\", \\\"also\\\", \\\" \\\", \\n     RowBox[{\\\"supported\\\", \
\\\".\\\"}]}]}]}],\\n  TraditionalForm],\\n TraditionalForm]\\)\"\>"], "Text",\

 CellChangeTimes->{{3.495475109795116*^9, 3.495475133382691*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivative", "::", "usage"}], "=", 
   "\"\<\\!\\(\\*FormBox[FormBox[\\n  RowBox[{\\n   RowBox[{\\n    \
RowBox[{\\n     RowBox[{\\\"ImageDerivative\\\", \\\"[\\\", \\n      \
RowBox[{SubscriptBox[\\\"n\\\", \\\"1\\\"], \\\",\\\", \
SubscriptBox[\\\"n\\\", \\\"2\\\"], \\\",\\\", \\\"\[Ellipsis]\\\"}], \\\"]\\\
\"}], \\\"[\\\", \\n     \
StyleBox[\\\"image\\\",\\nFontSlant->\\\"Italic\\\"], \\\"]\\\"}], \\\" \\\", \
\\\"generates\\\", \\\" \\\", \\\"an\\\", \\\" \\\", \\\"image\\\", \\\" \
\\\", \\\"array\\\", \\\" \\\", \\\"obtained\\\", \\\" \\\", \\\"from\\\", \\\
\" \\\", \\n    StyleBox[\\\"image\\\",\\nFontSlant->\\\"Italic\\\"], \\\" \\\
\", \\\"by\\\", \\\" \\\", \\\"differentiating\\\", \\\" \\\", \
SubscriptBox[\\\"n\\\", \\\"1\\\"], \\\" \\\", \\\"times\\\", \\\" \\\", \
\\\"with\\\", \\\" \\\", \\\"respect\\\", \\\" \\\", \\\"to\\\", \\\" \\\", \
\\\"the\\\", \\\" \\\", \\\"first\\\", \\\" \\\", \\\"dimension\\\"}], \
\\\",\\\", \\\" \\\", \\n   RowBox[{SubscriptBox[\\\"n\\\", \\\"2\\\"], \\\" \
\\\", \\\"times\\\", \\\" \\\", \\\"with\\\", \\\" \\\", \\\"respect\\\", \
\\\" \\\", \\\"to\\\", \\\" \\\", \\\"the\\\", \\\" \\\", \\\"second\\\", \
\\\" \\\", \\\"dimension\\\"}], \\\",\\\", \\\" \\\", \\n   RowBox[{\\n    \
RowBox[{\\\"and\\\", \\\" \\\", \\\"so\\\", \\\" \\\", \\n     RowBox[{\\\"on\
\\\", \\\".\\\", \\\" \\\", \\\"The\\\"}], \\\" \\\", \\\"derivatives\\\", \\\
\" \\\", \\\"are\\\", \\\" \\\", \\\"formed\\\", \\\" \\\", \\\"via\\\", \\\" \
\\\", \\\"interpolating\\\", \\\" \\\", \\\"B\\\"}], \\\"-\\\", \\n    \
RowBox[{\\\"spline\\\", \\\" \\\", \\\"of\\\", \\\" \\\", \\\"odd\\\", \\\" \
\\\", \\n     RowBox[{\\\"order\\\", \\\".\\\", \\\" \\\", \\\"Their\\\"}], \
\\\" \\\", \\\"order\\\", \\\" \\\", \\\"can\\\", \\\" \\\", \\\"be\\\", \\\" \
\\\", \\\"set\\\", \\\" \\\", \\\"by\\\", \\\" \\\", \\\"the\\\", \\\" \\\", \
\\\"option\\\", \\\" \\\", \\n     RowBox[{\\n      \
StyleBox[\\\"InterpolationOrder\\\", \\\"MR\\\"], \\\".\\\", \\\" \\\", \
\\\"The\\\"}], \\\" \\\", \\\"option\\\", \\\" \\\", \\n     \
StyleBox[\\\"ImageBoundary\\\", \\\"MR\\\"], \\\" \\\", \\\"is\\\", \\\" \
\\\", \\\"also\\\", \\\" \\\", \\n     RowBox[{\\\"supported\\\", \
\\\".\\\"}]}]}]}],\\n  TraditionalForm],\\n TraditionalForm]\\)\>\""}], 
  ";"}]], "PackageInput",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Package Code", "Section"],

Cell["Starting the private context of the package.", "Text"],

Cell[BoxData[
 RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}]], "PackageInput",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["ImageDerivativeTestFunction", "Subsection"],

Cell[TextData[{
 "Use these functions to create B-spline kernels for the derivative scheme \
below, if you want to incorporate scale ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DerivativeFilterKernelFunction", "[", 
    RowBox[{"1", ",", "0"}], "]"}], "=", " ", 
   RowBox[{"Compile", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"E", "^", 
            RowBox[{"(", 
             RowBox[{"x", "/", "t"}], ")"}]}], "-", 
           RowBox[{"2", "*", 
            RowBox[{"E", "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", 
                 RowBox[{"2", "*", "x"}]}], ")"}], "/", 
               RowBox[{"(", 
                RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}]}], ")"}], "*", 
         RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"E", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "+", "x"}], ")"}], "^", "2"}], "/", 
            RowBox[{"(", 
             RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}], "*", 
         RowBox[{"Sqrt", "[", "Pi", "]"}]}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "+", "x"}], ")"}], "*", 
            RowBox[{"Erf", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "-", "x"}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"2", "*", 
                RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], ")"}]}], 
         "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "x"}], ")"}], "*", 
          RowBox[{"Erf", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", "x"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
         RowBox[{"2", "*", "x", "*", 
          RowBox[{"Erf", "[", 
           RowBox[{"x", "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}]}], ")"}], 
       "/", "2"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.495706781924337*^9, 3.495706871732758*^9}, 
   3.4957069127997704`*^9, 3.495707376040183*^9, {3.49571179715147*^9, 
   3.495711797934902*^9}, 3.4957140964476023`*^9}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DerivativeFilterKernelFunction", "[", 
     RowBox[{"3", ",", "0"}], "]"}], "=", " ", 
    RowBox[{"Compile", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", "_Real"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", "t", "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", "*", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], 
             "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"4", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"6", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", "*", "t"}], "+", 
                 RowBox[{"x", "^", "2"}]}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"x", "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"4", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", "*", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}]}], ")"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"6", "*", 
          RowBox[{"Sqrt", "[", "Pi", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "+", "x"}], ")"}], "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"6", "*", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
             RowBox[{"Erf", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "-", "x"}], ")"}], "/", 
               RowBox[{"(", 
                RowBox[{"2", "*", 
                 RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], ")"}]}],
           "+", 
          RowBox[{"4", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"4", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"6", "*", "x", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", "*", "t"}], "+", 
             RowBox[{"x", "^", "2"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{"x", "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}]}], ")"}], 
        "/", "12"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DerivativeFilterKernelFunction", "[", 
     RowBox[{"3", ",", "1"}], "]"}], "=", " ", 
    RowBox[{"Compile", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", "_Real"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", "t", "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", "x"}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"4", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"6", "*", "x"}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"x", "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"4", "*", 
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "+", "x"}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}]}], ")"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", "*", 
          RowBox[{"Sqrt", "[", "Pi", "]"}]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", "*", "t"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
          RowBox[{"Erf", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "-", "x"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], ")"}], "/",
         "4"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "*", "t"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
        RowBox[{"Erf", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "-", "x"}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"2", "*", 
            RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "*", "t"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
        
        RowBox[{"Erf", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "x"}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"2", "*", 
            RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", "*", "t"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], 
          "*", 
          RowBox[{"Erf", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", "-", "x"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], ")"}], "/",
         "4"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"3", "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", "*", "t"}], "+", 
            RowBox[{"x", "^", "2"}]}], ")"}], "*", 
          RowBox[{"Erf", "[", 
           RowBox[{"x", "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], ")"}], "/",
         "2"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"DerivativeFilterKernelFunction", "[", 
    RowBox[{"3", ",", "2"}], "]"}], "=", " ", 
   RowBox[{"Compile", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"E", "^", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], "/", 
              RowBox[{"(", 
               RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}], "-", 
           RowBox[{"4", "/", 
            RowBox[{"E", "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}], "/", 
               RowBox[{"(", 
                RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
           RowBox[{"6", "/", 
            RowBox[{"E", "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"x", "^", "2"}], "/", 
               RowBox[{"(", 
                RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
           RowBox[{"4", "/", 
            RowBox[{"E", "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "+", "x"}], ")"}], "^", "2"}], "/", 
               RowBox[{"(", 
                RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
           RowBox[{"E", "^", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], "/", 
              RowBox[{"(", 
               RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], ")"}], "*", 
         RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}], "/", 
       RowBox[{"Sqrt", "[", "Pi", "]"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "+", "x"}], ")"}], "*", 
         RowBox[{"Erf", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "-", "x"}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"2", "*", 
             RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], ")"}], "/", 
       "2"}], "+", 
      RowBox[{"2", "*", 
       RowBox[{"(", 
        RowBox[{"1", "+", "x"}], ")"}], "*", 
       RowBox[{"Erf", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "-", "x"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"2", "*", 
           RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
      RowBox[{"2", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "x"}], ")"}], "*", 
       RowBox[{"Erf", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "x"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"2", "*", 
           RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", "x"}], ")"}], "*", 
         RowBox[{"Erf", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "-", "x"}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"2", "*", 
             RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], ")"}], "/", 
       "2"}], "+", 
      RowBox[{"3", "*", "x", "*", 
       RowBox[{"Erf", "[", 
        RowBox[{"x", "/", 
         RowBox[{"(", 
          RowBox[{"2", "*", 
           RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.495706875838758*^9, 3.49570688059227*^9}, 
   3.4957069258460712`*^9, 3.495707373630288*^9, {3.4957118057981873`*^9, 
   3.495711806805455*^9}, 3.49571409645924*^9, {3.495714189509693*^9, 
   3.4957141936110487`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DerivativeFilterKernelFunction", "[", 
     RowBox[{"5", ",", "0"}], "]"}], "=", " ", 
    RowBox[{"Compile", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", "_Real"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", "t", "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"32", "*", 
                RowBox[{"t", "^", "2"}]}], "+", 
               RowBox[{"18", "*", "t", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "4"}]}], ")"}], 
             "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"6", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"32", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"18", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "4"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"15", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"32", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"18", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"20", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"32", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"18", "*", "t", "*", 
                  RowBox[{"x", "^", "2"}]}], "+", 
                 RowBox[{"x", "^", "4"}]}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"x", "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"15", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"32", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"18", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "+", "x"}], ")"}], "^", "4"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"6", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"32", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"18", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"2", "+", "x"}], ")"}], "^", "4"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"32", "*", 
                RowBox[{"t", "^", "2"}]}], "+", 
               RowBox[{"18", "*", "t", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"3", "+", "x"}], ")"}], "^", "4"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"3", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}]}], ")"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"120", "*", 
          RowBox[{"Sqrt", "[", "Pi", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"3", "+", "x"}], ")"}], "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"60", "*", 
                RowBox[{"t", "^", "2"}]}], "+", 
               RowBox[{"20", "*", "t", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"3", "+", "x"}], ")"}], "^", "4"}]}], ")"}], "*", 
             RowBox[{"Erf", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "-", "x"}], ")"}], "/", 
               RowBox[{"(", 
                RowBox[{"2", "*", 
                 RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], ")"}]}],
           "+", 
          RowBox[{"6", "*", 
           RowBox[{"(", 
            RowBox[{"2", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"60", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"20", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", "+", "x"}], ")"}], "^", "4"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"15", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"60", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"20", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", "x"}], ")"}], "^", "4"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"15", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"60", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"20", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"6", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"60", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"20", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "4"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"60", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"20", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "4"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"3", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"20", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"60", "*", 
              RowBox[{"t", "^", "2"}], "*", "x"}], "+", 
             RowBox[{"20", "*", "t", "*", 
              RowBox[{"x", "^", "3"}]}], "+", 
             RowBox[{"x", "^", "5"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{"x", "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}]}], ")"}], 
        "/", "240"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DerivativeFilterKernelFunction", "[", 
     RowBox[{"5", ",", "1"}], "]"}], "=", " ", 
    RowBox[{"Compile", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", "_Real"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", "t", "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"10", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], 
                ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"6", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"10", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], 
                ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"15", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"10", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], 
                ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"20", "*", "x", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"10", "*", "t"}], "+", 
                 RowBox[{"x", "^", "2"}]}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"x", "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"15", "*", 
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"10", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"6", "*", 
               RowBox[{"(", 
                RowBox[{"2", "+", "x"}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"10", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"3", "+", "x"}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"10", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"3", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}]}], ")"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"24", "*", 
          RowBox[{"Sqrt", "[", "Pi", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "12"}], "*", 
              RowBox[{"t", "^", "2"}]}], "-", 
             RowBox[{"12", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"3", "+", "x"}], ")"}], "^", "4"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "3"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"6", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"12", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"12", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", "+", "x"}], ")"}], "^", "4"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"15", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"12", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"12", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", "x"}], ")"}], "^", "4"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"15", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"12", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"12", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"6", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"12", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"12", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "4"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "12"}], "*", 
              RowBox[{"t", "^", "2"}]}], "-", 
             RowBox[{"12", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "4"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"3", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"20", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"12", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"12", "*", "t", "*", 
              RowBox[{"x", "^", "2"}]}], "+", 
             RowBox[{"x", "^", "4"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{"x", "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}]}], ")"}], 
        "/", "48"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DerivativeFilterKernelFunction", "[", 
     RowBox[{"5", ",", "2"}], "]"}], "=", " ", 
    RowBox[{"Compile", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", "_Real"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", "t", "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", "*", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], 
             "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"6", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"15", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"20", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", "*", "t"}], "+", 
                 RowBox[{"x", "^", "2"}]}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"x", "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"15", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"6", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", "*", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"3", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}]}], ")"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"6", "*", 
          RowBox[{"Sqrt", "[", "Pi", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"3", "+", "x"}], ")"}], "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"6", "*", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
             RowBox[{"Erf", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "-", "x"}], ")"}], "/", 
               RowBox[{"(", 
                RowBox[{"2", "*", 
                 RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], ")"}]}],
           "+", 
          RowBox[{"6", "*", 
           RowBox[{"(", 
            RowBox[{"2", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"15", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"15", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"6", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"3", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"20", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", "*", "t", "*", "x"}], "+", 
             RowBox[{"x", "^", "3"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{"x", "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}]}], ")"}], 
        "/", "12"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DerivativeFilterKernelFunction", "[", 
     RowBox[{"5", ",", "3"}], "]"}], "=", " ", 
    RowBox[{"Compile", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", "_Real"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", "t", "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "3"}], "+", "x"}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"6", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"15", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"20", "*", "x"}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"x", "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"15", "*", 
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"6", "*", 
               RowBox[{"(", 
                RowBox[{"2", "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"3", "+", "x"}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"3", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}]}], ")"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", "*", 
          RowBox[{"Sqrt", "[", "Pi", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", "*", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
             RowBox[{"Erf", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "-", "x"}], ")"}], "/", 
               RowBox[{"(", 
                RowBox[{"2", "*", 
                 RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], ")"}]}],
           "+", 
          RowBox[{"6", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"15", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"15", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"6", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"3", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"20", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "*", "t"}], "+", 
             RowBox[{"x", "^", "2"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{"x", "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}]}], ")"}], 
        "/", "4"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"DerivativeFilterKernelFunction", "[", 
    RowBox[{"5", ",", "4"}], "]"}], "=", " ", 
   RowBox[{"Compile", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"E", "^", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], "/", 
              RowBox[{"(", 
               RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}], "-", 
           RowBox[{"6", "/", 
            RowBox[{"E", "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}], "/", 
               RowBox[{"(", 
                RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
           RowBox[{"15", "/", 
            RowBox[{"E", "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}], "/", 
               RowBox[{"(", 
                RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
           RowBox[{"20", "/", 
            RowBox[{"E", "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"x", "^", "2"}], "/", 
               RowBox[{"(", 
                RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
           RowBox[{"15", "/", 
            RowBox[{"E", "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "+", "x"}], ")"}], "^", "2"}], "/", 
               RowBox[{"(", 
                RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
           RowBox[{"6", "/", 
            RowBox[{"E", "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"2", "+", "x"}], ")"}], "^", "2"}], "/", 
               RowBox[{"(", 
                RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
           RowBox[{"E", "^", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], "/", 
              RowBox[{"(", 
               RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], ")"}], "*", 
         RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}], "/", 
       RowBox[{"Sqrt", "[", "Pi", "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"3", "+", "x"}], ")"}], "*", 
            RowBox[{"Erf", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "3"}], "-", "x"}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"2", "*", 
                RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], ")"}]}], 
         "+", 
         RowBox[{"6", "*", 
          RowBox[{"(", 
           RowBox[{"2", "+", "x"}], ")"}], "*", 
          RowBox[{"Erf", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "-", "x"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
         RowBox[{"15", "*", 
          RowBox[{"(", 
           RowBox[{"1", "+", "x"}], ")"}], "*", 
          RowBox[{"Erf", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "-", "x"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
         RowBox[{"15", "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "x"}], ")"}], "*", 
          RowBox[{"Erf", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", "x"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
         RowBox[{"6", "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", "x"}], ")"}], "*", 
          RowBox[{"Erf", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", "-", "x"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "3"}], "+", "x"}], ")"}], "*", 
          RowBox[{"Erf", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"3", "-", "x"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
         RowBox[{"20", "*", "x", "*", 
          RowBox[{"Erf", "[", 
           RowBox[{"x", "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}]}], ")"}], 
       "/", "2"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{
  3.49570688222827*^9, 3.495707303940659*^9, 3.495707372356511*^9, {
   3.495711808463278*^9, 3.495711809230781*^9}, 3.495714096531164*^9, {
   3.495714170098302*^9, 3.495714179745183*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DerivativeFilterKernelFunction", "[", 
     RowBox[{"7", ",", "0"}], "]"}], "=", " ", 
    RowBox[{"Compile", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", "_Real"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", "t", "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"384", "*", 
                RowBox[{"t", "^", "3"}]}], "+", 
               RowBox[{"348", "*", 
                RowBox[{"t", "^", "2"}], "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
               RowBox[{"40", "*", "t", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "6"}]}], ")"}], 
             "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"8", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "384"}], "*", 
                  RowBox[{"t", "^", "3"}]}], "-", 
                 RowBox[{"348", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], "-", 
                 
                 RowBox[{"40", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "4"}]}], "-", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "6"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"28", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"384", "*", 
                  RowBox[{"t", "^", "3"}]}], "+", 
                 RowBox[{"348", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 
                 RowBox[{"40", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "6"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"56", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"384", "*", 
                  RowBox[{"t", "^", "3"}]}], "+", 
                 RowBox[{"348", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 
                 RowBox[{"40", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "6"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"70", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"384", "*", 
                  RowBox[{"t", "^", "3"}]}], "+", 
                 RowBox[{"348", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{"x", "^", "2"}]}], "+", 
                 RowBox[{"40", "*", "t", "*", 
                  RowBox[{"x", "^", "4"}]}], "+", 
                 RowBox[{"x", "^", "6"}]}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"x", "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"56", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"384", "*", 
                  RowBox[{"t", "^", "3"}]}], "+", 
                 RowBox[{"348", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 RowBox[{"40", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", "x"}], ")"}], "^", "4"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "+", "x"}], ")"}], "^", "6"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"28", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"384", "*", 
                  RowBox[{"t", "^", "3"}]}], "+", 
                 RowBox[{"348", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 RowBox[{"40", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"2", "+", "x"}], ")"}], "^", "4"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"2", "+", "x"}], ")"}], "^", "6"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"8", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "384"}], "*", 
                  RowBox[{"t", "^", "3"}]}], "-", 
                 RowBox[{"348", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], "-", 
                 RowBox[{"40", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"3", "+", "x"}], ")"}], "^", "4"}]}], "-", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"3", "+", "x"}], ")"}], "^", "6"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"3", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"384", "*", 
                RowBox[{"t", "^", "3"}]}], "+", 
               RowBox[{"348", "*", 
                RowBox[{"t", "^", "2"}], "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", "+", "x"}], ")"}], "^", "2"}]}], "+", 
               RowBox[{"40", "*", "t", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", "+", "x"}], ")"}], "^", "4"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"4", "+", "x"}], ")"}], "^", "6"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}]}], ")"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"5040", "*", 
          RowBox[{"Sqrt", "[", "Pi", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"4", "+", "x"}], ")"}], "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"840", "*", 
                RowBox[{"t", "^", "3"}]}], "+", 
               RowBox[{"420", "*", 
                RowBox[{"t", "^", "2"}], "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", "+", "x"}], ")"}], "^", "2"}]}], "+", 
               RowBox[{"42", "*", "t", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", "+", "x"}], ")"}], "^", "4"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"4", "+", "x"}], ")"}], "^", "6"}]}], ")"}], "*", 
             RowBox[{"Erf", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "-", "x"}], ")"}], "/", 
               RowBox[{"(", 
                RowBox[{"2", "*", 
                 RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], ")"}]}],
           "+", 
          RowBox[{"8", "*", 
           RowBox[{"(", 
            RowBox[{"3", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"840", "*", 
              RowBox[{"t", "^", "3"}]}], "+", 
             RowBox[{"420", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"42", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"3", "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"3", "+", "x"}], ")"}], "^", "6"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "3"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"28", "*", 
           RowBox[{"(", 
            RowBox[{"2", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"840", "*", 
              RowBox[{"t", "^", "3"}]}], "+", 
             RowBox[{"420", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"42", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"2", "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", "+", "x"}], ")"}], "^", "6"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"56", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"840", "*", 
              RowBox[{"t", "^", "3"}]}], "+", 
             RowBox[{"420", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"42", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", "x"}], ")"}], "^", "6"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"56", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"840", "*", 
              RowBox[{"t", "^", "3"}]}], "+", 
             RowBox[{"420", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"42", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "6"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"28", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"840", "*", 
              RowBox[{"t", "^", "3"}]}], "+", 
             RowBox[{"420", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"42", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "6"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"8", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"840", "*", 
              RowBox[{"t", "^", "3"}]}], "+", 
             RowBox[{"420", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"42", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "6"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"3", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"840", "*", 
              RowBox[{"t", "^", "3"}]}], "+", 
             RowBox[{"420", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"42", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "6"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"4", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"70", "*", "x", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"840", "*", 
              RowBox[{"t", "^", "3"}]}], "+", 
             RowBox[{"420", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{"x", "^", "2"}]}], "+", 
             RowBox[{"42", "*", "t", "*", 
              RowBox[{"x", "^", "4"}]}], "+", 
             RowBox[{"x", "^", "6"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{"x", "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}]}], ")"}], 
        "/", "10080"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DerivativeFilterKernelFunction", "[", 
     RowBox[{"7", ",", "1"}], "]"}], "=", " ", 
    RowBox[{"Compile", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", "_Real"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", "t", "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"132", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"28", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "4"}]}], 
                ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"8", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"132", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"28", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "4"}]}], 
                ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"28", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"132", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"28", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "4"}]}], 
                ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"56", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"132", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"28", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], 
                ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"70", "*", "x", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"132", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"28", "*", "t", "*", 
                  RowBox[{"x", "^", "2"}]}], "+", 
                 RowBox[{"x", "^", "4"}]}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"x", "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"56", "*", 
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"132", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"28", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "+", "x"}], ")"}], "^", "4"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"28", "*", 
               RowBox[{"(", 
                RowBox[{"2", "+", "x"}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"132", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"28", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"2", "+", "x"}], ")"}], "^", "4"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"8", "*", 
               RowBox[{"(", 
                RowBox[{"3", "+", "x"}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"132", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"28", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"3", "+", "x"}], ")"}], "^", "4"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"3", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"4", "+", "x"}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"132", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"28", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"4", "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"4", "+", "x"}], ")"}], "^", "4"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}]}], ")"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"720", "*", 
          RowBox[{"Sqrt", "[", "Pi", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "120"}], "*", 
              RowBox[{"t", "^", "3"}]}], "-", 
             RowBox[{"180", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"4", "+", "x"}], ")"}], "^", "2"}]}], "-", 
             RowBox[{"30", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"4", "+", "x"}], ")"}], "^", "4"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"4", "+", "x"}], ")"}], "^", "6"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "4"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"1440", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", "*", 
                RowBox[{"t", "^", "3"}]}], ")"}], "/", "3"}], "+", 
             RowBox[{
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"t", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"3", "+", "x"}], ")"}], "^", "4"}]}], ")"}], "/", 
              "6"}], "+", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"3", "+", "x"}], ")"}], "^", "6"}], "/", "180"}]}], 
            ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "3"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"28", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"120", "*", 
              RowBox[{"t", "^", "3"}]}], "+", 
             RowBox[{"180", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"30", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"2", "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", "+", "x"}], ")"}], "^", "6"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"56", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"120", "*", 
              RowBox[{"t", "^", "3"}]}], "+", 
             RowBox[{"180", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"30", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", "x"}], ")"}], "^", "6"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"56", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"120", "*", 
              RowBox[{"t", "^", "3"}]}], "+", 
             RowBox[{"180", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"30", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "6"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"28", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"120", "*", 
              RowBox[{"t", "^", "3"}]}], "+", 
             RowBox[{"180", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"30", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "6"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"1440", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", "*", 
                RowBox[{"t", "^", "3"}]}], ")"}], "/", "3"}], "+", 
             RowBox[{
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"t", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "4"}]}], ")"}],
               "/", "6"}], "+", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "6"}], "/", 
              "180"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"3", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "120"}], "*", 
              RowBox[{"t", "^", "3"}]}], "-", 
             RowBox[{"180", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}]}], "-", 
             RowBox[{"30", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "4"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "6"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"4", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"70", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"120", "*", 
              RowBox[{"t", "^", "3"}]}], "+", 
             RowBox[{"180", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{"x", "^", "2"}]}], "+", 
             RowBox[{"30", "*", "t", "*", 
              RowBox[{"x", "^", "4"}]}], "+", 
             RowBox[{"x", "^", "6"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{"x", "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}]}], ")"}], 
        "/", "1440"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DerivativeFilterKernelFunction", "[", 
     RowBox[{"7", ",", "2"}], "]"}], "=", " ", 
    RowBox[{"Compile", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", "_Real"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", "t", "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"32", "*", 
                RowBox[{"t", "^", "2"}]}], "+", 
               RowBox[{"18", "*", "t", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "4"}]}], ")"}], 
             "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"8", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"32", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"18", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "4"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"28", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"32", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"18", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "4"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"56", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"32", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"18", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"70", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"32", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"18", "*", "t", "*", 
                  RowBox[{"x", "^", "2"}]}], "+", 
                 RowBox[{"x", "^", "4"}]}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"x", "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"56", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"32", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"18", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "+", "x"}], ")"}], "^", "4"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"28", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"32", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"18", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"2", "+", "x"}], ")"}], "^", "4"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"8", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"32", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"18", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"3", "+", "x"}], ")"}], "^", "4"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"3", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"32", "*", 
                RowBox[{"t", "^", "2"}]}], "+", 
               RowBox[{"18", "*", "t", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", "+", "x"}], ")"}], "^", "2"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"4", "+", "x"}], ")"}], "^", "4"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}]}], ")"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"120", "*", 
          RowBox[{"Sqrt", "[", "Pi", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"4", "+", "x"}], ")"}], "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"60", "*", 
                RowBox[{"t", "^", "2"}]}], "+", 
               RowBox[{"20", "*", "t", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", "+", "x"}], ")"}], "^", "2"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"4", "+", "x"}], ")"}], "^", "4"}]}], ")"}], "*", 
             RowBox[{"Erf", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "-", "x"}], ")"}], "/", 
               RowBox[{"(", 
                RowBox[{"2", "*", 
                 RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], ")"}]}],
           "+", 
          RowBox[{"8", "*", 
           RowBox[{"(", 
            RowBox[{"3", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"60", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"20", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"3", "+", "x"}], ")"}], "^", "4"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "3"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"28", "*", 
           RowBox[{"(", 
            RowBox[{"2", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"60", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"20", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", "+", "x"}], ")"}], "^", "4"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"56", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"60", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"20", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", "x"}], ")"}], "^", "4"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"56", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"60", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"20", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"28", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"60", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"20", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "4"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"8", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"60", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"20", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "4"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"3", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"60", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"20", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "4"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"4", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"70", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"60", "*", 
              RowBox[{"t", "^", "2"}], "*", "x"}], "+", 
             RowBox[{"20", "*", "t", "*", 
              RowBox[{"x", "^", "3"}]}], "+", 
             RowBox[{"x", "^", "5"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{"x", "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}]}], ")"}], 
        "/", "240"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DerivativeFilterKernelFunction", "[", 
     RowBox[{"7", ",", "3"}], "]"}], "=", " ", 
    RowBox[{"Compile", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", "_Real"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", "t", "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"10", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}]}], 
                ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"8", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"10", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], 
                ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"28", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"10", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], 
                ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"56", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"10", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], 
                ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"70", "*", "x", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"10", "*", "t"}], "+", 
                 RowBox[{"x", "^", "2"}]}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"x", "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"56", "*", 
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"10", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"28", "*", 
               RowBox[{"(", 
                RowBox[{"2", "+", "x"}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"10", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"8", "*", 
               RowBox[{"(", 
                RowBox[{"3", "+", "x"}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"10", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"3", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"4", "+", "x"}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"10", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"4", "+", "x"}], ")"}], "^", "2"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}]}], ")"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"24", "*", 
          RowBox[{"Sqrt", "[", "Pi", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"12", "*", 
                RowBox[{"t", "^", "2"}]}], "+", 
               RowBox[{"12", "*", "t", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", "+", "x"}], ")"}], "^", "2"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"4", "+", "x"}], ")"}], "^", "4"}]}], ")"}], "*", 
             RowBox[{"Erf", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "-", "x"}], ")"}], "/", 
               RowBox[{"(", 
                RowBox[{"2", "*", 
                 RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], ")"}]}],
           "+", 
          RowBox[{"48", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"2", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"3", "+", "x"}], ")"}], "^", "4"}], "/", "6"}]}], 
            ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "3"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"28", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"12", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"12", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", "+", "x"}], ")"}], "^", "4"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"56", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"12", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"12", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", "x"}], ")"}], "^", "4"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"56", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"12", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"12", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"28", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"12", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"12", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "4"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"48", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"2", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "4"}], "/", 
              "6"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"3", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"12", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"12", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "4"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"4", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"70", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"12", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"12", "*", "t", "*", 
              RowBox[{"x", "^", "2"}]}], "+", 
             RowBox[{"x", "^", "4"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{"x", "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}]}], ")"}], 
        "/", "48"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DerivativeFilterKernelFunction", "[", 
     RowBox[{"7", ",", "4"}], "]"}], "=", " ", 
    RowBox[{"Compile", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", "_Real"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", "t", "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", "*", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], 
             "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"8", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"28", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"56", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"70", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", "*", "t"}], "+", 
                 RowBox[{"x", "^", "2"}]}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"x", "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"56", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"28", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"8", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"3", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", "*", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"4", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}]}], ")"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"6", "*", 
          RowBox[{"Sqrt", "[", "Pi", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"4", "+", "x"}], ")"}], "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"6", "*", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"4", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
             RowBox[{"Erf", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "-", "x"}], ")"}], "/", 
               RowBox[{"(", 
                RowBox[{"2", "*", 
                 RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], ")"}]}],
           "+", 
          RowBox[{"8", "*", 
           RowBox[{"(", 
            RowBox[{"3", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "3"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"28", "*", 
           RowBox[{"(", 
            RowBox[{"2", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"56", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"56", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"28", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"8", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"3", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"4", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"70", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", "*", "t", "*", "x"}], "+", 
             RowBox[{"x", "^", "3"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{"x", "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}]}], ")"}], 
        "/", "12"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DerivativeFilterKernelFunction", "[", 
     RowBox[{"7", ",", "5"}], "]"}], "=", " ", 
    RowBox[{"Compile", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", "_Real"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", "t", "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "4"}], "+", "x"}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"8", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"28", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"56", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"70", "*", "x"}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"x", "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"56", "*", 
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"28", "*", 
               RowBox[{"(", 
                RowBox[{"2", "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"8", "*", 
               RowBox[{"(", 
                RowBox[{"3", "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"3", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"4", "+", "x"}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}]}], ")"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", "*", 
          RowBox[{"Sqrt", "[", "Pi", "]"}]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", "*", "t"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"4", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
          RowBox[{"Erf", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "4"}], "-", "x"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], ")"}], "/",
         "4"}], "+", 
       RowBox[{"2", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "*", "t"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
        RowBox[{"Erf", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "3"}], "-", "x"}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"2", "*", 
            RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
       RowBox[{"7", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "*", "t"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
        RowBox[{"Erf", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "-", "x"}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"2", "*", 
            RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
       RowBox[{"14", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "*", "t"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
        RowBox[{"Erf", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "-", "x"}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"2", "*", 
            RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
       RowBox[{"14", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "*", "t"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
        
        RowBox[{"Erf", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "-", "x"}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"2", "*", 
            RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
       RowBox[{"7", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "*", "t"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
        
        RowBox[{"Erf", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"2", "-", "x"}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"2", "*", 
            RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
       RowBox[{"2", "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "*", "t"}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
        
        RowBox[{"Erf", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"3", "-", "x"}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"2", "*", 
            RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", "*", "t"}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], 
          "*", 
          RowBox[{"Erf", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"4", "-", "x"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], ")"}], "/",
         "4"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"35", "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", "*", "t"}], "+", 
            RowBox[{"x", "^", "2"}]}], ")"}], "*", 
          RowBox[{"Erf", "[", 
           RowBox[{"x", "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], ")"}], "/",
         "2"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"DerivativeFilterKernelFunction", "[", 
    RowBox[{"7", ",", "6"}], "]"}], "=", " ", 
   RowBox[{"Compile", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"E", "^", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}]}], "/", 
              RowBox[{"(", 
               RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}], "-", 
           RowBox[{"8", "/", 
            RowBox[{"E", "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}], "/", 
               RowBox[{"(", 
                RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
           RowBox[{"28", "/", 
            RowBox[{"E", "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}], "/", 
               RowBox[{"(", 
                RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
           RowBox[{"56", "/", 
            RowBox[{"E", "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}], "/", 
               RowBox[{"(", 
                RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
           RowBox[{"70", "/", 
            RowBox[{"E", "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"x", "^", "2"}], "/", 
               RowBox[{"(", 
                RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
           RowBox[{"56", "/", 
            RowBox[{"E", "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "+", "x"}], ")"}], "^", "2"}], "/", 
               RowBox[{"(", 
                RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
           RowBox[{"28", "/", 
            RowBox[{"E", "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"2", "+", "x"}], ")"}], "^", "2"}], "/", 
               RowBox[{"(", 
                RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
           RowBox[{"8", "/", 
            RowBox[{"E", "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"3", "+", "x"}], ")"}], "^", "2"}], "/", 
               RowBox[{"(", 
                RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
           RowBox[{"E", "^", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"4", "+", "x"}], ")"}], "^", "2"}]}], "/", 
              RowBox[{"(", 
               RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], ")"}], "*", 
         RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}], "/", 
       RowBox[{"Sqrt", "[", "Pi", "]"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"4", "+", "x"}], ")"}], "*", 
         RowBox[{"Erf", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], "-", "x"}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"2", "*", 
             RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], ")"}], "/", 
       "2"}], "+", 
      RowBox[{"4", "*", 
       RowBox[{"(", 
        RowBox[{"3", "+", "x"}], ")"}], "*", 
       RowBox[{"Erf", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "3"}], "-", "x"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"2", "*", 
           RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
      RowBox[{"14", "*", 
       RowBox[{"(", 
        RowBox[{"2", "+", "x"}], ")"}], "*", 
       RowBox[{"Erf", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "-", "x"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"2", "*", 
           RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
      RowBox[{"28", "*", 
       RowBox[{"(", 
        RowBox[{"1", "+", "x"}], ")"}], "*", 
       RowBox[{"Erf", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "-", "x"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"2", "*", 
           RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
      RowBox[{"28", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "x"}], ")"}], "*", 
       RowBox[{"Erf", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "-", "x"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"2", "*", 
           RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
      RowBox[{"14", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "2"}], "+", "x"}], ")"}], "*", 
       RowBox[{"Erf", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"2", "-", "x"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"2", "*", 
           RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
      RowBox[{"4", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "3"}], "+", "x"}], ")"}], "*", 
       RowBox[{"Erf", "[", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"3", "-", "x"}], ")"}], "/", 
         RowBox[{"(", 
          RowBox[{"2", "*", 
           RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "4"}], "+", "x"}], ")"}], "*", 
         RowBox[{"Erf", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"4", "-", "x"}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"2", "*", 
             RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], ")"}], "/", 
       "2"}], "+", 
      RowBox[{"35", "*", "x", "*", 
       RowBox[{"Erf", "[", 
        RowBox[{"x", "/", 
         RowBox[{"(", 
          RowBox[{"2", "*", 
           RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{
  3.495706883948228*^9, 3.495707319702921*^9, 3.495707369074374*^9, {
   3.49571181062652*^9, 3.495711811361095*^9}, 3.49571409678528*^9, {
   3.49571413450736*^9, 3.495714152237564*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DerivativeFilterKernelFunction", "[", 
     RowBox[{"9", ",", "0"}], "]"}], "=", " ", 
    RowBox[{"Compile", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", "_Real"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", "t", "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"6144", "*", 
                RowBox[{"t", "^", "4"}]}], "+", 
               RowBox[{"7800", "*", 
                RowBox[{"t", "^", "3"}], "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
               RowBox[{"1380", "*", 
                RowBox[{"t", "^", "2"}], "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
               RowBox[{"70", "*", "t", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "6"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "8"}]}], ")"}], 
             "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"10", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "6144"}], "*", 
                  RowBox[{"t", "^", "4"}]}], "-", 
                 RowBox[{"7800", "*", 
                  RowBox[{"t", "^", "3"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}]}], "-", 
                 
                 RowBox[{"1380", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "4"}]}], "-", 
                 
                 RowBox[{"70", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "6"}]}], "-", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "8"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"45", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"6144", "*", 
                  RowBox[{"t", "^", "4"}]}], "+", 
                 RowBox[{"7800", "*", 
                  RowBox[{"t", "^", "3"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 
                 RowBox[{"1380", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
                 
                 RowBox[{"70", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "6"}]}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "8"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"120", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "6144"}], "*", 
                  RowBox[{"t", "^", "4"}]}], "-", 
                 RowBox[{"7800", "*", 
                  RowBox[{"t", "^", "3"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], "-", 
                 
                 RowBox[{"1380", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "4"}]}], "-", 
                 
                 RowBox[{"70", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "6"}]}], "-", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "8"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"210", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"6144", "*", 
                  RowBox[{"t", "^", "4"}]}], "+", 
                 RowBox[{"7800", "*", 
                  RowBox[{"t", "^", "3"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 
                 RowBox[{"1380", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
                 
                 RowBox[{"70", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "6"}]}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "8"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"252", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"6144", "*", 
                  RowBox[{"t", "^", "4"}]}], "+", 
                 RowBox[{"7800", "*", 
                  RowBox[{"t", "^", "3"}], "*", 
                  RowBox[{"x", "^", "2"}]}], "+", 
                 RowBox[{"1380", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{"x", "^", "4"}]}], "+", 
                 RowBox[{"70", "*", "t", "*", 
                  RowBox[{"x", "^", "6"}]}], "+", 
                 RowBox[{"x", "^", "8"}]}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"x", "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"210", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"6144", "*", 
                  RowBox[{"t", "^", "4"}]}], "+", 
                 RowBox[{"7800", "*", 
                  RowBox[{"t", "^", "3"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 RowBox[{"1380", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", "x"}], ")"}], "^", "4"}]}], "+", 
                 RowBox[{"70", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", "x"}], ")"}], "^", "6"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "+", "x"}], ")"}], "^", "8"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"120", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "6144"}], "*", 
                  RowBox[{"t", "^", "4"}]}], "-", 
                 RowBox[{"7800", "*", 
                  RowBox[{"t", "^", "3"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], "-", 
                 RowBox[{"1380", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"2", "+", "x"}], ")"}], "^", "4"}]}], "-", 
                 RowBox[{"70", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"2", "+", "x"}], ")"}], "^", "6"}]}], "-", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"2", "+", "x"}], ")"}], "^", "8"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"45", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"6144", "*", 
                  RowBox[{"t", "^", "4"}]}], "+", 
                 RowBox[{"7800", "*", 
                  RowBox[{"t", "^", "3"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 RowBox[{"1380", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"3", "+", "x"}], ")"}], "^", "4"}]}], "+", 
                 RowBox[{"70", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"3", "+", "x"}], ")"}], "^", "6"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"3", "+", "x"}], ")"}], "^", "8"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"3", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"10", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "6144"}], "*", 
                  RowBox[{"t", "^", "4"}]}], "-", 
                 RowBox[{"7800", "*", 
                  RowBox[{"t", "^", "3"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"4", "+", "x"}], ")"}], "^", "2"}]}], "-", 
                 RowBox[{"1380", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"4", "+", "x"}], ")"}], "^", "4"}]}], "-", 
                 RowBox[{"70", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"4", "+", "x"}], ")"}], "^", "6"}]}], "-", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"4", "+", "x"}], ")"}], "^", "8"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"6144", "*", 
                RowBox[{"t", "^", "4"}]}], "+", 
               RowBox[{"7800", "*", 
                RowBox[{"t", "^", "3"}], "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"5", "+", "x"}], ")"}], "^", "2"}]}], "+", 
               RowBox[{"1380", "*", 
                RowBox[{"t", "^", "2"}], "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"5", "+", "x"}], ")"}], "^", "4"}]}], "+", 
               RowBox[{"70", "*", "t", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"5", "+", "x"}], ")"}], "^", "6"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"5", "+", "x"}], ")"}], "^", "8"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"5", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}]}], ")"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"362880", "*", 
          RowBox[{"Sqrt", "[", "Pi", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"5", "+", "x"}], ")"}], "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"15120", "*", 
                RowBox[{"t", "^", "4"}]}], "+", 
               RowBox[{"10080", "*", 
                RowBox[{"t", "^", "3"}], "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"5", "+", "x"}], ")"}], "^", "2"}]}], "+", 
               RowBox[{"1512", "*", 
                RowBox[{"t", "^", "2"}], "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"5", "+", "x"}], ")"}], "^", "4"}]}], "+", 
               RowBox[{"72", "*", "t", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"5", "+", "x"}], ")"}], "^", "6"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"5", "+", "x"}], ")"}], "^", "8"}]}], ")"}], "*", 
             RowBox[{"Erf", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "5"}], "-", "x"}], ")"}], "/", 
               RowBox[{"(", 
                RowBox[{"2", "*", 
                 RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], ")"}]}],
           "+", 
          RowBox[{"10", "*", 
           RowBox[{"(", 
            RowBox[{"4", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"15120", "*", 
              RowBox[{"t", "^", "4"}]}], "+", 
             RowBox[{"10080", "*", 
              RowBox[{"t", "^", "3"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"4", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"1512", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"4", "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{"72", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"4", "+", "x"}], ")"}], "^", "6"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"4", "+", "x"}], ")"}], "^", "8"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "4"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"45", "*", 
           RowBox[{"(", 
            RowBox[{"3", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"15120", "*", 
              RowBox[{"t", "^", "4"}]}], "+", 
             RowBox[{"10080", "*", 
              RowBox[{"t", "^", "3"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"1512", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"3", "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{"72", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"3", "+", "x"}], ")"}], "^", "6"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"3", "+", "x"}], ")"}], "^", "8"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "3"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"120", "*", 
           RowBox[{"(", 
            RowBox[{"2", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"15120", "*", 
              RowBox[{"t", "^", "4"}]}], "+", 
             RowBox[{"10080", "*", 
              RowBox[{"t", "^", "3"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"1512", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"2", "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{"72", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"2", "+", "x"}], ")"}], "^", "6"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", "+", "x"}], ")"}], "^", "8"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"210", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"15120", "*", 
              RowBox[{"t", "^", "4"}]}], "+", 
             RowBox[{"10080", "*", 
              RowBox[{"t", "^", "3"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"1512", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{"72", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}], "^", "6"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", "x"}], ")"}], "^", "8"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"210", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"15120", "*", 
              RowBox[{"t", "^", "4"}]}], "+", 
             RowBox[{"10080", "*", 
              RowBox[{"t", "^", "3"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"1512", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{"72", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "6"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "8"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"120", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"15120", "*", 
              RowBox[{"t", "^", "4"}]}], "+", 
             RowBox[{"10080", "*", 
              RowBox[{"t", "^", "3"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"1512", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{"72", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "6"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "8"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"45", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"15120", "*", 
              RowBox[{"t", "^", "4"}]}], "+", 
             RowBox[{"10080", "*", 
              RowBox[{"t", "^", "3"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"1512", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{"72", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "6"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "8"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"3", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"10", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"15120", "*", 
              RowBox[{"t", "^", "4"}]}], "+", 
             RowBox[{"10080", "*", 
              RowBox[{"t", "^", "3"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"1512", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{"72", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "6"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "8"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"4", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"15120", "*", 
              RowBox[{"t", "^", "4"}]}], "+", 
             RowBox[{"10080", "*", 
              RowBox[{"t", "^", "3"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"1512", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{"72", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "6"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "8"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"5", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"252", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"15120", "*", 
              RowBox[{"t", "^", "4"}], "*", "x"}], "+", 
             RowBox[{"10080", "*", 
              RowBox[{"t", "^", "3"}], "*", 
              RowBox[{"x", "^", "3"}]}], "+", 
             RowBox[{"1512", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{"x", "^", "5"}]}], "+", 
             RowBox[{"72", "*", "t", "*", 
              RowBox[{"x", "^", "7"}]}], "+", 
             RowBox[{"x", "^", "9"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{"x", "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}]}], ")"}], 
        "/", "725760"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DerivativeFilterKernelFunction", "[", 
     RowBox[{"9", ",", "1"}], "]"}], "=", " ", 
    RowBox[{"Compile", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", "_Real"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", "t", "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2232", "*", 
                  RowBox[{"t", "^", "3"}]}], "+", 
                 RowBox[{"740", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 
                 RowBox[{"54", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "6"}]}], 
                ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "5"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"10", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2232", "*", 
                  RowBox[{"t", "^", "3"}]}], "+", 
                 RowBox[{"740", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 
                 RowBox[{"54", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "6"}]}], 
                ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"45", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2232", "*", 
                  RowBox[{"t", "^", "3"}]}], "+", 
                 RowBox[{"740", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 
                 RowBox[{"54", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "6"}]}], 
                ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"120", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2232", "*", 
                  RowBox[{"t", "^", "3"}]}], "+", 
                 RowBox[{"740", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 
                 RowBox[{"54", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "6"}]}], 
                ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"210", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2232", "*", 
                  RowBox[{"t", "^", "3"}]}], "+", 
                 RowBox[{"740", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 
                 RowBox[{"54", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "6"}]}], 
                ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"252", "*", "x", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2232", "*", 
                  RowBox[{"t", "^", "3"}]}], "+", 
                 RowBox[{"740", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{"x", "^", "2"}]}], "+", 
                 RowBox[{"54", "*", "t", "*", 
                  RowBox[{"x", "^", "4"}]}], "+", 
                 RowBox[{"x", "^", "6"}]}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"x", "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"210", "*", 
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2232", "*", 
                  RowBox[{"t", "^", "3"}]}], "+", 
                 RowBox[{"740", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 RowBox[{"54", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", "x"}], ")"}], "^", "4"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "+", "x"}], ")"}], "^", "6"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"120", "*", 
               RowBox[{"(", 
                RowBox[{"2", "+", "x"}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2232", "*", 
                  RowBox[{"t", "^", "3"}]}], "+", 
                 RowBox[{"740", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 RowBox[{"54", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"2", "+", "x"}], ")"}], "^", "4"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"2", "+", "x"}], ")"}], "^", "6"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"45", "*", 
               RowBox[{"(", 
                RowBox[{"3", "+", "x"}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2232", "*", 
                  RowBox[{"t", "^", "3"}]}], "+", 
                 RowBox[{"740", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 RowBox[{"54", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"3", "+", "x"}], ")"}], "^", "4"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"3", "+", "x"}], ")"}], "^", "6"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"3", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"10", "*", 
               RowBox[{"(", 
                RowBox[{"4", "+", "x"}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2232", "*", 
                  RowBox[{"t", "^", "3"}]}], "+", 
                 RowBox[{"740", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"4", "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 RowBox[{"54", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"4", "+", "x"}], ")"}], "^", "4"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"4", "+", "x"}], ")"}], "^", "6"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"5", "+", "x"}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"2232", "*", 
                  RowBox[{"t", "^", "3"}]}], "+", 
                 RowBox[{"740", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"5", "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 RowBox[{"54", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"5", "+", "x"}], ")"}], "^", "4"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"5", "+", "x"}], ")"}], "^", "6"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"5", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}]}], ")"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"40320", "*", 
          RowBox[{"Sqrt", "[", "Pi", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "1680"}], "*", 
              RowBox[{"t", "^", "4"}]}], "-", 
             RowBox[{"3360", "*", 
              RowBox[{"t", "^", "3"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"5", "+", "x"}], ")"}], "^", "2"}]}], "-", 
             RowBox[{"840", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"5", "+", "x"}], ")"}], "^", "4"}]}], "-", 
             RowBox[{"56", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"5", "+", "x"}], ")"}], "^", "6"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"5", "+", "x"}], ")"}], "^", "8"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"10", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"1680", "*", 
              RowBox[{"t", "^", "4"}]}], "+", 
             RowBox[{"3360", "*", 
              RowBox[{"t", "^", "3"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"4", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"840", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"4", "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{"56", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"4", "+", "x"}], ")"}], "^", "6"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"4", "+", "x"}], ")"}], "^", "8"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "4"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"45", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "1680"}], "*", 
              RowBox[{"t", "^", "4"}]}], "-", 
             RowBox[{"3360", "*", 
              RowBox[{"t", "^", "3"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], "-", 
             RowBox[{"840", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"3", "+", "x"}], ")"}], "^", "4"}]}], "-", 
             RowBox[{"56", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"3", "+", "x"}], ")"}], "^", "6"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"3", "+", "x"}], ")"}], "^", "8"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "3"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"80640", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"5", "*", 
                RowBox[{"t", "^", "4"}]}], ")"}], "/", "2"}], "+", 
             RowBox[{"5", "*", 
              RowBox[{"t", "^", "3"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"5", "*", 
                RowBox[{"t", "^", "2"}], "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "+", "x"}], ")"}], "^", "4"}]}], ")"}], "/", 
              "4"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"t", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "+", "x"}], ")"}], "^", "6"}]}], ")"}], "/", 
              "12"}], "+", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"2", "+", "x"}], ")"}], "^", "8"}], "/", "672"}]}], 
            ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"210", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "1680"}], "*", 
              RowBox[{"t", "^", "4"}]}], "-", 
             RowBox[{"3360", "*", 
              RowBox[{"t", "^", "3"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], "-", 
             RowBox[{"840", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}], "^", "4"}]}], "-", 
             RowBox[{"56", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}], "^", "6"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", "x"}], ")"}], "^", "8"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"210", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "1680"}], "*", 
              RowBox[{"t", "^", "4"}]}], "-", 
             RowBox[{"3360", "*", 
              RowBox[{"t", "^", "3"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], "-", 
             RowBox[{"840", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], "-", 
             RowBox[{"56", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "6"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "8"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"80640", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"5", "*", 
                RowBox[{"t", "^", "4"}]}], ")"}], "/", "2"}], "+", 
             RowBox[{"5", "*", 
              RowBox[{"t", "^", "3"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"5", "*", 
                RowBox[{"t", "^", "2"}], "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "4"}]}], ")"}],
               "/", "4"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"t", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "6"}]}], ")"}],
               "/", "12"}], "+", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "8"}], "/", 
              "672"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"45", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "1680"}], "*", 
              RowBox[{"t", "^", "4"}]}], "-", 
             RowBox[{"3360", "*", 
              RowBox[{"t", "^", "3"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], "-", 
             RowBox[{"840", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "4"}]}], "-", 
             RowBox[{"56", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "6"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "8"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"3", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"10", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"1680", "*", 
              RowBox[{"t", "^", "4"}]}], "+", 
             RowBox[{"3360", "*", 
              RowBox[{"t", "^", "3"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"840", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{"56", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "6"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "8"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"4", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "1680"}], "*", 
              RowBox[{"t", "^", "4"}]}], "-", 
             RowBox[{"3360", "*", 
              RowBox[{"t", "^", "3"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "2"}]}], "-", 
             RowBox[{"840", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "4"}]}], "-", 
             RowBox[{"56", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "6"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "8"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"5", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"252", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"1680", "*", 
              RowBox[{"t", "^", "4"}]}], "+", 
             RowBox[{"3360", "*", 
              RowBox[{"t", "^", "3"}], "*", 
              RowBox[{"x", "^", "2"}]}], "+", 
             RowBox[{"840", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{"x", "^", "4"}]}], "+", 
             RowBox[{"56", "*", "t", "*", 
              RowBox[{"x", "^", "6"}]}], "+", 
             RowBox[{"x", "^", "8"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{"x", "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}]}], ")"}], 
        "/", "80640"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DerivativeFilterKernelFunction", "[", 
     RowBox[{"9", ",", "2"}], "]"}], "=", " ", 
    RowBox[{"Compile", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", "_Real"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", "t", "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"384", "*", 
                RowBox[{"t", "^", "3"}]}], "+", 
               RowBox[{"348", "*", 
                RowBox[{"t", "^", "2"}], "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
               RowBox[{"40", "*", "t", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "6"}]}], ")"}], 
             "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"10", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "384"}], "*", 
                  RowBox[{"t", "^", "3"}]}], "-", 
                 RowBox[{"348", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}]}], "-", 
                 
                 RowBox[{"40", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "4"}]}], "-", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "6"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"45", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"384", "*", 
                  RowBox[{"t", "^", "3"}]}], "+", 
                 RowBox[{"348", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 
                 RowBox[{"40", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "6"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"120", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "384"}], "*", 
                  RowBox[{"t", "^", "3"}]}], "-", 
                 RowBox[{"348", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], "-", 
                 
                 RowBox[{"40", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "4"}]}], "-", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "6"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"210", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"384", "*", 
                  RowBox[{"t", "^", "3"}]}], "+", 
                 RowBox[{"348", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 
                 RowBox[{"40", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "6"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"252", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"384", "*", 
                  RowBox[{"t", "^", "3"}]}], "+", 
                 RowBox[{"348", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{"x", "^", "2"}]}], "+", 
                 RowBox[{"40", "*", "t", "*", 
                  RowBox[{"x", "^", "4"}]}], "+", 
                 RowBox[{"x", "^", "6"}]}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"x", "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"210", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"384", "*", 
                  RowBox[{"t", "^", "3"}]}], "+", 
                 RowBox[{"348", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 RowBox[{"40", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", "x"}], ")"}], "^", "4"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "+", "x"}], ")"}], "^", "6"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"120", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "384"}], "*", 
                  RowBox[{"t", "^", "3"}]}], "-", 
                 RowBox[{"348", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], "-", 
                 RowBox[{"40", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"2", "+", "x"}], ")"}], "^", "4"}]}], "-", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"2", "+", "x"}], ")"}], "^", "6"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"45", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"384", "*", 
                  RowBox[{"t", "^", "3"}]}], "+", 
                 RowBox[{"348", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 RowBox[{"40", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"3", "+", "x"}], ")"}], "^", "4"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"3", "+", "x"}], ")"}], "^", "6"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"3", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"10", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "384"}], "*", 
                  RowBox[{"t", "^", "3"}]}], "-", 
                 RowBox[{"348", "*", 
                  RowBox[{"t", "^", "2"}], "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"4", "+", "x"}], ")"}], "^", "2"}]}], "-", 
                 RowBox[{"40", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"4", "+", "x"}], ")"}], "^", "4"}]}], "-", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"4", "+", "x"}], ")"}], "^", "6"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"384", "*", 
                RowBox[{"t", "^", "3"}]}], "+", 
               RowBox[{"348", "*", 
                RowBox[{"t", "^", "2"}], "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"5", "+", "x"}], ")"}], "^", "2"}]}], "+", 
               RowBox[{"40", "*", "t", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"5", "+", "x"}], ")"}], "^", "4"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"5", "+", "x"}], ")"}], "^", "6"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"5", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}]}], ")"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"5040", "*", 
          RowBox[{"Sqrt", "[", "Pi", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"5", "+", "x"}], ")"}], "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"840", "*", 
                RowBox[{"t", "^", "3"}]}], "+", 
               RowBox[{"420", "*", 
                RowBox[{"t", "^", "2"}], "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"5", "+", "x"}], ")"}], "^", "2"}]}], "+", 
               RowBox[{"42", "*", "t", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"5", "+", "x"}], ")"}], "^", "4"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"5", "+", "x"}], ")"}], "^", "6"}]}], ")"}], "*", 
             RowBox[{"Erf", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "5"}], "-", "x"}], ")"}], "/", 
               RowBox[{"(", 
                RowBox[{"2", "*", 
                 RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], ")"}]}],
           "+", 
          RowBox[{"10", "*", 
           RowBox[{"(", 
            RowBox[{"4", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"840", "*", 
              RowBox[{"t", "^", "3"}]}], "+", 
             RowBox[{"420", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"4", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"42", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"4", "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"4", "+", "x"}], ")"}], "^", "6"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "4"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"45", "*", 
           RowBox[{"(", 
            RowBox[{"3", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"840", "*", 
              RowBox[{"t", "^", "3"}]}], "+", 
             RowBox[{"420", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"42", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"3", "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"3", "+", "x"}], ")"}], "^", "6"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "3"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"120", "*", 
           RowBox[{"(", 
            RowBox[{"2", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"840", "*", 
              RowBox[{"t", "^", "3"}]}], "+", 
             RowBox[{"420", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"42", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"2", "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", "+", "x"}], ")"}], "^", "6"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"210", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"840", "*", 
              RowBox[{"t", "^", "3"}]}], "+", 
             RowBox[{"420", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"42", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", "x"}], ")"}], "^", "6"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"210", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"840", "*", 
              RowBox[{"t", "^", "3"}]}], "+", 
             RowBox[{"420", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"42", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "6"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"120", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"840", "*", 
              RowBox[{"t", "^", "3"}]}], "+", 
             RowBox[{"420", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"42", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "6"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"45", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"840", "*", 
              RowBox[{"t", "^", "3"}]}], "+", 
             RowBox[{"420", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"42", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "6"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"3", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"10", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"840", "*", 
              RowBox[{"t", "^", "3"}]}], "+", 
             RowBox[{"420", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"42", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "6"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"4", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"840", "*", 
              RowBox[{"t", "^", "3"}]}], "+", 
             RowBox[{"420", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"42", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "6"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"5", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"252", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"840", "*", 
              RowBox[{"t", "^", "3"}], "*", "x"}], "+", 
             RowBox[{"420", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{"x", "^", "3"}]}], "+", 
             RowBox[{"42", "*", "t", "*", 
              RowBox[{"x", "^", "5"}]}], "+", 
             RowBox[{"x", "^", "7"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{"x", "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}]}], ")"}], 
        "/", "10080"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DerivativeFilterKernelFunction", "[", 
     RowBox[{"9", ",", "3"}], "]"}], "=", " ", 
    RowBox[{"Compile", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", "_Real"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", "t", "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"132", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"28", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "4"}]}], 
                ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "5"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"10", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"132", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"28", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "4"}]}], 
                ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"45", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"132", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"28", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "4"}]}], 
                ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"120", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"132", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"28", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "4"}]}], 
                ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"210", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"132", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"28", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], 
                ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"252", "*", "x", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"132", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"28", "*", "t", "*", 
                  RowBox[{"x", "^", "2"}]}], "+", 
                 RowBox[{"x", "^", "4"}]}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"x", "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"210", "*", 
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"132", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"28", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "+", "x"}], ")"}], "^", "4"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"120", "*", 
               RowBox[{"(", 
                RowBox[{"2", "+", "x"}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"132", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"28", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"2", "+", "x"}], ")"}], "^", "4"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"45", "*", 
               RowBox[{"(", 
                RowBox[{"3", "+", "x"}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"132", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"28", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"3", "+", "x"}], ")"}], "^", "4"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"3", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"10", "*", 
               RowBox[{"(", 
                RowBox[{"4", "+", "x"}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"132", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"28", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"4", "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"4", "+", "x"}], ")"}], "^", "4"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"5", "+", "x"}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"132", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"28", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"5", "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"5", "+", "x"}], ")"}], "^", "4"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"5", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}]}], ")"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"720", "*", 
          RowBox[{"Sqrt", "[", "Pi", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "120"}], "*", 
              RowBox[{"t", "^", "3"}]}], "-", 
             RowBox[{"180", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"5", "+", "x"}], ")"}], "^", "2"}]}], "-", 
             RowBox[{"30", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"5", "+", "x"}], ")"}], "^", "4"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"5", "+", "x"}], ")"}], "^", "6"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"10", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"120", "*", 
              RowBox[{"t", "^", "3"}]}], "+", 
             RowBox[{"180", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"4", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"30", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"4", "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"4", "+", "x"}], ")"}], "^", "6"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "4"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"45", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "120"}], "*", 
              RowBox[{"t", "^", "3"}]}], "-", 
             RowBox[{"180", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], "-", 
             RowBox[{"30", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"3", "+", "x"}], ")"}], "^", "4"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"3", "+", "x"}], ")"}], "^", "6"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "3"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"1440", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"10", "*", 
              RowBox[{"t", "^", "3"}]}], "+", 
             RowBox[{"15", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"5", "*", "t", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "+", "x"}], ")"}], "^", "4"}]}], ")"}], "/", 
              "2"}], "+", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{"2", "+", "x"}], ")"}], "^", "6"}], "/", "12"}]}], 
            ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"210", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"120", "*", 
              RowBox[{"t", "^", "3"}]}], "+", 
             RowBox[{"180", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"30", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", "x"}], ")"}], "^", "6"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"210", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"120", "*", 
              RowBox[{"t", "^", "3"}]}], "+", 
             RowBox[{"180", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"30", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "6"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"1440", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"10", "*", 
              RowBox[{"t", "^", "3"}]}], "+", 
             RowBox[{"15", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"5", "*", "t", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "4"}]}], ")"}],
               "/", "2"}], "+", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "6"}], "/", 
              "12"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"45", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "120"}], "*", 
              RowBox[{"t", "^", "3"}]}], "-", 
             RowBox[{"180", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], "-", 
             RowBox[{"30", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "4"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "6"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"3", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"10", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"120", "*", 
              RowBox[{"t", "^", "3"}]}], "+", 
             RowBox[{"180", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{"30", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "4"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "6"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"4", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "120"}], "*", 
              RowBox[{"t", "^", "3"}]}], "-", 
             RowBox[{"180", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "2"}]}], "-", 
             RowBox[{"30", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "4"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "6"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"5", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"252", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"120", "*", 
              RowBox[{"t", "^", "3"}]}], "+", 
             RowBox[{"180", "*", 
              RowBox[{"t", "^", "2"}], "*", 
              RowBox[{"x", "^", "2"}]}], "+", 
             RowBox[{"30", "*", "t", "*", 
              RowBox[{"x", "^", "4"}]}], "+", 
             RowBox[{"x", "^", "6"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{"x", "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}]}], ")"}], 
        "/", "1440"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DerivativeFilterKernelFunction", "[", 
     RowBox[{"9", ",", "4"}], "]"}], "=", " ", 
    RowBox[{"Compile", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", "_Real"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", "t", "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"32", "*", 
                RowBox[{"t", "^", "2"}]}], "+", 
               RowBox[{"18", "*", "t", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "4"}]}], ")"}], 
             "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"10", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"32", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"18", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "4"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"45", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"32", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"18", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "4"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"120", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"32", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"18", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "4"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"210", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"32", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"18", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"252", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"32", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"18", "*", "t", "*", 
                  RowBox[{"x", "^", "2"}]}], "+", 
                 RowBox[{"x", "^", "4"}]}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"x", "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"210", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"32", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"18", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "+", "x"}], ")"}], "^", "4"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"120", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"32", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"18", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"2", "+", "x"}], ")"}], "^", "4"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"45", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"32", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"18", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"3", "+", "x"}], ")"}], "^", "4"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"3", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"10", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"32", "*", 
                  RowBox[{"t", "^", "2"}]}], "+", 
                 RowBox[{"18", "*", "t", "*", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"4", "+", "x"}], ")"}], "^", "2"}]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"4", "+", "x"}], ")"}], "^", "4"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"32", "*", 
                RowBox[{"t", "^", "2"}]}], "+", 
               RowBox[{"18", "*", "t", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"5", "+", "x"}], ")"}], "^", "2"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"5", "+", "x"}], ")"}], "^", "4"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"5", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}]}], ")"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"120", "*", 
          RowBox[{"Sqrt", "[", "Pi", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"5", "+", "x"}], ")"}], "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"60", "*", 
                RowBox[{"t", "^", "2"}]}], "+", 
               RowBox[{"20", "*", "t", "*", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"5", "+", "x"}], ")"}], "^", "2"}]}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"5", "+", "x"}], ")"}], "^", "4"}]}], ")"}], "*", 
             RowBox[{"Erf", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "5"}], "-", "x"}], ")"}], "/", 
               RowBox[{"(", 
                RowBox[{"2", "*", 
                 RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], ")"}]}],
           "+", 
          RowBox[{"10", "*", 
           RowBox[{"(", 
            RowBox[{"4", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"60", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"20", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"4", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"4", "+", "x"}], ")"}], "^", "4"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "4"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"45", "*", 
           RowBox[{"(", 
            RowBox[{"3", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"60", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"20", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"3", "+", "x"}], ")"}], "^", "4"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "3"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"120", "*", 
           RowBox[{"(", 
            RowBox[{"2", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"60", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"20", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", "+", "x"}], ")"}], "^", "4"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"210", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"60", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"20", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", "x"}], ")"}], "^", "4"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"210", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"60", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"20", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"120", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"60", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"20", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "4"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"45", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"60", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"20", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "4"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"3", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"10", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"60", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"20", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "4"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"4", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"60", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"20", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "4"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"5", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"252", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"60", "*", 
              RowBox[{"t", "^", "2"}], "*", "x"}], "+", 
             RowBox[{"20", "*", "t", "*", 
              RowBox[{"x", "^", "3"}]}], "+", 
             RowBox[{"x", "^", "5"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{"x", "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}]}], ")"}], 
        "/", "240"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DerivativeFilterKernelFunction", "[", 
     RowBox[{"9", ",", "5"}], "]"}], "=", " ", 
    RowBox[{"Compile", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", "_Real"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", "t", "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"10", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "2"}]}], 
                ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "5"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"10", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"10", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}]}], 
                ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"45", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"10", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], 
                ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"120", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"10", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], 
                ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"210", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"10", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], 
                ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"252", "*", "x", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"10", "*", "t"}], "+", 
                 RowBox[{"x", "^", "2"}]}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"x", "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"210", "*", 
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"10", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"120", "*", 
               RowBox[{"(", 
                RowBox[{"2", "+", "x"}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"10", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"45", "*", 
               RowBox[{"(", 
                RowBox[{"3", "+", "x"}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"10", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"3", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"10", "*", 
               RowBox[{"(", 
                RowBox[{"4", "+", "x"}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"10", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"4", "+", "x"}], ")"}], "^", "2"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"5", "+", "x"}], ")"}], "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"10", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"5", "+", "x"}], ")"}], "^", "2"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"5", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}]}], ")"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"24", "*", 
          RowBox[{"Sqrt", "[", "Pi", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "12"}], "*", 
              RowBox[{"t", "^", "2"}]}], "-", 
             RowBox[{"12", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"5", "+", "x"}], ")"}], "^", "2"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"5", "+", "x"}], ")"}], "^", "4"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"10", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"12", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"12", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"4", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"4", "+", "x"}], ")"}], "^", "4"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "4"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"45", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"12", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"12", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"3", "+", "x"}], ")"}], "^", "4"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "3"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"120", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"12", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"12", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", "+", "x"}], ")"}], "^", "4"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"210", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"12", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"12", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", "x"}], ")"}], "^", "4"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"210", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"12", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"12", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "4"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"120", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"12", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"12", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "4"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"45", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"12", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"12", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "4"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"3", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"10", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"12", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"12", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "4"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"4", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "12"}], "*", 
              RowBox[{"t", "^", "2"}]}], "-", 
             RowBox[{"12", "*", "t", "*", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "2"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "4"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"5", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"252", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"12", "*", 
              RowBox[{"t", "^", "2"}]}], "+", 
             RowBox[{"12", "*", "t", "*", 
              RowBox[{"x", "^", "2"}]}], "+", 
             RowBox[{"x", "^", "4"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{"x", "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}]}], ")"}], 
        "/", "48"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DerivativeFilterKernelFunction", "[", 
     RowBox[{"9", ",", "6"}], "]"}], "=", " ", 
    RowBox[{"Compile", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", "_Real"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", "t", "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", "*", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], 
             "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"10", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"45", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"120", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"210", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], 
                ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"252", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", "*", "t"}], "+", 
                 RowBox[{"x", "^", "2"}]}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"x", "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"210", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"120", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"45", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"3", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"10", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"4", "*", "t"}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"4", "+", "x"}], ")"}], "^", "2"}]}], ")"}]}], 
              ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", "*", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"5", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"5", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}]}], ")"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"6", "*", 
          RowBox[{"Sqrt", "[", "Pi", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"5", "+", "x"}], ")"}], "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"6", "*", "t"}], "+", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"5", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
             RowBox[{"Erf", "[", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "5"}], "-", "x"}], ")"}], "/", 
               RowBox[{"(", 
                RowBox[{"2", "*", 
                 RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], ")"}]}],
           "+", 
          RowBox[{"10", "*", 
           RowBox[{"(", 
            RowBox[{"4", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"4", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "4"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"45", "*", 
           RowBox[{"(", 
            RowBox[{"3", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "3"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"120", "*", 
           RowBox[{"(", 
            RowBox[{"2", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"210", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "x"}], ")"}], "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"210", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"120", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"45", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"3", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"10", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"4", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], 
           "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "5"}], "+", "x"}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"5", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"252", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"6", "*", "t", "*", "x"}], "+", 
             RowBox[{"x", "^", "3"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{"x", "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}]}], ")"}], 
        "/", "12"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"DerivativeFilterKernelFunction", "[", 
     RowBox[{"9", ",", "7"}], "]"}], "=", " ", 
    RowBox[{"Compile", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"t", ",", "_Real"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sqrt", "[", "t", "]"}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "+", "x"}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"10", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "4"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"45", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "3"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"120", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"210", "*", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"252", "*", "x"}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"x", "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"210", "*", 
               RowBox[{"(", 
                RowBox[{"1", "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"120", "*", 
               RowBox[{"(", 
                RowBox[{"2", "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"2", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"45", "*", 
               RowBox[{"(", 
                RowBox[{"3", "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"3", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"10", "*", 
               RowBox[{"(", 
                RowBox[{"4", "+", "x"}], ")"}]}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"5", "+", "x"}], ")"}], "/", 
             RowBox[{"E", "^", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"5", "+", "x"}], ")"}], "^", "2"}], "/", 
                RowBox[{"(", 
                 RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}]}], ")"}]}], 
         ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"2", "*", 
          RowBox[{"Sqrt", "[", "Pi", "]"}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], "*", "t"}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"5", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "5"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"10", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"4", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "4"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"45", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"3", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "3"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"120", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"2", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "2"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"210", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", "x"}], ")"}], "^", "2"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"210", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"1", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"120", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"2", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"45", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"3", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{"10", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "*", "t"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"4", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], "*", "t"}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "2"}]}], ")"}], 
           "*", 
           RowBox[{"Erf", "[", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"5", "-", "x"}], ")"}], "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
          RowBox[{"252", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", "*", "t"}], "+", 
             RowBox[{"x", "^", "2"}]}], ")"}], "*", 
           RowBox[{"Erf", "[", 
            RowBox[{"x", "/", 
             RowBox[{"(", 
              RowBox[{"2", "*", 
               RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}]}], ")"}], 
        "/", "4"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"DerivativeFilterKernelFunction", "[", 
    RowBox[{"9", ",", "8"}], "]"}], "=", " ", 
   RowBox[{"Compile", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "_Real"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"E", "^", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "5"}], "+", "x"}], ")"}], "^", "2"}]}], "/", 
              RowBox[{"(", 
               RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}], "-", 
           RowBox[{"10", "/", 
            RowBox[{"E", "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "4"}], "+", "x"}], ")"}], "^", "2"}], "/", 
               RowBox[{"(", 
                RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
           RowBox[{"45", "/", 
            RowBox[{"E", "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "3"}], "+", "x"}], ")"}], "^", "2"}], "/", 
               RowBox[{"(", 
                RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
           RowBox[{"120", "/", 
            RowBox[{"E", "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "2"}], "+", "x"}], ")"}], "^", "2"}], "/", 
               RowBox[{"(", 
                RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
           RowBox[{"210", "/", 
            RowBox[{"E", "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", "1"}], "+", "x"}], ")"}], "^", "2"}], "/", 
               RowBox[{"(", 
                RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
           RowBox[{"252", "/", 
            RowBox[{"E", "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"x", "^", "2"}], "/", 
               RowBox[{"(", 
                RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
           RowBox[{"210", "/", 
            RowBox[{"E", "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "+", "x"}], ")"}], "^", "2"}], "/", 
               RowBox[{"(", 
                RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
           RowBox[{"120", "/", 
            RowBox[{"E", "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"2", "+", "x"}], ")"}], "^", "2"}], "/", 
               RowBox[{"(", 
                RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
           RowBox[{"45", "/", 
            RowBox[{"E", "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"3", "+", "x"}], ")"}], "^", "2"}], "/", 
               RowBox[{"(", 
                RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "-", 
           RowBox[{"10", "/", 
            RowBox[{"E", "^", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"4", "+", "x"}], ")"}], "^", "2"}], "/", 
               RowBox[{"(", 
                RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], "+", 
           RowBox[{"E", "^", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"5", "+", "x"}], ")"}], "^", "2"}]}], "/", 
              RowBox[{"(", 
               RowBox[{"4", "*", "t"}], ")"}]}], ")"}]}]}], ")"}], "*", 
         RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}], "/", 
       RowBox[{"Sqrt", "[", "Pi", "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"5", "+", "x"}], ")"}], "*", 
            RowBox[{"Erf", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "5"}], "-", "x"}], ")"}], "/", 
              RowBox[{"(", 
               RowBox[{"2", "*", 
                RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], ")"}]}], 
         "+", 
         RowBox[{"10", "*", 
          RowBox[{"(", 
           RowBox[{"4", "+", "x"}], ")"}], "*", 
          RowBox[{"Erf", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "4"}], "-", "x"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
         RowBox[{"45", "*", 
          RowBox[{"(", 
           RowBox[{"3", "+", "x"}], ")"}], "*", 
          RowBox[{"Erf", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "3"}], "-", "x"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
         RowBox[{"120", "*", 
          RowBox[{"(", 
           RowBox[{"2", "+", "x"}], ")"}], "*", 
          RowBox[{"Erf", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "-", "x"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
         RowBox[{"210", "*", 
          RowBox[{"(", 
           RowBox[{"1", "+", "x"}], ")"}], "*", 
          RowBox[{"Erf", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "1"}], "-", "x"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
         RowBox[{"210", "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "x"}], ")"}], "*", 
          RowBox[{"Erf", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "-", "x"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
         RowBox[{"120", "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", "x"}], ")"}], "*", 
          RowBox[{"Erf", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", "-", "x"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
         RowBox[{"45", "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "3"}], "+", "x"}], ")"}], "*", 
          RowBox[{"Erf", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"3", "-", "x"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "+", 
         RowBox[{"10", "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "4"}], "+", "x"}], ")"}], "*", 
          RowBox[{"Erf", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"4", "-", "x"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "5"}], "+", "x"}], ")"}], "*", 
          RowBox[{"Erf", "[", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"5", "-", "x"}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}], "-", 
         RowBox[{"252", "*", "x", "*", 
          RowBox[{"Erf", "[", 
           RowBox[{"x", "/", 
            RowBox[{"(", 
             RowBox[{"2", "*", 
              RowBox[{"Sqrt", "[", "t", "]"}]}], ")"}]}], "]"}]}]}], ")"}], 
       "/", "2"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{
  3.495706885893561*^9, {3.495707342410225*^9, 3.4957073650980988`*^9}, {
   3.49570744972497*^9, 3.495707451013638*^9}, {3.495711812878689*^9, 
   3.495711813878645*^9}, {3.4957140201019297`*^9, 3.4957140964252987`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ImageDerivativeFilter", "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivativeFilter", "[", 
    RowBox[{"0", ",", "3"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "4", ",", "1"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivativeFilter", "[", 
    RowBox[{"1", ",", "3"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"3", ",", "0", ",", 
     RowBox[{"-", "3"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivativeFilter", "[", 
    RowBox[{"2", ",", "3"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"6", ",", 
     RowBox[{"-", "12"}], ",", "6"}], "}"}]}], ";"}]}], "PackageInput"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivativeFilter", "[", 
    RowBox[{"0", ",", "5"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "26", ",", "66", ",", "26", ",", "1"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivativeFilter", "[", 
    RowBox[{"1", ",", "5"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"5", ",", "50", ",", "0", ",", 
     RowBox[{"-", "50"}], ",", 
     RowBox[{"-", "5"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivativeFilter", "[", 
    RowBox[{"2", ",", "5"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"20", ",", "40", ",", 
     RowBox[{"-", "120"}], ",", "40", ",", "20"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivativeFilter", "[", 
    RowBox[{"3", ",", "5"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"60", ",", 
     RowBox[{"-", "120"}], ",", "0", ",", "120", ",", 
     RowBox[{"-", "60"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivativeFilter", "[", 
    RowBox[{"4", ",", "5"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"120", ",", 
     RowBox[{"-", "480"}], ",", "720", ",", 
     RowBox[{"-", "480"}], ",", "120"}], "}"}]}], ";"}]}], "PackageInput"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivativeFilter", "[", 
    RowBox[{"0", ",", "7"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "120", ",", "1191", ",", "2416", ",", "1191", ",", "120", ",", 
     "1"}], "}"}]}], ";", 
  RowBox[{
   RowBox[{"ImageDerivativeFilter", "[", 
    RowBox[{"1", ",", "7"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"7", ",", "392", ",", "1715", ",", "0", ",", 
     RowBox[{"-", "1715"}], ",", 
     RowBox[{"-", "392"}], ",", 
     RowBox[{"-", "7"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivativeFilter", "[", 
    RowBox[{"2", ",", "7"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"42", ",", "1008", ",", "630", ",", 
     RowBox[{"-", "3360"}], ",", "630", ",", "1008", ",", "42"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivativeFilter", "[", 
    RowBox[{"3", ",", "7"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"210", ",", "1680", ",", 
     RowBox[{"-", "3990"}], ",", "0", ",", "3990", ",", 
     RowBox[{"-", "1680"}], ",", 
     RowBox[{"-", "210"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivativeFilter", "[", 
    RowBox[{"4", ",", "7"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"840", ",", "0", ",", 
     RowBox[{"-", "7560"}], ",", "13440", ",", 
     RowBox[{"-", "7560"}], ",", "0", ",", "840"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivativeFilter", "[", 
    RowBox[{"5", ",", "7"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"2520", ",", 
     RowBox[{"-", "10080"}], ",", "12600", ",", "0", ",", 
     RowBox[{"-", "12600"}], ",", "10080", ",", 
     RowBox[{"-", "2520"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivativeFilter", "[", 
    RowBox[{"6", ",", "7"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"5040", ",", 
     RowBox[{"-", "30240"}], ",", "75600", ",", 
     RowBox[{"-", "100800"}], ",", "75600", ",", 
     RowBox[{"-", "30240"}], ",", "5040"}], "}"}]}], ";"}]}], "PackageInput"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivativeFilter", "[", 
    RowBox[{"0", ",", "9"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "502", ",", "14608", ",", "88234", ",", "156190", ",", "88234", 
     ",", "14608", ",", "502", ",", "1"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivativeFilter", "[", 
    RowBox[{"1", ",", "9"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"9", ",", "2214", ",", "36414", ",", "101934", ",", "0", ",", 
     RowBox[{"-", "101934"}], ",", 
     RowBox[{"-", "36414"}], ",", 
     RowBox[{"-", "2214"}], ",", 
     RowBox[{"-", "9"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivativeFilter", "[", 
    RowBox[{"2", ",", "9"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"72", ",", "8496", ",", "68544", ",", "11088", ",", 
     RowBox[{"-", "176400"}], ",", "11088", ",", "68544", ",", "8496", ",", 
     "72"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivativeFilter", "[", 
    RowBox[{"3", ",", "9"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"504", ",", "27216", ",", "67536", ",", 
     RowBox[{"-", "218736"}], ",", "0", ",", "218736", ",", 
     RowBox[{"-", "67536"}], ",", 
     RowBox[{"-", "27216"}], ",", 
     RowBox[{"-", "504"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivativeFilter", "[", 
    RowBox[{"4", ",", "9"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"3024", ",", "66528", ",", 
     RowBox[{"-", "96768"}], ",", 
     RowBox[{"-", "260064"}], ",", "574560", ",", 
     RowBox[{"-", "260064"}], ",", 
     RowBox[{"-", "96768"}], ",", "66528", ",", "3024"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivativeFilter", "[", 
    RowBox[{"5", ",", "9"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"15120", ",", "90720", ",", 
     RowBox[{"-", "514080"}], ",", "695520", ",", "0", ",", 
     RowBox[{"-", "695520"}], ",", "514080", ",", 
     RowBox[{"-", "90720"}], ",", 
     RowBox[{"-", "15120"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivativeFilter", "[", 
    RowBox[{"6", ",", "9"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"60480", ",", 
     RowBox[{"-", "120960"}], ",", 
     RowBox[{"-", "483840"}], ",", "2056320", ",", 
     RowBox[{"-", "3024000"}], ",", "2056320", ",", 
     RowBox[{"-", "483840"}], ",", 
     RowBox[{"-", "120960"}], ",", "60480"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivativeFilter", "[", 
    RowBox[{"7", ",", "9"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"181440", ",", 
     RowBox[{"-", "1088640"}], ",", "2540160", ",", 
     RowBox[{"-", "2540160"}], ",", "0", ",", "2540160", ",", 
     RowBox[{"-", "2540160"}], ",", "1088640", ",", 
     RowBox[{"-", "181440"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivativeFilter", "[", 
    RowBox[{"8", ",", "9"}], "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"362880", ",", 
     RowBox[{"-", "2903040"}], ",", "10160640", ",", 
     RowBox[{"-", "20321280"}], ",", "25401600", ",", 
     RowBox[{"-", "20321280"}], ",", "10160640", ",", 
     RowBox[{"-", "2903040"}], ",", "362880"}], "}"}]}], 
  ";"}]}], "PackageInput"]
}, Closed]],

Cell[CellGroupData[{

Cell["ImageDerivative1D", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ImageDerivative1D", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"ord", ":", 
         RowBox[{"(", 
          RowBox[{"1", "|", "3", "|", "5", "|", "7", "|", "9"}], ")"}]}], ",",
         "boundary_"}], "}"}], ",", 
      RowBox[{"depth_Integer:", "1"}]}], "]"}], "[", "img_", "]"}], ":=", 
   "img"}], ";"}]], "PackageInput"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivative", "::", "ordnotdef"}], "=", 
   "\"\<The B-spline order `1` is not implemented.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivative", "::", "ordtoolow"}], " ", "=", " ", 
   "\"\<A B-spline of order `1` does not support derivatives of \
`2`-order.\>\""}], ";"}]}], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ImageDerivative1D", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", 
        RowBox[{"ord_Integer", "?", "Positive"}], ",", "boundary_"}], "}"}], 
      ",", 
      RowBox[{"depth_Integer:", "1"}]}], "]"}], "[", "img_", "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Message", "[", 
       RowBox[{
        RowBox[{"ImageDerivative", "::", "ordnotdef"}], ",", "ord"}], "]"}], 
      ";", "$Failed"}], ")"}], " ", "/;", 
    RowBox[{
     RowBox[{"EvenQ", "[", "ord", "]"}], " ", "\[Or]", " ", 
     RowBox[{"ord", ">", "7"}]}]}]}], ";"}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ImageDerivative1D", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"n_", ",", 
        RowBox[{"ord", ":", 
         RowBox[{"(", 
          RowBox[{"1", "|", "3", "|", "5", "|", "7", "|", "9"}], ")"}]}], ",",
         "boundary_"}], "}"}], ",", 
      RowBox[{"depth_Integer:", "1"}]}], "]"}], "[", "img_", "]"}], ":=", " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Message", "[", 
       RowBox[{
        RowBox[{"ImageDerivative", "::", "ordtoolow"}], ",", "ord", ",", 
        "n"}], "]"}], ";", 
      RowBox[{"Array", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", "0.", ")"}], "&"}], ",", 
        RowBox[{"Dimensions", "[", "img", "]"}]}], "]"}]}], ")"}], " ", "/;", 
    
    RowBox[{"n", "\[GreaterEqual]", "ord"}]}]}], ";"}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivative1D", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"n_Integer", "?", "NonNegative"}], ",", 
       RowBox[{"ord", ":", 
        RowBox[{"(", 
         RowBox[{"1", "|", "3", "|", "5", "|", "7", "|", "9"}], ")"}]}], ",", 
       "boundary_"}], "}"}], ",", 
     RowBox[{"depth_Integer:", "1"}]}], "]"}], "[", "img_", "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"ListConvolve", "[", 
   RowBox[{
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Nest", "[", 
        RowBox[{"List", ",", "#", ",", 
         RowBox[{"depth", "-", "1"}]}], "]"}], "&"}], ",", 
      RowBox[{"ImageDerivativeFilter", "[", 
       RowBox[{"n", ",", "ord"}], "]"}]}], "]"}], ",", 
    RowBox[{"BSplineInterpolationFilter1D", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"ord", ",", "boundary", ",", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"ord", "-", "1"}], ")"}], "/", "2"}]}], "}"}], ",", "img"}],
      "]"}]}], "]"}]}]], "PackageInput"]
}, Closed]],

Cell[CellGroupData[{

Cell["ImageDerivative", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "ImageDerivative", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"ImageBoundary", "\[Rule]", " ", 
      RowBox[{"{", "Reflective", "}"}]}], ",", 
     RowBox[{"InterpolationOrder", "\[Rule]", " ", "5"}]}], "}"}]}], 
  ";"}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivative", "::", "toomanyn"}], " ", "=", " ", 
   "\"\<ImageDerivative encountered with more derivative indices than \
dimensions in the data.\>\""}], ";"}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivative", "[", 
    RowBox[{"ny_Integer", ",", "nx_Integer", ",", 
     RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], "[", 
   RowBox[{"img_", "?", "ImageQ"}], "]"}], ":=", 
  RowBox[{"Image", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"ImageDerivative", "[", 
      RowBox[{"ny", ",", "nx", ",", "opts"}], "]"}], "[", 
     RowBox[{"ImageData", "[", 
      RowBox[{"img", ",", 
       RowBox[{"Interleaving", "\[Rule]", " ", "True"}]}], "]"}], "]"}], ",", 
    
    RowBox[{"Sequence", "@@", 
     RowBox[{"Options", "[", "img", "]"}]}]}], "]"}]}]], "PackageInput",
 CellChangeTimes->{3.492862703374106*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivative", "[", 
    RowBox[{"ns__Integer", ",", 
     RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], "[", "img_List", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"dim", "=", 
       RowBox[{"TensorRank", "[", "img", "]"}]}], ",", 
      RowBox[{"nn", "=", 
       RowBox[{"Length", "[", 
        RowBox[{"{", "ns", "}"}], "]"}]}], ",", "dimrot", ",", 
      "\[IndentingNewLine]", 
      RowBox[{"bounds", " ", "=", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"ImageBoundary", " ", "/.", " ", 
          RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
         RowBox[{"Options", "[", "ImageDerivative", "]"}]}], ")"}]}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"orders", " ", "=", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"InterpolationOrder", "/.", 
          RowBox[{"{", "opts", "}"}]}], "/.", 
         RowBox[{"Options", "[", "ImageDerivative", "]"}]}], ")"}]}]}], "}"}],
     ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"dim", "<", "nn"}], ",", 
       RowBox[{
        RowBox[{"Message", "[", 
         RowBox[{"ImageDerivative", "::", "toomanyn"}], "]"}], ";", 
        RowBox[{"Return", "[", "$Failed", "]"}]}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Head", "[", "bounds", "]"}], "=!=", "List"}], ",", 
       RowBox[{"bounds", "=", 
        RowBox[{"{", "bounds", "}"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"bounds", "=", 
      RowBox[{"PadRight", "[", 
       RowBox[{"bounds", ",", "nn", ",", 
        RowBox[{"Last", "[", "bounds", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Head", "[", "orders", "]"}], "=!=", "List"}], ",", 
       RowBox[{"orders", "=", 
        RowBox[{"{", "orders", "}"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
     RowBox[{"orders", "=", 
      RowBox[{"PadRight", "[", 
       RowBox[{"orders", ",", "nn", ",", 
        RowBox[{"Last", "[", "orders", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"dimrot", "=", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"RotateRight", "[", 
         RowBox[{"Range", "[", "nn", "]"}], "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{
          RowBox[{"nn", "+", "1"}], ",", "dim"}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Fold", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"ImageDerivative1D", "[", 
            RowBox[{"#2", ",", "dim"}], "]"}], "[", "#1", "]"}], ",", 
          "dimrot"}], "]"}], "&"}], ",", "\[IndentingNewLine]", "img", ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "ns", "}"}], ",", "orders", ",", "bounds"}], "}"}], 
        "]"}]}], "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ImageDerivative", "[", 
    RowBox[{
     RowBox[{"ns", ":", 
      RowBox[{
       RowBox[{"{", "__Integer", "}"}], ".."}]}], ",", 
     RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], "[", "img_List", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"dim", "=", 
        RowBox[{"TensorRank", "[", "img", "]"}]}], ",", 
       RowBox[{"nn", "=", 
        RowBox[{"Last", "[", 
         RowBox[{"Dimensions", "[", 
          RowBox[{"{", "ns", "}"}], "]"}], "]"}]}], ",", "dimrot", ",", 
       "\[IndentingNewLine]", 
       RowBox[{"bounds", " ", "=", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"ImageBoundary", " ", "/.", " ", 
           RowBox[{"{", "opts", "}"}]}], " ", "/.", " ", 
          RowBox[{"Options", "[", "ImageDerivative", "]"}]}], ")"}]}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"orders", " ", "=", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"InterpolationOrder", "/.", 
           RowBox[{"{", "opts", "}"}]}], "/.", 
          RowBox[{"Options", "[", "ImageDerivative", "]"}]}], ")"}]}], ",", 
       "\[IndentingNewLine]", "filtered"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"dim", "<", "nn"}], ",", 
        RowBox[{
         RowBox[{"Message", "[", 
          RowBox[{"ImageDerivative", "::", "toomanyn"}], "]"}], ";", 
         RowBox[{"Return", "[", "$Failed", "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "bounds", "]"}], "=!=", "List"}], ",", 
        RowBox[{"bounds", "=", 
         RowBox[{"{", "bounds", "}"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"bounds", "=", 
       RowBox[{"PadRight", "[", 
        RowBox[{"bounds", ",", "nn", ",", 
         RowBox[{"Last", "[", "bounds", "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Head", "[", "orders", "]"}], "=!=", "List"}], ",", 
        RowBox[{"orders", "=", 
         RowBox[{"{", "orders", "}"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"orders", "=", 
       RowBox[{"PadRight", "[", 
        RowBox[{"orders", ",", "nn", ",", 
         RowBox[{"Last", "[", "orders", "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"dimrot", "=", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"RotateRight", "[", 
          RowBox[{"Range", "[", "nn", "]"}], "]"}], ",", 
         RowBox[{"Range", "[", 
          RowBox[{
           RowBox[{"nn", "+", "1"}], ",", "dim"}], "]"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"filtered", "=", 
       RowBox[{"Fold", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"Transpose", "[", 
           RowBox[{
            RowBox[{"BSplineInterpolationFilter1D", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                "#2", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
                ",", 
                RowBox[{
                "#2", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
                ",", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{
                   "#2", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], "-", "1"}], ")"}], "/", 
                 "2"}]}], "}"}], ",", "#1"}], "]"}], ",", "dimrot"}], "]"}], 
          "&"}], ",", "\[IndentingNewLine]", "img", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"orders", ",", "bounds"}], "}"}], "]"}]}], 
        "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Map", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"Fold", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{
            RowBox[{"Transpose", "[", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"ListConvolve", "[", 
               RowBox[{
                RowBox[{"Map", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Nest", "[", 
                    RowBox[{"List", ",", "#", ",", 
                    RowBox[{"dim", "-", "1"}]}], "]"}], "&"}], ",", 
                  RowBox[{"Evaluate", "[", 
                   RowBox[{"ImageDerivativeFilter", "[", 
                    RowBox[{
                    RowBox[{
                    "#2", "\[LeftDoubleBracket]", "1", 
                    "\[RightDoubleBracket]"}], ",", 
                    RowBox[{
                    "#2", "\[LeftDoubleBracket]", "2", 
                    "\[RightDoubleBracket]"}]}], "]"}], "]"}]}], "]"}], ",", 
                "#1"}], "]"}], ",", "dimrot"}], "]"}], "&"}], ",", 
           "\[IndentingNewLine]", "filtered", ",", "\[IndentingNewLine]", 
           RowBox[{"Transpose", "[", 
            RowBox[{"{", 
             RowBox[{"#", ",", "orders"}], "}"}], "]"}]}], 
          "\[IndentingNewLine]", "]"}], "&"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", "ns", "}"}]}], "\[IndentingNewLine]", "]"}]}]}], 
    "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{"MatrixQ", "[", 
    RowBox[{"{", "ns", "}"}], "]"}]}]}]], "PackageInput"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Closing Package", "Section"],

Cell["Closing the package and locking all the symbols.", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"End", "[", "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SetAttributes", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "ImageDerivative", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"Protected", ",", "ReadProtected"}], "}"}]}], 
    "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{"EndPackage", "[", "]"}]}], "PackageInput",
 InitializationCell->True]
}, Closed]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowSize->{1226, 971},
WindowMargins->{{150, Automatic}, {Automatic, 0}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
ShowSelection->True,
Magnification->1.5,
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (October 7, \
2010)",
StyleDefinitions->"PackageNotebook.nb",
PrivateNotebookOptions -> {"NotebookAuthor" -> ""}
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 41, 0, 144, "Title"],
Cell[611, 24, 100, 4, 118, "Subsubtitle"],
Cell[CellGroupData[{
Cell[736, 32, 25, 0, 72, "Section"],
Cell[764, 34, 985, 25, 654, "PackageInput"],
Cell[1752, 61, 128, 3, 87, "Text"],
Cell[1883, 66, 3257, 93, 1689, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[5177, 164, 32, 0, 40, "Section"],
Cell[5212, 166, 92, 2, 657, "Text"],
Cell[5307, 170, 476, 11, 3006, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[5820, 186, 42, 0, 40, "Section"],
Cell[5865, 188, 2331, 32, 187, "Text"],
Cell[8199, 222, 2388, 36, 816, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[10624, 263, 31, 0, 40, "Section"],
Cell[10658, 265, 60, 0, 39, "Text"],
Cell[10721, 267, 108, 2, 60, "PackageInput",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[10854, 273, 49, 0, 63, "Subsection"],
Cell[10906, 275, 202, 6, 39, "Text"],
Cell[11111, 283, 2796, 81, 153, "Input"],
Cell[13910, 366, 16866, 494, 707, "Input"],
Cell[30779, 862, 47133, 1326, 1721, "Input"],
Cell[77915, 2190, 98395, 2740, 3218, "Input"],
Cell[176313, 4932, 177986, 4850, 5980, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[354336, 9787, 43, 0, 63, "Subsection"],
Cell[354382, 9789, 657, 21, 107, "PackageInput"],
Cell[355042, 9812, 1293, 39, 153, "PackageInput"],
Cell[356338, 9853, 2109, 60, 199, "PackageInput"],
Cell[358450, 9915, 3346, 91, 314, "PackageInput"]
}, Closed]],
Cell[CellGroupData[{
Cell[361833, 10011, 39, 0, 37, "Subsection"],
Cell[361875, 10013, 424, 13, 63, "PackageInput"],
Cell[362302, 10028, 383, 10, 107, "PackageInput"],
Cell[362688, 10040, 663, 20, 85, "PackageInput"],
Cell[363354, 10062, 854, 26, 86, "PackageInput"],
Cell[364211, 10090, 1056, 31, 133, "PackageInput"]
}, Closed]],
Cell[CellGroupData[{
Cell[365304, 10126, 37, 0, 37, "Subsection"],
Cell[365344, 10128, 314, 9, 60, "PackageInput"],
Cell[365661, 10139, 228, 5, 84, "PackageInput"],
Cell[365892, 10146, 664, 18, 85, "PackageInput"],
Cell[366559, 10166, 3225, 86, 430, "PackageInput"],
Cell[369787, 10254, 5560, 141, 683, "PackageInput"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[375396, 10401, 34, 0, 72, "Section"],
Cell[375433, 10403, 64, 0, 657, "Text"],
Cell[375500, 10405, 499, 12, 3786, "PackageInput",
 InitializationCell->True]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
