(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     57061,       1555]
NotebookOptionsPosition[     54298,       1462]
NotebookOutlinePosition[     54720,       1480]
CellTagsIndexPosition[     54677,       1477]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Image Frame Package", "Title"],

Cell["\<\
Markus van Almsick
Technische Universiteit Eindhoven
\[Copyright]2006-\[Copyright]2008\
\>", "Subsubtitle"],

Cell[CellGroupData[{

Cell["Prefix", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "TimeSamp", " ", "for", " ", "Package", " ", "Version", " ", "Control"}], 
   " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Unprotect", "[", "TimeStamp", "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"TimeStamp", "::", "usage"}], "=", 
     "\"\<TimeStamp[context] should be set to a Date[]-List indicating the \
version of the corresponding package.\>\""}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"TimeStamp", "[", "\"\<MathVisionTools`ImageFrame`\>\"", "]"}], 
     " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{"2008", ",", "8", ",", "9", ",", "11", ",", "30", ",", "0"}], 
      "}"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Protect", "[", "TimeStamp", "]"}], ";"}]}]}]], "PackageInput"],

Cell["\<\
The preamble of the package containing all kinds of remarks about authorship, \
contence, and copyright.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Name", ":", " ", "MathVisionTools`ImageFrame`"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Author", ":", " ", 
     RowBox[{"Markus", " ", "van", " ", "Almsick"}]}]}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Email", " ", 
     RowBox[{"address", ":", " ", 
      RowBox[{"M", ".", "v", ".", 
       RowBox[{"Almsick", "@", "tue"}], ".", "nl"}]}]}]}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Context", ":", " ", "MathVisionTools`ImageFrame`"}]}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Package", " ", 
     RowBox[{"Version", ":", " ", "1.3"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Mathematica", " ", 
     RowBox[{"Version", ":", " ", "5.0"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"Copyright", ":", " ", 
      RowBox[{"Copyright", " ", "2004"}]}]}], ",", " ", 
    RowBox[{"Technische", " ", "Universiteit", " ", "Eindhoven"}]}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"Title", ":", " ", "Padding"}]}], ",", " ", "Frame", ",", " ", 
    "Boundary"}], " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"Summary", ":", " ", 
      RowBox[{
      "This", " ", "package", " ", "implements", " ", "the", " ", 
       "ImageFrame", " ", "function"}]}]}], ",", " ", 
    RowBox[{
     RowBox[{
     "which", " ", "wraps", " ", "a", " ", "frame", " ", "around", " ", "an", 
      " ", "n"}], "-", 
     RowBox[{"dimensional", " ", "dataset", " ", "with", " ", "scalar"}]}], 
    ",", " ", "vectorial", ",", " ", 
    RowBox[{"or", " ", "tensorial", " ", "data", " ", 
     RowBox[{"values", ".", " ", "The"}], " ", "frame", " ", "can", " ", 
     "emulate", " ", "cylcic"}], ",", " ", "reflective", ",", " ", 
    RowBox[{"and", " ", "constant", " ", "boundary", " ", 
     RowBox[{"conditions", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"Keywords", ":", " ", "Padding"}]}], ",", " ", "Frame", ",", " ",
     "Boundary"}], " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Requirements", ":", " ", "None"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Source", ":", " ", "None"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"History", ":", " ", 
      RowBox[{
      "Version", " ", "1.0", " ", "by", " ", "Markus", " ", "van", " ", 
       "Almsick"}]}]}], ",", " ", 
    RowBox[{"November", " ", "2003"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Limitations", ":"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Discussion", ":"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"To", " ", 
     RowBox[{"do", ":"}]}]}], " ", "*)"}]}]], "PackageInput",
 InitializationCell->True],

Cell["System command fix:", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Unprotect", "[", "Take", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Take", "[", 
   RowBox[{"expr_List", ",", "seq___", ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", 
      RowBox[{"_", "?", "Positive"}], ",", 
      RowBox[{"-", "1"}]}], "}"}], ",", "___"}], "]"}], " ", ":=", 
  RowBox[{"Replace", "[", 
   RowBox[{
    RowBox[{"Take", "[", 
     RowBox[{"expr", ",", "seq"}], "]"}], ",", 
    RowBox[{"_List", "\[Rule]", " ", 
     RowBox[{"{", "}"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"Length", "[", 
      RowBox[{"{", "seq", "}"}], "]"}], "}"}]}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"Take", "[", 
   RowBox[{"expr_List", ",", "seq___", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"_", "?", "Negative"}], ",", "0", ",", 
      RowBox[{"-", "1"}]}], "}"}], ",", "___"}], "]"}], " ", ":=", 
  RowBox[{"Replace", "[", 
   RowBox[{
    RowBox[{"Take", "[", 
     RowBox[{"expr", ",", "seq"}], "]"}], ",", 
    RowBox[{"_List", "\[Rule]", " ", 
     RowBox[{"{", "}"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"Length", "[", 
      RowBox[{"{", "seq", "}"}], "]"}], "}"}]}], "]"}]}], "\n", 
 RowBox[{
  RowBox[{"Protect", "[", "Take", "]"}], ";"}]}], "PackageInput"]
}, Closed]],

Cell[CellGroupData[{

Cell["Begin Package", "Section"],

Cell["\<\
Declaring the package and unlocking all symbols defined in the code.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"BeginPackage", "[", "\[IndentingNewLine]", 
   RowBox[{
   "\"\<MathVisionTools`ImageFrame`\>\"", ",", "\[IndentingNewLine]", 
    "\"\<MathVisionTools`Common`MathVisionToolsCommon`\>\""}], 
   "\[IndentingNewLine]", "]"}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{"Unprotect", "[", "\[IndentingNewLine]", 
  RowBox[{
  "ImageFrame", ",", "\[IndentingNewLine]", "RemoveImageFrame", ",", 
   "\[IndentingNewLine]", "ImageFrame1D", ",", "\[IndentingNewLine]", 
   "ImageBoundary", ",", "\[IndentingNewLine]", "Cyclic", ",", 
   "\[IndentingNewLine]", "Truncate", ",", "\[IndentingNewLine]", 
   "Reflective", ",", "\[IndentingNewLine]", "Constant"}], 
  "\[IndentingNewLine]", "]"}]}], "PackageInput",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Online Help and Options", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ImageFrame", "::", "usage"}], "=", 
   "\"\<ImageFrame[data, d, opts] wraps a frame around an n-dimensional data \
set with width d. The frame type is specified by the ImageBoundary option. \
ImageFrame[data, d, level, opts] applies a frame to the specified level only. \
Width d can also be a List of {left, right} width specifications for each \
data level respectively. Note that the sequence of these level specifications \
are in reverse order to the intuative x,y,z-order exhibited when plotting the \
data. The default ImageBoundary is Cyclic emulating cylcic boundary \
conditions. Other types are Reflective, Truncate, and Constant. These type \
spcifications can also be given in a List for each data level respectively.\>\
\""}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"RemoveImageFrame", "::", "usage"}], "=", 
   "\"\<ImageFrame[data, d, opts] removes a frame of width d around an \
n-dimensional data set. RemoveImageFrame[data, d, level, opts] removes a \
frame at the specified level only. Width d can also be a List of {left, \
right} width specifications for each data level respectively. Note that the \
sequence of these level specifications are in reverse order to the intuative \
x,y,z-order exhibited when plotting the data.\>\""}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImageFrame1D", "::", "usage"}], "=", 
   "\"\<ImageFrame1D[data, {{widthLeft, widthRight}, level, mode}] adds a \
frame around an n-dimensional data set at the given level with width \
{widthLeft, widthRight} in the modes Cyclic, Truncate, Constant, or \
Refelctive.\>\""}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Head", "[", 
      RowBox[{"ImageBoundary", "::", "usage"}], "]"}], "===", "MessageName"}],
     ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ImageBoundary", "::", "usage"}], "=", 
     "\"\<ImageBoundary is an option of ImageFrame to determine the frame \
type.\>\""}], ",", "\[IndentingNewLine]", 
    RowBox[{"If", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Not", "[", 
       RowBox[{"StringMatchQ", "[", 
        RowBox[{
         RowBox[{"ImageBoundary", "::", "usage"}], ",", 
         "\"\<*ImageFrame*\>\""}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ImageBoundary", "::", "usage"}], "=", 
       RowBox[{
        RowBox[{"ImageBoundary", "::", "usage"}], "<>", 
        "\"\<\\nImageBoundary is also an option of ImageFrame to specify the \
frame type.\>\""}]}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]",
    "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Head", "[", 
      RowBox[{"Cyclic", "::", "usage"}], "]"}], "===", "MessageName"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Cyclic", "::", "usage"}], "=", 
     "\"\<Is a value for the ImageFrame option ImageBoundary. It generates a \
frame with cyclic image values.\>\""}], ",", "\[IndentingNewLine]", 
    RowBox[{"If", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Not", "[", 
       RowBox[{"StringMatchQ", "[", 
        RowBox[{
         RowBox[{"Cyclic", "::", "usage"}], ",", "\"\<*ImageFrame*\>\""}], 
        "]"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Cyclic", "::", "usage"}], "=", 
       RowBox[{
        RowBox[{"Cyclic", "::", "usage"}], "<>", 
        "\"\<\\nIt is also a value for the ImageFrame option ImageBoundary. \
It generates a frame with cyclic image values.\>\""}]}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Head", "[", 
      RowBox[{"Truncate", "::", "usage"}], "]"}], "===", "MessageName"}], ",",
     "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Truncate", "::", "usage"}], "=", 
     "\"\<Is a value for the ImageFrame option ImageBoundary. It generates a \
frame with zero image values.\>\""}], ",", "\[IndentingNewLine]", 
    RowBox[{"If", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Not", "[", 
       RowBox[{"StringMatchQ", "[", 
        RowBox[{
         RowBox[{"Truncate", "::", "usage"}], ",", "\"\<*ImageFrame*\>\""}], 
        "]"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Truncate", "::", "usage"}], "=", 
       RowBox[{
        RowBox[{"Truncate", "::", "usage"}], "<>", 
        "\"\<\\nIt is also a value for the ImageFrame option ImageBoundary. \
It generates a frame with zero image values.\>\""}]}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Head", "[", 
      RowBox[{"Reflective", "::", "usage"}], "]"}], "===", "MessageName"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Reflective", "::", "usage"}], "=", 
     "\"\<Is a value for the ImageFrame option ImageBoundary. It generates a \
frame with reflected image values.\>\""}], ",", "\[IndentingNewLine]", 
    RowBox[{"If", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Not", "[", 
       RowBox[{"StringMatchQ", "[", 
        RowBox[{
         RowBox[{"Reflective", "::", "usage"}], ",", "\"\<*ImageFrame*\>\""}],
         "]"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Reflective", "::", "usage"}], "=", 
       RowBox[{
        RowBox[{"Reflective", "::", "usage"}], "<>", 
        "\"\<\\nIt is also a value for the ImageFrame option ImageBoundary. \
It generates a frame with reflected image values.\>\""}]}]}], 
     "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Not", "[", 
     RowBox[{"StringMatchQ", "[", 
      RowBox[{
       RowBox[{"Constant", "::", "usage"}], ",", "\"\<*ImageFrame*\>\""}], 
      "]"}], "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Constant", "::", "usage"}], "=", 
     RowBox[{
      RowBox[{"Constant", "::", "usage"}], "<>", 
      "\"\<\\nIt is also a value for the ImageFrame option ImageBoundary. It \
generates a frame by extending the value of each boundary pixel as a constant \
across the frame.\>\""}]}]}], "\[IndentingNewLine]", "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "ImageFrame", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"ImageBoundary", " ", "\[Rule]", " ", "Cyclic"}], "}"}]}], 
  ";"}]}], "PackageInput",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Package Code", "Section"],

Cell["Starting the private context of the package.", "Text"],

Cell[BoxData[
 RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}]], "PackageInput",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["RemoveImageFrame", "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"RemoveImageFrame", "[", 
     RowBox[{"img_List", ",", 
      RowBox[{"0", "|", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"0", "|", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}]}], ")"}], ".."}], "}"}]}], ",", 
      "___"}], "]"}], "=", "img"}], ";"}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"RemoveImageFrame", "[", 
     RowBox[{"img_List", ",", "width_", ",", "opts___Rule"}], "]"}], ":=", 
    RowBox[{"RemoveImageFrame", "[", 
     RowBox[{"img", ",", "width", ",", 
      RowBox[{"Range", "[", 
       RowBox[{"TensorRank", "[", "img", "]"}], "]"}], ",", "opts"}], "]"}]}],
    ";"}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"RemoveImageFrame", "[", 
     RowBox[{"img_List", ",", "width_", ",", 
      RowBox[{"maxrank_Integer", "?", "Positive"}], ",", "opts___Rule"}], 
     "]"}], ":=", 
    RowBox[{"RemoveImageFrame", "[", 
     RowBox[{"img", ",", "width", ",", 
      RowBox[{"Range", "[", "maxrank", "]"}], ",", "opts"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"RemoveImageFrame", "[", 
    RowBox[{"img_List", ",", "width_", ",", "All", ",", "opts___Rule"}], 
    "]"}], ":=", 
   RowBox[{"RemoveImageFrame", "[", 
    RowBox[{"img", ",", "width", ",", 
     RowBox[{"Range", "[", 
      RowBox[{"TensorRank", "[", "img", "]"}], "]"}], ",", "opts"}], "]"}]}], 
  ";"}]}], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"RemoveImageFrame", "[", 
    RowBox[{"img_List", ",", "width_", ",", 
     RowBox[{"ranks", ":", 
      RowBox[{"{", 
       RowBox[{"firstRank__Integer", "?", "Positive"}], "}"}]}], ",", 
     "opts___Rule"}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"rng", "=", 
       RowBox[{"Table", "[", 
        RowBox[{"All", ",", 
         RowBox[{"{", 
          RowBox[{"Max", "[", "ranks", "]"}], "}"}]}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{
       "rng", "\[LeftDoubleBracket]", "ranks", "\[RightDoubleBracket]"}], "=",
        "\[IndentingNewLine]", 
       RowBox[{"Map", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"Switch", "[", 
           RowBox[{"#", ",", 
            RowBox[{"_Integer", "?", "Positive"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"#", "+", "1"}], ",", 
              RowBox[{
               RowBox[{"-", "#"}], "-", "1"}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"_", ",", "_"}], "}"}], ",", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"1", ",", 
               RowBox[{"-", "1"}]}], "}"}], 
             RowBox[{"(", 
              RowBox[{"#", "+", "1"}], ")"}]}], ",", "_", ",", "All"}], "]"}],
           "&"}], ",", 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Head", "[", "width", "]"}], "===", "List"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"PadRight", "[", 
            RowBox[{"width", ",", 
             RowBox[{"Length", "[", "ranks", "]"}], ",", "width"}], "]"}], 
           ",", "\[IndentingNewLine]", 
           RowBox[{"PadRight", "[", 
            RowBox[{
             RowBox[{"{", "width", "}"}], ",", 
             RowBox[{"Length", "[", "ranks", "]"}], ",", 
             RowBox[{"{", "width", "}"}]}], "]"}]}], "\[IndentingNewLine]", 
          "]"}]}], "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", "rng", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Apply", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Take", "[", 
          RowBox[{"img", ",", "##"}], "]"}], "&"}], ",", "rng"}], "]"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "PackageInput",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ImageFrame", "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ImageFrame", "[", 
     RowBox[{"img_List", ",", 
      RowBox[{"0", "|", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"0", "|", 
           RowBox[{"{", 
            RowBox[{"0", ",", "0"}], "}"}]}], ")"}], ".."}], "}"}]}], ",", 
      "___"}], "]"}], "=", "img"}], ";"}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ImageFrame", "[", 
     RowBox[{"img_List", ",", "width_", ",", "opts___Rule"}], "]"}], ":=", 
    RowBox[{"ImageFrame", "[", 
     RowBox[{"img", ",", "width", ",", 
      RowBox[{"Range", "[", 
       RowBox[{"TensorRank", "[", "img", "]"}], "]"}], ",", "opts"}], "]"}]}],
    ";"}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ImageFrame", "[", 
     RowBox[{"img_List", ",", "width_", ",", 
      RowBox[{"maxrank_Integer", "?", "Positive"}], ",", "opts___Rule"}], 
     "]"}], ":=", 
    RowBox[{"ImageFrame", "[", 
     RowBox[{"img", ",", "width", ",", 
      RowBox[{"Range", "[", "maxrank", "]"}], ",", "opts"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"ImageFrame", "[", 
    RowBox[{"img_List", ",", "width_", ",", "All", ",", "opts___Rule"}], 
    "]"}], ":=", 
   RowBox[{"ImageFrame", "[", 
    RowBox[{"img", ",", "width", ",", 
     RowBox[{"Range", "[", 
      RowBox[{"TensorRank", "[", "img", "]"}], "]"}], ",", "opts"}], "]"}]}], 
  ";"}]}], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ImageFrame", "[", 
    RowBox[{"img_List", ",", "width_", ",", 
     RowBox[{"ranks", ":", 
      RowBox[{"{", 
       RowBox[{"firstRank__Integer", "?", "Positive"}], "}"}]}], ",", 
     "opts___Rule"}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"type", "=", 
       RowBox[{
        RowBox[{"ImageBoundary", " ", "/.", " ", 
         RowBox[{"{", "opts", "}"}]}], "/.", "  ", 
        RowBox[{"Options", "[", "ImageFrame", "]"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Fold", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"ImageFrame1D", "[", 
         RowBox[{"#1", ",", "#2"}], "]"}], "&"}], ",", "\[IndentingNewLine]", 
       "img", ",", "\[IndentingNewLine]", 
       RowBox[{"Transpose", "[", 
        RowBox[{"{", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Map", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"Round", "[", 
              RowBox[{"If", "[", 
               RowBox[{
                RowBox[{"NumericQ", "[", "#", "]"}], ",", 
                RowBox[{"{", 
                 RowBox[{"#", ",", "#"}], "}"}], ",", "#"}], "]"}], "]"}], 
             "&"}], ",", "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Head", "[", "width", "]"}], "===", "List"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"PadRight", "[", 
               RowBox[{"width", ",", 
                RowBox[{"Length", "[", "ranks", "]"}], ",", "width"}], "]"}], 
              ",", "\[IndentingNewLine]", 
              RowBox[{"PadRight", "[", 
               RowBox[{
                RowBox[{"{", "width", "}"}], ",", 
                RowBox[{"Length", "[", "ranks", "]"}], ",", 
                RowBox[{"{", "width", "}"}]}], "]"}]}], "\[IndentingNewLine]",
              "]"}]}], "\[IndentingNewLine]", "]"}], ",", 
          "\[IndentingNewLine]", "ranks", ",", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Head", "[", "type", "]"}], "===", "List"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"PadRight", "[", 
             RowBox[{"type", ",", 
              RowBox[{"Length", "[", "ranks", "]"}], ",", "type"}], "]"}], 
            ",", "\[IndentingNewLine]", 
            RowBox[{"PadRight", "[", 
             RowBox[{
              RowBox[{"{", "type", "}"}], ",", 
              RowBox[{"Length", "[", "ranks", "]"}], ",", 
              RowBox[{"{", "type", "}"}]}], "]"}]}], "\[IndentingNewLine]", 
           "]"}]}], "\[IndentingNewLine]", "}"}], "]"}]}], 
      "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]], "PackageInput",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["ImageFrame1D", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ImageFrame1D", "[", 
    RowBox[{"img_List", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", 
       RowBox[{"rank_Integer", "?", "Positive"}], ",", "_"}], "}"}]}], "]"}], 
   ":=", "img"}], ";"}]], "PackageInput",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["Reflective Boundary", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ImageFrame1D", "[", 
     RowBox[{"img_List", ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"widthRight_Integer", "?", "Positive"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"rank_Integer", "?", "Positive"}], ",", "\[IndentingNewLine]",
         "Reflective"}], "}"}]}], "]"}], ":=", "\[IndentingNewLine]", 
    RowBox[{"With", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"w", " ", "=", " ", 
        RowBox[{
         RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
         "rank", "\[RightDoubleBracket]"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Apply", "[", "\[IndentingNewLine]", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"MapThread", "[", "\[IndentingNewLine]", 
          RowBox[{"Join", ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"##", ",", "\[IndentingNewLine]", 
             RowBox[{"If", "[", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"EvenQ", "[", 
                RowBox[{"Quotient", "[", 
                 RowBox[{"widthRight", ",", "w"}], "]"}], "]"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{
                 RowBox[{"Take", "[", 
                  RowBox[{"img", ",", "##"}], "]"}], "&"}], "@@", 
                RowBox[{"PadLeft", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "1"}], ",", 
                    RowBox[{"-", 
                    RowBox[{"Mod", "[", 
                    RowBox[{"widthRight", ",", "w"}], "]"}]}], ",", 
                    RowBox[{"-", "1"}]}], "}"}], "}"}], ",", "rank", ",", 
                  "All"}], "]"}]}], ",", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{
                 RowBox[{"Take", "[", 
                  RowBox[{"img", ",", "##"}], "]"}], "&"}], "@@", 
                RowBox[{"PadLeft", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{"1", ",", 
                    RowBox[{"Mod", "[", 
                    RowBox[{"widthRight", ",", "w"}], "]"}], ",", "1"}], 
                    "}"}], "}"}], ",", "rank", ",", "All"}], "]"}]}]}], 
              "\[IndentingNewLine]", "]"}]}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"rank", "-", "1"}]}], "\[IndentingNewLine]", "]"}], "&"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"{", "img", "}"}], ",", 
            RowBox[{"PadRight", "[", 
             RowBox[{
              RowBox[{"{", "}"}], ",", 
              RowBox[{"Quotient", "[", 
               RowBox[{"widthRight", ",", "w"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"#", ",", "img"}], "}"}]}], "]"}]}], "]"}], "&"}], "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Take", "[", 
            RowBox[{"img", ",", "##"}], "]"}], "&"}], "@@", 
          RowBox[{"PadLeft", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1", ",", 
               RowBox[{"-", "1"}]}], "}"}], "}"}], ",", "rank", ",", "All"}], 
           "]"}]}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ImageFrame1D", "[", 
     RowBox[{"img_List", ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"widthLeft_Integer", "?", "Positive"}], ",", "0"}], "}"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"rank_Integer", "?", "Positive"}], ",", "\[IndentingNewLine]",
         "Reflective"}], "}"}]}], "]"}], ":=", "\[IndentingNewLine]", 
    RowBox[{"With", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"w", " ", "=", " ", 
        RowBox[{
         RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
         "rank", "\[RightDoubleBracket]"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"Apply", "[", "\[IndentingNewLine]", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"MapThread", "[", "\[IndentingNewLine]", 
          RowBox[{"Join", ",", "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"If", "[", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"EvenQ", "[", 
                RowBox[{"Quotient", "[", 
                 RowBox[{"widthLeft", ",", "w"}], "]"}], "]"}], ",", 
               "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{
                 RowBox[{"Take", "[", 
                  RowBox[{"img", ",", "##"}], "]"}], "&"}], "@@", 
                RowBox[{"PadLeft", "[", 
                 RowBox[{
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{"widthLeft", "===", "0"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", "0"}], "}"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Mod", "[", 
                    RowBox[{"widthLeft", ",", "w"}], "]"}], ",", "1", ",", 
                    RowBox[{"-", "1"}]}], "}"}], "}"}]}], "]"}], ",", "rank", 
                  ",", "All"}], "]"}]}], ",", "\[IndentingNewLine]", 
               RowBox[{
                RowBox[{
                 RowBox[{"Take", "[", 
                  RowBox[{"img", ",", "##"}], "]"}], "&"}], "@@", 
                RowBox[{"PadLeft", "[", 
                 RowBox[{
                  RowBox[{"{", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Mod", "[", 
                    RowBox[{"widthLeft", ",", "w"}], "]"}]}], ",", 
                    RowBox[{"-", "1"}], ",", "1"}], "}"}], "}"}], ",", "rank",
                   ",", "All"}], "]"}]}]}], "\[IndentingNewLine]", "]"}], ",",
              "\[IndentingNewLine]", "##"}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"rank", "-", "1"}]}], "\[IndentingNewLine]", "]"}], "&"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"PadLeft", "[", 
             RowBox[{
              RowBox[{"{", "}"}], ",", 
              RowBox[{"Quotient", "[", 
               RowBox[{"widthLeft", ",", "w"}], "]"}], ",", 
              RowBox[{"{", 
               RowBox[{"img", ",", "#"}], "}"}]}], "]"}], ",", 
            RowBox[{"{", "img", "}"}]}], "]"}], "&"}], "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Take", "[", 
            RowBox[{"img", ",", "##"}], "]"}], "&"}], "@@", 
          RowBox[{"PadLeft", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"-", "1"}], ",", "1", ",", 
               RowBox[{"-", "1"}]}], "}"}], "}"}], ",", "rank", ",", "All"}], 
           "]"}]}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImageFrame1D", "[", 
    RowBox[{"img_List", ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"widthLeft_Integer", "?", "Positive"}], ",", 
         RowBox[{"widthRight_Integer", "?", "Positive"}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"rank_Integer", "?", "Positive"}], ",", "\[IndentingNewLine]", 
       "Reflective"}], "}"}]}], "]"}], ":=", "\[IndentingNewLine]", 
   RowBox[{"With", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"w", " ", "=", " ", 
       RowBox[{
        RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
        "rank", "\[RightDoubleBracket]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Apply", "[", "\[IndentingNewLine]", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"MapThread", "[", "\[IndentingNewLine]", 
         RowBox[{"Join", ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"If", "[", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"EvenQ", "[", 
               RowBox[{"Quotient", "[", 
                RowBox[{"widthLeft", ",", "w"}], "]"}], "]"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{"Take", "[", 
                 RowBox[{"img", ",", "##"}], "]"}], "&"}], "@@", 
               RowBox[{"PadLeft", "[", 
                RowBox[{
                 RowBox[{"If", "[", 
                  RowBox[{
                   RowBox[{"widthLeft", "===", "0"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{"1", ",", "0"}], "}"}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Mod", "[", 
                    RowBox[{"widthLeft", ",", "w"}], "]"}], ",", "1", ",", 
                    RowBox[{"-", "1"}]}], "}"}], "}"}]}], "]"}], ",", "rank", 
                 ",", "All"}], "]"}]}], ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{"Take", "[", 
                 RowBox[{"img", ",", "##"}], "]"}], "&"}], "@@", 
               RowBox[{"PadLeft", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"-", 
                    RowBox[{"Mod", "[", 
                    RowBox[{"widthLeft", ",", "w"}], "]"}]}], ",", 
                    RowBox[{"-", "1"}], ",", "1"}], "}"}], "}"}], ",", "rank",
                  ",", "All"}], "]"}]}]}], "\[IndentingNewLine]", "]"}], ",", 
            "\[IndentingNewLine]", "##", ",", "\[IndentingNewLine]", 
            RowBox[{"If", "[", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"EvenQ", "[", 
               RowBox[{"Quotient", "[", 
                RowBox[{"widthRight", ",", "w"}], "]"}], "]"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{"Take", "[", 
                 RowBox[{"img", ",", "##"}], "]"}], "&"}], "@@", 
               RowBox[{"PadLeft", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"-", "1"}], ",", 
                    RowBox[{"-", 
                    RowBox[{"Mod", "[", 
                    RowBox[{"widthRight", ",", "w"}], "]"}]}], ",", 
                    RowBox[{"-", "1"}]}], "}"}], "}"}], ",", "rank", ",", 
                 "All"}], "]"}]}], ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{"Take", "[", 
                 RowBox[{"img", ",", "##"}], "]"}], "&"}], "@@", 
               RowBox[{"PadLeft", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"{", 
                   RowBox[{"1", ",", 
                    RowBox[{"Mod", "[", 
                    RowBox[{"widthRight", ",", "w"}], "]"}], ",", "1"}], 
                   "}"}], "}"}], ",", "rank", ",", "All"}], "]"}]}]}], 
             "\[IndentingNewLine]", "]"}]}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"rank", "-", "1"}]}], "\[IndentingNewLine]", "]"}], "&"}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"Join", "[", 
          RowBox[{
           RowBox[{"PadLeft", "[", 
            RowBox[{
             RowBox[{"{", "}"}], ",", 
             RowBox[{"Quotient", "[", 
              RowBox[{"widthLeft", ",", "w"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"img", ",", "#"}], "}"}]}], "]"}], ",", 
           RowBox[{"{", "img", "}"}], ",", 
           RowBox[{"PadRight", "[", 
            RowBox[{
             RowBox[{"{", "}"}], ",", 
             RowBox[{"Quotient", "[", 
              RowBox[{"widthRight", ",", "w"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"#", ",", "img"}], "}"}]}], "]"}]}], "]"}], "&"}], "[", 
        
        RowBox[{
         RowBox[{
          RowBox[{"Take", "[", 
           RowBox[{"img", ",", "##"}], "]"}], "&"}], "@@", 
         RowBox[{"PadLeft", "[", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "1"}], ",", "1", ",", 
              RowBox[{"-", "1"}]}], "}"}], "}"}], ",", "rank", ",", "All"}], 
          "]"}]}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]}], "PackageInput",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Cyclic Boundary", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ImageFrame1D", "[", "\[IndentingNewLine]", 
    RowBox[{"img_List", ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"widthLeft_Integer", "?", "NonNegative"}], ",", 
         RowBox[{"widthRight_Integer", "?", "NonNegative"}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"rank_Integer", "?", "Positive"}], ",", " ", 
       "\[IndentingNewLine]", "Cyclic"}], "}"}]}], "]"}], ":=", 
   "\[IndentingNewLine]", 
   RowBox[{"With", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"w", " ", "=", " ", 
       RowBox[{
        RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
        "rank", "\[RightDoubleBracket]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", " ", 
     RowBox[{"Apply", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"MapThread", "[", "\[IndentingNewLine]", 
         RowBox[{"Join", ",", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Take", "[", 
               RowBox[{"img", ",", "##"}], "]"}], "&"}], "@@", 
             RowBox[{"PadLeft", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"Mod", "[", 
                    RowBox[{"widthLeft", ",", "w"}], "]"}]}], ",", 
                  RowBox[{"-", "1"}]}], "}"}], "}"}], ",", "rank", ",", 
               "All"}], "]"}]}], ",", "\[IndentingNewLine]", "##", ",", 
            "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"Take", "[", 
               RowBox[{"img", ",", "##"}], "]"}], "&"}], "@@", 
             RowBox[{"PadLeft", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"{", 
                 RowBox[{"1", ",", 
                  RowBox[{"Mod", "[", 
                   RowBox[{"widthRight", ",", "w"}], "]"}]}], "}"}], "}"}], 
               ",", "rank", ",", "All"}], "]"}]}]}], "}"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"rank", "-", "1"}]}], "\[IndentingNewLine]", "]"}], "&"}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"Table", "[", 
        RowBox[{"img", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Quotient", "[", 
            RowBox[{"widthLeft", ",", "w"}], "]"}], "+", 
           RowBox[{"Quotient", "[", 
            RowBox[{"widthRight", ",", "w"}], "]"}], "+", "1"}], "}"}]}], 
        "]"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "PackageInput",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Numeric Boundary", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ImageFrame1D", "[", "\[IndentingNewLine]", 
     RowBox[{"img_List", ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"width_Integer", "?", "NonNegative"}], ",", "width_"}], 
         "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{"rank_Integer", "?", "Positive"}], ",", "\[IndentingNewLine]", 
        RowBox[{"b_", "?", "NumericQ"}]}], "}"}]}], "]"}], ":=", 
    "\[IndentingNewLine]", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"MapThread", "[", "\[IndentingNewLine]", 
       RowBox[{"Join", ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"#", ",", "img", ",", "#"}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"rank", "-", "1"}]}], "\[IndentingNewLine]", "]"}], "&"}], 
     "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{"b", ",", "##"}], "]"}], "&"}], "@@", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"ReplacePart", "[", 
         RowBox[{
          RowBox[{"Dimensions", "[", "img", "]"}], ",", "width", ",", 
          "rank"}], "]"}], "}"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImageFrame1D", "[", "\[IndentingNewLine]", 
    RowBox[{"img_List", ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"widthLeft_Integer", "?", "NonNegative"}], ",", 
         RowBox[{"widthRight_Integer", "?", "NonNegative"}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"rank_Integer", "?", "Positive"}], ",", "\[IndentingNewLine]", 
       
       RowBox[{"b_", "?", "NumericQ"}]}], "}"}]}], "]"}], ":=", 
   "\[IndentingNewLine]", " ", 
   RowBox[{"MapThread", "[", "\[IndentingNewLine]", 
    RowBox[{"Join", ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{"b", ",", "##"}], "]"}], "&"}], "@@", 
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"ReplacePart", "[", 
           RowBox[{
            RowBox[{"Dimensions", "[", "img", "]"}], ",", "widthLeft", ",", 
            "rank"}], "]"}], "}"}], "]"}]}], ",", "\[IndentingNewLine]", 
       "img", ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{"b", ",", "##"}], "]"}], "&"}], "@@", 
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"ReplacePart", "[", 
           RowBox[{
            RowBox[{"Dimensions", "[", "img", "]"}], ",", "widthRight", ",", 
            "rank"}], "]"}], "}"}], "]"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"rank", "-", "1"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]}], "PackageInput",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Truncate Boundary", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ImageFrame1D", "[", "\[IndentingNewLine]", 
     RowBox[{"img_List", ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"width_Integer", "?", "Positive"}], ",", "width_"}], "}"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"rank_Integer", "?", "Positive"}], ",", "\[IndentingNewLine]",
         "Truncate"}], "}"}]}], "]"}], ":=", "\[IndentingNewLine]", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"MapThread", "[", "\[IndentingNewLine]", 
       RowBox[{"Join", ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{"#", ",", "img", ",", "#"}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"rank", "-", "1"}]}], "\[IndentingNewLine]", "]"}], "&"}], 
     "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{"0", ",", "##"}], "]"}], "&"}], "@@", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"ReplacePart", "[", 
         RowBox[{
          RowBox[{"Dimensions", "[", "img", "]"}], ",", "width", ",", 
          "rank"}], "]"}], "}"}], "]"}]}], "]"}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImageFrame1D", "[", "\[IndentingNewLine]", 
    RowBox[{"img_List", ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"widthRight_Integer", "?", "Positive"}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"rank_Integer", "?", "Positive"}], ",", "\[IndentingNewLine]", 
       "Truncate"}], "}"}]}], "]"}], ":=", "\[IndentingNewLine]", " ", 
   RowBox[{"MapThread", "[", "\[IndentingNewLine]", 
    RowBox[{"Join", ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"img", ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{"0", ",", "##"}], "]"}], "&"}], "@@", 
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"ReplacePart", "[", 
           RowBox[{
            RowBox[{"Dimensions", "[", "img", "]"}], ",", "widthRight", ",", 
            "rank"}], "]"}], "}"}], "]"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"rank", "-", "1"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ImageFrame1D", "[", "\[IndentingNewLine]", 
     RowBox[{"img_List", ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"widthLeft_Integer", "?", "Positive"}], ",", "0"}], "}"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"rank_Integer", "?", "Positive"}], ",", "\[IndentingNewLine]",
         "Truncate"}], "}"}]}], "]"}], ":=", "\[IndentingNewLine]", " ", 
    RowBox[{"MapThread", "[", "\[IndentingNewLine]", 
     RowBox[{"Join", ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{"0", ",", "##"}], "]"}], "&"}], "@@", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"ReplacePart", "[", 
            RowBox[{
             RowBox[{"Dimensions", "[", "img", "]"}], ",", "widthLeft", ",", 
             "rank"}], "]"}], "}"}], "]"}]}], ",", "\[IndentingNewLine]", 
        "img"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"rank", "-", "1"}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImageFrame1D", "[", "\[IndentingNewLine]", 
    RowBox[{"img_List", ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"widthLeft_Integer", "?", "Positive"}], ",", 
         RowBox[{"widthRight_Integer", "?", "Positive"}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"rank_Integer", "?", "Positive"}], ",", "\[IndentingNewLine]", 
       "Truncate"}], "}"}]}], "]"}], ":=", "\[IndentingNewLine]", " ", 
   RowBox[{"MapThread", "[", "\[IndentingNewLine]", 
    RowBox[{"Join", ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{"0", ",", "##"}], "]"}], "&"}], "@@", 
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"ReplacePart", "[", 
           RowBox[{
            RowBox[{"Dimensions", "[", "img", "]"}], ",", "widthLeft", ",", 
            "rank"}], "]"}], "}"}], "]"}]}], ",", "\[IndentingNewLine]", 
       "img", ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{"0", ",", "##"}], "]"}], "&"}], "@@", 
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"ReplacePart", "[", 
           RowBox[{
            RowBox[{"Dimensions", "[", "img", "]"}], ",", "widthRight", ",", 
            "rank"}], "]"}], "}"}], "]"}]}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"rank", "-", "1"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]}], "PackageInput",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Constant Boundary", "Subsubsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ImageFrame1D", "[", "\[IndentingNewLine]", 
     RowBox[{"img_List", ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", 
          RowBox[{"widthRight_Integer", "?", "Positive"}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"rank_Integer", "?", "Positive"}], ",", " ", 
        "\[IndentingNewLine]", "Constant"}], "}"}]}], "]"}], ":=", 
    "\[IndentingNewLine]", " ", 
    RowBox[{"MapThread", "[", "\[IndentingNewLine]", 
     RowBox[{"Join", ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{"img", ",", "\[IndentingNewLine]", 
        RowBox[{"Transpose", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Part", "[", 
               RowBox[{"img", ",", "##"}], "]"}], "&"}], "@@", 
             RowBox[{"PadLeft", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"-", "1"}], "}"}], ",", "rank", ",", "All"}], "]"}]}],
             ",", 
            RowBox[{"{", "widthRight", "}"}]}], "]"}], ",", 
          RowBox[{"RotateRight", "[", 
           RowBox[{"Range", "[", "rank", "]"}], "]"}]}], "]"}]}], "}"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"rank", "-", "1"}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ImageFrame1D", "[", "\[IndentingNewLine]", 
     RowBox[{"img_List", ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"widthLeft_Integer", "?", "Positive"}], ",", "0"}], "}"}], 
        ",", "\[IndentingNewLine]", 
        RowBox[{"rank_Integer", "?", "Positive"}], ",", " ", 
        "\[IndentingNewLine]", "Constant"}], "}"}]}], "]"}], ":=", 
    "\[IndentingNewLine]", " ", 
    RowBox[{"MapThread", "[", "\[IndentingNewLine]", 
     RowBox[{"Join", ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{
          RowBox[{"Table", "[", 
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{"Part", "[", 
               RowBox[{"img", ",", "##"}], "]"}], "&"}], "@@", 
             RowBox[{"PadLeft", "[", 
              RowBox[{
               RowBox[{"{", "1", "}"}], ",", "rank", ",", "All"}], "]"}]}], 
            ",", 
            RowBox[{"{", "widthLeft", "}"}]}], "]"}], ",", 
          RowBox[{"RotateRight", "[", 
           RowBox[{"Range", "[", "rank", "]"}], "]"}]}], "]"}], ",", 
        "\[IndentingNewLine]", "img"}], "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{"rank", "-", "1"}]}], "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ImageFrame1D", "[", "\[IndentingNewLine]", 
    RowBox[{"img_List", ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"widthLeft_Integer", "?", "NonNegative"}], ",", 
         RowBox[{"widthRight_Integer", "?", "NonNegative"}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"rank_Integer", "?", "Positive"}], ",", " ", 
       "\[IndentingNewLine]", "Constant"}], "}"}]}], "]"}], ":=", 
   "\[IndentingNewLine]", " ", 
   RowBox[{"MapThread", "[", "\[IndentingNewLine]", 
    RowBox[{"Join", ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Part", "[", 
              RowBox[{"img", ",", "##"}], "]"}], "&"}], "@@", 
            RowBox[{"PadLeft", "[", 
             RowBox[{
              RowBox[{"{", "1", "}"}], ",", "rank", ",", "All"}], "]"}]}], 
           ",", 
           RowBox[{"{", "widthLeft", "}"}]}], "]"}], ",", 
         RowBox[{"RotateRight", "[", 
          RowBox[{"Range", "[", "rank", "]"}], "]"}]}], "]"}], ",", 
       "\[IndentingNewLine]", "img", ",", "\[IndentingNewLine]", 
       RowBox[{"Transpose", "[", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"Part", "[", 
              RowBox[{"img", ",", "##"}], "]"}], "&"}], "@@", 
            RowBox[{"PadLeft", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"-", "1"}], "}"}], ",", "rank", ",", "All"}], "]"}]}], 
           ",", 
           RowBox[{"{", "widthRight", "}"}]}], "]"}], ",", 
         RowBox[{"RotateRight", "[", 
          RowBox[{"Range", "[", "rank", "]"}], "]"}]}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"rank", "-", "1"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]}], "PackageInput",
 InitializationCell->True]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Closing Package", "Section"],

Cell["Closing the package and locking all the symbols.", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"End", "[", "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SetAttributes", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "ImageFrame", ",", "\[IndentingNewLine]", "RemoveImageFrame", ",", 
       "\[IndentingNewLine]", "ImageFrame1D", ",", "\[IndentingNewLine]", 
       "Constant"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"Protected", ",", " ", "ReadProtected"}], "}"}]}], 
    "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{"EndPackage", "[", "]"}]}], "PackageInput",
 InitializationCell->True]
}, Closed]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowSize->{1172, 744},
WindowMargins->{{40, Automatic}, {Automatic, 0}},
ShowSelection->True,
Magnification->1.5,
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (November 10, 2008)",
StyleDefinitions->"PackageNotebook.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 36, 0, 144, "Title"],
Cell[606, 24, 117, 4, 118, "Subsubtitle"],
Cell[CellGroupData[{
Cell[748, 32, 25, 0, 72, "Section"],
Cell[776, 34, 944, 24, 436, "PackageInput"],
Cell[1723, 60, 128, 3, 58, "Text"],
Cell[1854, 65, 3633, 98, 1230, "PackageInput",
 InitializationCell->True],
Cell[5490, 165, 35, 0, 58, "Text"],
Cell[5528, 167, 1215, 36, 270, "PackageInput"]
}, Closed]],
Cell[CellGroupData[{
Cell[6780, 208, 32, 0, 40, "Section"],
Cell[6815, 210, 92, 2, 58, "Text"],
Cell[6910, 214, 762, 15, 574, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[7709, 234, 42, 0, 40, "Section"],
Cell[7754, 236, 6935, 156, 3093, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[14726, 397, 31, 0, 40, "Section"],
Cell[14760, 399, 60, 0, 39, "Text"],
Cell[14823, 401, 108, 2, 60, "PackageInput",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[14956, 407, 38, 0, 63, "Subsection"],
Cell[14997, 409, 1544, 44, 273, "PackageInput"],
Cell[16544, 455, 2478, 65, 362, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[19059, 525, 32, 0, 37, "Subsection"],
Cell[19094, 527, 1502, 44, 273, "PackageInput"],
Cell[20599, 573, 2928, 70, 545, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[23564, 648, 34, 0, 37, "Subsection"],
Cell[23601, 650, 346, 11, 139, "PackageInput",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[23972, 665, 44, 0, 127, "Subsubsection"],
Cell[24019, 667, 13298, 327, 3867, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[37354, 999, 40, 0, 76, "Subsubsection"],
Cell[37397, 1001, 2761, 70, 1021, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[40195, 1076, 41, 0, 76, "Subsubsection"],
Cell[40239, 1078, 2929, 78, 1279, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[43205, 1161, 42, 0, 76, "Subsubsection"],
Cell[43250, 1163, 5179, 134, 2493, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[48466, 1302, 42, 0, 76, "Subsubsection"],
Cell[48511, 1304, 4923, 127, 2160, "PackageInput",
 InitializationCell->True]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[53495, 1438, 34, 0, 40, "Section"],
Cell[53532, 1440, 64, 0, 87, "Text"],
Cell[53599, 1442, 671, 16, 654, "PackageInput",
 InitializationCell->True]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
