(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    402045,      10463]
NotebookOptionsPosition[    391914,      10168]
NotebookOutlinePosition[    392508,      10191]
CellTagsIndexPosition[    392465,      10188]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Image Transformation Package", "Title"],

Cell["\<\
Markus van Almsick
Technische Universiteit Eindhoven
\[Copyright]2008\
\>", "Subsubtitle"],

Cell[CellGroupData[{

Cell["Prefix", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "TimeSamp", " ", "for", " ", "Package", " ", "Version", " ", "Control"}], 
   " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Unprotect", "[", "TimeStamp", "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"TimeStamp", "::", "usage"}], "=", 
     "\"\<TimeStamp[context] should be set to a Date[]-List indicating the \
version of the corresponding package.\>\""}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
    "TimeStamp", "[", "\"\<MathVisionTools`ImageTransformation`\>\"", "]"}], 
    "=", 
    RowBox[{"{", 
     RowBox[{"2010", ",", "8", ",", "8", ",", "21", ",", "0", ",", "0"}], 
     "}"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Protect", "[", "TimeStamp", "]"}], ";"}]}]}]], "PackageInput",
 CellChangeTimes->{{3.490282620461877*^9, 3.490282628952767*^9}}],

Cell["\<\
The preamble of the package containing all kinds of remarks about authorship, \
contence, and copyright.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Name", ":", "MathVisionTools`ImageTransformation`"}]}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Author", ":", 
     RowBox[{"Markus", " ", "van", " ", "Almsick"}]}]}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Email", " ", 
     RowBox[{"address", ":", 
      RowBox[{"M", ".", "v", ".", 
       RowBox[{"Almsick", "@", "tue"}], ".", "nl"}]}]}]}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Context", ":", "MathVisionTools`ImageTransformation`"}]}], 
   "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Package", " ", 
     RowBox[{"Version", ":", 
      RowBox[{"1.6", ".1"}]}]}]}], "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Mathematica", " ", 
     RowBox[{"Version", ":", "5.2"}]}]}], "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"Copyright", ":", 
      RowBox[{"Copyright", " ", "2005"}]}]}], ",", 
    RowBox[{"Technische", " ", "Universiteit", " ", "Eindhoven"}]}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Title", ":", 
     RowBox[{"Image", " ", "Transformation"}]}]}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Summary", ":", 
     RowBox[{
     "This", " ", "package", " ", "implements", " ", "rigid", " ", 
      "transformations", " ", "of", " ", 
      RowBox[{"pixel", "/", "voxel"}], " ", "arrays"}]}]}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"Keywords", ":", "Transformation"}]}], ",", "Translation", ",", 
    "Rotation"}], "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Requirements", ":", "None"}]}], "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Source", ":", "None"}]}], "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"History", ":", 
      RowBox[{
      "Version", " ", "1.0", " ", "by", " ", "Markus", " ", "van", " ", 
       "Almsick"}]}]}], ",", " ", 
    RowBox[{"March", " ", "2005"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"History", ":", 
      RowBox[{
      "Version", " ", "1.5", " ", "by", " ", "Markus", " ", "van", " ", 
       "Almsick"}]}]}], ",", " ", 
    RowBox[{"January", " ", "2008"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"History", ":", 
      RowBox[{
      "Version", " ", "1.6", " ", "by", " ", "Markus", " ", "van", " ", 
       "Almsick"}]}]}], ",", " ", 
    RowBox[{"September", " ", "2008"}]}], "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Limitations", ":"}]}], "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Discussion", ":"}]}], "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"To", " ", 
     RowBox[{"do", ":"}]}]}], "*)"}]}]], "PackageInput",
 InitializationCell->True,
 CellChangeTimes->{{3.490282632221612*^9, 3.490282632557481*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Begin Package", "Section"],

Cell["\<\
Declaring the package and unlocking all symbols defined in the code.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "BeginPackage", "[", "\"\<MathVisionTools`ImageTransformation`\>\"", "]"}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{"Unprotect", "[", "\[IndentingNewLine]", 
  RowBox[{
  "NConstantImageInterpolation", ",", "NConstantImageInterpolation3D", ",", 
   "NConstant2DImageInterpolation3D", ",", "NLinearImageInterpolation", ",", 
   "NLinearImageInterpolation3D", ",", "NLinear2DImageInterpolation3D", ",", 
   "CubicBSplineImageInterpolationFilter", ",", 
   "NCubicBSplineImageInterpolation", ",", 
   "NCubicBSplineImageInterpolation3D", ",", 
   "NCubicBSpline2DImageInterpolation3D", ",", "TranslateArray", ",", 
   "RotateArray", ",", "ScaleArray", ",", "NLinearAffineTransform", ",", 
   "NConstantAffineTransform", ",", "NLinearAffineTransform3D", ",", 
   "NConstantAffineTransform3D", ",", "NLinearAffine2DTransform3D", ",", 
   "NConsantAffine2DTransform3D", ",", "NCubicBSplineAffineTransform", ",", 
   "NCubicBSplineAffineTransform3D", ",", "NCubicBSplineAffine2DTransform3D", 
   ",", "PerspectiveTransformArray", ",", "ArrayInterpolation", ",", 
   "\[IndentingNewLine]", "ConstantInterpolation", ",", " ", 
   "LinearInterpolation", ",", "CubicBSplineInterpolation", ",", 
   "NCubicBSplineInterpolation"}], "\[IndentingNewLine]", 
  "]"}]}], "PackageInput",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Online Help and Options", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"NConstantImageInterpolation", "::", "usage"}], "=", 
   "\"\<NConstantImageInterpolation[data,x,y,xn,yn,offcol] performs a fast \
numerical constant interpolation of 2-dimensional image data with dimensions \
{xn,yn} at position {x,y}. Positions {x,y} outside the image domain render \
offcol.\>\""}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"NConstant2DImageInterpolation3D", "::", "usage"}], "=", 
   "\"\<NConstant2DImageInterpolation3D[data,x,y,xn,yn,zoffcol] performs a \
fast numerical 2-dimensional constant interpolation of 3-dimensional image \
data with dimensions {xn,yn,zn} at position {x,y}. Positions {x,y} outside \
the image domain render offcol.\>\""}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"NConstantImageInterpolation3D", "::", "usage"}], "=", 
   "\"\<NConstantImageInterpolation3D[data,x,y,z,xn,yn,zn,offcol] performs a \
fast numerical constant interpolation of 3-dimensional image data with \
dimensions {xn,yn,zn} at position {x,y,z}. Positions {x,y,z} outside the \
image domain render offcol.\>\""}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"NLinearImageInterpolation", "::", "usage"}], "=", 
   "\"\<NLinearImageInterpolation[data,x,y,xn,yn,offcol] performs a fast \
numerical linear interpolation of 2-dimensional image data with dimensions \
{xn,yn} at position {x,y}. Positions {x,y,z} outside the image domain render \
offcol.\>\""}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"NLinear2DImageInterpolation3D", "::", "usage"}], "=", 
   "\"\<NLinear2DImageInterpolation3D[data,x,y,xn,yn,zn,offcol] performs a \
fast numerical 2-dimensional linear interpolation of 3-dimensional image data \
with dimensions {xn,yn,zn} at position {x,y}. Positions {x,y} outside the \
image domain render offcol.\>\""}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"NLinearImageInterpolation3D", "::", "usage"}], "=", 
   "\"\<NLinearImageInterpolation3D[data,x,y,z,xn,yn,zn,offcol] performs a \
fast numerical linear interpolation of 3-dimensional image data with \
dimensions {xn,yn,zn} at position {x,y,z}. Positions {x,y,z} outside the \
image domain render offcol.\>\""}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"CubicBSplineImageInterpolationFilter", "::", "usage"}], "=", 
   "\[IndentingNewLine]", 
   "\"\<CubicBSplineImageInterpolationFilter[data] performs the prefiltering \
for a cubic B-spline interpolation with NCubicBSplineImageInterpolation for \
n-dimensional image data. CubicBSplineImageInterpolationFilter[data,m] \
filters only the first m dimensions.\>\""}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"NCubicBSplineImageInterpolation", "::", "usage"}], "=", 
   "\"\<NCubicBSplineImageInterpolation[data,x,y,xn,yn,offcol] performs a \
fast numerical cubic B-spline interpolation of 2-dimensional preprocessed \
image data with dimensions {xn,yn} at position {x,y}. The image data need to \
be preprocessed by CubicBSplineImageInterpolationFilter to counteract blur. \
Positions {x,y} outside the image domain render offcol. Note, that the grid \
of the preprocessed image data is larger than the one of the original image. \
Nevertheless, coordinates x, y, xn, and yn refer to the original image \
grid.\>\""}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"NCubicBSplineInterpolation", "::", "usage"}], "=", 
   "\"\<NCubicBSplineInterpolation[data,x,xn,offcol] performs a fast \
numerical cubic B-spline interpolation of 1-dimensional preprocessed data \
list with length xn at position x. The line data need to be preprocessed by \
CubicBSplineImageInterpolationFilter to counteract blur. Positions x outside \
the image domain render offcol. Note, that the grid of the preprocessed image \
data is larger than the one of the original image. Nevertheless, coordinates \
x and xn refer to the original line grid.\>\""}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"NCubicBSplineImageInterpolation3D", "::", "usage"}], "=", 
   "\"\<NCubicBSplineImageInterpolation[data,x,y,z,xn,yn,zn,offcol] performs \
a fast numerical cubic B-spline interpolation of 3-dimensional preprocessed \
image data with dimensions {xn,yn,zn} at position {x,y,z}. The image data \
need to be preprocessed by CubicBSplineImageInterpolationFilter to counteract \
blur. Positions {x,y,z} outside the image domain render offcol. Note, that \
the grid of the preprocessed image data is larger than the one of the \
original image. Nevertheless, coordinates x, y, z, xn, yn, and zn refer to \
the original image grid.\>\""}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"NCubicBSpline2DImageInterpolation3D", "::", "usage"}], "=", 
   "\[IndentingNewLine]", 
   "\"\<NLinear2DImageInterpolation3D[data,x,y,xn,yn,zn,zoffcol] performs a \
fast numerical 2-dimensional cubic B-spline interpolation of 3-dimensional \
image data with dimensions {xn,yn,zn} at position {x,y}. The image data need \
to be preprocessed by CubicBSplineImageInterpolationFilter[img,2] to \
counteract blur. Positions {x,y} outside the image domain render offcol. \
Note, that the grid of the preprocessed image data is larger than the one of \
the original image. Nevertheless, coordinates x, y, xn, and yn refer to the \
original image grid.\>\""}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"TranslateArray", "::", "usage"}], "=", 
   "\"\<TranslateArray[img,{x,y},offcol:0] translates a 2-dimensional image \
by {x,y}. TranslateArray[img,{x,y,z},offcol:0] translates a 3-dimensional \
image by {x,y,z}. Pixel and voxel elements outside the image domain are set \
to offcol.\>\""}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"RotateArray", "::", "usage"}], "=", 
   "\"\<RotateArray[img,\[Alpha],{x0,y0},offcol:0] rotates a 2-dimensional \
image by \[Alpha] around {x0,y0}. RotateArray[img,\[Alpha]] rotates the image \
around its center. RotateArray[img,\[Alpha],\[Beta],\[Gamma],{x0,y0,z0}] \
rotates a 3-dimensional image by Euler angles \[Alpha],\[Beta],\[Gamma] \
around {x0,y0,z0}. RotateArray[img,\[Alpha],\[Beta],\[Gamma]] rotates the \
image around its center. Pixel and voxel elements outside the image domain \
are set to offcol.\>\""}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"ScaleArray", "::", "usage"}], "=", 
   "\"\<ScaleArray[img,s,{x0,y0},offcol:0] scales a 2-dimensional image by \
factor s around {x0,y0}. ScaleArray[img,{sx,sy},{x0,y0},offcol:0] scales a \
2-dimensional image by factor sx in x-direction and sy in y-direction around \
{x0,y0}. ScaleArray[img,{sx,sy,sz},{x0,y0,z0},offcol:0] scales a \
3-dimensional image by factor sx in x-direction, sy in y-direction, and sz in \
z-direction around {x0,y0,z0}. Pixel and voxel elements outside the image \
domain are set to offcol.\>\""}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"NCubicBSplineAffineTransform", "::", "usage"}], "=", 
   "\[IndentingNewLine]", 
   "\"\<NCubicBSplineAffineTransform[img,x0,y0,x1,y1,rxx,rxy,ryx,ryy,offcol:0]\
 performs an affine transformation of a 2-dimensional image using cubic \
B-spline interpolation. The image is first translated by {x0,y0}, transformed \
by (\!\(\*GridBox[{
{rxx, rxy},
{ryx, ryy}
}]\)), and then translated back by {x1,y1}. Pixel elements outside the image \
domain are set to offcol.\>\""}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"NConstantAffineTransform", "::", "usage"}], "=", 
   "\"\<NConstantAffineTransform[img,x0,y0,x1,y1,rxx,rxy,ryx,ryy,offcol:0] \
performs an affine transformation of a 2-dimensional image using constant \
interpolation. The image is first translated by {x0,y0}, linearly transformed \
by (\!\(\*GridBox[{
{rxx, rxy},
{ryx, ryy}
}]\)), and then translated back by {x1,y1}. Pixel elements outside the image \
domain are set to offcol.\>\""}], "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"NLinearAffineTransform", "::", "usage"}], "=", 
   "\"\<NLinearAffineTransform[img,x0,y0,x1,y1,rxx,rxy,ryx,ryy,offcol:0] \
performs an affine transformation of a 2-dimensional image using linear \
interpolation. The image is first translated by {x0,y0}, linearly transformed \
by (\!\(\*GridBox[{
{rxx, rxy},
{ryx, ryy}
}]\)), and then translated back by {x1,y1}. Pixel elements outside the image \
domain are set to offcol.\>\""}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"NCubicBSplineAffine2DTransform3D", "::", "usage"}], "=", 
   "\[IndentingNewLine]", 
   "\"\<NCubicBSplineAffine2DTransform3D[img,x0,y0,x1,y1,rxx,rxy,ryx,ryy,\
offcol:0] performs an affine transformation in x-y of a 3-dimensional image \
using cubic B-spline interpolation. The image is first translated by \
(\!\(\*GridBox[{
{x0},
{y0},
{0}
}]\)), transformed by (\!\(\*GridBox[{
{rxx, rxy, 0},
{ryx, ryy, 0},
{0, 0, 1}
}]\)), and then translated back by (\!\(\*GridBox[{
{x1},
{y1},
{0}
}]\)). Voxel elements outside the image domain are set to offcol.\>\""}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"NLinearAffine2DTransform3D", "::", "usage"}], "=", 
   "\"\<NLinearAffine2DTransform3D[img,x0,y0,x1,y1,rxx,rxy,ryx,ryy,offcol:0] \
performs an affine transformation in x-y of a 3-dimensional image using \
linear interpolation. The image is first translated by (\!\(\*GridBox[{
{x0},
{y0},
{0}
}]\)), linearly transformed by (\!\(\*GridBox[{
{rxx, rxy, 0},
{ryx, ryy, 0},
{0, 0, 1}
}]\)), and then translated back by (\!\(\*GridBox[{
{x1},
{y1},
{0}
}]\)). Voxel elements outside the image domain are set to offcol.\>\""}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"NConstantAffine2DTransform3D", "::", "usage"}], "=", 
   "\"\<NConstantAffine2DTransform3D[img,x0,y0,x1,y1,rxx,rxy,ryx,ryy,offcol:0]\
 performs an affine transformation in x-y of a 3-dimensional image using \
constant interpolation. The image is first translated by (\!\(\*GridBox[{
{x0},
{y0},
{0}
}]\)), linearly transformed by (\!\(\*GridBox[{
{rxx, rxy, 0},
{ryx, ryy, 0},
{0, 0, 1}
}]\)), and then translated back by (\!\(\*GridBox[{
{x1},
{y1},
{0}
}]\)). Voxel elements outside the image domain are set to offcol.\>\""}], 
  "\n"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"NCubicBSplineAffineTransform3D", "::", "usage"}], "=", 
   "\[IndentingNewLine]", 
   "\"\<NCubicBSplineAffineTransform3D[img,x0,y0,z0,x1,y1,z1,rxx,rxy,rxz,ryx,\
ryy,ryz,rzx,rzy,rzz,offcol] performs an affine transformation of a \
3-dimensional image using cubic B-spline interpolation. The image is first \
translated by (\!\(\*GridBox[{
{x0},
{y0},
{z0}
}]\)), transformed by (\!\(\*GridBox[{
{rxx, rxy, rxz},
{ryx, ryy, ryz},
{rzx, rzy, rzz}
}]\)), and then translated back by (\!\(\*GridBox[{
{x1},
{y1},
{z1}
}]\)). Voxel elements outside the image domain are set to offcol.\>\""}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"NLinearAffineTransform3D", "::", "usage"}], "=", 
   "\"\<NLinearAffineTransform3D[img,x0,y0,z0,x1,y1,z1,rxx,rxy,rxz,ryx,ryy,\
ryz,rzx,rzy,rzz,offcol] performs an affine transformation of a 3-dimensional \
image using linear interpolation. The image is first translated by \
(\!\(\*GridBox[{
{x0},
{y0},
{z0}
}]\)), linearly transformed by (\!\(\*GridBox[{
{rxx, rxy, rxz},
{ryx, ryy, ryz},
{rzx, rzy, rzz}
}]\)), and then translated back by (\!\(\*GridBox[{
{x1},
{y1},
{z1}
}]\)). Voxel elements outside the image domain are set to offcol.\>\""}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"NConstantAffineTransform3D", "::", "usage"}], "=", 
   "\"\<NConstantAffineTransform3D[img,x0,y0,z0,x1,y1,z1,rxx,rxy,rxz,ryx,ryy,\
ryz,rzx,rzy,rzz,offcol] performs an affine transformation of a 3-dimensional \
image using constant interpolation. The image is first translated by \
(\!\(\*GridBox[{
{x0},
{y0},
{z0}
}]\)), linearly transformed by (\!\(\*GridBox[{
{rxx, rxy, rxz},
{ryx, ryy, ryz},
{rzx, rzy, rzz}
}]\)), and then translated back by (\!\(\*GridBox[{
{x1},
{y1},
{z1}
}]\)). Voxel elements outside the image domain are set to offcol.\>\""}], 
  "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"PerspectiveTransformArray", "::", "usage"}], "=", 
   "\"\<PerspectiveTransformArray[image,{y0,dyl,dyr},offcol:0] contracts or \
dilates an image in y direction around y0 by the factor dyl on the left and \
by the factor dyr on the right. \
PerspectiveTransformArray[image,{x0,dxb,dxt},{y0,dyb,dyt},offcol:0] contracts \
or dilates the 3D image in x-direction around x0 by the factor dxb on the \
bottom (z-minimum side) and by the factor dxt on the top (z-maximum side) and \
contracts or dilates in y-direction around y0 by the factor dyb on the bottom \
and by the factor by dyt on the top. Pixels or voxels outside the image \
domain are set to offcol.\>\""}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ArrayInterpolation", "::", "usage"}], "=", 
   "\"\<ArrayInterpolation is an Option for ScaleArray, RotateArray, \
TranslateArray, and PerspectiveTransformArray. It determines the kind of \
interpolation used in the transformation. Possible values are: \
ConstantInterpolation, LinearInterpolation, or \
CubicBSplineInterpolation.\>\""}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ConstantInterpolation", "::", "usage"}], "=", 
   "\"\<ConstantInterpolation is an Option-value of ArrayInterpolation. \
Interpolating values assume the value of the nearest pixel or voxel.\>\""}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"LinearInterpolation", "::", "usage"}], "=", 
   "\"\<LinearInterpolation is an Option-value of ArrayInterpolation. \
Interpolating values assume the linear distance-weighted average value of the \
nearest 4 pixels or nearest 8 voxels.\>\""}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CubicBSplineInterpolation", "::", "usage"}], "=", 
  "\"\<CubicBSplineInterpolation is an Option-value of ArrayInterpolation. \
Interpolating values are determined via 3rd order BSpline interpolation with \
reflective boundary conditions.\>\""}]}], "PackageInput",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Package Code", "Section"],

Cell["Starting the private context of the package.", "Text"],

Cell[BoxData[
 RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}]], "PackageInput",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["Constant Interpolation", "Subsection"],

Cell[CellGroupData[{

Cell["2D", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NConstantImageInterpolation", "=", "\[IndentingNewLine]", 
   RowBox[{"Compile", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"img", ",", "_Real", ",", "2"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"x", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"xn", ",", "_Integer"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"yn", ",", "_Integer"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"offColor", ",", "_Real"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Block", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x0", "=", 
          RowBox[{"Round", "[", "x", "]"}]}], ",", 
         RowBox[{"y0", "=", 
          RowBox[{"Round", "[", "y", "]"}]}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"0", "<", "x0", "<", "xn"}], "\[And]", 
          RowBox[{"0", "<", "y0", "<", "yn"}]}], ",", 
         RowBox[{"img", "\[LeftDoubleBracket]", 
          RowBox[{"y0", ",", "x0"}], "\[RightDoubleBracket]"}], ",", 
         "offColor"}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "PackageInput"]
}, Closed]],

Cell[CellGroupData[{

Cell["3D", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NConstantImageInterpolation3D", "=", "\[IndentingNewLine]", 
   RowBox[{"Compile", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"img", ",", "_Real", ",", "3"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"x", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"xn", ",", "_Integer"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"yn", ",", "_Integer"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"zn", ",", "_Integer"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"offColor", ",", "_Real"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Block", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x0", "=", 
          RowBox[{"Round", "[", "x", "]"}]}], ",", 
         RowBox[{"y0", "=", 
          RowBox[{"Round", "[", "y", "]"}]}], ",", 
         RowBox[{"z0", "=", 
          RowBox[{"Round", "[", "z", "]"}]}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"0", "<", "x0", "<", "xn"}], "\[And]", 
          RowBox[{"0", "<", "y0", "<", "yn"}], "\[And]", 
          RowBox[{"0", "<", "z0", "<", "zn"}]}], ",", 
         RowBox[{"img", "\[LeftDoubleBracket]", 
          RowBox[{"z0", ",", "y0", ",", "x0"}], "\[RightDoubleBracket]"}], 
         ",", "offColor"}], "]"}]}], "\[IndentingNewLine]", "]"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "PackageInput"]
}, Closed]],

Cell[CellGroupData[{

Cell["2D in 3D", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NConstant2DImageInterpolation3D", "=", "\[IndentingNewLine]", 
   RowBox[{"Compile", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"img", ",", "_Real", ",", "3"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"x", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"xn", ",", "_Integer"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"yn", ",", "_Integer"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"zn", ",", "_Integer"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"offColor", ",", "_Real"}], "}"}]}], "\[IndentingNewLine]", 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Block", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x0", "=", 
          RowBox[{"Round", "[", "x", "]"}]}], ",", 
         RowBox[{"y0", "=", 
          RowBox[{"Round", "[", "y", "]"}]}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"0", "<", "x0", "<", "xn"}], "\[And]", 
          RowBox[{"0", "<", "y0", "<", "yn"}]}], ",", 
         RowBox[{"img", "\[LeftDoubleBracket]", 
          RowBox[{"All", ",", "y0", ",", "x0"}], "\[RightDoubleBracket]"}], 
         ",", 
         RowBox[{"Table", "[", 
          RowBox[{"offColor", ",", 
           RowBox[{"{", "zn", "}"}]}], "]"}]}], "]"}]}], 
      "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]], "PackageInput"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Linear Interpolation", "Subsection"],

Cell[CellGroupData[{

Cell["2D", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NLinearImageInterpolation", "=", "\[IndentingNewLine]", 
   RowBox[{"Compile", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"img", ",", "_Real", ",", "2"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"x", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"xn", ",", "_Integer"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"yn", ",", "_Integer"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"offColor", ",", "_Real"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Block", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x0", "=", 
          RowBox[{"Floor", "[", "x", "]"}]}], ",", 
         RowBox[{"y0", "=", 
          RowBox[{"Floor", "[", "y", "]"}]}], ",", 
         RowBox[{"dx", "=", 
          RowBox[{"x", "-", "x0"}]}], ",", 
         RowBox[{"dy", "=", 
          RowBox[{"y", "-", "y0"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Which", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"0", "<", "x0", "<", "xn"}], "\[And]", 
          RowBox[{"0", "<", "y0", "<", "yn"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "dx"}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "dy"}], ")"}], " ", 
              RowBox[{"img", "\[LeftDoubleBracket]", 
               RowBox[{"y0", ",", "x0"}], "\[RightDoubleBracket]"}]}], "+", 
             RowBox[{"dy", " ", 
              RowBox[{"img", "\[LeftDoubleBracket]", 
               RowBox[{
                RowBox[{"y0", "+", "1"}], ",", "x0"}], 
               "\[RightDoubleBracket]"}]}]}], ")"}]}], "+", 
          RowBox[{"dx", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "dy"}], ")"}], " ", 
              RowBox[{"img", "\[LeftDoubleBracket]", 
               RowBox[{"y0", ",", 
                RowBox[{"x0", "+", "1"}]}], "\[RightDoubleBracket]"}]}], "+", 
             
             RowBox[{"dy", " ", 
              RowBox[{"img", "\[LeftDoubleBracket]", 
               RowBox[{
                RowBox[{"y0", "+", "1"}], ",", 
                RowBox[{"x0", "+", "1"}]}], "\[RightDoubleBracket]"}]}]}], 
            ")"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"x", "\[Equal]", "xn"}], "\[And]", 
          RowBox[{"0", "<", "y0", "<", "yn"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "dy"}], ")"}], " ", 
           RowBox[{"img", "\[LeftDoubleBracket]", 
            RowBox[{"y0", ",", "x0"}], "\[RightDoubleBracket]"}]}], "+", 
          RowBox[{"dy", " ", 
           RowBox[{"img", "\[LeftDoubleBracket]", 
            RowBox[{
             RowBox[{"y0", "+", "1"}], ",", "x0"}], 
            "\[RightDoubleBracket]"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"y", "\[Equal]", "yn"}], "\[And]", 
          RowBox[{"0", "<", "x0", "<", "xn"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "dx"}], ")"}], 
           RowBox[{"img", "\[LeftDoubleBracket]", 
            RowBox[{"y0", ",", "x0"}], "\[RightDoubleBracket]"}]}], "+", 
          RowBox[{"dx", " ", 
           RowBox[{"img", "\[LeftDoubleBracket]", 
            RowBox[{"y0", ",", 
             RowBox[{"x0", "+", "1"}]}], "\[RightDoubleBracket]"}]}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"x", "\[Equal]", "xn"}], "\[And]", 
          RowBox[{"y", "\[Equal]", "yn"}]}], ",", 
         RowBox[{"img", "\[LeftDoubleBracket]", 
          RowBox[{"y0", ",", "x0"}], "\[RightDoubleBracket]"}], ",", 
         "\[IndentingNewLine]", "True", ",", "offColor"}], 
        "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "PackageInput"]
}, Closed]],

Cell[CellGroupData[{

Cell["3D", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NLinearImageInterpolation3D", "=", "\[IndentingNewLine]", 
   RowBox[{"Compile", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"img", ",", "_Real", ",", "3"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"x", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"xn", ",", "_Integer"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"yn", ",", "_Integer"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"zn", ",", "_Integer"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"offColor", ",", "_Real"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Block", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x0", "=", 
          RowBox[{"Floor", "[", "x", "]"}]}], ",", 
         RowBox[{"y0", "=", 
          RowBox[{"Floor", "[", "y", "]"}]}], ",", 
         RowBox[{"z0", "=", 
          RowBox[{"Floor", "[", "z", "]"}]}], ",", 
         RowBox[{"dx", "=", 
          RowBox[{"x", "-", "x0"}]}], ",", 
         RowBox[{"dy", "=", 
          RowBox[{"y", "-", "y0"}]}], ",", 
         RowBox[{"dz", "=", 
          RowBox[{"z", "-", "z0"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Which", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"0", "<", "x0", "<", "xn"}], "\[And]", 
          RowBox[{"0", "<", "y0", "<", "yn"}], "\[And]", 
          RowBox[{"0", "<", "z0", "<", "zn"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "dx"}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "dy"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "-", "dz"}], ")"}], " ", 
                 RowBox[{"img", "\[LeftDoubleBracket]", 
                  RowBox[{"z0", ",", "y0", ",", "x0"}], 
                  "\[RightDoubleBracket]"}]}], "+", 
                RowBox[{"dz", " ", 
                 RowBox[{"img", "\[LeftDoubleBracket]", 
                  RowBox[{
                   RowBox[{"z0", "+", "1"}], ",", "y0", ",", "x0"}], 
                  "\[RightDoubleBracket]"}]}]}], ")"}]}], "+", 
             RowBox[{"dy", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "-", "dz"}], ")"}], " ", 
                 RowBox[{"img", "\[LeftDoubleBracket]", 
                  RowBox[{"z0", ",", 
                   RowBox[{"y0", "+", "1"}], ",", "x0"}], 
                  "\[RightDoubleBracket]"}]}], "+", 
                RowBox[{"dz", " ", 
                 RowBox[{"img", "\[LeftDoubleBracket]", 
                  RowBox[{
                   RowBox[{"z0", "+", "1"}], ",", 
                   RowBox[{"y0", "+", "1"}], ",", "x0"}], 
                  "\[RightDoubleBracket]"}]}]}], ")"}]}]}], ")"}]}], "+", 
          RowBox[{"dx", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "dy"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "-", "dz"}], ")"}], " ", 
                 RowBox[{"img", "\[LeftDoubleBracket]", 
                  RowBox[{"z0", ",", "y0", ",", 
                   RowBox[{"x0", "+", "1"}]}], "\[RightDoubleBracket]"}]}], 
                "+", 
                RowBox[{"dz", " ", 
                 RowBox[{"img", "\[LeftDoubleBracket]", 
                  RowBox[{
                   RowBox[{"z0", "+", "1"}], ",", "y0", ",", 
                   RowBox[{"x0", "+", "1"}]}], "\[RightDoubleBracket]"}]}]}], 
               ")"}]}], "+", 
             RowBox[{"dy", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"1", "-", "dz"}], ")"}], " ", 
                 RowBox[{"img", "\[LeftDoubleBracket]", 
                  RowBox[{"z0", ",", 
                   RowBox[{"y0", "+", "1"}], ",", 
                   RowBox[{"x0", "+", "1"}]}], "\[RightDoubleBracket]"}]}], 
                "+", 
                RowBox[{"dz", " ", 
                 RowBox[{"img", "\[LeftDoubleBracket]", 
                  RowBox[{
                   RowBox[{"z0", "+", "1"}], ",", 
                   RowBox[{"y0", "+", "1"}], ",", 
                   RowBox[{"x0", "+", "1"}]}], "\[RightDoubleBracket]"}]}]}], 
               ")"}]}]}], ")"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"x", "\[Equal]", "xn"}], "\[And]", 
          RowBox[{"0", "<", "y0", "<", "yn"}], "\[And]", 
          RowBox[{"0", "<", "z0", "<", "zn"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "dy"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "dz"}], ")"}], " ", 
              RowBox[{"img", "\[LeftDoubleBracket]", 
               RowBox[{"z0", ",", "y0", ",", "x0"}], 
               "\[RightDoubleBracket]"}]}], "+", 
             RowBox[{"dz", " ", 
              RowBox[{"img", "\[LeftDoubleBracket]", 
               RowBox[{
                RowBox[{"z0", "+", "1"}], ",", "y0", ",", "x0"}], 
               "\[RightDoubleBracket]"}]}]}], ")"}]}], "+", 
          RowBox[{"dy", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "dz"}], ")"}], " ", 
              RowBox[{"img", "\[LeftDoubleBracket]", 
               RowBox[{"z0", ",", 
                RowBox[{"y0", "+", "1"}], ",", "x0"}], 
               "\[RightDoubleBracket]"}]}], "+", 
             RowBox[{"dz", " ", 
              RowBox[{"img", "\[LeftDoubleBracket]", 
               RowBox[{
                RowBox[{"z0", "+", "1"}], ",", 
                RowBox[{"y0", "+", "1"}], ",", "x0"}], 
               "\[RightDoubleBracket]"}]}]}], ")"}]}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"y", "\[Equal]", "yn"}], "\[And]", 
          RowBox[{"0", "<", "x0", "<", "xn"}], "\[And]", 
          RowBox[{"0", "<", "z0", "<", "zn"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "dx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "dz"}], ")"}], " ", 
              RowBox[{"img", "\[LeftDoubleBracket]", 
               RowBox[{"z0", ",", "y0", ",", "x0"}], 
               "\[RightDoubleBracket]"}]}], "+", 
             RowBox[{"dz", " ", 
              RowBox[{"img", "\[LeftDoubleBracket]", 
               RowBox[{
                RowBox[{"z0", "+", "1"}], ",", "y0", ",", "x0"}], 
               "\[RightDoubleBracket]"}]}]}], ")"}]}], "+", 
          RowBox[{"dx", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "dz"}], ")"}], " ", 
              RowBox[{"img", "\[LeftDoubleBracket]", 
               RowBox[{"z0", ",", "y0", ",", 
                RowBox[{"x0", "+", "1"}]}], "\[RightDoubleBracket]"}]}], "+", 
             
             RowBox[{"dz", " ", 
              RowBox[{"img", "\[LeftDoubleBracket]", 
               RowBox[{
                RowBox[{"1", "+", "z0"}], ",", "y0", ",", 
                RowBox[{"x0", "+", "1"}]}], "\[RightDoubleBracket]"}]}]}], 
            ")"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"z", "\[Equal]", "zn"}], "\[And]", 
          RowBox[{"0", "<", "x0", "<", "xn"}], "\[And]", 
          RowBox[{"0", "<", "y0", "<", "yn"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "dx"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "dy"}], ")"}], " ", 
              RowBox[{"img", "\[LeftDoubleBracket]", 
               RowBox[{"z0", ",", "y0", ",", "x0"}], 
               "\[RightDoubleBracket]"}]}], "+", 
             RowBox[{"dy", " ", 
              RowBox[{"img", "\[LeftDoubleBracket]", 
               RowBox[{"z0", ",", 
                RowBox[{"y0", "+", "1"}], ",", "x0"}], 
               "\[RightDoubleBracket]"}]}]}], ")"}]}], "+", 
          RowBox[{"dx", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "dy"}], ")"}], " ", 
              RowBox[{"img", "\[LeftDoubleBracket]", 
               RowBox[{"z0", ",", "y0", ",", 
                RowBox[{"x0", "+", "1"}]}], "\[RightDoubleBracket]"}]}], "+", 
             
             RowBox[{"dy", " ", 
              RowBox[{"img", "\[LeftDoubleBracket]", 
               RowBox[{"z0", ",", 
                RowBox[{"y0", "+", "1"}], ",", 
                RowBox[{"x0", "+", "1"}]}], "\[RightDoubleBracket]"}]}]}], 
            ")"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"x", "\[Equal]", "xn"}], "\[And]", 
          RowBox[{"y", "\[Equal]", "yn"}], "\[And]", 
          RowBox[{"0", "<", "z0", "<", "zn"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "dz"}], ")"}], " ", 
           RowBox[{"img", "\[LeftDoubleBracket]", 
            RowBox[{"z0", ",", "y0", ",", "x0"}], "\[RightDoubleBracket]"}]}],
           "+", 
          RowBox[{"dz", " ", 
           RowBox[{"img", "\[LeftDoubleBracket]", 
            RowBox[{
             RowBox[{"z0", "+", "1"}], ",", "y0", ",", "x0"}], 
            "\[RightDoubleBracket]"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"x", "\[Equal]", "xn"}], "\[And]", 
          RowBox[{"z", "\[Equal]", "zn"}], "\[And]", 
          RowBox[{"0", "<", "y0", "<", "yn"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "dy"}], ")"}], " ", 
           RowBox[{"img", "\[LeftDoubleBracket]", 
            RowBox[{"z0", ",", "y0", ",", "x0"}], "\[RightDoubleBracket]"}]}],
           "+", 
          RowBox[{"dy", " ", 
           RowBox[{"img", "\[LeftDoubleBracket]", 
            RowBox[{"z0", ",", 
             RowBox[{"y0", "+", "1"}], ",", "x0"}], 
            "\[RightDoubleBracket]"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"y", "\[Equal]", "yn"}], "\[And]", 
          RowBox[{"z", "\[Equal]", "zn"}], "\[And]", 
          RowBox[{"0", "<", "x0", "<", "xn"}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "dx"}], ")"}], " ", 
           RowBox[{"img", "\[LeftDoubleBracket]", 
            RowBox[{"z0", ",", "y0", ",", "x0"}], "\[RightDoubleBracket]"}]}],
           "+", 
          RowBox[{"dx", " ", 
           RowBox[{"img", "\[LeftDoubleBracket]", 
            RowBox[{"z0", ",", "y0", ",", 
             RowBox[{"x0", "+", "1"}]}], "\[RightDoubleBracket]"}]}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"x", "\[Equal]", "xn"}], "\[And]", 
          RowBox[{"y", "\[Equal]", "yn"}], "\[And]", 
          RowBox[{"z", "\[Equal]", "zn"}]}], ",", 
         RowBox[{"img", "\[LeftDoubleBracket]", 
          RowBox[{"z0", ",", "y0", ",", "x0"}], "\[RightDoubleBracket]"}], 
         ",", "\[IndentingNewLine]", "True", ",", "offColor"}], 
        "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "PackageInput"]
}, Closed]],

Cell[CellGroupData[{

Cell["2D in 3D", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NLinear2DImageInterpolation3D", "=", " ", "\[IndentingNewLine]", 
   RowBox[{"Compile", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"img", ",", "_Real", ",", "3"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"x", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"xn", ",", "_Integer"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"yn", ",", "_Integer"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"zn", ",", "_Integer"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"offColor", ",", "_Real"}], "}"}]}], "\[IndentingNewLine]", 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Block", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x0", "=", 
          RowBox[{"Floor", "[", "x", "]"}]}], ",", 
         RowBox[{"y0", "=", 
          RowBox[{"Floor", "[", "y", "]"}]}], ",", 
         RowBox[{"dx", "=", 
          RowBox[{"x", "-", "x0"}]}], ",", 
         RowBox[{"dy", "=", 
          RowBox[{"y", "-", "y0"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Which", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"0", "<", "x0", "<", "xn"}], "\[And]", 
          RowBox[{"0", "<", "y0", "<", "yn"}]}], ",", "\[IndentingNewLine]", 
         "\t", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "dx"}], ")"}], 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "dy"}], ")"}], " ", 
              RowBox[{"img", "\[LeftDoubleBracket]", 
               RowBox[{"All", ",", "y0", ",", "x0"}], 
               "\[RightDoubleBracket]"}]}], "+", 
             RowBox[{"dy", " ", 
              RowBox[{"img", "\[LeftDoubleBracket]", 
               RowBox[{"All", ",", 
                RowBox[{"y0", "+", "1"}], ",", "x0"}], 
               "\[RightDoubleBracket]"}]}]}], ")"}]}], "+", 
          RowBox[{"dx", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "-", "dy"}], ")"}], " ", 
              RowBox[{"img", "\[LeftDoubleBracket]", 
               RowBox[{"All", ",", "y0", ",", 
                RowBox[{"x0", "+", "1"}]}], "\[RightDoubleBracket]"}]}], "+", 
             
             RowBox[{"dy", " ", 
              RowBox[{"img", "\[LeftDoubleBracket]", 
               RowBox[{"All", ",", 
                RowBox[{"y0", "+", "1"}], ",", 
                RowBox[{"x0", "+", "1"}]}], "\[RightDoubleBracket]"}]}]}], 
            ")"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"x", "\[Equal]", "xn"}], " ", "\[And]", " ", 
          RowBox[{"0", "<", "y0", "<", "yn"}]}], ",", "\[IndentingNewLine]", 
         "\t", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "dy"}], ")"}], " ", 
           RowBox[{"img", "\[LeftDoubleBracket]", 
            RowBox[{"All", ",", "y0", ",", "x0"}], 
            "\[RightDoubleBracket]"}]}], "+", 
          RowBox[{"dy", " ", 
           RowBox[{"img", "\[LeftDoubleBracket]", 
            RowBox[{"All", ",", 
             RowBox[{"y0", "+", "1"}], ",", "x0"}], 
            "\[RightDoubleBracket]"}]}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"y", "\[Equal]", "yn"}], " ", "\[And]", " ", 
          RowBox[{"0", "<", "x0", "<", "xn"}]}], ",", "\[IndentingNewLine]", 
         "\t", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", "dx"}], ")"}], 
           RowBox[{"img", "\[LeftDoubleBracket]", 
            RowBox[{"All", ",", "y0", ",", "x0"}], 
            "\[RightDoubleBracket]"}]}], "+", 
          RowBox[{"dx", " ", 
           RowBox[{"img", "\[LeftDoubleBracket]", 
            RowBox[{"All", ",", "y0", ",", 
             RowBox[{"x0", "+", "1"}]}], "\[RightDoubleBracket]"}]}]}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"x", "\[Equal]", "xn"}], " ", "\[And]", " ", 
          RowBox[{"y", "==", "yn"}]}], ",", "\[IndentingNewLine]", "\t", 
         RowBox[{"img", "\[LeftDoubleBracket]", 
          RowBox[{"All", ",", "y0", ",", "x0"}], "\[RightDoubleBracket]"}], 
         ",", "\[IndentingNewLine]", "True", ",", "\[IndentingNewLine]", "\t", 
         RowBox[{"Table", "[", 
          RowBox[{"offColor", ",", 
           RowBox[{"{", "zn", "}"}]}], "]"}]}], "\[IndentingNewLine]", 
        "]"}]}], "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "PackageInput"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Cubic B-Spline Interpolation", "Subsection"],

Cell["\<\
Source: M. Unser, A. Aldroubi and M. Eden, IEEE Transactions on Pattern \
Analysis and Machine Intelligence. Fast B-Spline Transforms 
for Continuous Image Representation and Interpolation, volume 13, March 1991\
\>", "Text"],

Cell[CellGroupData[{

Cell["CubicBSplineImageInterpolationFilter", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CubicBSplineImageInterpolationFilter", "[", 
   RowBox[{"img_", ",", 
    RowBox[{"nn_Integer:", "256"}]}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"n", " ", "=", " ", 
       RowBox[{"Min", "[", 
        RowBox[{"nn", ",", 
         RowBox[{"ArrayDepth", "[", "img", "]"}]}], "]"}]}], ",", 
      RowBox[{"\[Alpha]", "=", 
       RowBox[{"N", "[", 
        RowBox[{
         SqrtBox["3"], "-", "2"}], "]"}]}], ",", "shift", ",", 
      RowBox[{"tmp", "=", "img"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"shift", "=", 
      RowBox[{"RotateRight", "[", 
       RowBox[{"Range", "[", "n", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     
     RowBox[{"Do", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"tmp", "=", 
        RowBox[{"Transpose", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"FoldList", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"\[Alpha]", " ", "#1"}], "+", "#2"}], ")"}], "&"}], 
             ",", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"1", ",", "\[Alpha]", ",", 
                SuperscriptBox["\[Alpha]", "2"], ",", 
                SuperscriptBox["\[Alpha]", "3"]}], "}"}], ".", 
              RowBox[{"tmp", "\[LeftDoubleBracket]", 
               RowBox[{"{", 
                RowBox[{"1", ",", "2", ",", "3", ",", "4"}], "}"}], 
               "\[RightDoubleBracket]"}]}], ",", 
             RowBox[{"Append", "[", 
              RowBox[{"tmp", ",", " ", 
               RowBox[{"Last", "[", "tmp", "]"}]}], "]"}]}], "]"}], "+", 
           RowBox[{"Reverse", "[", 
            RowBox[{"FoldList", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"\[Alpha]", " ", "#1"}], "+", "#2"}], ")"}], "&"}], 
              ",", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"1", ",", "\[Alpha]", ",", 
                 SuperscriptBox["\[Alpha]", "2"], ",", 
                 SuperscriptBox["\[Alpha]", "3"]}], "}"}], ".", 
               RowBox[{"tmp", "\[LeftDoubleBracket]", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"-", "1"}], ",", 
                  RowBox[{"-", "2"}], ",", 
                  RowBox[{"-", "3"}], ",", 
                  RowBox[{"-", "4"}]}], "}"}], "\[RightDoubleBracket]"}]}], 
              ",", 
              RowBox[{"Append", "[", 
               RowBox[{
                RowBox[{"Reverse", "[", "tmp", "]"}], ",", " ", 
                RowBox[{"First", "[", "tmp", "]"}]}], "]"}]}], "]"}], "]"}], 
           "-", "\[IndentingNewLine]", 
           RowBox[{"Prepend", "[", 
            RowBox[{
             RowBox[{"Append", "[", 
              RowBox[{"tmp", ",", " ", 
               RowBox[{"Last", "[", "tmp", "]"}]}], "]"}], ",", 
             RowBox[{"First", "[", "tmp", "]"}]}], "]"}]}], ",", 
          "\[IndentingNewLine]", "shift"}], "\[IndentingNewLine]", "]"}]}], 
       ",", "\[IndentingNewLine]", 
       RowBox[{"{", "n", "}"}]}], "\[IndentingNewLine]", "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"Return", "[", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", "\[Alpha]"}], 
           RowBox[{"1", "-", 
            SuperscriptBox["\[Alpha]", "2"]}]]}], ")"}], "n"], "*", "tmp"}], 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1D", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NCubicBSplineInterpolation", " ", "=", "\n", "  ", 
   RowBox[{"Compile", "[", "\n", "   ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"img", ",", " ", "_Real", ",", " ", "1"}], "}"}], ",", "\n", 
       "    ", 
       RowBox[{"{", 
        RowBox[{"x", ",", " ", "_Real"}], "}"}], ",", "\n", "    ", 
       RowBox[{"{", 
        RowBox[{"xn", ",", " ", "_Integer"}], "}"}], ",", "\n", "    ", 
       RowBox[{"{", 
        RowBox[{"offColor", ",", " ", "_Real"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", " ", 
     RowBox[{"Block", "[", "\[IndentingNewLine]", " ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x0", " ", "=", " ", 
          RowBox[{"Floor", "[", "x", "]"}]}], ",", " ", 
         RowBox[{"dx", " ", "=", " ", 
          RowBox[{"x", " ", "-", " ", "x0"}]}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Which", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"0", " ", "<", " ", "x0", " ", "<", " ", "xn"}], " ", ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"Take", "[", 
            RowBox[{"img", ",", 
             RowBox[{"{", 
              RowBox[{"x0", ",", 
               RowBox[{"x0", "+", "3"}]}], "}"}]}], "]"}], ".", 
           RowBox[{"{", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"1", "-", "dx"}], ")"}], "3"], ",", 
             RowBox[{"4", "+", 
              RowBox[{"3", " ", 
               SuperscriptBox["dx", "2"], 
               RowBox[{"(", 
                RowBox[{"dx", "-", "2"}], " ", ")"}]}]}], ",", 
             RowBox[{"1", "+", 
              RowBox[{"3", " ", "dx", 
               RowBox[{"(", 
                RowBox[{"1", "+", "dx", "-", 
                 SuperscriptBox["dx", "2"]}], ")"}]}]}], ",", 
             SuperscriptBox["dx", "3"]}], "}"}]}], "/", "6"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"x", " ", "==", " ", "xn"}], " ", ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"Take", "[", 
            RowBox[{"img", ",", 
             RowBox[{"{", 
              RowBox[{"x0", ",", 
               RowBox[{"x0", "+", "2"}]}], "}"}]}], "]"}], ".", 
           RowBox[{"{", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"1", "-", "dx"}], ")"}], "3"], ",", 
             RowBox[{"4", "+", 
              RowBox[{"3", " ", 
               SuperscriptBox["dx", "2"], 
               RowBox[{"(", 
                RowBox[{"dx", "-", "2"}], " ", ")"}]}]}], ",", 
             RowBox[{"1", "+", 
              RowBox[{"3", " ", "dx", 
               RowBox[{"(", 
                RowBox[{"1", "+", "dx", "-", 
                 SuperscriptBox["dx", "2"]}], ")"}]}]}]}], "}"}]}], "/", 
          "6"}], ",", " ", "True", ",", " ", "offColor"}], 
        "\[IndentingNewLine]", " ", "]"}]}], "\[IndentingNewLine]", " ", 
      "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Take", "[", 
         RowBox[{"_", ",", "_"}], "]"}], ",", "_Real", ",", "1"}], "}"}], 
      "}"}]}], "\[IndentingNewLine]", "]"}]}], ";"}]], "PackageInput"]
}, Closed]],

Cell[CellGroupData[{

Cell["2D", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NCubicBSplineImageInterpolation", " ", "=", "\n", "  ", 
   RowBox[{"Compile", "[", "\n", "   ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"img", ",", " ", "_Real", ",", " ", "2"}], "}"}], ",", "\n", 
       "    ", 
       RowBox[{"{", 
        RowBox[{"x", ",", " ", "_Real"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"y", ",", " ", "_Real"}], "}"}], ",", "\n", "    ", 
       RowBox[{"{", 
        RowBox[{"xn", ",", " ", "_Integer"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"yn", ",", " ", "_Integer"}], "}"}], ",", "\n", "    ", 
       RowBox[{"{", 
        RowBox[{"offColor", ",", " ", "_Real"}], "}"}]}], "}"}], ",", "\n", 
     "   ", 
     RowBox[{"Block", "[", "\n", "    ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x0", " ", "=", " ", 
          RowBox[{"Floor", "[", "x", "]"}]}], ",", " ", 
         RowBox[{"y0", " ", "=", " ", 
          RowBox[{"Floor", "[", "y", "]"}]}], ",", " ", 
         RowBox[{"dx", " ", "=", " ", 
          RowBox[{"x", " ", "-", " ", "x0"}]}], ",", " ", 
         RowBox[{"dy", " ", "=", " ", 
          RowBox[{"y", " ", "-", " ", "y0"}]}]}], "}"}], ",", "\n", "    ", 
       RowBox[{"Which", "[", "\n", "     ", 
        RowBox[{
         RowBox[{
          RowBox[{"0", " ", "<", " ", "x0", " ", "<", " ", "xn"}], " ", 
          "\[And]", " ", 
          RowBox[{"0", " ", "<", " ", "y0", " ", "<", " ", "yn"}]}], ",", " ",
          "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "-", "dy"}], ")"}], "3"], ",", 
              RowBox[{"4", "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["dy", "2"], 
                RowBox[{"(", 
                 RowBox[{"dy", "-", "2"}], " ", ")"}]}]}], ",", 
              RowBox[{"1", "+", 
               RowBox[{"3", " ", "dy", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "dy", "-", 
                  SuperscriptBox["dy", "2"]}], ")"}]}]}], ",", 
              SuperscriptBox["dy", "3"]}], "}"}], ".", "\[IndentingNewLine]", 
            
            RowBox[{"Take", "[", 
             RowBox[{"img", ",", 
              RowBox[{"{", 
               RowBox[{"y0", ",", 
                RowBox[{"y0", "+", "3"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"x0", ",", 
                RowBox[{"x0", "+", "3"}]}], "}"}]}], "]"}], ".", 
            "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "-", "dx"}], ")"}], "3"], ",", 
              RowBox[{"4", "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["dx", "2"], 
                RowBox[{"(", 
                 RowBox[{"dx", "-", "2"}], " ", ")"}]}]}], ",", 
              RowBox[{"1", "+", 
               RowBox[{"3", " ", "dx", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "dx", "-", 
                  SuperscriptBox["dx", "2"]}], ")"}]}]}], ",", 
              SuperscriptBox["dx", "3"]}], "}"}]}], ")"}], "/", "36"}], ",", 
         "\n", "     ", 
         RowBox[{
          RowBox[{"x", " ", "==", " ", "xn"}], " ", "\[And]", " ", 
          RowBox[{"0", " ", "<", " ", "y0", " ", "<", " ", "yn"}]}], ",", " ",
          "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "-", "dy"}], ")"}], "3"], ",", 
              RowBox[{"4", "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["dy", "2"], 
                RowBox[{"(", 
                 RowBox[{"dy", "-", "2"}], " ", ")"}]}]}], ",", 
              RowBox[{"1", "+", 
               RowBox[{"3", " ", "dy", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "dy", "-", 
                  SuperscriptBox["dy", "2"]}], ")"}]}]}], ",", 
              SuperscriptBox["dy", "3"]}], "}"}], ".", "\[IndentingNewLine]", 
            
            RowBox[{"Take", "[", 
             RowBox[{"img", ",", 
              RowBox[{"{", 
               RowBox[{"y0", ",", 
                RowBox[{"y0", "+", "3"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"x0", ",", 
                RowBox[{"x0", "+", "2"}]}], "}"}]}], "]"}], ".", 
            "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "-", "dx"}], ")"}], "3"], ",", 
              RowBox[{"4", "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["dx", "2"], 
                RowBox[{"(", 
                 RowBox[{"dx", "-", "2"}], " ", ")"}]}]}], ",", 
              RowBox[{"1", "+", 
               RowBox[{"3", " ", "dx", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "dx", "-", 
                  SuperscriptBox["dx", "2"]}], ")"}]}]}]}], "}"}]}], ")"}], 
          "/", "36"}], ",", "\n", "     ", 
         RowBox[{
          RowBox[{"y", " ", "==", " ", "yn"}], " ", "\[And]", " ", 
          RowBox[{"0", " ", "<", " ", "x0", " ", "<", " ", "xn"}]}], ",", " ",
          "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "-", "dy"}], ")"}], "3"], ",", 
              RowBox[{"4", "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["dy", "2"], 
                RowBox[{"(", 
                 RowBox[{"dy", "-", "2"}], " ", ")"}]}]}], ",", 
              RowBox[{"1", "+", 
               RowBox[{"3", " ", "dy", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "dy", "-", 
                  SuperscriptBox["dy", "2"]}], ")"}]}]}]}], "}"}], ".", 
            "\[IndentingNewLine]", 
            RowBox[{"Take", "[", 
             RowBox[{"img", ",", 
              RowBox[{"{", 
               RowBox[{"y0", ",", 
                RowBox[{"y0", "+", "2"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"x0", ",", 
                RowBox[{"x0", "+", "3"}]}], "}"}]}], "]"}], ".", 
            "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "-", "dx"}], ")"}], "3"], ",", 
              RowBox[{"4", "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["dx", "2"], 
                RowBox[{"(", 
                 RowBox[{"dx", "-", "2"}], " ", ")"}]}]}], ",", 
              RowBox[{"1", "+", 
               RowBox[{"3", " ", "dx", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "dx", "-", 
                  SuperscriptBox["dx", "2"]}], ")"}]}]}], ",", 
              SuperscriptBox["dx", "3"]}], "}"}]}], ")"}], "/", "36"}], ",", 
         "\n", "     ", 
         RowBox[{
          RowBox[{"x", " ", "==", " ", "xn"}], " ", "\[And]", " ", 
          RowBox[{"y", " ", "==", " ", "yn"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "-", "dy"}], ")"}], "3"], ",", 
              RowBox[{"4", "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["dy", "2"], 
                RowBox[{"(", 
                 RowBox[{"dy", "-", "2"}], " ", ")"}]}]}], ",", 
              RowBox[{"1", "+", 
               RowBox[{"3", " ", "dy", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "dy", "-", 
                  SuperscriptBox["dy", "2"]}], ")"}]}]}]}], "}"}], ".", 
            "\[IndentingNewLine]", 
            RowBox[{"Take", "[", 
             RowBox[{"img", ",", 
              RowBox[{"{", 
               RowBox[{"y0", ",", 
                RowBox[{"y0", "+", "2"}]}], "}"}], ",", 
              RowBox[{"{", 
               RowBox[{"x0", ",", 
                RowBox[{"x0", "+", "2"}]}], "}"}]}], "]"}], ".", 
            "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "-", "dx"}], ")"}], "3"], ",", 
              RowBox[{"4", "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["dx", "2"], 
                RowBox[{"(", 
                 RowBox[{"dx", "-", "2"}], " ", ")"}]}]}], ",", 
              RowBox[{"1", "+", 
               RowBox[{"3", " ", "dx", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "dx", "-", 
                  SuperscriptBox["dx", "2"]}], ")"}]}]}]}], "}"}]}], ")"}], 
          "/", "36"}], ",", "\n", "     ", "True", ",", " ", "offColor"}], 
        "\n", "     ", "]"}]}], "\n", "    ", "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Take", "[", 
         RowBox[{"_", ",", "_", ",", "_"}], "]"}], ",", "_Real", ",", "2"}], 
       "}"}], "}"}]}], "\n", "   ", "]"}]}], ";"}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3D", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NCubicBSplineImageInterpolation3D", " ", "=", "\n", "  ", 
   RowBox[{"Compile", "[", "\n", "   ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"img", ",", " ", "_Real", ",", " ", "3"}], "}"}], ",", "\n", 
       "    ", 
       RowBox[{"{", 
        RowBox[{"x", ",", " ", "_Real"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"y", ",", " ", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", " ", "_Real"}], "}"}], ",", "\n", "    ", 
       RowBox[{"{", 
        RowBox[{"xn", ",", " ", "_Integer"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"yn", ",", " ", "_Integer"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"zn", ",", " ", "_Integer"}], "}"}], ",", "\n", "    ", 
       RowBox[{"{", 
        RowBox[{"offColor", ",", " ", "_Real"}], "}"}]}], "}"}], ",", "\n", 
     "   ", 
     RowBox[{"Block", "[", "\n", "    ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x0", "=", 
          RowBox[{"Floor", "[", "x", "]"}]}], ",", 
         RowBox[{"y0", "=", 
          RowBox[{"Floor", "[", "y", "]"}]}], ",", 
         RowBox[{"z0", "=", 
          RowBox[{"Floor", "[", "z", "]"}]}], ",", 
         RowBox[{"dx", "=", 
          RowBox[{"x", "-", "x0"}]}], ",", 
         RowBox[{"dy", "=", 
          RowBox[{"y", "-", "y0"}]}], ",", 
         RowBox[{"dz", "=", 
          RowBox[{"z", "-", "z0"}]}]}], "}"}], ",", "\n", "    ", 
       RowBox[{"Which", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"0", "<", "x0", "<", "xn"}], "\[And]", 
          RowBox[{"0", "<", "y0", "<", "yn"}], "\[And]", 
          RowBox[{"0", "<", "z0", "<", "zn"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "-", "dy"}], ")"}], "3"], ",", 
              RowBox[{"4", "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["dy", "2"], 
                RowBox[{"(", 
                 RowBox[{"dy", "-", "2"}], " ", ")"}]}]}], ",", 
              RowBox[{"1", "+", 
               RowBox[{"3", " ", "dy", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "dy", "-", 
                  SuperscriptBox["dy", "2"]}], ")"}]}]}], ",", 
              SuperscriptBox["dy", "3"]}], "}"}], ".", 
            RowBox[{"(", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"1", "-", "dz"}], ")"}], "3"], ",", 
                RowBox[{"4", "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["dz", "2"], 
                  RowBox[{"(", 
                   RowBox[{"dz", "-", "2"}], " ", ")"}]}]}], ",", 
                RowBox[{"1", "+", 
                 RowBox[{"3", " ", "dz", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "dz", "-", 
                    SuperscriptBox["dz", "2"]}], ")"}]}]}], ",", 
                SuperscriptBox["dz", "3"]}], "}"}], ".", 
              "\[IndentingNewLine]", 
              RowBox[{"Take", "[", 
               RowBox[{"img", ",", 
                RowBox[{"{", 
                 RowBox[{"z0", ",", 
                  RowBox[{"z0", "+", "3"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"y0", ",", 
                  RowBox[{"y0", "+", "3"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"x0", ",", 
                  RowBox[{"x0", "+", "3"}]}], "}"}]}], "]"}], ".", 
              "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"1", "-", "dx"}], ")"}], "3"], ",", 
                RowBox[{"4", "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["dx", "2"], 
                  RowBox[{"(", 
                   RowBox[{"dx", "-", "2"}], " ", ")"}]}]}], ",", 
                RowBox[{"1", "+", 
                 RowBox[{"3", " ", "dx", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "dx", "-", 
                    SuperscriptBox["dx", "2"]}], ")"}]}]}], ",", 
                SuperscriptBox["dx", "3"]}], "}"}]}], ")"}]}], ")"}], "/", 
          "36"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"x", "\[Equal]", "xn"}], "\[And]", 
          RowBox[{"0", "<", "y0", "<", "yn"}], "\[And]", 
          RowBox[{"0", "<", "z0", "<", "zn"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "-", "dy"}], ")"}], "3"], ",", 
              RowBox[{"4", "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["dy", "2"], 
                RowBox[{"(", 
                 RowBox[{"dy", "-", "2"}], " ", ")"}]}]}], ",", 
              RowBox[{"1", "+", 
               RowBox[{"3", " ", "dy", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "dy", "-", 
                  SuperscriptBox["dy", "2"]}], ")"}]}]}], ",", 
              SuperscriptBox["dy", "3"]}], "}"}], ".", 
            RowBox[{"(", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"1", "-", "dz"}], ")"}], "3"], ",", 
                RowBox[{"4", "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["dz", "2"], 
                  RowBox[{"(", 
                   RowBox[{"dz", "-", "2"}], " ", ")"}]}]}], ",", 
                RowBox[{"1", "+", 
                 RowBox[{"3", " ", "dz", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "dz", "-", 
                    SuperscriptBox["dz", "2"]}], ")"}]}]}], ",", 
                SuperscriptBox["dz", "3"]}], "}"}], ".", 
              "\[IndentingNewLine]", 
              RowBox[{"Take", "[", 
               RowBox[{"img", ",", 
                RowBox[{"{", 
                 RowBox[{"z0", ",", 
                  RowBox[{"z0", "+", "3"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"y0", ",", 
                  RowBox[{"y0", "+", "3"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"x0", ",", 
                  RowBox[{"x0", "+", "2"}]}], "}"}]}], "]"}], ".", 
              "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"1", "-", "dx"}], ")"}], "3"], ",", 
                RowBox[{"4", "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["dx", "2"], 
                  RowBox[{"(", 
                   RowBox[{"dx", "-", "2"}], " ", ")"}]}]}], ",", 
                RowBox[{"1", "+", 
                 RowBox[{"3", " ", "dx", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "dx", "-", 
                    SuperscriptBox["dx", "2"]}], ")"}]}]}]}], "}"}]}], 
             ")"}]}], ")"}], "/", "36"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"y", "\[Equal]", "yn"}], "\[And]", 
          RowBox[{"0", "<", "x0", "<", "xn"}], "\[And]", 
          RowBox[{"0", "<", "z0", "<", "zn"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "-", "dy"}], ")"}], "3"], ",", 
              RowBox[{"4", "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["dy", "2"], 
                RowBox[{"(", 
                 RowBox[{"dy", "-", "2"}], " ", ")"}]}]}], ",", 
              RowBox[{"1", "+", 
               RowBox[{"3", " ", "dy", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "dy", "-", 
                  SuperscriptBox["dy", "2"]}], ")"}]}]}]}], "}"}], ".", 
            RowBox[{"(", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"1", "-", "dz"}], ")"}], "3"], ",", 
                RowBox[{"4", "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["dz", "2"], 
                  RowBox[{"(", 
                   RowBox[{"dz", "-", "2"}], " ", ")"}]}]}], ",", 
                RowBox[{"1", "+", 
                 RowBox[{"3", " ", "dz", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "dz", "-", 
                    SuperscriptBox["dz", "2"]}], ")"}]}]}], ",", 
                SuperscriptBox["dz", "3"]}], "}"}], ".", 
              "\[IndentingNewLine]", 
              RowBox[{"Take", "[", 
               RowBox[{"img", ",", 
                RowBox[{"{", 
                 RowBox[{"z0", ",", 
                  RowBox[{"z0", "+", "3"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"y0", ",", 
                  RowBox[{"y0", "+", "2"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"x0", ",", 
                  RowBox[{"x0", "+", "3"}]}], "}"}]}], "]"}], ".", 
              "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"1", "-", "dx"}], ")"}], "3"], ",", 
                RowBox[{"4", "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["dx", "2"], 
                  RowBox[{"(", 
                   RowBox[{"dx", "-", "2"}], " ", ")"}]}]}], ",", 
                RowBox[{"1", "+", 
                 RowBox[{"3", " ", "dx", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "dx", "-", 
                    SuperscriptBox["dx", "2"]}], ")"}]}]}], ",", 
                SuperscriptBox["dx", "3"]}], "}"}]}], ")"}]}], ")"}], "/", 
          "36"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"z", "\[Equal]", "zn"}], "\[And]", 
          RowBox[{"0", "<", "x0", "<", "xn"}], "\[And]", 
          RowBox[{"0", "<", "y0", "<", "yn"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "-", "dy"}], ")"}], "3"], ",", 
              RowBox[{"4", "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["dy", "2"], 
                RowBox[{"(", 
                 RowBox[{"dy", "-", "2"}], " ", ")"}]}]}], ",", 
              RowBox[{"1", "+", 
               RowBox[{"3", " ", "dy", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "dy", "-", 
                  SuperscriptBox["dy", "2"]}], ")"}]}]}], ",", 
              SuperscriptBox["dy", "3"]}], "}"}], ".", 
            RowBox[{"(", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"1", "-", "dz"}], ")"}], "3"], ",", 
                RowBox[{"4", "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["dz", "2"], 
                  RowBox[{"(", 
                   RowBox[{"dz", "-", "2"}], " ", ")"}]}]}], ",", 
                RowBox[{"1", "+", 
                 RowBox[{"3", " ", "dz", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "dz", "-", 
                    SuperscriptBox["dz", "2"]}], ")"}]}]}]}], "}"}], ".", 
              "\[IndentingNewLine]", 
              RowBox[{"Take", "[", 
               RowBox[{"img", ",", 
                RowBox[{"{", 
                 RowBox[{"z0", ",", 
                  RowBox[{"z0", "+", "2"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"y0", ",", 
                  RowBox[{"y0", "+", "3"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"x0", ",", 
                  RowBox[{"x0", "+", "3"}]}], "}"}]}], "]"}], ".", 
              "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"1", "-", "dx"}], ")"}], "3"], ",", 
                RowBox[{"4", "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["dx", "2"], 
                  RowBox[{"(", 
                   RowBox[{"dx", "-", "2"}], " ", ")"}]}]}], ",", 
                RowBox[{"1", "+", 
                 RowBox[{"3", " ", "dx", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "dx", "-", 
                    SuperscriptBox["dx", "2"]}], ")"}]}]}], ",", 
                SuperscriptBox["dx", "3"]}], "}"}]}], ")"}]}], ")"}], "/", 
          "36"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"x", "\[Equal]", "xn"}], "\[And]", 
          RowBox[{"y", "\[Equal]", "yn"}], "\[And]", 
          RowBox[{"0", "<", "z0", "<", "zn"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "-", "dy"}], ")"}], "3"], ",", 
              RowBox[{"4", "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["dy", "2"], 
                RowBox[{"(", 
                 RowBox[{"dy", "-", "2"}], " ", ")"}]}]}], ",", 
              RowBox[{"1", "+", 
               RowBox[{"3", " ", "dy", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "dy", "-", 
                  SuperscriptBox["dy", "2"]}], ")"}]}]}]}], "}"}], ".", 
            RowBox[{"(", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"1", "-", "dz"}], ")"}], "3"], ",", 
                RowBox[{"4", "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["dz", "2"], 
                  RowBox[{"(", 
                   RowBox[{"dz", "-", "2"}], " ", ")"}]}]}], ",", 
                RowBox[{"1", "+", 
                 RowBox[{"3", " ", "dz", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "dz", "-", 
                    SuperscriptBox["dz", "2"]}], ")"}]}]}], ",", 
                SuperscriptBox["dz", "3"]}], "}"}], ".", 
              "\[IndentingNewLine]", 
              RowBox[{"Take", "[", 
               RowBox[{"img", ",", 
                RowBox[{"{", 
                 RowBox[{"z0", ",", 
                  RowBox[{"z0", "+", "3"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"y0", ",", 
                  RowBox[{"y0", "+", "2"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"x0", ",", 
                  RowBox[{"x0", "+", "2"}]}], "}"}]}], "]"}], ".", 
              "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"1", "-", "dx"}], ")"}], "3"], ",", 
                RowBox[{"4", "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["dx", "2"], 
                  RowBox[{"(", 
                   RowBox[{"dx", "-", "2"}], " ", ")"}]}]}], ",", 
                RowBox[{"1", "+", 
                 RowBox[{"3", " ", "dx", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "dx", "-", 
                    SuperscriptBox["dx", "2"]}], ")"}]}]}]}], "}"}]}], 
             ")"}]}], ")"}], "/", "36"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"x", "\[Equal]", "xn"}], "\[And]", 
          RowBox[{"z", "\[Equal]", "zn"}], "\[And]", 
          RowBox[{"0", "<", "y0", "<", "yn"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "-", "dy"}], ")"}], "3"], ",", 
              RowBox[{"4", "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["dy", "2"], 
                RowBox[{"(", 
                 RowBox[{"dy", "-", "2"}], " ", ")"}]}]}], ",", 
              RowBox[{"1", "+", 
               RowBox[{"3", " ", "dy", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "dy", "-", 
                  SuperscriptBox["dy", "2"]}], ")"}]}]}], ",", 
              SuperscriptBox["dy", "3"]}], "}"}], ".", 
            RowBox[{"(", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"1", "-", "dz"}], ")"}], "3"], ",", 
                RowBox[{"4", "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["dz", "2"], 
                  RowBox[{"(", 
                   RowBox[{"dz", "-", "2"}], " ", ")"}]}]}], ",", 
                RowBox[{"1", "+", 
                 RowBox[{"3", " ", "dz", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "dz", "-", 
                    SuperscriptBox["dz", "2"]}], ")"}]}]}]}], "}"}], ".", 
              "\[IndentingNewLine]", 
              RowBox[{"Take", "[", 
               RowBox[{"img", ",", 
                RowBox[{"{", 
                 RowBox[{"z0", ",", 
                  RowBox[{"z0", "+", "2"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"y0", ",", 
                  RowBox[{"y0", "+", "3"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"x0", ",", 
                  RowBox[{"x0", "+", "2"}]}], "}"}]}], "]"}], ".", 
              "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"1", "-", "dx"}], ")"}], "3"], ",", 
                RowBox[{"4", "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["dx", "2"], 
                  RowBox[{"(", 
                   RowBox[{"dx", "-", "2"}], " ", ")"}]}]}], ",", 
                RowBox[{"1", "+", 
                 RowBox[{"3", " ", "dx", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "dx", "-", 
                    SuperscriptBox["dx", "2"]}], ")"}]}]}]}], "}"}]}], 
             ")"}]}], ")"}], "/", "36"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"y", "\[Equal]", "yn"}], "\[And]", 
          RowBox[{"z", "\[Equal]", "zn"}], "\[And]", 
          RowBox[{"0", "<", "x0", "<", "xn"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "-", "dy"}], ")"}], "3"], ",", 
              RowBox[{"4", "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["dy", "2"], 
                RowBox[{"(", 
                 RowBox[{"dy", "-", "2"}], " ", ")"}]}]}], ",", 
              RowBox[{"1", "+", 
               RowBox[{"3", " ", "dy", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "dy", "-", 
                  SuperscriptBox["dy", "2"]}], ")"}]}]}]}], "}"}], ".", 
            RowBox[{"(", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"1", "-", "dz"}], ")"}], "3"], ",", 
                RowBox[{"4", "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["dz", "2"], 
                  RowBox[{"(", 
                   RowBox[{"dz", "-", "2"}], " ", ")"}]}]}], ",", 
                RowBox[{"1", "+", 
                 RowBox[{"3", " ", "dz", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "dz", "-", 
                    SuperscriptBox["dz", "2"]}], ")"}]}]}]}], "}"}], ".", 
              "\[IndentingNewLine]", 
              RowBox[{"Take", "[", 
               RowBox[{"img", ",", 
                RowBox[{"{", 
                 RowBox[{"z0", ",", 
                  RowBox[{"z0", "+", "2"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"y0", ",", 
                  RowBox[{"y0", "+", "2"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"x0", ",", 
                  RowBox[{"x0", "+", "3"}]}], "}"}]}], "]"}], ".", 
              "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"1", "-", "dx"}], ")"}], "3"], ",", 
                RowBox[{"4", "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["dx", "2"], 
                  RowBox[{"(", 
                   RowBox[{"dx", "-", "2"}], " ", ")"}]}]}], ",", 
                RowBox[{"1", "+", 
                 RowBox[{"3", " ", "dx", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "dx", "-", 
                    SuperscriptBox["dx", "2"]}], ")"}]}]}], ",", 
                SuperscriptBox["dx", "3"]}], "}"}]}], ")"}]}], ")"}], "/", 
          "36"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"x", "\[Equal]", "xn"}], "\[And]", 
          RowBox[{"y", "\[Equal]", "yn"}], "\[And]", 
          RowBox[{"z", "\[Equal]", "zn"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "-", "dy"}], ")"}], "3"], ",", 
              RowBox[{"4", "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["dy", "2"], 
                RowBox[{"(", 
                 RowBox[{"dy", "-", "2"}], " ", ")"}]}]}], ",", 
              RowBox[{"1", "+", 
               RowBox[{"3", " ", "dy", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "dy", "-", 
                  SuperscriptBox["dy", "2"]}], ")"}]}]}]}], "}"}], ".", 
            RowBox[{"(", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"1", "-", "dz"}], ")"}], "3"], ",", 
                RowBox[{"4", "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["dz", "2"], 
                  RowBox[{"(", 
                   RowBox[{"dz", "-", "2"}], " ", ")"}]}]}], ",", 
                RowBox[{"1", "+", 
                 RowBox[{"3", " ", "dz", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "dz", "-", 
                    SuperscriptBox["dz", "2"]}], ")"}]}]}]}], "}"}], ".", 
              "\[IndentingNewLine]", 
              RowBox[{"Take", "[", 
               RowBox[{"img", ",", 
                RowBox[{"{", 
                 RowBox[{"z0", ",", 
                  RowBox[{"z0", "+", "2"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"y0", ",", 
                  RowBox[{"y0", "+", "2"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"x0", ",", 
                  RowBox[{"x0", "+", "2"}]}], "}"}]}], "]"}], ".", 
              "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"1", "-", "dx"}], ")"}], "3"], ",", 
                RowBox[{"4", "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["dx", "2"], 
                  RowBox[{"(", 
                   RowBox[{"dx", "-", "2"}], " ", ")"}]}]}], ",", 
                RowBox[{"1", "+", 
                 RowBox[{"3", " ", "dx", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "dx", "-", 
                    SuperscriptBox["dx", "2"]}], ")"}]}]}]}], "}"}]}], 
             ")"}]}], ")"}], "/", "36"}], ",", "\[IndentingNewLine]", "True", 
         ",", "offColor"}], "\[IndentingNewLine]", "]"}]}], " ", "\n", "    ",
       "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Take", "[", 
         RowBox[{"_", ",", "_", ",", "_", ",", "_"}], "]"}], ",", "_Real", 
        ",", "3"}], "}"}], "}"}]}], "\n", "   ", "]"}]}], 
  ";"}]], "PackageInput"]
}, Closed]],

Cell[CellGroupData[{

Cell["2D in 3D", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NCubicBSpline2DImageInterpolation3D", " ", "=", "\n", "  ", 
   RowBox[{"Compile", "[", "\n", "   ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"img", ",", " ", "_Real", ",", " ", "3"}], "}"}], ",", "\n", 
       "    ", 
       RowBox[{"{", 
        RowBox[{"x", ",", " ", "_Real"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"y", ",", " ", "_Real"}], "}"}], ",", "\n", "    ", 
       RowBox[{"{", 
        RowBox[{"xn", ",", " ", "_Integer"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"yn", ",", " ", "_Integer"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"zn", ",", " ", "_Integer"}], "}"}], ",", "\n", "    ", 
       RowBox[{"{", 
        RowBox[{"offColor", ",", " ", "_Real"}], "}"}]}], "}"}], ",", "\n", 
     "   ", 
     RowBox[{"Block", "[", "\n", "    ", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"x0", "=", 
          RowBox[{"Floor", "[", "x", "]"}]}], ",", 
         RowBox[{"y0", "=", 
          RowBox[{"Floor", "[", "y", "]"}]}], ",", 
         RowBox[{"dx", "=", 
          RowBox[{"x", "-", "x0"}]}], ",", 
         RowBox[{"dy", "=", 
          RowBox[{"y", "-", "y0"}]}]}], "}"}], ",", "\n", "    ", 
       RowBox[{"Which", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"0", "<", "x0", "<", "xn"}], "\[And]", 
          RowBox[{"0", "<", "y0", "<", "yn"}]}], ",", "\[IndentingNewLine]", 
         "\t", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Take", "[", 
               RowBox[{"img", ",", "All", ",", 
                RowBox[{"{", 
                 RowBox[{"y0", ",", 
                  RowBox[{"y0", "+", "3"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"x0", ",", 
                  RowBox[{"x0", "+", "3"}]}], "}"}]}], "]"}], ".", 
              "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"1", "-", "dx"}], ")"}], "3"], ",", 
                RowBox[{"4", "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["dx", "2"], 
                  RowBox[{"(", 
                   RowBox[{"dx", "-", "2"}], " ", ")"}]}]}], ",", 
                RowBox[{"1", "+", 
                 RowBox[{"3", " ", "dx", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "dx", "-", 
                    SuperscriptBox["dx", "2"]}], ")"}]}]}], ",", 
                SuperscriptBox["dx", "3"]}], "}"}]}], ")"}], ".", 
            RowBox[{"{", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "-", "dy"}], ")"}], "3"], ",", 
              RowBox[{"4", "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["dy", "2"], 
                RowBox[{"(", 
                 RowBox[{"dy", "-", "2"}], " ", ")"}]}]}], ",", 
              RowBox[{"1", "+", 
               RowBox[{"3", " ", "dy", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "dy", "-", 
                  SuperscriptBox["dy", "2"]}], ")"}]}]}], ",", 
              SuperscriptBox["dy", "3"]}], "}"}]}], ")"}], "/", "36"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"x", "\[Equal]", "xn"}], " ", "\[And]", " ", 
          RowBox[{"0", "<", "y0", "<", "yn"}]}], ",", "\[IndentingNewLine]", 
         "\t", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Take", "[", 
               RowBox[{"img", ",", "All", ",", 
                RowBox[{"{", 
                 RowBox[{"y0", ",", 
                  RowBox[{"y0", "+", "3"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"x0", ",", 
                  RowBox[{"x0", "+", "2"}]}], "}"}]}], "]"}], ".", 
              "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"1", "-", "dx"}], ")"}], "3"], ",", 
                RowBox[{"4", "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["dx", "2"], 
                  RowBox[{"(", 
                   RowBox[{"dx", "-", "2"}], " ", ")"}]}]}], ",", 
                RowBox[{"1", "+", 
                 RowBox[{"3", " ", "dx", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "dx", "-", 
                    SuperscriptBox["dx", "2"]}], ")"}]}]}]}], "}"}]}], ")"}], 
            ".", 
            RowBox[{"{", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "-", "dy"}], ")"}], "3"], ",", 
              RowBox[{"4", "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["dy", "2"], 
                RowBox[{"(", 
                 RowBox[{"dy", "-", "2"}], " ", ")"}]}]}], ",", 
              RowBox[{"1", "+", 
               RowBox[{"3", " ", "dy", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "dy", "-", 
                  SuperscriptBox["dy", "2"]}], ")"}]}]}], ",", 
              SuperscriptBox["dy", "3"]}], "}"}]}], ")"}], "/", "36"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"y", "\[Equal]", "yn"}], " ", "\[And]", " ", 
          RowBox[{"0", "<", "x0", "<", "xn"}]}], ",", "\[IndentingNewLine]", 
         "\t", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Take", "[", 
               RowBox[{"img", ",", "All", ",", 
                RowBox[{"{", 
                 RowBox[{"y0", ",", 
                  RowBox[{"y0", "+", "2"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"x0", ",", 
                  RowBox[{"x0", "+", "3"}]}], "}"}]}], "]"}], ".", 
              "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"1", "-", "dx"}], ")"}], "3"], ",", 
                RowBox[{"4", "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["dx", "2"], 
                  RowBox[{"(", 
                   RowBox[{"dx", "-", "2"}], " ", ")"}]}]}], ",", 
                RowBox[{"1", "+", 
                 RowBox[{"3", " ", "dx", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "dx", "-", 
                    SuperscriptBox["dx", "2"]}], ")"}]}]}], ",", 
                SuperscriptBox["dx", "3"]}], "}"}]}], ")"}], ".", 
            RowBox[{"{", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "-", "dy"}], ")"}], "3"], ",", 
              RowBox[{"4", "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["dy", "2"], 
                RowBox[{"(", 
                 RowBox[{"dy", "-", "2"}], " ", ")"}]}]}], ",", 
              RowBox[{"1", "+", 
               RowBox[{"3", " ", "dy", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "dy", "-", 
                  SuperscriptBox["dy", "2"]}], ")"}]}]}]}], "}"}]}], ")"}], 
          "/", "36"}], ",", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"x", "\[Equal]", "xn"}], " ", "\[And]", " ", 
          RowBox[{"y", "==", "yn"}]}], ",", "\[IndentingNewLine]", "\t", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"Take", "[", 
               RowBox[{"img", ",", "All", ",", 
                RowBox[{"{", 
                 RowBox[{"y0", ",", 
                  RowBox[{"y0", "+", "2"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"x0", ",", 
                  RowBox[{"x0", "+", "2"}]}], "}"}]}], "]"}], ".", 
              "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{"1", "-", "dx"}], ")"}], "3"], ",", 
                RowBox[{"4", "+", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["dx", "2"], 
                  RowBox[{"(", 
                   RowBox[{"dx", "-", "2"}], " ", ")"}]}]}], ",", 
                RowBox[{"1", "+", 
                 RowBox[{"3", " ", "dx", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "dx", "-", 
                    SuperscriptBox["dx", "2"]}], ")"}]}]}]}], "}"}]}], ")"}], 
            ".", 
            RowBox[{"{", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"(", 
                RowBox[{"1", "-", "dy"}], ")"}], "3"], ",", 
              RowBox[{"4", "+", 
               RowBox[{"3", " ", 
                SuperscriptBox["dy", "2"], 
                RowBox[{"(", 
                 RowBox[{"dy", "-", "2"}], " ", ")"}]}]}], ",", 
              RowBox[{"1", "+", 
               RowBox[{"3", " ", "dy", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "dy", "-", 
                  SuperscriptBox["dy", "2"]}], ")"}]}]}]}], "}"}]}], ")"}], 
          "/", "36"}], ",", "\[IndentingNewLine]", "True", ",", 
         "\[IndentingNewLine]", "\t", 
         RowBox[{"Table", "[", 
          RowBox[{"offColor", ",", 
           RowBox[{"{", "zn", "}"}]}], "]"}]}], "\[IndentingNewLine]", 
        "]"}]}], " ", "\n", "    ", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Take", "[", 
          RowBox[{"_", ",", "_", ",", "_", ",", "_"}], "]"}], ",", "_Real", 
         ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Table", "[", 
          RowBox[{"_", ",", "_"}], "]"}], ",", "_Real", ",", "1"}], "}"}]}], 
      "}"}]}], "\n", "   ", "]"}]}], ";"}]], "PackageInput"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Affine Transformations", "Subsection"],

Cell[CellGroupData[{

Cell["2D", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NConstantAffineTransform", "=", "\[IndentingNewLine]", 
   RowBox[{"Compile", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"img", ",", "_Real", ",", "2"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"x0", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y0", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"x1", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y1", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"rxx", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"rxy", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"ryx", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ryy", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"offColor", ",", "_Real"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"With", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"xn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "2", "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{"yn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "1", "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"NConstantImageInterpolation", "[", 
          RowBox[{"img", ",", 
           RowBox[{
            RowBox[{"rxx", " ", "x"}], "+", 
            RowBox[{"rxy", " ", "y"}], "+", "x1"}], ",", 
           RowBox[{
            RowBox[{"ryx", " ", "x"}], "+", 
            RowBox[{"ryy", " ", "y"}], "+", "y1"}], ",", "xn", ",", "yn", ",",
            "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"y", ",", 
           RowBox[{"1", "-", "y0"}], ",", 
           RowBox[{"yn", "-", "y0"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"1", "-", "x0"}], ",", 
           RowBox[{"xn", "-", "x0"}]}], "}"}]}], "\[IndentingNewLine]", 
        "]"}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"NConstantImageInterpolation", "[", 
         RowBox[{"_", ",", "_", ",", "_", ",", "_", ",", "_", ",", "_"}], 
         "]"}], ",", "_Real"}], "}"}], "}"}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "PackageInput",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"NLinearAffineTransform", "=", "\[IndentingNewLine]", 
   RowBox[{"Compile", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"img", ",", "_Real", ",", "2"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"x0", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y0", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"x1", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y1", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"rxx", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"rxy", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"ryx", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ryy", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"offColor", ",", "_Real"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"With", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"xn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "2", "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{"yn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "1", "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"NLinearImageInterpolation", "[", 
          RowBox[{"img", ",", 
           RowBox[{
            RowBox[{"rxx", " ", "x"}], "+", 
            RowBox[{"rxy", " ", "y"}], "+", "x1"}], ",", 
           RowBox[{
            RowBox[{"ryx", " ", "x"}], "+", 
            RowBox[{"ryy", " ", "y"}], "+", "y1"}], ",", "xn", ",", "yn", ",",
            "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"y", ",", 
           RowBox[{"1", "-", "y0"}], ",", 
           RowBox[{"yn", "-", "y0"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"1", "-", "x0"}], ",", 
           RowBox[{"xn", "-", "x0"}]}], "}"}]}], "\[IndentingNewLine]", 
        "]"}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"NLinearImageInterpolation", "[", 
         RowBox[{"_", ",", "_", ",", "_", ",", "_", ",", "_", ",", "_"}], 
         "]"}], ",", "_Real"}], "}"}], "}"}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "PackageInput",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"NCubicBSplineAffineTransform", "=", "\[IndentingNewLine]", 
   RowBox[{"Compile", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"img", ",", "_Real", ",", "2"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"x0", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y0", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"x1", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y1", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"rxx", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"rxy", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"ryx", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ryy", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"offColor", ",", "_Real"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Module", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"xn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "2", "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{"yn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "1", "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{"tmp", "=", 
          RowBox[{
          "CubicBSplineImageInterpolationFilter", "[", "img", "]"}]}]}], 
        "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"NCubicBSplineImageInterpolation", "[", 
          RowBox[{"tmp", ",", 
           RowBox[{
            RowBox[{"rxx", " ", "x"}], "+", 
            RowBox[{"rxy", " ", "y"}], "+", "x1"}], ",", 
           RowBox[{
            RowBox[{"ryx", " ", "x"}], "+", 
            RowBox[{"ryy", " ", "y"}], "+", "y1"}], ",", "xn", ",", "yn", ",",
            "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"y", ",", 
           RowBox[{"1", "-", "y0"}], ",", 
           RowBox[{"yn", "-", "y0"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"1", "-", "x0"}], ",", 
           RowBox[{"xn", "-", "x0"}]}], "}"}]}], "\[IndentingNewLine]", 
        "]"}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"NCubicBSplineImageInterpolation", "[", 
          RowBox[{"_", ",", "_", ",", "_", ",", "_", ",", "_", ",", "_"}], 
          "]"}], ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"CubicBSplineImageInterpolationFilter", "[", "_", "]"}], ",",
          "_Real", ",", "2"}], "}"}]}], "}"}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "PackageInput",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["3D", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NConstantAffineTransform3D", "=", "\[IndentingNewLine]", 
   RowBox[{"Compile", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"img", ",", "_Real", ",", "3"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"x0", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y0", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"z0", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"x1", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y1", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"z1", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"rxx", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"rxy", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"rxz", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"ryx", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ryy", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ryz", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"rzx", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"rzy", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"rzz", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"offColor", ",", "_Real"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"With", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"xn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "3", "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{"yn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "2", "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{"zn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "1", "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
         "NConstantImageInterpolation3D", "[", "\[IndentingNewLine]", 
          RowBox[{"img", ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"rxx", " ", "x"}], "+", "x1", "+", 
            RowBox[{"rxy", " ", "y"}], "+", 
            RowBox[{"rxz", " ", "z"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"ryx", " ", "x"}], "+", 
            RowBox[{"ryy", " ", "y"}], "+", "y1", "+", 
            RowBox[{"ryz", " ", "z"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"rzx", " ", "x"}], "+", 
            RowBox[{"rzy", " ", "y"}], "+", 
            RowBox[{"rzz", " ", "z"}], "+", "z1"}], ",", 
           "\[IndentingNewLine]", "xn", ",", "yn", ",", "zn", ",", 
           "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"z", ",", 
           RowBox[{"1", "-", "z0"}], ",", 
           RowBox[{"zn", "-", "z0"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"y", ",", 
           RowBox[{"1", "-", "y0"}], ",", 
           RowBox[{"yn", "-", "y0"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"1", "-", "x0"}], ",", 
           RowBox[{"xn", "-", "x0"}]}], "}"}]}], "\[IndentingNewLine]", 
        "]"}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"NConstantImageInterpolation3D", "[", 
         RowBox[{
         "_", ",", "_", ",", "_", ",", "_", ",", "_", ",", "_", ",", "_", ",",
           "_"}], "]"}], ",", "_Real"}], "}"}], "}"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "PackageInput",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"NLinearAffineTransform3D", "=", "\[IndentingNewLine]", 
   RowBox[{"Compile", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"img", ",", "_Real", ",", "3"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"x0", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y0", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"z0", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"x1", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y1", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"z1", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"rxx", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"rxy", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"rxz", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"ryx", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ryy", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ryz", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"rzx", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"rzy", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"rzz", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"offColor", ",", "_Real"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"With", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"xn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "3", "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{"yn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "2", "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{"zn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "1", "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"NLinearImageInterpolation3D", "[", "\[IndentingNewLine]", 
          RowBox[{"img", ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"rxx", " ", "x"}], "+", "x1", "+", 
            RowBox[{"rxy", " ", "y"}], "+", 
            RowBox[{"rxz", " ", "z"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"ryx", " ", "x"}], "+", 
            RowBox[{"ryy", " ", "y"}], "+", "y1", "+", 
            RowBox[{"ryz", " ", "z"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"rzx", " ", "x"}], "+", 
            RowBox[{"rzy", " ", "y"}], "+", 
            RowBox[{"rzz", " ", "z"}], "+", "z1"}], ",", 
           "\[IndentingNewLine]", "xn", ",", "yn", ",", "zn", ",", 
           "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"z", ",", 
           RowBox[{"1", "-", "z0"}], ",", 
           RowBox[{"zn", "-", "z0"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"y", ",", 
           RowBox[{"1", "-", "y0"}], ",", 
           RowBox[{"yn", "-", "y0"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"1", "-", "x0"}], ",", 
           RowBox[{"xn", "-", "x0"}]}], "}"}]}], "\[IndentingNewLine]", 
        "]"}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"NLinearImageInterpolation3D", "[", 
         RowBox[{
         "_", ",", "_", ",", "_", ",", "_", ",", "_", ",", "_", ",", "_", ",",
           "_"}], "]"}], ",", "_Real"}], "}"}], "}"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "PackageInput",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"NCubicBSplineAffineTransform3D", "=", "\[IndentingNewLine]", 
   RowBox[{"Compile", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"img", ",", "_Real", ",", "3"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"x0", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y0", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"z0", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"x1", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y1", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"z1", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"rxx", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"rxy", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"rxz", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"ryx", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ryy", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ryz", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"rzx", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"rzy", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"rzz", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"offColor", ",", "_Real"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Module", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"xn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "3", "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{"yn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "2", "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{"zn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "1", "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{"tmp", "=", 
          RowBox[{
          "CubicBSplineImageInterpolationFilter", "[", "img", "]"}]}]}], 
        "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
         "NCubicBSplineImageInterpolation3D", "[", "\[IndentingNewLine]", 
          RowBox[{"tmp", ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"rxx", " ", "x"}], "+", "x1", "+", 
            RowBox[{"rxy", " ", "y"}], "+", 
            RowBox[{"rxz", " ", "z"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"ryx", " ", "x"}], "+", 
            RowBox[{"ryy", " ", "y"}], "+", "y1", "+", 
            RowBox[{"ryz", " ", "z"}]}], ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"rzx", " ", "x"}], "+", 
            RowBox[{"rzy", " ", "y"}], "+", 
            RowBox[{"rzz", " ", "z"}], "+", "z1"}], ",", 
           "\[IndentingNewLine]", "xn", ",", "yn", ",", "zn", ",", 
           "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"z", ",", 
           RowBox[{"1", "-", "z0"}], ",", 
           RowBox[{"zn", "-", "z0"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"y", ",", 
           RowBox[{"1", "-", "y0"}], ",", 
           RowBox[{"yn", "-", "y0"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"1", "-", "x0"}], ",", 
           RowBox[{"xn", "-", "x0"}]}], "}"}]}], "\[IndentingNewLine]", 
        "]"}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"NCubicBSplineImageInterpolation3D", "[", 
          RowBox[{
          "_", ",", "_", ",", "_", ",", "_", ",", "_", ",", "_", ",", "_", 
           ",", "_"}], "]"}], ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"CubicBSplineImageInterpolationFilter", "[", "_", "]"}], ",",
          "_Real", ",", "3"}], "}"}]}], "}"}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "PackageInput",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["2D in 3D", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NConstantAffine2DTransform3D", "=", "\[IndentingNewLine]", 
   RowBox[{"Compile", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"img", ",", "_Real", ",", "3"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"x0", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y0", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"x1", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y1", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"rxx", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"rxy", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"ryx", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ryy", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"offColor", ",", "_Real"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"With", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"xn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "3", "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{"yn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "2", "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{"zn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "1", "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
         "NConstant2DImageInterpolation3D", "[", "\[IndentingNewLine]", 
          RowBox[{"img", ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"rxx", " ", "x"}], "-", 
            RowBox[{"rxy", " ", "y"}], "+", "x1"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"ryx", " ", "x"}], "+", 
            RowBox[{"ryy", " ", "y"}], "+", "y1"}], ",", 
           "\[IndentingNewLine]", "xn", ",", "yn", ",", "zn", ",", 
           "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"y", ",", 
           RowBox[{"1", "-", "y0"}], ",", 
           RowBox[{"yn", "-", "y0"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"1", "-", "x0"}], ",", 
           RowBox[{"xn", "-", "x0"}]}], "}"}]}], "\[IndentingNewLine]", 
        "]"}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"NConstant2DImageInterpolation3D", "[", 
         RowBox[{
         "_", ",", "_", ",", "_", ",", "_", ",", "_", ",", "_", ",", "_"}], 
         "]"}], ",", "_Real", ",", "1"}], "}"}], "}"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "PackageInput",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"NLinearAffine2DTransform3D", "=", "\[IndentingNewLine]", 
   RowBox[{"Compile", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"img", ",", "_Real", ",", "3"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"x0", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y0", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"x1", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y1", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"rxx", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"rxy", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"ryx", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ryy", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"offColor", ",", "_Real"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"With", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"xn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "3", "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{"yn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "2", "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{"zn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "1", "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
         "NLinear2DImageInterpolation3D", "[", "\[IndentingNewLine]", 
          RowBox[{"img", ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"rxx", " ", "x"}], "-", 
            RowBox[{"rxy", " ", "y"}], "+", "x1"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"ryx", " ", "x"}], "+", 
            RowBox[{"ryy", " ", "y"}], "+", "y1"}], ",", 
           "\[IndentingNewLine]", "xn", ",", "yn", ",", "zn", ",", 
           "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"y", ",", 
           RowBox[{"1", "-", "y0"}], ",", 
           RowBox[{"yn", "-", "y0"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"1", "-", "x0"}], ",", 
           RowBox[{"xn", "-", "x0"}]}], "}"}]}], "\[IndentingNewLine]", 
        "]"}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"NLinear2DImageInterpolation3D", "[", 
         RowBox[{
         "_", ",", "_", ",", "_", ",", "_", ",", "_", ",", "_", ",", "_"}], 
         "]"}], ",", "_Real", ",", "1"}], "}"}], "}"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "PackageInput",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"NCubicBSplineAffine2DTransform3D", "=", "\[IndentingNewLine]", 
   RowBox[{"Compile", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"img", ",", "_Real", ",", "3"}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"x0", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y0", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"x1", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y1", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"rxx", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"rxy", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"ryx", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ryy", ",", "_Real"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"{", 
        RowBox[{"offColor", ",", "_Real"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Module", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"xn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "3", "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{"yn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "2", "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{"zn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "1", "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{"tmp", "=", 
          RowBox[{"CubicBSplineImageInterpolationFilter", "[", 
           RowBox[{"img", ",", "2"}], "]"}]}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
         "NCubicBSpline2DImageInterpolation3D", "[", "\[IndentingNewLine]", 
          RowBox[{"tmp", ",", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"rxx", " ", "x"}], "+", 
            RowBox[{"rxy", " ", "y"}], "+", "x1"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"ryx", " ", "x"}], "+", 
            RowBox[{"ryy", " ", "y"}], "+", "y1"}], ",", 
           "\[IndentingNewLine]", "xn", ",", "yn", ",", "offColor"}], "]"}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"y", ",", 
           RowBox[{"1", "-", "y0"}], ",", 
           RowBox[{"yn", "-", "y0"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"1", "-", "x0"}], ",", 
           RowBox[{"xn", "-", "x0"}]}], "}"}]}], "\[IndentingNewLine]", 
        "]"}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"NCubicBSpline2DImageInterpolation3D", "[", 
          RowBox[{
          "_", ",", "_", ",", "_", ",", "_", ",", "_", ",", "_", ",", "_"}], 
          "]"}], ",", "_Real", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"CubicBSplineImageInterpolationFilter", "[", 
          RowBox[{"_", ",", "_"}], "]"}], ",", "_Real", ",", "3"}], "}"}]}], 
      "}"}]}], "\[IndentingNewLine]", "]"}]}], ";"}]], "PackageInput",
 InitializationCell->True]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Combined Transformations", "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetAttributes", "[", 
   RowBox[{"Translate", ",", "HoldFirst"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetAttributes", "[", 
   RowBox[{"Rotate", ",", "HoldFirst"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetAttributes", "[", 
   RowBox[{"Scale", ",", "HoldFirst"}], "]"}], ";"}]}], "PackageInput",
 InitializationCell->True],

Cell[CellGroupData[{

Cell["Rotate-Scale-Translate", "Subsubsection"],

Cell["2D", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TranslateArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ScaleArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"RotateArray", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"img_", "?", "ArrayQ"}], ",", "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x0_", "?", "NumberQ"}], ",", 
          RowBox[{"y0_", "?", "NumberQ"}]}], "}"}], ",", 
        RowBox[{"offColor_:", "0"}], ",", 
        RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"sx_", "?", "NumberQ"}], ",", 
        RowBox[{"sy_", "?", "NumberQ"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x0_", "?", "NumberQ"}], ",", 
        RowBox[{"y0_", "?", "NumberQ"}]}], "}"}], ",", 
      RowBox[{"offColor_:", "0"}], ",", 
      RowBox[{"opts2___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tx_", "?", "NumberQ"}], ",", 
      RowBox[{"ty_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"offColor_:", "0"}], ",", 
    RowBox[{"opts3___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts3", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}], ",", 
         RowBox[{"{", "opts1", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "TranslateArray", "]"}], ",", 
        RowBox[{"Options", "[", "ScaleArray", "]"}], ",", 
        RowBox[{"Options", "[", "RotateArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffineTransform", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", "x0", ",", "y0", ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sy"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sy"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     "CubicBSplineInterpolation", ",", "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffineTransform", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", "x0", ",", "y0", ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sy"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sy"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffineTransform", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", "x0", ",", "y0", ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sy"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sy"}], ",", 
       "offColor"}], "]"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "2"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"TranslateArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RotateArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ScaleArray", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"img_", "?", "ArrayQ"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"sx_", "?", "NumberQ"}], ",", 
          RowBox[{"sy_", "?", "NumberQ"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x0_", "?", "NumberQ"}], ",", 
          RowBox[{"y0_", "?", "NumberQ"}]}], "}"}], ",", 
        RowBox[{"offColor_:", "0"}], ",", 
        RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x0_", "?", "NumberQ"}], ",", 
        RowBox[{"y0_", "?", "NumberQ"}]}], "}"}], ",", 
      RowBox[{"offColor_:", "0"}], ",", 
      RowBox[{"opts2___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tx_", "?", "NumberQ"}], ",", 
      RowBox[{"ty_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"offColor_:", "0"}], ",", 
    RowBox[{"opts3___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts3", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}], ",", 
         RowBox[{"{", "opts1", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "TranslateArray", "]"}], ",", 
        RowBox[{"Options", "[", "RotateArray", "]"}], ",", 
        RowBox[{"Options", "[", "ScaleArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffineTransform", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", "x0", ",", "y0", ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "/", "sy"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sy"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     "CubicBSplineInterpolation", ",", "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffineTransform", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", "x0", ",", "y0", ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "/", "sy"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sy"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffineTransform", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", "x0", ",", "y0", ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "/", "sy"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sy"}], ",", 
       "offColor"}], "]"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "2"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"ScaleArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RotateArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"TranslateArray", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"img_", "?", "ArrayQ"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"tx_", "?", "NumberQ"}], ",", 
          RowBox[{"ty_", "?", "NumberQ"}]}], "}"}], ",", 
        RowBox[{"offColor_:", "0"}], ",", 
        RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x0_", "?", "NumberQ"}], ",", 
        RowBox[{"y0_", "?", "NumberQ"}]}], "}"}], ",", 
      RowBox[{"offColor_:", "0"}], ",", 
      RowBox[{"opts2___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sx_", "?", "NumberQ"}], ",", 
      RowBox[{"sy_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x0_", "?", "NumberQ"}], ",", 
      RowBox[{"y0_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"offColor_:", "0"}], ",", 
    RowBox[{"opts3___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts1", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}], ",", 
         RowBox[{"{", "opts3", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "TranslateArray", "]"}], ",", 
        RowBox[{"Options", "[", "RotateArray", "]"}], ",", 
        RowBox[{"Options", "[", "ScaleArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffineTransform", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sy"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sy"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     "CubicBSplineInterpolation", ",", "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffineTransform", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sy"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sy"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffineTransform", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sy"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sy"}], ",", 
       "offColor"}], "]"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "2"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"RotateArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ScaleArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"TranslateArray", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"img_", "?", "ArrayQ"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"tx_", "?", "NumberQ"}], ",", 
          RowBox[{"ty_", "?", "NumberQ"}]}], "}"}], ",", 
        RowBox[{"offColor_:", "0"}], ",", 
        RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"sx_", "?", "NumberQ"}], ",", 
        RowBox[{"sy_", "?", "NumberQ"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x0_", "?", "NumberQ"}], ",", 
        RowBox[{"y0_", "?", "NumberQ"}]}], "}"}], ",", 
      RowBox[{"offColor_:", "0"}], ",", 
      RowBox[{"opts2___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x0_", "?", "NumberQ"}], ",", 
      RowBox[{"y0_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"offColor_:", "0"}], ",", 
    RowBox[{"opts3___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts1", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}], ",", 
         RowBox[{"{", "opts3", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "TranslateArray", "]"}], ",", 
        RowBox[{"Options", "[", "ScaleArray", "]"}], ",", 
        RowBox[{"Options", "[", "RotateArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffineTransform", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "/", "sy"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sy"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     "CubicBSplineInterpolation", ",", "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffineTransform", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "/", "sy"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sy"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffineTransform", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "/", "sy"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sy"}], ",", 
       "offColor"}], "]"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "2"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell["3D", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TranslateArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ScaleArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"RotateArray", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"img_", "?", "ArrayQ"}], ",", "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
        RowBox[{"\[Beta]_", "?", "NumericQ"}], ",", 
        RowBox[{"\[Gamma]_", "?", "NumericQ"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x0_", "?", "NumberQ"}], ",", 
          RowBox[{"y0_", "?", "NumberQ"}], ",", 
          RowBox[{"z0_", "?", "NumberQ"}]}], "}"}], ",", 
        RowBox[{"offColor_:", "0"}], ",", 
        RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"sx_", "?", "NumberQ"}], ",", 
        RowBox[{"sy_", "?", "NumberQ"}], ",", 
        RowBox[{"sz_", "?", "NumberQ"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x0_", "?", "NumberQ"}], ",", 
        RowBox[{"y0_", "?", "NumberQ"}], ",", 
        RowBox[{"z0_", "?", "NumberQ"}]}], "}"}], ",", 
      RowBox[{"offColor_:", "0"}], ",", 
      RowBox[{"opts2___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tx_", "?", "NumberQ"}], ",", 
      RowBox[{"ty_", "?", "NumberQ"}], ",", 
      RowBox[{"tz_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"offColor_:", "0"}], ",", 
    RowBox[{"opts3___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts1", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}], ",", 
         RowBox[{"{", "opts3", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "RotateArray", "]"}], ",", 
        RowBox[{"Options", "[", "ScaleArray", "]"}], ",", 
        RowBox[{"Options", "[", "TranslateArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffineTransform3D", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", 
       RowBox[{"z0", "+", "tz"}], ",", "x0", ",", "y0", ",", "z0", ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], ")"}], "/", "sz"}], 
       ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sx"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sy"}]}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     "CubicBSplineInterpolation", ",", "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffineTransform3D", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", 
       RowBox[{"z0", "+", "tz"}], ",", "x0", ",", "y0", ",", "z0", ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], ")"}], "/", "sz"}], 
       ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sx"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sy"}]}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffineTransform3D", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", 
       RowBox[{"z0", "+", "tz"}], ",", "x0", ",", "y0", ",", "z0", ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], ")"}], "/", "sz"}], 
       ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sx"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sy"}]}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}], ",", 
       "offColor"}], "]"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"TranslateArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ScaleArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"RotateArray", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"img_", "?", "ArrayQ"}], ",", "\[IndentingNewLine]", 
        RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
        RowBox[{"0", "|", "0.0"}], ",", 
        RowBox[{"\[Gamma]_", "?", "NumericQ"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x0_", "?", "NumberQ"}], ",", 
          RowBox[{"y0_", "?", "NumberQ"}], ",", "_"}], "}"}], ",", 
        RowBox[{"offColor_:", "0"}], ",", 
        RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"sx_", "?", "NumberQ"}], ",", 
        RowBox[{"sy_", "?", "NumberQ"}], ",", 
        RowBox[{"1", "|", "1.0"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x0_", "?", "NumberQ"}], ",", 
        RowBox[{"y0_", "?", "NumberQ"}], ",", "_"}], "}"}], ",", 
      RowBox[{"offColor_:", "0"}], ",", 
      RowBox[{"opts2___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tx_", "?", "NumberQ"}], ",", 
      RowBox[{"ty_", "?", "NumberQ"}], ",", 
      RowBox[{"0", "|", "0.0"}]}], "}"}], ",", 
    RowBox[{"offColor_:", "0"}], ",", 
    RowBox[{"opts3___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts1", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}], ",", 
         RowBox[{"{", "opts3", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "RotateArray", "]"}], ",", 
        RowBox[{"Options", "[", "ScaleArray", "]"}], ",", 
        RowBox[{"Options", "[", "TranslateArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffine2DTransform3D", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", "x0", ",", "y0", ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sy"}], 
       ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", 
           RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}]}], "/", "sx"}],
        ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sy"}], 
       ",", "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     "CubicBSplineInterpolation", ",", "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffine2DTransform3D", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", "x0", ",", "y0", ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sy"}], 
       ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", 
           RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}]}], "/", "sx"}],
        ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sy"}], 
       ",", "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffine2DTransform3D", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", "x0", ",", "y0", ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sy"}], 
       ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", 
           RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}]}], "/", "sx"}],
        ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sy"}], 
       ",", "offColor"}], "]"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"TranslateArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RotateArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ScaleArray", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"img_", "?", "ArrayQ"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"sx_", "?", "NumberQ"}], ",", 
          RowBox[{"sy_", "?", "NumberQ"}], ",", 
          RowBox[{"sz_", "?", "NumberQ"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x0_", "?", "NumberQ"}], ",", 
          RowBox[{"y0_", "?", "NumberQ"}], ",", 
          RowBox[{"z0_", "?", "NumberQ"}]}], "}"}], ",", 
        RowBox[{"offColor_:", "0"}], ",", 
        RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
      RowBox[{"\[Beta]_", "?", "NumericQ"}], ",", 
      RowBox[{"\[Gamma]_", "?", "NumericQ"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x0_", "?", "NumberQ"}], ",", 
        RowBox[{"y0_", "?", "NumberQ"}], ",", 
        RowBox[{"z0_", "?", "NumberQ"}]}], "}"}], ",", 
      RowBox[{"offColor_:", "0"}], ",", 
      RowBox[{"opts2___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tx_", "?", "NumberQ"}], ",", 
      RowBox[{"ty_", "?", "NumberQ"}], ",", 
      RowBox[{"tz_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"offColor_:", "0"}], ",", 
    RowBox[{"opts3___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts1", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}], ",", 
         RowBox[{"{", "opts3", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "ScaleArray", "]"}], ",", 
        RowBox[{"Options", "[", "RotateArray", "]"}], ",", 
        RowBox[{"Options", "[", "TranslateArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffineTransform3D", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", 
       RowBox[{"z0", "+", "tz"}], ",", "x0", ",", "y0", ",", "z0", ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], ")"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sy"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}]}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     "CubicBSplineInterpolation", ",", "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffineTransform3D", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", 
       RowBox[{"z0", "+", "tz"}], ",", "x0", ",", "y0", ",", "z0", ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], ")"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sy"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}]}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffineTransform3D", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", 
       RowBox[{"z0", "+", "tz"}], ",", "x0", ",", "y0", ",", "z0", ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], ")"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sy"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}]}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}], ",", 
       "offColor"}], "]"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"TranslateArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RotateArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ScaleArray", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"img_", "?", "ArrayQ"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"sx_", "?", "NumberQ"}], ",", 
          RowBox[{"sy_", "?", "NumberQ"}], ",", 
          RowBox[{"1", "|", "1.0"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x0_", "?", "NumberQ"}], ",", 
          RowBox[{"y0_", "?", "NumberQ"}], ",", "_"}], "}"}], ",", 
        RowBox[{"offColor_:", "0"}], ",", 
        RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
      RowBox[{"0", "|", "0.0"}], ",", 
      RowBox[{"\[Gamma]_", "?", "NumericQ"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x0_", "?", "NumberQ"}], ",", 
        RowBox[{"y0_", "?", "NumberQ"}], ",", "_"}], "}"}], ",", 
      RowBox[{"offColor_:", "0"}], ",", 
      RowBox[{"opts2___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tx_", "?", "NumberQ"}], ",", 
      RowBox[{"ty_", "?", "NumberQ"}], ",", 
      RowBox[{"0", "|", "0.0"}]}], "}"}], ",", 
    RowBox[{"offColor_:", "0"}], ",", 
    RowBox[{"opts3___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts1", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}], ",", 
         RowBox[{"{", "opts3", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "ScaleArray", "]"}], ",", 
        RowBox[{"Options", "[", "RotateArray", "]"}], ",", 
        RowBox[{"Options", "[", "TranslateArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffine2DTransform3D", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", "x0", ",", "y0", ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", 
           RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}]}], "/", "sy"}],
        ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sy"}], 
       ",", "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     "CubicBSplineInterpolation", ",", "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffine2DTransform3D", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", "x0", ",", "y0", ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", 
           RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}]}], "/", "sy"}],
        ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sy"}], 
       ",", "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffine2DTransform3D", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", "x0", ",", "y0", ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", 
           RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}]}], "/", "sy"}],
        ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sy"}], 
       ",", "offColor"}], "]"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"ScaleArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RotateArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"TranslateArray", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"img_", "?", "ArrayQ"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"tx_", "?", "NumberQ"}], ",", 
          RowBox[{"ty_", "?", "NumberQ"}], ",", 
          RowBox[{"tz_", "?", "NumberQ"}]}], "}"}], ",", 
        RowBox[{"offColor_:", "0"}], ",", 
        RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
      RowBox[{"\[Beta]_", "?", "NumericQ"}], ",", 
      RowBox[{"\[Gamma]_", "?", "NumericQ"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x0_", "?", "NumberQ"}], ",", 
        RowBox[{"y0_", "?", "NumberQ"}], ",", 
        RowBox[{"z0_", "?", "NumberQ"}]}], "}"}], ",", 
      RowBox[{"offColor_:", "0"}], ",", 
      RowBox[{"opts2___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sx_", "?", "NumberQ"}], ",", 
      RowBox[{"sy_", "?", "NumberQ"}], ",", 
      RowBox[{"sz_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x0_", "?", "NumberQ"}], ",", 
      RowBox[{"y0_", "?", "NumberQ"}], ",", 
      RowBox[{"z0_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"offColor_:", "0"}], ",", 
    RowBox[{"opts3___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts1", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}], ",", 
         RowBox[{"{", "opts3", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "TranslateArray", "]"}], ",", 
        RowBox[{"Options", "[", "RotateArray", "]"}], ",", 
        RowBox[{"Options", "[", "ScaleArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffineTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "z0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{"z0", "-", "tz"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], ")"}], "/", "sz"}], 
       ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sx"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sy"}]}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     "CubicBSplineInterpolation", ",", "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffineTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "z0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{"z0", "-", "tz"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], ")"}], "/", "sz"}], 
       ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sx"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sy"}]}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffineTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "z0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{"z0", "-", "tz"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], ")"}], "/", "sz"}], 
       ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sx"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sy"}]}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}], ",", 
       "offColor"}], "]"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"ScaleArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RotateArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"TranslateArray", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"img_", "?", "ArrayQ"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"tx_", "?", "NumberQ"}], ",", 
          RowBox[{"ty_", "?", "NumberQ"}], ",", 
          RowBox[{"0", "|", "0.0"}]}], "}"}], ",", 
        RowBox[{"offColor_:", "0"}], ",", 
        RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
      RowBox[{"0", "|", "0.0"}], ",", 
      RowBox[{"\[Gamma]_", "?", "NumericQ"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x0_", "?", "NumberQ"}], ",", 
        RowBox[{"y0_", "?", "NumberQ"}], ",", "_"}], "}"}], ",", 
      RowBox[{"offColor_:", "0"}], ",", 
      RowBox[{"opts2___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sx_", "?", "NumberQ"}], ",", 
      RowBox[{"sy_", "?", "NumberQ"}], ",", 
      RowBox[{"1", "|", "1.0"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x0_", "?", "NumberQ"}], ",", 
      RowBox[{"y0_", "?", "NumberQ"}], ",", "_"}], "}"}], ",", 
    RowBox[{"offColor_:", "0"}], ",", 
    RowBox[{"opts3___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts1", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}], ",", 
         RowBox[{"{", "opts3", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "TranslateArray", "]"}], ",", 
        RowBox[{"Options", "[", "RotateArray", "]"}], ",", 
        RowBox[{"Options", "[", "ScaleArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffine2DTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sy"}], 
       ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", 
           RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}]}], "/", "sx"}],
        ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sy"}], 
       ",", "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     "CubicBSplineInterpolation", ",", "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffine2DTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sy"}], 
       ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", 
           RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}]}], "/", "sx"}],
        ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sy"}], 
       ",", "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffine2DTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sy"}], 
       ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", 
           RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}]}], "/", "sx"}],
        ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sy"}], 
       ",", "offColor"}], "]"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"RotateArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ScaleArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"TranslateArray", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"img_", "?", "ArrayQ"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"tx_", "?", "NumberQ"}], ",", 
          RowBox[{"ty_", "?", "NumberQ"}], ",", 
          RowBox[{"tz_", "?", "NumberQ"}]}], "}"}], ",", 
        RowBox[{"offColor_:", "0"}], ",", 
        RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"sx_", "?", "NumberQ"}], ",", 
        RowBox[{"sy_", "?", "NumberQ"}], ",", 
        RowBox[{"sz_", "?", "NumberQ"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x0_", "?", "NumberQ"}], ",", 
        RowBox[{"y0_", "?", "NumberQ"}], ",", 
        RowBox[{"z0_", "?", "NumberQ"}]}], "}"}], ",", 
      RowBox[{"offColor_:", "0"}], ",", 
      RowBox[{"opts2___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
    RowBox[{"\[Beta]_", "?", "NumericQ"}], ",", 
    RowBox[{"\[Gamma]_", "?", "NumericQ"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x0_", "?", "NumberQ"}], ",", 
      RowBox[{"y0_", "?", "NumberQ"}], ",", 
      RowBox[{"z0_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"offColor_:", "0"}], ",", 
    RowBox[{"opts3___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts1", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}], ",", 
         RowBox[{"{", "opts3", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "TranslateArray", "]"}], ",", 
        RowBox[{"Options", "[", "ScaleArray", "]"}], ",", 
        RowBox[{"Options", "[", "RotateArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffineTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "z0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{"z0", "-", "tz"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], ")"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sy"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}]}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     "CubicBSplineInterpolation", ",", "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffineTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "z0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{"z0", "-", "tz"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], ")"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sy"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}]}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffineTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "z0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{"z0", "-", "tz"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], ")"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sy"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}]}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}], ",", 
       "offColor"}], "]"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"RotateArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ScaleArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"TranslateArray", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"img_", "?", "ArrayQ"}], ",", "\[IndentingNewLine]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"tx_", "?", "NumberQ"}], ",", 
          RowBox[{"ty_", "?", "NumberQ"}], ",", 
          RowBox[{"0", "|", "0.0"}]}], "}"}], ",", 
        RowBox[{"offColor_:", "0"}], ",", 
        RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
      ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"sx_", "?", "NumberQ"}], ",", 
        RowBox[{"sy_", "?", "NumberQ"}], ",", 
        RowBox[{"1", "|", "1.0"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x0_", "?", "NumberQ"}], ",", 
        RowBox[{"y0_", "?", "NumberQ"}], ",", "_"}], "}"}], ",", 
      RowBox[{"offColor_:", "0"}], ",", 
      RowBox[{"opts2___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
    RowBox[{"0", "|", "0.0"}], ",", 
    RowBox[{"\[Gamma]_", "?", "NumericQ"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x0_", "?", "NumberQ"}], ",", 
      RowBox[{"y0_", "?", "NumberQ"}], ",", "_"}], "}"}], ",", 
    RowBox[{"offColor_:", "0"}], ",", 
    RowBox[{"opts3___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts1", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}], ",", 
         RowBox[{"{", "opts3", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "TranslateArray", "]"}], ",", 
        RowBox[{"Options", "[", "ScaleArray", "]"}], ",", 
        RowBox[{"Options", "[", "RotateArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffine2DTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", 
           RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}]}], "/", "sy"}],
        ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sy"}], 
       ",", "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     "CubicBSplineInterpolation", ",", "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffine2DTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", 
           RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}]}], "/", "sy"}],
        ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sy"}], 
       ",", "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffine2DTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", 
           RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}]}], "/", "sy"}],
        ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sy"}], 
       ",", "offColor"}], "]"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rotate-Translate", "Subsubsection"],

Cell["2D", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RotateArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TranslateArray", "[", "\[IndentingNewLine]", 
     RowBox[{"img_", ",", 
      RowBox[{"{", 
       RowBox[{"tx_", ",", "ty_"}], "}"}], ",", 
      RowBox[{"offColor_:", "0"}], ",", 
      RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", "\[IndentingNewLine]", "\[Alpha]_", ",", 
    RowBox[{"{", 
     RowBox[{"x0_", ",", "y0_"}], "}"}], ",", 
    RowBox[{"offColor_:", "0"}], ",", 
    RowBox[{"opts2___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts1", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "TranslateArray", "]"}], ",", 
        RowBox[{"Options", "[", "RotateArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffineTransform", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], ",", 
       RowBox[{"Sin", "[", 
        RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], ",", 
       RowBox[{"-", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], ",", "offColor"}], "]"}], 
     ",", "\[IndentingNewLine]", "CubicBSplineInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffineTransform", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], ",", 
       RowBox[{"Sin", "[", 
        RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], ",", 
       RowBox[{"-", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], ",", "offColor"}], "]"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffineTransform", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], ",", 
       RowBox[{"Sin", "[", 
        RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], ",", 
       RowBox[{"-", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], ",", "offColor"}], 
      "]"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "2"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"TranslateArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RotateArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"img_", "?", "ArrayQ"}], ",", 
      RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x0_", "?", "NumberQ"}], ",", 
        RowBox[{"y0_", "?", "NumberQ"}]}], "}"}], ",", 
      RowBox[{"offColor_:", "0"}], ",", 
      RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tx_", "?", "NumberQ"}], ",", 
      RowBox[{"ty_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"offColor_:", "0"}], ",", 
    RowBox[{"opts2___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts1", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "RotateArray", "]"}], ",", 
        RowBox[{"Options", "[", "TranslateArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffineTransform", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", "x0", ",", "y0", ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], ",", 
       RowBox[{"Sin", "[", 
        RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], ",", 
       RowBox[{"-", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], ",", "offColor"}], "]"}], 
     ",", "\[IndentingNewLine]", "CubicBSplineInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffineTransform", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", "x0", ",", "y0", ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], ",", 
       RowBox[{"Sin", "[", 
        RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], ",", 
       RowBox[{"-", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], ",", "offColor"}], "]"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffineTransform", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", "x0", ",", "y0", ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], ",", 
       RowBox[{"Sin", "[", 
        RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], ",", 
       RowBox[{"-", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], ",", "offColor"}], 
      "]"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "2"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell["3D", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RotateArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TranslateArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"img_", "?", "ArrayQ"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"tx_", "?", "NumberQ"}], ",", 
        RowBox[{"ty_", "?", "NumberQ"}], ",", 
        RowBox[{"tz_", "?", "NumberQ"}]}], "}"}], ",", 
      RowBox[{"offColor_:", "0"}], ",", 
      RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
    RowBox[{"\[Beta]_", "?", "NumericQ"}], ",", 
    RowBox[{"\[Gamma]_", "?", "NumericQ"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x0_", "?", "NumberQ"}], ",", 
      RowBox[{"y0_", "?", "NumberQ"}], ",", 
      RowBox[{"z0_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"offColor_:", "0"}], ",", 
    RowBox[{"opts2___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts1", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "TranslateArray", "]"}], ",", 
        RowBox[{"Options", "[", "RotateArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffineTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "z0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{"z0", "-", "tz"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Cos", "[", 
           RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], ",", "offColor"}], "]"}], 
     ",", "\[IndentingNewLine]", "CubicBSplineInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffineTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "z0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{"z0", "-", "tz"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Cos", "[", 
           RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], ",", "offColor"}], "]"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffineTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "z0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{"z0", "-", "tz"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Cos", "[", 
           RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], ",", "offColor"}], "]"}]}],
     "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"RotateArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TranslateArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"img_", "?", "ArrayQ"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"tx_", "?", "NumberQ"}], ",", 
        RowBox[{"ty_", "?", "NumberQ"}], ",", 
        RowBox[{"0", "|", "0.0"}]}], "}"}], ",", 
      RowBox[{"offColor_:", "0"}], ",", 
      RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
    RowBox[{"0", "|", "0.0"}], ",", 
    RowBox[{"\[Gamma]_", "?", "NumericQ"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x0_", "?", "NumberQ"}], ",", 
      RowBox[{"y0_", "?", "NumberQ"}], ",", "_"}], "}"}], ",", 
    RowBox[{"offColor_:", "0"}], ",", 
    RowBox[{"opts2___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts1", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "TranslateArray", "]"}], ",", 
        RowBox[{"Options", "[", "RotateArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffine2DTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", 
         RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], ",", 
       RowBox[{"Sin", "[", 
        RowBox[{"N", "[", 
         RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], ",", 
       RowBox[{"-", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}]}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", 
         RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     "CubicBSplineInterpolation", ",", "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffine2DTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", 
         RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], ",", 
       RowBox[{"Sin", "[", 
        RowBox[{"N", "[", 
         RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], ",", 
       RowBox[{"-", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}]}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", 
         RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffine2DTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", 
         RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], ",", 
       RowBox[{"Sin", "[", 
        RowBox[{"N", "[", 
         RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], ",", 
       RowBox[{"-", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}]}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", 
         RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], ",", 
       "offColor"}], "]"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"TranslateArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RotateArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"img_", "?", "ArrayQ"}], ",", "\[IndentingNewLine]", 
      RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
      RowBox[{"\[Beta]_", "?", "NumericQ"}], ",", 
      RowBox[{"\[Gamma]_", "?", "NumericQ"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x0_", "?", "NumberQ"}], ",", 
        RowBox[{"y0_", "?", "NumberQ"}], ",", 
        RowBox[{"z0_", "?", "NumberQ"}]}], "}"}], ",", 
      RowBox[{"offColor_:", "0"}], ",", 
      RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tx_", "?", "NumberQ"}], ",", 
      RowBox[{"ty_", "?", "NumberQ"}], ",", 
      RowBox[{"tz_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"offColor_:", "0"}], ",", 
    RowBox[{"opts2___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts1", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "RotateArray", "]"}], ",", 
        RowBox[{"Options", "[", "TranslateArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffineTransform3D", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", 
       RowBox[{"z0", "+", "tz"}], ",", "x0", ",", "y0", ",", "z0", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Cos", "[", 
           RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], ",", "offColor"}], "]"}], 
     ",", "\[IndentingNewLine]", "CubicBSplineInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffineTransform3D", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", 
       RowBox[{"z0", "+", "tz"}], ",", "x0", ",", "y0", ",", "z0", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Cos", "[", 
           RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], ",", "offColor"}], "]"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffineTransform3D", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", 
       RowBox[{"z0", "+", "tz"}], ",", "x0", ",", "y0", ",", "z0", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Cos", "[", 
           RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], ",", "offColor"}], "]"}]}],
     "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"TranslateArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RotateArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"img_", "?", "ArrayQ"}], ",", 
      RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
      RowBox[{"0", "|", "0.0"}], ",", 
      RowBox[{"\[Gamma]_", "?", "NumericQ"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x0_", "?", "NumberQ"}], ",", 
        RowBox[{"y0_", "?", "NumberQ"}], ",", "_"}], "}"}], ",", 
      RowBox[{"offColor_:", "0"}], ",", 
      RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tx_", "?", "NumberQ"}], ",", 
      RowBox[{"ty_", "?", "NumberQ"}], ",", 
      RowBox[{"0", "|", "0.0"}]}], "}"}], ",", 
    RowBox[{"offColor_:", "0"}], ",", 
    RowBox[{"opts2___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts1", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "RotateArray", "]"}], ",", 
        RowBox[{"Options", "[", "TranslateArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffine2DTransform3D", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", "x0", ",", "y0", ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", 
         RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], ",", 
       RowBox[{"Sin", "[", 
        RowBox[{"N", "[", 
         RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], ",", 
       RowBox[{"-", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}]}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", 
         RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     "CubicBSplineInterpolation", ",", "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffine2DTransform3D", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", "x0", ",", "y0", ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", 
         RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], ",", 
       RowBox[{"Sin", "[", 
        RowBox[{"N", "[", 
         RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], ",", 
       RowBox[{"-", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}]}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", 
         RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffine2DTransform3D", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", "x0", ",", "y0", ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", 
         RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], ",", 
       RowBox[{"Sin", "[", 
        RowBox[{"N", "[", 
         RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], ",", 
       RowBox[{"-", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}]}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", 
         RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], ",", 
       "offColor"}], "]"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Scale-Translate", "Subsubsection"],

Cell["2D", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ScaleArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TranslateArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"img_", "?", "ArrayQ"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"tx_", "?", "NumberQ"}], ",", 
        RowBox[{"ty_", "?", "NumberQ"}]}], "}"}], ",", 
      RowBox[{"offColor_:", "0"}], ",", 
      RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sx_", "?", "NumberQ"}], ",", 
      RowBox[{"sy_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x0_", "?", "NumberQ"}], ",", 
      RowBox[{"y0_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"offColor_:", "0"}], ",", 
    RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts1", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "TranslateArray", "]"}], ",", 
        RowBox[{"Options", "[", "ScaleArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffineTransform", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{"1", "/", "sx"}], ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sy"}], ",", "offColor"}], "]"}], ",", 
     "\[IndentingNewLine]", "CubicBSplineInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffineTransform", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{"1", "/", "sx"}], ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sy"}], ",", "offColor"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffineTransform", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{"1", "/", "sx"}], ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sy"}], ",", "offColor"}], "]"}]}], 
    "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "2"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"TranslateArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ScaleArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"img_", "?", "ArrayQ"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"sx_", "?", "NumberQ"}], ",", 
        RowBox[{"sy_", "?", "NumberQ"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x0_", "?", "NumberQ"}], ",", 
        RowBox[{"y0_", "?", "NumberQ"}]}], "}"}], ",", 
      RowBox[{"offColor_:", "0"}], ",", 
      RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tx_", "?", "NumberQ"}], ",", 
      RowBox[{"ty_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"offColor_:", "0"}], ",", 
    RowBox[{"opts2___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts1", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "ScaleArray", "]"}], ",", 
        RowBox[{"Options", "[", "TranslateArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffineTransform", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", "x0", ",", "y0", ",", 
       RowBox[{"1", "/", "sx"}], ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sy"}], ",", "offColor"}], "]"}], ",", 
     "\[IndentingNewLine]", "CubicBSplineInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffineTransform", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", "x0", ",", "y0", ",", 
       RowBox[{"1", "/", "sx"}], ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sy"}], ",", "offColor"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffineTransform", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", "x0", ",", "y0", ",", 
       RowBox[{"1", "/", "sx"}], ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sy"}], ",", "offColor"}], "]"}]}], 
    "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "2"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell["3D", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ScaleArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TranslateArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"img_", "?", "ArrayQ"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"tx_", "?", "NumberQ"}], ",", 
        RowBox[{"ty_", "?", "NumberQ"}], ",", 
        RowBox[{"tz_", "?", "NumberQ"}]}], "}"}], ",", 
      RowBox[{"offColor_:", "0"}], ",", 
      RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sx_", "?", "NumberQ"}], ",", 
      RowBox[{"sy_", "?", "NumberQ"}], ",", 
      RowBox[{"sz_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x0_", "?", "NumberQ"}], ",", 
      RowBox[{"y0_", "?", "NumberQ"}], ",", 
      RowBox[{"z0_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"offColor_:", "0"}], ",", 
    RowBox[{"opts2___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts1", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "TranslateArray", "]"}], ",", 
        RowBox[{"Options", "[", "ScaleArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffineTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "z0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{"z0", "-", "tz"}], ",", 
       RowBox[{"1", "/", "sx"}], ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sy"}], ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sz"}], ",", "offColor"}], "]"}], ",", 
     "\[IndentingNewLine]", "CubicBSplineInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffineTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "z0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{"z0", "-", "tz"}], ",", 
       RowBox[{"1", "/", "sx"}], ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sy"}], ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sz"}], ",", "offColor"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffineTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "z0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{"z0", "-", "tz"}], ",", 
       RowBox[{"1", "/", "sx"}], ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sy"}], ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sz"}], ",", "offColor"}], "]"}]}], 
    "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"TranslateArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ScaleArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"img_", "?", "ArrayQ"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"sx_", "?", "NumberQ"}], ",", 
        RowBox[{"sy_", "?", "NumberQ"}], ",", 
        RowBox[{"sz_", "?", "NumberQ"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x0_", "?", "NumberQ"}], ",", 
        RowBox[{"y0_", "?", "NumberQ"}], ",", 
        RowBox[{"z0_", "?", "NumberQ"}]}], "}"}], ",", 
      RowBox[{"offColor_:", "0"}], ",", 
      RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tx_", "?", "NumberQ"}], ",", 
      RowBox[{"ty_", "?", "NumberQ"}], ",", 
      RowBox[{"tz_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"offColor_:", "0"}], ",", 
    RowBox[{"opts2___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts1", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "ScaleArray", "]"}], ",", 
        RowBox[{"Options", "[", "TranslateArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffineTransform3D", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", 
       RowBox[{"z0", "+", "tz"}], ",", "x0", ",", "y0", ",", "z0", ",", 
       RowBox[{"1", "/", "sx"}], ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sy"}], ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sz"}], ",", "offColor"}], "]"}], ",", 
     "\[IndentingNewLine]", "CubicBSplineInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffineTransform3D", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", 
       RowBox[{"z0", "+", "tz"}], ",", "x0", ",", "y0", ",", "z0", ",", 
       RowBox[{"1", "/", "sx"}], ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sy"}], ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sz"}], ",", "offColor"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffineTransform3D", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", 
       RowBox[{"z0", "+", "tz"}], ",", "x0", ",", "y0", ",", "z0", ",", 
       RowBox[{"1", "/", "sx"}], ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sy"}], ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sz"}], ",", "offColor"}], "]"}]}], 
    "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"ScaleArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"TranslateArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"img_", "?", "ArrayQ"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"tx_", "?", "NumberQ"}], ",", 
        RowBox[{"ty_", "?", "NumberQ"}], ",", 
        RowBox[{"0", "|", "0.0"}]}], "}"}], ",", 
      RowBox[{"offColor", ":", 
       RowBox[{
        RowBox[{"Except", "[", 
         RowBox[{
          RowBox[{"_Rule", " ", "|", " ", "_RuleDelayed"}], ",", " ", "_"}], 
         "]"}], ":", "0"}]}], ",", 
      RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sx_", "?", "NumberQ"}], ",", 
      RowBox[{"sy_", "?", "NumberQ"}], ",", 
      RowBox[{"1", "|", "1.0"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x0_", "?", "NumberQ"}], ",", 
      RowBox[{"y0_", "?", "NumberQ"}], ",", 
      RowBox[{"z0_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"offColor", ":", 
     RowBox[{
      RowBox[{"Except", "[", 
       RowBox[{
        RowBox[{"_Rule", " ", "|", " ", "_RuleDelayed"}], ",", " ", "_"}], 
       "]"}], ":", "0"}]}], ",", 
    RowBox[{"opts2___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts1", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "TranslateArray", "]"}], ",", 
        RowBox[{"Options", "[", "ScaleArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffineTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{"1", "/", "sx"}], ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sy"}], ",", "offColor"}], "]"}], ",", 
     "\[IndentingNewLine]", "CubicBSplineInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffineTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{"1", "/", "sx"}], ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sy"}], ",", "offColor"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffineTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", 
       RowBox[{"x0", "-", "tx"}], ",", 
       RowBox[{"y0", "-", "ty"}], ",", 
       RowBox[{"1", "/", "sx"}], ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sy"}], ",", "offColor"}], "]"}]}], 
    "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"TranslateArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ScaleArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"img_", "?", "ArrayQ"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"sx_", "?", "NumberQ"}], ",", 
        RowBox[{"sy_", "?", "NumberQ"}], ",", 
        RowBox[{"1", "|", "1.0"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x0_", "?", "NumberQ"}], ",", 
        RowBox[{"y0_", "?", "NumberQ"}], ",", "_"}], "}"}], ",", 
      RowBox[{"offColor", ":", 
       RowBox[{
        RowBox[{"Except", "[", 
         RowBox[{
          RowBox[{"_Rule", " ", "|", " ", "_RuleDelayed"}], ",", " ", "_"}], 
         "]"}], ":", "0"}]}], ",", 
      RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tx_", "?", "NumberQ"}], ",", 
      RowBox[{"ty_", "?", "NumberQ"}], ",", 
      RowBox[{"0", "|", "0.0"}]}], "}"}], ",", 
    RowBox[{"offColor", ":", 
     RowBox[{
      RowBox[{"Except", "[", 
       RowBox[{
        RowBox[{"_Rule", " ", "|", " ", "_RuleDelayed"}], ",", " ", "_"}], 
       "]"}], ":", "0"}]}], ",", 
    RowBox[{"opts2___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts1", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "ScaleArray", "]"}], ",", 
        RowBox[{"Options", "[", "TranslateArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffine2DTransform3D", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", "x0", ",", "y0", ",", 
       RowBox[{"1", "/", "sx"}], ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sy"}], ",", "offColor"}], "]"}], ",", 
     "\[IndentingNewLine]", "CubicBSplineInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffine2DTransform3D", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", "x0", ",", "y0", ",", 
       RowBox[{"1", "/", "sx"}], ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sy"}], ",", "offColor"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffine2DTransform3D", "[", 
      RowBox[{"img", ",", 
       RowBox[{"x0", "+", "tx"}], ",", 
       RowBox[{"y0", "+", "ty"}], ",", "x0", ",", "y0", ",", 
       RowBox[{"1", "/", "sx"}], ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sy"}], ",", "offColor"}], "]"}]}], 
    "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rotate-Scale", "Subsubsection"],

Cell["2D", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ScaleArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RotateArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"img_", "?", "ArrayQ"}], ",", "\[IndentingNewLine]", 
      RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x0_", "?", "NumberQ"}], ",", 
        RowBox[{"y0_", "?", "NumberQ"}]}], "}"}], ",", 
      RowBox[{"offColor", ":", 
       RowBox[{
        RowBox[{"Except", "[", 
         RowBox[{
          RowBox[{"_Rule", " ", "|", " ", "_RuleDelayed"}], ",", " ", "_"}], 
         "]"}], ":", "0"}]}], ",", 
      RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sx_", "?", "NumberQ"}], ",", 
      RowBox[{"sy_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x0_", "?", "NumberQ"}], ",", 
      RowBox[{"y0_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"offColor", ":", 
     RowBox[{
      RowBox[{"Except", "[", 
       RowBox[{
        RowBox[{"_Rule", " ", "|", " ", "_RuleDelayed"}], ",", " ", "_"}], 
       "]"}], ":", "0"}]}], ",", 
    RowBox[{"opts2___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts1", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "RotateArray", "]"}], ",", 
        RowBox[{"Options", "[", "ScaleArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffineTransform", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "x0", ",", "y0", ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sy"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sy"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     "CubicBSplineInterpolation", ",", "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffineTransform", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "x0", ",", "y0", ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sy"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sy"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffineTransform", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "x0", ",", "y0", ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sy"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sy"}], ",", 
       "offColor"}], "]"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "2"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"RotateArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ScaleArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"img_", "?", "ArrayQ"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"sx_", "?", "NumberQ"}], ",", 
        RowBox[{"sy_", "?", "NumberQ"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x0_", "?", "NumberQ"}], ",", 
        RowBox[{"y0_", "?", "NumberQ"}]}], "}"}], ",", 
      RowBox[{"offColor", ":", 
       RowBox[{
        RowBox[{"Except", "[", 
         RowBox[{
          RowBox[{"_Rule", " ", "|", " ", "_RuleDelayed"}], ",", " ", "_"}], 
         "]"}], ":", "0"}]}], ",", 
      RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x0_", "?", "NumberQ"}], ",", 
      RowBox[{"y0_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"offColor", ":", 
     RowBox[{
      RowBox[{"Except", "[", 
       RowBox[{
        RowBox[{"_Rule", " ", "|", " ", "_RuleDelayed"}], ",", " ", "_"}], 
       "]"}], ":", "0"}]}], ",", 
    RowBox[{"opts2___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts1", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "ScaleArray", "]"}], ",", 
        RowBox[{"Options", "[", "RotateArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffineTransform", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "x0", ",", "y0", ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "/", "sy"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sy"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     "CubicBSplineInterpolation", ",", "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffineTransform", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "x0", ",", "y0", ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "/", "sy"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sy"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffineTransform", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "x0", ",", "y0", ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sx"}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "/", "sy"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "/", "sy"}], ",", 
       "offColor"}], "]"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "2"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell["3D", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ScaleArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RotateArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"img_", "?", "ArrayQ"}], ",", "\[IndentingNewLine]", 
      RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
      RowBox[{"\[Beta]_", "?", "NumericQ"}], ",", 
      RowBox[{"\[Gamma]_", "?", "NumericQ"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x0_", "?", "NumberQ"}], ",", 
        RowBox[{"y0_", "?", "NumberQ"}], ",", 
        RowBox[{"z0_", "?", "NumberQ"}]}], "}"}], ",", 
      RowBox[{"offColor", ":", 
       RowBox[{
        RowBox[{"Except", "[", 
         RowBox[{
          RowBox[{"_Rule", " ", "|", " ", "_RuleDelayed"}], ",", " ", "_"}], 
         "]"}], ":", "0"}]}], ",", 
      RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sx_", "?", "NumberQ"}], ",", 
      RowBox[{"sy_", "?", "NumberQ"}], ",", 
      RowBox[{"sz_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x0_", "?", "NumberQ"}], ",", 
      RowBox[{"y0_", "?", "NumberQ"}], ",", 
      RowBox[{"z0_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"offColor", ":", 
     RowBox[{
      RowBox[{"Except", "[", 
       RowBox[{
        RowBox[{"_Rule", " ", "|", " ", "_RuleDelayed"}], ",", " ", "_"}], 
       "]"}], ":", "0"}]}], ",", 
    RowBox[{"opts2___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts1", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "RotateArray", "]"}], ",", 
        RowBox[{"Options", "[", "ScaleArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffineTransform3D", "[", 
      RowBox[{
      "img", ",", "x0", ",", "y0", ",", "z0", ",", "x0", ",", "y0", ",", "z0",
        ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], ")"}], "/", "sz"}], 
       ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sx"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sy"}]}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     "CubicBSplineInterpolation", ",", "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffineTransform3D", "[", 
      RowBox[{
      "img", ",", "x0", ",", "y0", ",", "z0", ",", "x0", ",", "y0", ",", "z0",
        ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], ")"}], "/", "sz"}], 
       ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sx"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sy"}]}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffineTransform3D", "[", 
      RowBox[{
      "img", ",", "x0", ",", "y0", ",", "z0", ",", "x0", ",", "y0", ",", "z0",
        ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], ")"}], "/", "sz"}], 
       ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sx"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sy"}]}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}], ",", 
       "offColor"}], "]"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"ScaleArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RotateArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"img_", "?", "ArrayQ"}], ",", "\[IndentingNewLine]", 
      RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
      RowBox[{"0", "|", "0.0"}], ",", 
      RowBox[{"\[Gamma]_", "?", "NumericQ"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x0_", "?", "NumberQ"}], ",", 
        RowBox[{"y0_", "?", "NumberQ"}], ",", "_"}], "}"}], ",", 
      RowBox[{"offColor", ":", 
       RowBox[{
        RowBox[{"Except", "[", 
         RowBox[{
          RowBox[{"_Rule", " ", "|", " ", "_RuleDelayed"}], ",", " ", "_"}], 
         "]"}], ":", "0"}]}], ",", 
      RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sx_", "?", "NumberQ"}], ",", 
      RowBox[{"sy_", "?", "NumberQ"}], ",", 
      RowBox[{"1", "|", "1.0"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x0_", "?", "NumberQ"}], ",", 
      RowBox[{"y0_", "?", "NumberQ"}], ",", "_"}], "}"}], ",", 
    RowBox[{"offColor", ":", 
     RowBox[{
      RowBox[{"Except", "[", 
       RowBox[{
        RowBox[{"_Rule", " ", "|", " ", "_RuleDelayed"}], ",", " ", "_"}], 
       "]"}], ":", "0"}]}], ",", 
    RowBox[{"opts2___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts1", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "RotateArray", "]"}], ",", 
        RowBox[{"Options", "[", "ScaleArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffine2DTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "x0", ",", "y0", ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sy"}], 
       ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", 
           RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}]}], "/", "sx"}],
        ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sy"}], 
       ",", "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     "CubicBSplineInterpolation", ",", "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffine2DTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "x0", ",", "y0", ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sy"}], 
       ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", 
           RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}]}], "/", "sx"}],
        ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sy"}], 
       ",", "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffine2DTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "x0", ",", "y0", ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sy"}], 
       ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", 
           RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}]}], "/", "sx"}],
        ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sy"}], 
       ",", "offColor"}], "]"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"RotateArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ScaleArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"img_", "?", "ArrayQ"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"sx_", "?", "NumberQ"}], ",", 
        RowBox[{"sy_", "?", "NumberQ"}], ",", 
        RowBox[{"sz_", "?", "NumberQ"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x0_", "?", "NumberQ"}], ",", 
        RowBox[{"y0_", "?", "NumberQ"}], ",", 
        RowBox[{"z0_", "?", "NumberQ"}]}], "}"}], ",", 
      RowBox[{"offColor", ":", 
       RowBox[{
        RowBox[{"Except", "[", 
         RowBox[{
          RowBox[{"_Rule", " ", "|", " ", "_RuleDelayed"}], ",", " ", "_"}], 
         "]"}], ":", "0"}]}], ",", 
      RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
    RowBox[{"\[Beta]_", "?", "NumericQ"}], ",", 
    RowBox[{"\[Gamma]_", "?", "NumericQ"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x0_", "?", "NumberQ"}], ",", 
      RowBox[{"y0_", "?", "NumberQ"}], ",", 
      RowBox[{"z0_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"offColor", ":", 
     RowBox[{
      RowBox[{"Except", "[", 
       RowBox[{
        RowBox[{"_Rule", " ", "|", " ", "_RuleDelayed"}], ",", " ", "_"}], 
       "]"}], ":", "0"}]}], ",", 
    RowBox[{"opts2___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts1", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "ScaleArray", "]"}], ",", 
        RowBox[{"Options", "[", "RotateArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffineTransform3D", "[", 
      RowBox[{
      "img", ",", "x0", ",", "y0", ",", "z0", ",", "x0", ",", "y0", ",", "z0",
        ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], ")"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sy"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}]}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     "CubicBSplineInterpolation", ",", "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffineTransform3D", "[", 
      RowBox[{
      "img", ",", "x0", ",", "y0", ",", "z0", ",", "x0", ",", "y0", ",", "z0",
        ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], ")"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sy"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}]}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffineTransform3D", "[", 
      RowBox[{
      "img", ",", "x0", ",", "y0", ",", "z0", ",", "x0", ",", "y0", ",", "z0",
        ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sx"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
          RowBox[{"Sin", "[", 
           RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], ")"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
             RowBox[{"Cos", "[", 
              RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
             RowBox[{"Sin", "[", 
              RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "*", 
           RowBox[{"Cos", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
          RowBox[{
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
           RowBox[{"Sin", "[", 
            RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ")"}], "/", 
        "sy"}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sy"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "*", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}]}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], "/", "sz"}], ",", 
       "offColor"}], "]"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"RotateArray", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ScaleArray", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"img_", "?", "ArrayQ"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"sx_", "?", "NumberQ"}], ",", 
        RowBox[{"sy_", "?", "NumberQ"}], ",", 
        RowBox[{"1", "|", "1.0"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x0_", "?", "NumberQ"}], ",", 
        RowBox[{"y0_", "?", "NumberQ"}], ",", "_"}], "}"}], ",", 
      RowBox[{"offColor", ":", 
       RowBox[{
        RowBox[{"Except", "[", 
         RowBox[{
          RowBox[{"_Rule", " ", "|", " ", "_RuleDelayed"}], ",", " ", "_"}], 
         "]"}], ":", "0"}]}], ",", 
      RowBox[{"opts1___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
    RowBox[{"0", "|", "0.0"}], ",", 
    RowBox[{"\[Gamma]_", "?", "NumericQ"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x0_", "?", "NumberQ"}], ",", 
      RowBox[{"y0_", "?", "NumberQ"}], ",", "_"}], "}"}], ",", 
    RowBox[{"offColor", ":", 
     RowBox[{
      RowBox[{"Except", "[", 
       RowBox[{
        RowBox[{"_Rule", " ", "|", " ", "_RuleDelayed"}], ",", " ", "_"}], 
       "]"}], ":", "0"}]}], ",", 
    RowBox[{"opts2___", "?", "OptionQ"}]}], "\[IndentingNewLine]", "]"}], ":=",
   "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"{", "opts1", "}"}], ",", 
         RowBox[{"{", "opts2", "}"}]}], "]"}]}], "/.", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Options", "[", "ScaleArray", "]"}], ",", 
        RowBox[{"Options", "[", "RotateArray", "]"}]}], "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffine2DTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "x0", ",", "y0", ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", 
           RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}]}], "/", "sy"}],
        ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sy"}], 
       ",", "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     "CubicBSplineInterpolation", ",", "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffine2DTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "x0", ",", "y0", ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", 
           RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}]}], "/", "sy"}],
        ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sy"}], 
       ",", "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffine2DTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "x0", ",", "y0", ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sx"}], 
       ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", 
           RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}]}], "/", "sy"}],
        ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], "/", "sy"}], 
       ",", "offColor"}], "]"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Translate", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "TranslateArray", "]"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"ArrayInterpolation", "->", " ", "LinearInterpolation"}], "}"}]}],
   ";"}]], "PackageInput"],

Cell["2D", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TranslateArray", "[", 
   RowBox[{
    RowBox[{"img_", "?", "ArrayQ"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tx_", "?", "NumberQ"}], ",", 
      RowBox[{"ty_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"offColor", ":", 
     RowBox[{
      RowBox[{"Except", "[", 
       RowBox[{
        RowBox[{"_Rule", " ", "|", " ", "_RuleDelayed"}], ",", " ", "_"}], 
       "]"}], ":", "0"}]}], ",", " ", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"{", "opts", "}"}]}], "/.", 
      RowBox[{"Options", "[", "TranslateArray", "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffineTransform", "[", 
      RowBox[{
      "img", ",", "tx", ",", "ty", ",", "0", ",", "0", ",", "1", ",", "0", 
       ",", "0", ",", "1", ",", "offColor"}], "]"}], ",", 
     "\[IndentingNewLine]", "CubicBSplineInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffineTransform", "[", 
      RowBox[{
      "img", ",", "tx", ",", "ty", ",", "0", ",", "0", ",", "1", ",", "0", 
       ",", "0", ",", "1", ",", "offColor"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffineTransform", "[", 
      RowBox[{
      "img", ",", "tx", ",", "ty", ",", "0", ",", "0", ",", "1", ",", "0", 
       ",", "0", ",", "1", ",", "offColor"}], "]"}]}], "\[IndentingNewLine]", 
    "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "2"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell["3D", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"TranslateArray", "[", 
   RowBox[{
    RowBox[{"img_", "?", "ArrayQ"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tx_", "?", "NumberQ"}], ",", 
      RowBox[{"ty_", "?", "NumberQ"}], ",", 
      RowBox[{"0", "|", "0.0"}]}], "}"}], ",", 
    RowBox[{"offColor", ":", 
     RowBox[{
      RowBox[{"Except", "[", 
       RowBox[{
        RowBox[{"_Rule", " ", "|", " ", "_RuleDelayed"}], ",", " ", "_"}], 
       "]"}], ":", "0"}]}], ",", " ", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Switch", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"ArrayInterpolation", "/.", " ", 
        RowBox[{"{", "opts", "}"}]}], "/.", 
       RowBox[{"Options", "[", "TranslateArray", "]"}]}], ",", 
      "\[IndentingNewLine]", "ConstantInterpolation", ",", 
      "\[IndentingNewLine]", 
      RowBox[{"NConstantAffine2DTransform3D", "[", 
       RowBox[{
       "img", ",", "tx", ",", "ty", ",", "0", ",", "0", ",", "1", ",", "0", 
        ",", "0", ",", "1", ",", "offColor"}], "]"}], ",", 
      "\[IndentingNewLine]", "CubicBSplineInterpolation", ",", 
      "\[IndentingNewLine]", 
      RowBox[{"NCubicBSplineAffine2DTransform3D", "[", 
       RowBox[{
       "img", ",", "tx", ",", "ty", ",", "0", ",", "0", ",", "1", ",", "0", 
        ",", "0", ",", "1", ",", "offColor"}], "]"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
      RowBox[{"NLinearAffine2DTransform3D", "[", 
       RowBox[{
       "img", ",", "tx", ",", "ty", ",", "0", ",", "0", ",", "1", ",", "0", 
        ",", "0", ",", "1", ",", "offColor"}], "]"}]}], "\[IndentingNewLine]",
      "]"}], 
    RowBox[{"NLinearAffine2DTransform3D", "[", 
     RowBox[{
     "img", ",", "tx", ",", "ty", ",", "0", ",", "0", ",", "1", ",", "0", ",",
       "0", ",", "1", ",", "offColor"}], "]"}]}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"TranslateArray", "[", 
   RowBox[{
    RowBox[{"img_", "?", "ArrayQ"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"tx_", "?", "NumberQ"}], ",", 
      RowBox[{"ty_", "?", "NumberQ"}], ",", 
      RowBox[{"tz_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"offColor", ":", 
     RowBox[{
      RowBox[{"Except", "[", 
       RowBox[{
        RowBox[{"_Rule", " ", "|", " ", "_RuleDelayed"}], ",", " ", "_"}], 
       "]"}], ":", "0"}]}], ",", " ", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"{", "opts", "}"}]}], "/.", 
      RowBox[{"Options", "[", "TranslateArray", "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffineTransform3D", "[", 
      RowBox[{
      "img", ",", "tx", ",", "ty", ",", "tz", ",", "0", ",", "0", ",", "0", 
       ",", "1", ",", "0", ",", "0", ",", "0", ",", "1", ",", "0", ",", "0", 
       ",", "0", ",", "1", ",", "offColor"}], "]"}], ",", 
     "\[IndentingNewLine]", "CubicBSplineInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffineTransform3D", "[", 
      RowBox[{
      "img", ",", "tx", ",", "ty", ",", "tz", ",", "0", ",", "0", ",", "0", 
       ",", "1", ",", "0", ",", "0", ",", "0", ",", "1", ",", "0", ",", "0", 
       ",", "0", ",", "1", ",", "offColor"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffineTransform3D", "[", 
      RowBox[{
      "img", ",", "tx", ",", "ty", ",", "tz", ",", "0", ",", "0", ",", "0", 
       ",", "1", ",", "0", ",", "0", ",", "0", ",", "1", ",", "0", ",", "0", 
       ",", "0", ",", "1", ",", "offColor"}], "]"}]}], "\[IndentingNewLine]", 
    "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Rotate", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "RotateArray", "]"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"ArrayInterpolation", "->", " ", "LinearInterpolation"}], "}"}]}],
   ";"}]], "PackageInput"],

Cell["2D", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RotateArray", "[", 
   RowBox[{"img_", ",", "\[Alpha]_", ",", 
    RowBox[{"offColor", ":", 
     RowBox[{
      RowBox[{"Except", "[", 
       RowBox[{
        RowBox[{"_Rule", " ", "|", " ", "_RuleDelayed"}], ",", " ", "_"}], 
       "]"}], ":", "0"}]}], ",", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{"RotateArray", "[", 
    RowBox[{"img", ",", "\[Alpha]", ",", 
     RowBox[{
      RowBox[{"Reverse", "[", 
       RowBox[{
        RowBox[{"Dimensions", "[", "img", "]"}], "+", "1"}], "]"}], "/", 
      "2"}], ",", "offColor", ",", "opts"}], "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "2"}]}]}]], "PackageInput",\

 InitializationCell->True,
 CellChangeTimes->{{3.4902818933570642`*^9, 3.4902818937989264`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"RotateArray", "[", 
   RowBox[{
    RowBox[{"img_", "?", "ArrayQ"}], ",", 
    RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x0_", "?", "NumberQ"}], ",", 
      RowBox[{"y0_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"offColor", ":", 
     RowBox[{
      RowBox[{"Except", "[", 
       RowBox[{
        RowBox[{"_", "?", "OptionQ"}], ",", " ", "_"}], "]"}], ":", "0"}]}], 
    ",", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"{", "opts", "}"}]}], "/.", 
      RowBox[{"Options", "[", "RotateArray", "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffineTransform", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "x0", ",", "y0", ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], ",", 
       RowBox[{"Sin", "[", 
        RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], ",", 
       RowBox[{"-", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], ",", "offColor"}], "]"}], 
     ",", "\[IndentingNewLine]", "CubicBSplineInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffineTransform", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "x0", ",", "y0", ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], ",", 
       RowBox[{"Sin", "[", 
        RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], ",", 
       RowBox[{"-", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], ",", "offColor"}], "]"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffineTransform", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "x0", ",", "y0", ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], ",", 
       RowBox[{"Sin", "[", 
        RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], ",", 
       RowBox[{"-", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], ",", "offColor"}], 
      "]"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "2"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell["3D", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"RotateArray", "[", 
   RowBox[{"img_", ",", 
    RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
    RowBox[{"{", 
     RowBox[{"x0_", ",", "y0_", ",", "z0_"}], "}"}], ",", 
    RowBox[{"offColor", ":", 
     RowBox[{
      RowBox[{"Except", "[", 
       RowBox[{
        RowBox[{"_", "?", "OptionQ"}], ",", " ", "_"}], "]"}], ":", "0"}]}], 
    ",", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{"RotateArray", "[", 
    RowBox[{"img", ",", "\[Alpha]", ",", "0", ",", "0", ",", 
     RowBox[{"{", 
      RowBox[{"x0", ",", "y0", ",", "z0"}], "}"}], ",", "offColor", ",", 
     "opts"}], "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"RotateArray", "[", 
   RowBox[{"img_", ",", 
    RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
    RowBox[{"\[Beta]_", "?", "NumericQ"}], ",", 
    RowBox[{"{", 
     RowBox[{"x0_", ",", "y0_", ",", "z0_"}], "}"}], ",", 
    RowBox[{"offColor", ":", 
     RowBox[{
      RowBox[{"Except", "[", 
       RowBox[{
        RowBox[{"_", "?", "OptionQ"}], ",", " ", "_"}], "]"}], ":", "0"}]}], 
    ",", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{"RotateArray", "[", 
    RowBox[{"img", ",", "\[Alpha]", ",", "\[Beta]", ",", "0", ",", 
     RowBox[{"{", 
      RowBox[{"x0", ",", "y0", ",", "z0"}], "}"}], ",", "offColor", ",", 
     "opts"}], "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"RotateArray", "[", 
   RowBox[{"img_", ",", 
    RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
    RowBox[{"\[Beta]_", "?", "NumericQ"}], ",", 
    RowBox[{"\[Gamma]_", "?", "NumericQ"}], ",", 
    RowBox[{"{", 
     RowBox[{"x0_", ",", "y0_", ",", "z0_"}], "}"}], ",", 
    RowBox[{"offColor", ":", 
     RowBox[{
      RowBox[{"Except", "[", 
       RowBox[{
        RowBox[{"_", "?", "OptionQ"}], ",", " ", "_"}], "]"}], ":", "0"}]}], 
    ",", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{"RotateArray", "[", 
    RowBox[{"img", ",", "\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", 
     RowBox[{"{", 
      RowBox[{"x0", ",", "y0", ",", "z0"}], "}"}], ",", "offColor", ",", 
     "opts"}], "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"RotateArray", "[", 
   RowBox[{"img_", ",", 
    RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
    RowBox[{"\[Beta]_", "?", "NumericQ"}], ",", 
    RowBox[{"\[Gamma]_", "?", "NumericQ"}], ",", 
    RowBox[{"offColor", ":", 
     RowBox[{
      RowBox[{"Except", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"_", "?", "OptionQ"}], "|", "_List"}], ",", " ", "_"}], 
       "]"}], ":", "0"}]}], ",", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{"RotateArray", "[", 
    RowBox[{"img", ",", "\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", 
     RowBox[{
      RowBox[{"Reverse", "[", 
       RowBox[{
        RowBox[{"Dimensions", "[", "img", "]"}], "+", "1"}], "]"}], "/", 
      "2"}], ",", "offColor", ",", "opts"}], "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True,
 CellChangeTimes->{{3.490282594685446*^9, 3.490282595080676*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"RotateArray", "[", 
   RowBox[{
    RowBox[{"img_", "?", "ArrayQ"}], ",", 
    RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
    RowBox[{"0", "|", "0.0"}], ",", 
    RowBox[{"\[Gamma]_", "?", "NumericQ"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x0_", "?", "NumberQ"}], ",", 
      RowBox[{"y0_", "?", "NumberQ"}], ",", "_"}], "}"}], ",", 
    RowBox[{"offColor", ":", 
     RowBox[{"Except", "[", 
      RowBox[{
       RowBox[{"_", "?", "OptionQ"}], ",", " ", "_"}], "]"}]}], ",", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"{", "opts", "}"}]}], "/.", 
      RowBox[{"Options", "[", "RotateArray", "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffine2DTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "x0", ",", "y0", ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", 
         RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], ",", 
       RowBox[{"Sin", "[", 
        RowBox[{"N", "[", 
         RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], ",", 
       RowBox[{"-", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}]}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", 
         RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     "CubicBSplineInterpolation", ",", "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffine2DTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "x0", ",", "y0", ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", 
         RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], ",", 
       RowBox[{"Sin", "[", 
        RowBox[{"N", "[", 
         RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], ",", 
       RowBox[{"-", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}]}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", 
         RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], ",", 
       "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffine2DTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "x0", ",", "y0", ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", 
         RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], ",", 
       RowBox[{"Sin", "[", 
        RowBox[{"N", "[", 
         RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], ",", 
       RowBox[{"-", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", 
          RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}]}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", 
         RowBox[{"\[Alpha]", "+", "\[Gamma]"}], "]"}], "]"}], ",", 
       "offColor"}], "]"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"RotateArray", "[", 
   RowBox[{
    RowBox[{"img_", "?", "ArrayQ"}], ",", 
    RowBox[{"\[Alpha]_", "?", "NumericQ"}], ",", 
    RowBox[{"\[Beta]_", "?", "NumericQ"}], ",", 
    RowBox[{"\[Gamma]_", "?", "NumericQ"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x0_", "?", "NumberQ"}], ",", 
      RowBox[{"y0_", "?", "NumberQ"}], ",", 
      RowBox[{"z0_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"offColor", ":", 
     RowBox[{"Except", "[", 
      RowBox[{
       RowBox[{"_", "?", "OptionQ"}], ",", " ", "_"}], "]"}]}], ",", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"{", "opts", "}"}]}], "/.", 
      RowBox[{"Options", "[", "RotateArray", "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffineTransform3D", "[", 
      RowBox[{
      "img", ",", "x0", ",", "y0", ",", "z0", ",", "x0", ",", "y0", ",", "z0",
        ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Cos", "[", 
           RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], ",", "offColor"}], "]"}], 
     ",", "\[IndentingNewLine]", "CubicBSplineInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffineTransform3D", "[", 
      RowBox[{
      "img", ",", "x0", ",", "y0", ",", "z0", ",", "x0", ",", "y0", ",", "z0",
        ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Cos", "[", 
           RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], ",", "offColor"}], "]"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffineTransform3D", "[", 
      RowBox[{
      "img", ",", "x0", ",", "y0", ",", "z0", ",", "x0", ",", "y0", ",", "z0",
        ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "+", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"Cos", "[", 
           RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], " ", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
         RowBox[{"Sin", "[", 
          RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"Cos", "[", 
         RowBox[{"N", "[", "\[Gamma]", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Cos", "[", 
          RowBox[{"N", "[", "\[Alpha]", "]"}], "]"}]}], " ", 
        RowBox[{"Sin", "[", 
         RowBox[{"N", "[", "\[Beta]", "]"}], "]"}]}], ",", 
       RowBox[{"Cos", "[", 
        RowBox[{"N", "[", "\[Beta]", "]"}], "]"}], ",", "offColor"}], "]"}]}],
     "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Scale", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "ScaleArray", "]"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"ArrayInterpolation", "->", " ", "LinearInterpolation"}], "}"}]}],
   ";"}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ScaleArray", "[", 
   RowBox[{"img_", ",", 
    RowBox[{"s", ":", 
     RowBox[{"Except", "[", 
      RowBox[{"_List", ",", "_"}], "]"}]}], ",", 
    RowBox[{"offColor", ":", 
     RowBox[{
      RowBox[{"Except", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"_", "?", "OptionQ"}], "|", "_List"}], ",", " ", "_"}], 
       "]"}], ":", "0"}]}], ",", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], ":=", 
  RowBox[{"ScaleArray", "[", 
   RowBox[{"img", ",", 
    RowBox[{"Table", "[", 
     RowBox[{"s", ",", " ", 
      RowBox[{"{", 
       RowBox[{"ArrayDepth", "[", "img", "]"}], "}"}]}], "]"}], ",", 
    RowBox[{"Reverse", "[", 
     RowBox[{"Dimensions", "[", "img", "]"}], "]"}], ",", "offColor", ",", 
    "opts"}], "]"}]}]], "PackageInput",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"ScaleArray", "[", 
   RowBox[{"img_", ",", 
    RowBox[{"s", ":", 
     RowBox[{"Except", "[", 
      RowBox[{"_List", ",", "_"}], "]"}]}], ",", 
    RowBox[{"{", "pos0__", "}"}], ",", 
    RowBox[{"offColor", ":", 
     RowBox[{
      RowBox[{"Except", "[", 
       RowBox[{
        RowBox[{"_", "?", "OptionQ"}], ",", " ", "_"}], "]"}], ":", "0"}]}], 
    ",", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], ":=", 
  RowBox[{"ScaleArray", "[", 
   RowBox[{"img", ",", 
    RowBox[{"Table", "[", 
     RowBox[{"s", ",", " ", 
      RowBox[{"{", 
       RowBox[{"ArrayDepth", "[", "img", "]"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", "pos0", "}"}], ",", "offColor", ",", "opts"}], 
   "]"}]}]], "PackageInput",
 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"ScaleArray", "[", 
   RowBox[{"img_", ",", 
    RowBox[{"{", "s__", "}"}], ",", 
    RowBox[{"{", "pos0__", "}"}], ",", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], ":=", 
  RowBox[{"ScaleArray", "[", 
   RowBox[{"img", ",", 
    RowBox[{"{", "s", "}"}], ",", 
    RowBox[{"{", "pos0", "}"}], ",", "0", ",", "opts"}], 
   "]"}]}]], "PackageInput",
 InitializationCell->True],

Cell["2D", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ScaleArray", "[", 
   RowBox[{
    RowBox[{"img_", "?", "ArrayQ"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sx_", "?", "NumericQ"}], ",", 
      RowBox[{"sy_", "?", "NumericQ"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x0_", "?", "NumberQ"}], ",", 
      RowBox[{"y0_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"offColor", ":", 
     RowBox[{
      RowBox[{"Except", "[", 
       RowBox[{
        RowBox[{"_", "?", "OptionQ"}], ",", " ", "_"}], "]"}], ":", "0"}]}], 
    ",", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"{", "opts", "}"}]}], "/.", 
      RowBox[{"Options", "[", "ScaleArray", "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffineTransform", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "x0", ",", "y0", ",", 
       RowBox[{"1", "/", "sx"}], ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sy"}], ",", "offColor"}], "]"}], ",", 
     "\[IndentingNewLine]", "CubicBSplineInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffineTransform", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "x0", ",", "y0", ",", 
       RowBox[{"1", "/", "sx"}], ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sy"}], ",", "offColor"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffineTransform", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "x0", ",", "y0", ",", 
       RowBox[{"1", "/", "sx"}], ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sy"}], ",", "offColor"}], "]"}]}], 
    "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "2"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell["3D", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ScaleArray", "[", 
   RowBox[{
    RowBox[{"img_", "?", "ArrayQ"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sx_", "?", "NumericQ"}], ",", 
      RowBox[{"sy_", "?", "NumericQ"}], ",", 
      RowBox[{"1", "|", "1.0"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x0_", "?", "NumberQ"}], ",", 
      RowBox[{"y0_", "?", "NumberQ"}], ",", 
      RowBox[{"z0_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"offColor", ":", 
     RowBox[{
      RowBox[{"Except", "[", 
       RowBox[{
        RowBox[{"_", "?", "OptionQ"}], ",", " ", "_"}], "]"}], ":", "0"}]}], 
    ",", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"{", "opts", "}"}]}], "/.", 
      RowBox[{"Options", "[", "ScaleArray", "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffine2DTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "x0", ",", "y0", ",", 
       RowBox[{"1", "/", "sx"}], ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sy"}], ",", "offColor"}], "]"}], ",", 
     "\[IndentingNewLine]", "CubicBSplineInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffine2DTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "x0", ",", "y0", ",", 
       RowBox[{"1", "/", "sx"}], ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sy"}], ",", "offColor"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffine2DTransform3D", "[", 
      RowBox[{"img", ",", "x0", ",", "y0", ",", "x0", ",", "y0", ",", 
       RowBox[{"1", "/", "sx"}], ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sy"}], ",", "offColor"}], "]"}]}], 
    "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"ScaleArray", "[", 
   RowBox[{
    RowBox[{"img_", "?", "ArrayQ"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"sx_", "?", "NumericQ"}], ",", 
      RowBox[{"sy_", "?", "NumericQ"}], ",", 
      RowBox[{"sz_", "?", "NumericQ"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x0_", "?", "NumberQ"}], ",", 
      RowBox[{"y0_", "?", "NumberQ"}], ",", 
      RowBox[{"z0_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"offColor", ":", 
     RowBox[{
      RowBox[{"Except", "[", 
       RowBox[{
        RowBox[{"_", "?", "OptionQ"}], ",", " ", "_"}], "]"}], ":", "0"}]}], 
    ",", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"{", "opts", "}"}]}], "/.", 
      RowBox[{"Options", "[", "ScaleArray", "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantAffineTransform3D", "[", 
      RowBox[{
      "img", ",", "x0", ",", "y0", ",", "z0", ",", "x0", ",", "y0", ",", "z0",
        ",", 
       RowBox[{"1", "/", "sx"}], ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sy"}], ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sz"}], ",", "offColor"}], "]"}], ",", 
     "\[IndentingNewLine]", "CubicBSplineInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplineAffineTransform3D", "[", 
      RowBox[{
      "img", ",", "x0", ",", "y0", ",", "z0", ",", "x0", ",", "y0", ",", "z0",
        ",", 
       RowBox[{"1", "/", "sx"}], ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sy"}], ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sz"}], ",", "offColor"}], "]"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearAffineTransform3D", "[", 
      RowBox[{
      "img", ",", "x0", ",", "y0", ",", "z0", ",", "x0", ",", "y0", ",", "z0",
        ",", 
       RowBox[{"1", "/", "sx"}], ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sy"}], ",", "0", ",", "0", ",", "0", ",", 
       RowBox[{"1", "/", "sz"}], ",", "offColor"}], "]"}]}], 
    "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Perspective Transformations", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "PerspectiveTransformArray", "]"}], " ", "=", " ", 
   
   RowBox[{"{", 
    RowBox[{"ArrayInterpolation", "->", " ", "LinearInterpolation"}], "}"}]}],
   ";"}]], "PackageInput"],

Cell[CellGroupData[{

Cell["2D", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"PerspectiveTransformArray", "[", 
   RowBox[{
    RowBox[{"img_", "?", "ArrayQ"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"y0_", "?", "NumberQ"}], ",", 
      RowBox[{"a_", "?", "NumberQ"}], ",", 
      RowBox[{"b_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"offColor", ":", 
     RowBox[{
      RowBox[{"Except", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"_", "?", "OptionQ"}], "|", "_List"}], ",", "_"}], "]"}], 
      ":", "0"}]}], ",", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"{", "opts", "}"}]}], "/.", 
      RowBox[{"Options", "[", "PerspectiveTransformArray", "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantPerspectiveTransform", "[", 
      RowBox[{"img", ",", "a", ",", "b", ",", "y0", ",", "offColor"}], "]"}], 
     ",", "\[IndentingNewLine]", "CubicBSplineInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplinePerspectiveTransform", "[", 
      RowBox[{"img", ",", "a", ",", "b", ",", "y0", ",", "offColor"}], "]"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearPerspectiveTransform", "[", 
      RowBox[{"img", ",", "a", ",", "b", ",", "y0", ",", "offColor"}], 
      "]"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "2"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"NConstantPerspectiveTransform", "=", "\[IndentingNewLine]", 
   RowBox[{"Compile", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"img", ",", "_Real", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"b", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y0", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"offColor", ",", "_Real"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"With", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"xn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "2", "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{"yn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "1", "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"NConstantImageInterpolation", "[", 
          RowBox[{"img", ",", "x", ",", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"a", "*", 
                  RowBox[{"(", 
                   RowBox[{"x", "-", "1"}], ")"}]}], "+", 
                 RowBox[{"b", "*", 
                  RowBox[{"(", 
                   RowBox[{"xn", "-", "x"}], ")"}]}]}], ")"}], "/", 
               RowBox[{"(", 
                RowBox[{"xn", "-", "1"}], ")"}]}], ")"}], "*", "y"}], "+", 
            "y0"}], ",", "xn", ",", "yn", ",", "offColor"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"y", ",", 
           RowBox[{"1", "-", "y0"}], ",", 
           RowBox[{"yn", "-", "y0"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"x", ",", "1", ",", "xn"}], "}"}]}], "\[IndentingNewLine]", 
        "]"}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"NConstantImageInterpolation", "[", 
         RowBox[{"_", ",", "_", ",", "_", ",", "_", ",", "_", ",", "_"}], 
         "]"}], ",", "_Real"}], "}"}], "}"}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NLinearPerspectiveTransform", "=", "\[IndentingNewLine]", 
   RowBox[{"Compile", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"img", ",", "_Real", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"b", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y0", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"offColor", ",", "_Real"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"With", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"xn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "2", "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{"yn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "1", "\[RightDoubleBracket]"}]}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"NLinearImageInterpolation", "[", 
          RowBox[{"img", ",", "x", ",", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"a", "*", 
                  RowBox[{"(", 
                   RowBox[{"x", "-", "1"}], ")"}]}], "+", 
                 RowBox[{"b", "*", 
                  RowBox[{"(", 
                   RowBox[{"xn", "-", "x"}], ")"}]}]}], ")"}], "/", 
               RowBox[{"(", 
                RowBox[{"xn", "-", "1"}], ")"}]}], ")"}], "*", "y"}], "+", 
            "y0"}], ",", "xn", ",", "yn", ",", "offColor"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"y", ",", 
           RowBox[{"1", "-", "y0"}], ",", 
           RowBox[{"yn", "-", "y0"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"x", ",", "1", ",", "xn"}], "}"}]}], "\[IndentingNewLine]", 
        "]"}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"NLinearImageInterpolation", "[", 
         RowBox[{"_", ",", "_", ",", "_", ",", "_", ",", "_", ",", "_"}], 
         "]"}], ",", "_Real"}], "}"}], "}"}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NCubicBSplinePerspectiveTransform", "=", "\[IndentingNewLine]", 
   RowBox[{"Compile", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"img", ",", "_Real", ",", "2"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"b", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y0", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"offColor", ",", "_Real"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"With", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"xn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "2", "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{"yn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "\[LeftDoubleBracket]", 
           "1", "\[RightDoubleBracket]"}]}], ",", 
         RowBox[{"tmp", "=", 
          RowBox[{
          "CubicBSplineImageInterpolationFilter", "[", "img", "]"}]}]}], 
        "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"NCubicBSplineImageInterpolation", "[", 
          RowBox[{"tmp", ",", "x", ",", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"a", "*", 
                  RowBox[{"(", 
                   RowBox[{"x", "-", "1"}], ")"}]}], "+", 
                 RowBox[{"b", "*", 
                  RowBox[{"(", 
                   RowBox[{"xn", "-", "x"}], ")"}]}]}], ")"}], "/", 
               RowBox[{"(", 
                RowBox[{"xn", "-", "1"}], ")"}]}], ")"}], "*", "y"}], "+", 
            "y0"}], ",", "xn", ",", "yn", ",", "offColor"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"y", ",", 
           RowBox[{"1", "-", "y0"}], ",", 
           RowBox[{"yn", "-", "y0"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"x", ",", "1", ",", "xn"}], "}"}]}], "\[IndentingNewLine]", 
        "]"}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"NCubicBSplineImageInterpolation", "[", 
          RowBox[{"_", ",", "_", ",", "_", ",", "_", ",", "_", ",", "_"}], 
          "]"}], ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"CubicBSplineImageInterpolationFilter", "[", "_", "]"}], ",",
          "_Real", ",", "2"}], "}"}]}], "}"}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "PackageInput"]
}, Closed]],

Cell[CellGroupData[{

Cell["3D", "Subsubsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"PerspectiveTransformArray", "[", 
   RowBox[{
    RowBox[{"img_", "?", "ArrayQ"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x0_", "?", "NumberQ"}], ",", 
      RowBox[{"ax_", "?", "NumberQ"}], ",", 
      RowBox[{"bx_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"y0_", "?", "NumberQ"}], ",", 
      RowBox[{"ay_", "?", "NumberQ"}], ",", 
      RowBox[{"by_", "?", "NumberQ"}]}], "}"}], ",", 
    RowBox[{"offColor", ":", 
     RowBox[{
      RowBox[{"Except", "[", 
       RowBox[{
        RowBox[{"_", "?", "OptionQ"}], ",", "_"}], "]"}], ":", "0"}]}], ",", 
    RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Switch", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ArrayInterpolation", "/.", " ", 
       RowBox[{"{", "opts", "}"}]}], "/.", 
      RowBox[{"Options", "[", "PerspectiveTransformArray", "]"}]}], ",", 
     "\[IndentingNewLine]", "ConstantInterpolation", ",", 
     "\[IndentingNewLine]", 
     RowBox[{"NConstantPerspectiveTransform3D", "[", 
      RowBox[{
      "img", ",", "ax", ",", "bx", ",", "ay", ",", "by", ",", "x0", ",", "y0",
        ",", "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     "CubicBSplineInterpolation", ",", "\[IndentingNewLine]", 
     RowBox[{"NCubicBSplinePerspectiveTransform3D", "[", 
      RowBox[{
      "img", ",", "ax", ",", "bx", ",", "ay", ",", "by", ",", "x0", ",", "y0",
        ",", "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"LinearInterpolation", "|", "_"}], ",", "\[IndentingNewLine]", 
     RowBox[{"NLinearPerspectiveTransform3D", "[", 
      RowBox[{
      "img", ",", "ax", ",", "bx", ",", "ay", ",", "by", ",", "x0", ",", "y0",
        ",", "offColor"}], "]"}]}], "\[IndentingNewLine]", "]"}], "/;", " ", 
   RowBox[{
    RowBox[{"ArrayDepth", "[", "img", "]"}], "===", "3"}]}]}]], "PackageInput",\

 InitializationCell->True],

Cell[BoxData[
 RowBox[{
  RowBox[{"NConstantPerspectiveTransform3D", "=", "\[IndentingNewLine]", 
   RowBox[{"Compile", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"img", ",", "_Real", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ax", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"bx", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ay", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"by", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x0", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y0", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"offColor", ",", "_Real"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"With", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"xn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "[", 
           RowBox[{"[", "3", "]"}], "]"}]}], ",", 
         RowBox[{"yn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], ",", 
         RowBox[{"zn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"NConstantImageInterpolation3D", "[", 
          RowBox[{"img", ",", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"ax", "*", 
                  RowBox[{"(", 
                   RowBox[{"z", "-", "1"}], ")"}]}], "+", 
                 RowBox[{"bx", "*", 
                  RowBox[{"(", 
                   RowBox[{"zn", "-", "z"}], ")"}]}]}], ")"}], "/", 
               RowBox[{"(", 
                RowBox[{"zn", "-", "1"}], ")"}]}], ")"}], "*", "x"}], "+", 
            "x0"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"ay", "*", 
                  RowBox[{"(", 
                   RowBox[{"z", "-", "1"}], ")"}]}], "+", 
                 RowBox[{"by", "*", 
                  RowBox[{"(", 
                   RowBox[{"zn", "-", "z"}], ")"}]}]}], ")"}], "/", 
               RowBox[{"(", 
                RowBox[{"zn", "-", "1"}], ")"}]}], ")"}], "*", "y"}], "+", 
            "y0"}], ",", "z", ",", "xn", ",", "yn", ",", "zn", ",", 
           "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"z", ",", "1", ",", "zn"}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"y", ",", 
           RowBox[{"1", "-", "y0"}], ",", 
           RowBox[{"yn", "-", "y0"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"1", "-", "x0"}], ",", 
           RowBox[{"xn", "-", "x0"}]}], "}"}]}], "\[IndentingNewLine]", 
        "]"}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"NConstantImageInterpolation3D", "[", 
         RowBox[{
         "_", ",", "_", ",", "_", ",", "_", ",", "_", ",", "_", ",", "_", ",",
           "_"}], "]"}], ",", "_Real"}], "}"}], "}"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NLinearPerspectiveTransform3D", "=", "\[IndentingNewLine]", 
   RowBox[{"Compile", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"img", ",", "_Real", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ax", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"bx", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ay", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"by", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x0", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y0", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"offColor", ",", "_Real"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"With", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"xn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "[", 
           RowBox[{"[", "3", "]"}], "]"}]}], ",", 
         RowBox[{"yn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], ",", 
         RowBox[{"zn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}]}], "}"}], ",", 
       "\[IndentingNewLine]", 
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"NLinearImageInterpolation3D", "[", 
          RowBox[{"img", ",", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"ax", "*", 
                  RowBox[{"(", 
                   RowBox[{"z", "-", "1"}], ")"}]}], "+", 
                 RowBox[{"bx", "*", 
                  RowBox[{"(", 
                   RowBox[{"zn", "-", "z"}], ")"}]}]}], ")"}], "/", 
               RowBox[{"(", 
                RowBox[{"zn", "-", "1"}], ")"}]}], ")"}], "*", "x"}], "+", 
            "x0"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"ay", "*", 
                  RowBox[{"(", 
                   RowBox[{"z", "-", "1"}], ")"}]}], "+", 
                 RowBox[{"by", "*", 
                  RowBox[{"(", 
                   RowBox[{"zn", "-", "z"}], ")"}]}]}], ")"}], "/", 
               RowBox[{"(", 
                RowBox[{"zn", "-", "1"}], ")"}]}], ")"}], "*", "y"}], "+", 
            "y0"}], ",", "z", ",", "xn", ",", "yn", ",", "zn", ",", 
           "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"z", ",", "1", ",", "zn"}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"y", ",", 
           RowBox[{"1", "-", "y0"}], ",", 
           RowBox[{"yn", "-", "y0"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"1", "-", "x0"}], ",", 
           RowBox[{"xn", "-", "x0"}]}], "}"}]}], "\[IndentingNewLine]", 
        "]"}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"NLinearImageInterpolation3D", "[", 
         RowBox[{
         "_", ",", "_", ",", "_", ",", "_", ",", "_", ",", "_", ",", "_", ",",
           "_"}], "]"}], ",", "_Real"}], "}"}], "}"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "PackageInput"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NCubicBSplinePerspectiveTransform3D", "=", "\[IndentingNewLine]", 
   RowBox[{"Compile", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"img", ",", "_Real", ",", "3"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ax", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"bx", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"ay", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"by", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x0", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"y0", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"offColor", ",", "_Real"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"With", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"xn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "[", 
           RowBox[{"[", "3", "]"}], "]"}]}], ",", 
         RowBox[{"yn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "[", 
           RowBox[{"[", "2", "]"}], "]"}]}], ",", 
         RowBox[{"zn", "=", 
          RowBox[{
           RowBox[{"Dimensions", "[", "img", "]"}], "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ",", "\[IndentingNewLine]", 
         RowBox[{"tmp", "=", 
          RowBox[{
          "CubicBSplineImageInterpolationFilter", "[", "img", "]"}]}]}], 
        "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"NCubicBSplineImageInterpolation3D", "[", 
          RowBox[{"tmp", ",", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"ax", "*", 
                  RowBox[{"(", 
                   RowBox[{"z", "-", "1"}], ")"}]}], "+", 
                 RowBox[{"bx", "*", 
                  RowBox[{"(", 
                   RowBox[{"zn", "-", "z"}], ")"}]}]}], ")"}], "/", 
               RowBox[{"(", 
                RowBox[{"zn", "-", "1"}], ")"}]}], ")"}], "*", "x"}], "+", 
            "x0"}], ",", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"ay", "*", 
                  RowBox[{"(", 
                   RowBox[{"z", "-", "1"}], ")"}]}], "+", 
                 RowBox[{"by", "*", 
                  RowBox[{"(", 
                   RowBox[{"zn", "-", "z"}], ")"}]}]}], ")"}], "/", 
               RowBox[{"(", 
                RowBox[{"zn", "-", "1"}], ")"}]}], ")"}], "*", "y"}], "+", 
            "y0"}], ",", "z", ",", "xn", ",", "yn", ",", "zn", ",", 
           "offColor"}], "]"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"z", ",", "1", ",", "zn"}], "}"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"y", ",", 
           RowBox[{"1", "-", "y0"}], ",", 
           RowBox[{"yn", "-", "y0"}]}], "}"}], ",", "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"1", "-", "x0"}], ",", 
           RowBox[{"xn", "-", "x0"}]}], "}"}]}], "\[IndentingNewLine]", 
        "]"}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"NCubicBSplineImageInterpolation3D", "[", 
          RowBox[{
          "_", ",", "_", ",", "_", ",", "_", ",", "_", ",", "_", ",", "_", 
           ",", "_"}], "]"}], ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"CubicBSplineImageInterpolationFilter", "[", "_", "]"}], ",",
          "_Real", ",", "3"}], "}"}]}], "}"}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "PackageInput"]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Closing Package", "Section"],

Cell["Closing the package and locking all the symbols.", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"End", "[", "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SetAttributes", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "NConstantImageInterpolation", ",", "NConstantImageInterpolation3D", 
       ",", "NConstant2DImageInterpolation3D", ",", 
       "NLinearImageInterpolation", ",", "NLinearImageInterpolation3D", ",", 
       "NLinear2DImageInterpolation3D", ",", 
       "CubicBSplineImageInterpolationFilter", ",", 
       "NCubicBSplineImageInterpolation", ",", 
       "NCubicBSplineImageInterpolation3D", ",", 
       "NCubicBSpline2DImageInterpolation3D", ",", "TranslateArray", ",", 
       "RotateArray", ",", "ScaleArray", ",", "NLinearAffineTransform", ",", 
       "NConstantAffineTransform", ",", "NLinearAffineTransform3D", ",", 
       "NConstantAffineTransform3D", ",", "NLinearAffine2DTransform3D", ",", 
       "NConsantAffine2DTransform3D", ",", "NCubicBSplineAffineTransform", 
       ",", "NCubicBSplineAffineTransform3D", ",", 
       "NCubicBSplineAffine2DTransform3D", ",", "PerspectiveTransformArray", 
       ",", "ArrayInterpolation", ",", "\[IndentingNewLine]", 
       "ConstantInterpolation", ",", " ", "LinearInterpolation", ",", 
       "CubicBSplineInterpolation", ",", "NCubicBSplineInterpolation"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"Protected", ",", "ReadProtected"}], "}"}]}], 
    "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{"EndPackage", "[", "]"}]}], "PackageInput",
 InitializationCell->True]
}, Closed]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowSize->{1117, 966},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
PrivateNotebookOptions->{"NotebookAuthor"->""},
ShowSelection->True,
Magnification->1.5,
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (August 3, \
2010)",
StyleDefinitions->"PackageNotebook.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 45, 0, 144, "Title"],
Cell[615, 24, 100, 4, 118, "Subsubtitle"],
Cell[CellGroupData[{
Cell[740, 32, 25, 0, 72, "Section"],
Cell[768, 34, 988, 25, 291, "PackageInput"],
Cell[1759, 61, 128, 3, 39, "Text"],
Cell[1890, 66, 3626, 104, 797, "PackageInput",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[5553, 175, 32, 0, 72, "Section"],
Cell[5588, 177, 92, 2, 87, "Text"],
Cell[5683, 181, 1338, 24, 861, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[7058, 210, 42, 0, 40, "Section"],
Cell[7103, 212, 14542, 321, 11575, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[21682, 538, 31, 0, 40, "Section"],
Cell[21716, 540, 60, 0, 39, "Text"],
Cell[21779, 542, 108, 2, 60, "PackageInput",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[21912, 548, 44, 0, 63, "Subsection"],
Cell[CellGroupData[{
Cell[21981, 552, 27, 0, 127, "Subsubsection"],
Cell[22011, 554, 1484, 38, 663, "PackageInput"]
}, Closed]],
Cell[CellGroupData[{
Cell[23532, 597, 27, 0, 76, "Subsubsection"],
Cell[23562, 599, 1782, 45, 663, "PackageInput"]
}, Closed]],
Cell[CellGroupData[{
Cell[25381, 649, 33, 0, 76, "Subsubsection"],
Cell[25417, 651, 1707, 44, 715, "PackageInput"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[27173, 701, 42, 0, 37, "Subsection"],
Cell[CellGroupData[{
Cell[27240, 705, 27, 0, 127, "Subsubsection"],
Cell[27270, 707, 4274, 105, 1026, "PackageInput"]
}, Closed]],
Cell[CellGroupData[{
Cell[31581, 817, 27, 0, 76, "Subsubsection"],
Cell[31611, 819, 12059, 292, 1698, "PackageInput"]
}, Closed]],
Cell[CellGroupData[{
Cell[43707, 1116, 33, 0, 76, "Subsubsection"],
Cell[43743, 1118, 4834, 116, 1336, "PackageInput"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[48626, 1240, 50, 0, 37, "Subsection"],
Cell[48679, 1242, 235, 4, 62, "Text"],
Cell[CellGroupData[{
Cell[48939, 1250, 61, 0, 57, "Subsubsection"],
Cell[49003, 1252, 3696, 93, 535, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[52736, 1350, 27, 0, 57, "Subsubsection"],
Cell[52766, 1352, 3321, 85, 1140, "PackageInput"]
}, Closed]],
Cell[CellGroupData[{
Cell[56124, 1442, 27, 0, 34, "Subsubsection"],
Cell[56154, 1444, 9420, 238, 833, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[65611, 1687, 27, 0, 57, "Subsubsection"],
Cell[65641, 1689, 24856, 607, 3349, "PackageInput"]
}, Closed]],
Cell[CellGroupData[{
Cell[90534, 2301, 33, 0, 34, "Subsubsection"],
Cell[90570, 2303, 10049, 254, 1962, "PackageInput"]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[100668, 2563, 44, 0, 63, "Subsection"],
Cell[CellGroupData[{
Cell[100737, 2567, 27, 0, 57, "Subsubsection"],
Cell[100767, 2569, 2803, 69, 482, "PackageInput",
 InitializationCell->True],
Cell[103573, 2640, 2797, 69, 459, "PackageInput",
 InitializationCell->True],
Cell[106373, 2711, 3127, 77, 529, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[109537, 2793, 27, 0, 34, "Subsubsection"],
Cell[109567, 2795, 4125, 100, 621, "PackageInput",
 InitializationCell->True],
Cell[113695, 2897, 4109, 99, 621, "PackageInput",
 InitializationCell->True],
Cell[117807, 2998, 4450, 108, 668, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[122294, 3111, 33, 0, 34, "Subsubsection"],
Cell[122330, 3113, 3158, 77, 1239, "PackageInput",
 InitializationCell->True],
Cell[125491, 3192, 3152, 77, 1239, "PackageInput",
 InitializationCell->True],
Cell[128646, 3271, 3513, 85, 1345, "PackageInput",
 InitializationCell->True]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[132208, 3362, 46, 0, 63, "Subsection"],
Cell[132257, 3364, 409, 12, 240, "PackageInput",
 InitializationCell->True],
Cell[CellGroupData[{
Cell[132691, 3380, 47, 0, 127, "Subsubsection"],
Cell[132741, 3382, 18, 0, 87, "Text"],
Cell[132762, 3384, 4479, 111, 1341, "PackageInput",
 InitializationCell->True],
Cell[137244, 3497, 4485, 111, 1341, "PackageInput",
 InitializationCell->True],
Cell[141732, 3610, 4469, 111, 1287, "PackageInput",
 InitializationCell->True],
Cell[146204, 3723, 4475, 111, 1341, "PackageInput",
 InitializationCell->True],
Cell[150682, 3836, 18, 0, 87, "Text"],
Cell[150703, 3838, 14101, 369, 2326, "PackageInput",
 InitializationCell->True],
Cell[164807, 4209, 5217, 136, 1395, "PackageInput",
 InitializationCell->True],
Cell[170027, 4347, 14105, 369, 2326, "PackageInput",
 InitializationCell->True],
Cell[184135, 4718, 5221, 136, 1395, "PackageInput",
 InitializationCell->True],
Cell[189359, 4856, 14085, 369, 2326, "PackageInput",
 InitializationCell->True],
Cell[203447, 5227, 5205, 136, 1395, "PackageInput",
 InitializationCell->True],
Cell[208655, 5365, 14089, 369, 2326, "PackageInput",
 InitializationCell->True],
Cell[222747, 5736, 5209, 136, 1395, "PackageInput",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[227993, 5877, 41, 0, 127, "Subsubsection"],
Cell[228037, 5879, 18, 0, 87, "Text"],
Cell[228058, 5881, 3251, 78, 1075, "PackageInput",
 InitializationCell->True],
Cell[231312, 5961, 3453, 84, 1075, "PackageInput",
 InitializationCell->True],
Cell[234768, 6047, 18, 0, 87, "Text"],
Cell[234789, 6049, 11482, 292, 1750, "PackageInput",
 InitializationCell->True],
Cell[246274, 6343, 4053, 99, 1129, "PackageInput",
 InitializationCell->True],
Cell[250330, 6444, 11511, 292, 1804, "PackageInput",
 InitializationCell->True],
Cell[261844, 6738, 4034, 99, 1077, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[265915, 6842, 40, 0, 76, "Subsubsection"],
Cell[265958, 6844, 18, 0, 87, "Text"],
Cell[265979, 6846, 2738, 66, 973, "PackageInput",
 InitializationCell->True],
Cell[268720, 6914, 2746, 66, 1027, "PackageInput",
 InitializationCell->True],
Cell[271469, 6982, 18, 0, 87, "Text"],
Cell[271490, 6984, 3271, 75, 1183, "PackageInput",
 InitializationCell->True],
Cell[274764, 7061, 3281, 75, 1183, "PackageInput",
 InitializationCell->True],
Cell[278048, 7138, 3201, 79, 1134, "PackageInput",
 InitializationCell->True],
Cell[281252, 7219, 3157, 78, 1080, "PackageInput",
 InitializationCell->True]
}, Open  ]],
Cell[CellGroupData[{
Cell[284446, 7302, 37, 0, 127, "Subsubsection"],
Cell[284486, 7304, 18, 0, 87, "Text"],
Cell[284507, 7306, 4137, 104, 1237, "PackageInput",
 InitializationCell->True],
Cell[288647, 7412, 4143, 104, 1237, "PackageInput",
 InitializationCell->True],
Cell[292793, 7518, 18, 0, 87, "Text"],
Cell[292814, 7520, 13662, 364, 2169, "PackageInput",
 InitializationCell->True],
Cell[306479, 7886, 4830, 128, 1237, "PackageInput",
 InitializationCell->True],
Cell[311312, 8016, 13666, 364, 2169, "PackageInput",
 InitializationCell->True],
Cell[324981, 8382, 4834, 128, 1237, "PackageInput",
 InitializationCell->True]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[329864, 8516, 31, 0, 37, "Subsection"],
Cell[329898, 8518, 225, 6, 135, "PackageInput"],
Cell[330126, 8526, 18, 0, 87, "Text"],
Cell[330147, 8528, 1814, 45, 661, "PackageInput",
 InitializationCell->True],
Cell[331964, 8575, 18, 0, 87, "Text"],
Cell[331985, 8577, 2094, 51, 712, "PackageInput",
 InitializationCell->True],
Cell[334082, 8630, 2077, 48, 661, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[336196, 8683, 28, 0, 37, "Subsection"],
Cell[336227, 8685, 222, 6, 60, "PackageInput"],
Cell[336452, 8693, 18, 0, 39, "Text"],
Cell[336473, 8695, 829, 23, 109, "PackageInput",
 InitializationCell->True],
Cell[337305, 8720, 2781, 67, 364, "PackageInput",
 InitializationCell->True],
Cell[340089, 8789, 18, 0, 39, "Text"],
Cell[340110, 8791, 794, 23, 109, "PackageInput",
 InitializationCell->True],
Cell[340907, 8816, 849, 24, 109, "PackageInput",
 InitializationCell->True],
Cell[341759, 8842, 906, 25, 109, "PackageInput",
 InitializationCell->True],
Cell[342668, 8869, 1004, 27, 133, "PackageInput",
 InitializationCell->True],
Cell[343675, 8898, 3308, 79, 365, "PackageInput",
 InitializationCell->True],
Cell[346986, 8979, 10758, 275, 664, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[357781, 9259, 27, 0, 37, "Subsection"],
Cell[357811, 9261, 221, 6, 135, "PackageInput"],
Cell[358035, 9269, 824, 24, 244, "PackageInput",
 InitializationCell->True],
Cell[358862, 9295, 776, 23, 193, "PackageInput",
 InitializationCell->True],
Cell[359641, 9320, 415, 12, 139, "PackageInput",
 InitializationCell->True],
Cell[360059, 9334, 18, 0, 87, "Text"],
Cell[360080, 9336, 2047, 49, 661, "PackageInput",
 InitializationCell->True],
Cell[362130, 9387, 18, 0, 87, "Text"],
Cell[362151, 9389, 2143, 51, 715, "PackageInput",
 InitializationCell->True],
Cell[364297, 9442, 2492, 60, 870, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[366826, 9507, 49, 0, 37, "Subsection"],
Cell[366878, 9509, 240, 7, 135, "PackageInput"],
Cell[CellGroupData[{
Cell[367143, 9520, 27, 0, 127, "Subsubsection"],
Cell[367173, 9522, 1702, 41, 661, "PackageInput",
 InitializationCell->True],
Cell[368878, 9565, 2528, 64, 814, "PackageInput"],
Cell[371409, 9631, 2522, 64, 814, "PackageInput"],
Cell[373934, 9697, 2850, 72, 919, "PackageInput"]
}, Closed]],
Cell[CellGroupData[{
Cell[376821, 9774, 27, 0, 76, "Subsubsection"],
Cell[376851, 9776, 1976, 47, 715, "PackageInput",
 InitializationCell->True],
Cell[378830, 9825, 3640, 95, 919, "PackageInput"],
Cell[382473, 9922, 3634, 95, 919, "PackageInput"],
Cell[386110, 10019, 3986, 103, 1026, "PackageInput"]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[390157, 10129, 34, 0, 72, "Section"],
Cell[390194, 10131, 64, 0, 87, "Text"],
Cell[390261, 10133, 1625, 31, 1068, "PackageInput",
 InitializationCell->True]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
