(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    134596,       3914]
NotebookOptionsPosition[    129458,       3750]
NotebookOutlinePosition[    129883,       3768]
CellTagsIndexPosition[    129840,       3765]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["MarchingCubes", "Title",
 Background->RGBColor[0, 1, 1]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Copyright", " ", 
    RowBox[{"(", "C", ")"}], " ", "2005"}], ",", " ", 
   RowBox[{
    RowBox[{"E", ".", "G", ".", "W", ".", " ", "ter"}], " ", "Voert"}], ",", 
   " ", 
   RowBox[{"MarchingCubes", " ", "for", " ", "Mathematica", " ", "5.1"}]}], 
  " ", "*)"}]], "PackageInput",
 CellChangeTimes->{{3.4888880033791*^9, 3.488888018568265*^9}}],

Cell["\<\
United States Patent Number:4,710,876
Date of Patent:Dec.1,1987
Inventors:Harvey E.Cline,William E.Lorensen
Assignee:General Electric Company
Title:\"System and Method for the Display of Surface Structures Contained
        Within the Interior Region of a Solid Body\"
Filed:Jun.5, 1985

United States Patent Number:4,885,688
Date of Patent:Dec.5,1989
Inventor:Carl R.Crawford
Assignee:General Electric Company
Title:\"Minimization of Directed Points Generated in Three-Dimensional \
Dividing Cubes Method\"
Filed:Nov.25, 1987\
\>", "Text",
 FontSize->9],

Cell[CellGroupData[{

Cell["Prefix", "Section",
 CellFrame->{{0, 0}, {0, 2}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"Print", "[", "\"\<MarchingCubes package version 0.3\>\"", "]"}], 
  ";"}]], "PackageInput"]
}, Closed]],

Cell[CellGroupData[{

Cell["Package Code", "Section",
 CellFrame->{{0, 0}, {0, 2}}],

Cell[BoxData[
 StyleBox[
  RowBox[{"BeginPackage", "[", 
   RowBox[{"\"\<MarchingCubes`\>\"", ",", "\"\<Geometry`Rotations`\>\""}], 
   "]"}], "PackageInput"]], "PackageInput"]
}, Closed]],

Cell[CellGroupData[{

Cell["Online Help and Options", "Section",
 CellFrame->{{0, 0}, {0, 2}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"MCfindSurfaceInCubes", "::", "usage"}], "=", 
    "\"\<MCfindSurfaceInCubes[cubes,isolevel,image]; cubes={{x,y,z},...}, \
isolevel=0, {dimZ,dimY,dimX}=Dimensions[image].\\n   This function returns a \
list of estimated coordinates {{{ex,ey,ez},...},...} on the surface inside \
the given cubes and a list of polygons connecting these points. \
{coordinates,polygons}\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"MCfindSurfaceInCube", "::", "usage"}], "=", 
    "\"\<MCfindIsoSurfaceInCube[cube,isolevel,image]; cube={x,y,z}, \
isolevel=0, {dimZ,dimY,dimX}=Dimensions[image].\\n   This function returns a \
list of estimated coordinates {{ex,ey,ez},...} on the surface inside the \
given cube and a list of polygons connecting these points. \
{coordinates,polygons}\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MCcubeIndexC", "::", "usage"}], "=", 
   "\"\<MCcubeIndexC[isolevel,vertexValues]; isolevel=0, \
vertexValues={vertext8,vertext7,vertext6,vertext5,vertext4,vertext3,vertext2,\
vertext1}. Calculates the cubeindex of the cube. \\n   returns:0,if all \
verticeValues are < isolevel;(inside)\\n   returns:255,if all verticeValues \
are \[GreaterEqual] isolevel;(outside)\\n   returns:1-254 otherwise;(surface)\
\\n   example:MCcubeIndexC[0.5,{0.1,0.2,0.1,0.5,0.6,0.7,0.0,1.0}].\>\""}], 
  ";"}]}], "PackageInput"]
}, Closed]],

Cell[CellGroupData[{

Cell["For tests only:", "Subsubtitle"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"basicMarchingCubePatterns", "::", "usage"}], "=", 
   "\"\<This are the 23 basic MarchingCube Patterns. First colomn is the \
cubeIndex in binary and the second colomn are the 'triangles'. 'triangles' is \
a list of 3 edge numbers indicating the edges of the cube on which a triangle \
vertex is located. {1,4,9} means that there is a triangle with a vertex on \
cube edge 1, a vertex on cube edge 4 and a vertex on cube edge 9.\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"showCubeLayOut", "::", "usage"}], "=", 
   "\"\<This shows the used cube layout\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"plotMarchingCube", "::", "usage"}], "=", 
   "\"\<Example: \
plotMarchingCube[{{1,0,1,0,1,1,0,1},{{1,8,9},{1,7,8},{1,2,7},{2,7,11},{5,6,10}\
}}]. The first list is a vertex list. It is the cubeIndex in binary form. The \
second list is a list of 'triangles'. 'triangles' is a list of 3 edge numbers \
indicating the edges of the cube on which a triangle vertex is located. \
{1,4,9} means that there is a triangle with a vertex on cube edge 1, a vertex \
on cube edge 4 and a vertex on cube edge 9.\>\""}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"findAllRotations", "::", "usage"}], "=", 
   "\"\<given the vertices and the triangles \
{{0,1,0,0,0,0,1,1},{{2,4,9},{2,9,10},{6,7,11}}} it returns a list of all \
posible rotations:{{{0,1,0,0,0,0,1,1},{{2,4,9},{2,9,10},{6,7,11}}},...}\>\""}]\
, ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MCfindSurfaceInCubeA", "::", "usage"}], "=", "\"\<bla\>\""}], 
  ";"}]}], "PackageInput"],

Cell["\<\
(* old stuff *)
MCedgeTable::usage=
    \"This table contains a list of cube edges cut by the iso-surface for \
each \\
possible cube; the listindex matches the CubeIndex number. If one wants the \\
edges that need to be interpolated for cubeIndex 5 then MCedgeTable[[5]] \\
returns the list of edges.\";
triangleTable::usage=\"This table contains a list of 'triangles' for each \
possible cube; the listindex matches the CubeIndex number. If one wants the \
triangles for cubeIndex 5 then triangleTable[[5]] returns the list of \
triangles. 'triangles' is a list of 3 edge numbers indicating the edges of \
the cube on which a triangle vertex is located. {1,4,9} means that there is a \
triangle with a vertex on cube edge 1, a vertex on cube edge 4 and a vertex \
on cube edge 9.\";\
\>", "Text"],

Cell[CellGroupData[{

Cell["Function definitions", "Section",
 CellFrame->{{0, 0}, {0, 2}}],

Cell[BoxData[
 StyleBox[
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  "PackageInput"]], "PackageInput"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Creating the tables (only used to initialize the package)", "Subtitle",
 Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["Globals", "Subsection"],

Cell["basicMarchingCubePatterns", "Text"],

Cell["rotations", "Text"],

Cell["triangleTable", "Text"],

Cell["edgeTable", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cube Lay-out", "Subsection"],

Cell["Show the lay-out of the cube, the edge numbers and vertices", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"showCubeLayOut", "[", "]"}], ":=", 
    RowBox[{"Module", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Show", "[", 
        RowBox[{
         RowBox[{"Graphics3D", "[", "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"1", ",", "1", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}], "]"}], ",",
             "\[IndentingNewLine]", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"1", ",", "0", ",", "1"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}], "]"}], ",",
             "\[IndentingNewLine]", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "}"}], "]"}], ",", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"1", ",", "0", ",", "1"}], "}"}]}], "}"}], "]"}], ",",
             "\[IndentingNewLine]", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"1", ",", "1", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "}"}], "]"}], ",", 
            RowBox[{"Line", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "1", ",", "1"}], "}"}]}], "}"}], "]"}], ",",
             "\[IndentingNewLine]", 
            RowBox[{"RGBColor", "[", 
             RowBox[{"1", ",", "0", ",", "0"}], "]"}], ",", 
            RowBox[{"Text", "[", 
             RowBox[{"\"\<1\>\"", ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", 
                RowBox[{"0", "-", ".1"}], ",", "0"}], "}"}]}], "]"}], ",", 
            RowBox[{"Text", "[", 
             RowBox[{"\"\<2\>\"", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"1", "+", ".1"}], ",", 
                RowBox[{"0", "-", ".1"}], ",", "0"}], "}"}]}], "]"}], ",", 
            RowBox[{"Text", "[", 
             RowBox[{"\"\<3\>\"", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"1", "+", ".1"}], ",", 
                RowBox[{"1", "-", ".1"}], ",", "0"}], "}"}]}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"Text", "[", 
             RowBox[{"\"\<4\>\"", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"0", "-", ".1"}], ",", 
                RowBox[{"1", "-", ".1"}], ",", "0"}], "}"}]}], "]"}], ",", 
            RowBox[{"Text", "[", 
             RowBox[{"\"\<5\>\"", ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", 
                RowBox[{"0", "-", ".1"}], ",", "1"}], "}"}]}], "]"}], ",", 
            RowBox[{"Text", "[", 
             RowBox[{"\"\<6\>\"", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"1", "+", ".1"}], ",", 
                RowBox[{"0", "-", ".1"}], ",", "1"}], "}"}]}], "]"}], ",", 
            RowBox[{"Text", "[", 
             RowBox[{"\"\<7\>\"", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"1", "+", ".1"}], ",", 
                RowBox[{"1", "-", ".1"}], ",", "1"}], "}"}]}], "]"}], ",", 
            RowBox[{"Text", "[", 
             RowBox[{"\"\<8\>\"", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"0", "-", ".1"}], ",", 
                RowBox[{"1", "-", ".1"}], ",", "1"}], "}"}]}], "]"}], ",", 
            "\[IndentingNewLine]", 
            RowBox[{"RGBColor", "[", 
             RowBox[{"0", ",", "0", ",", "1"}], "]"}], ",", 
            RowBox[{"Text", "[", 
             RowBox[{"\"\<1\>\"", ",", 
              RowBox[{"{", 
               RowBox[{"0.5", ",", 
                RowBox[{"0", "-", ".1"}], ",", "0"}], "}"}]}], "]"}], ",", 
            RowBox[{"Text", "[", 
             RowBox[{"\"\<2\>\"", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"1", "+", ".1"}], ",", ".5", ",", "0"}], "}"}]}], 
             "]"}], ",", 
            RowBox[{"Text", "[", 
             RowBox[{"\"\<3\>\"", ",", 
              RowBox[{"{", 
               RowBox[{"0.5", ",", 
                RowBox[{"1", "-", ".1"}], ",", "0"}], "}"}]}], "]"}], ",", 
            RowBox[{"Text", "[", 
             RowBox[{"\"\<4\>\"", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"0", "+", ".1"}], ",", ".5", ",", "0"}], "}"}]}], 
             "]"}], ",", 
            RowBox[{"Text", "[", 
             RowBox[{"\"\<5\>\"", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"0.5", "+", ".1"}], ",", 
                RowBox[{"0", "-", ".1"}], ",", "1"}], "}"}]}], "]"}], ",", 
            RowBox[{"Text", "[", 
             RowBox[{"\"\<6\>\"", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"1", "+", ".1"}], ",", 
                RowBox[{".5", "-", ".1"}], ",", "1"}], "}"}]}], "]"}], ",", 
            RowBox[{"Text", "[", 
             RowBox[{"\"\<7\>\"", ",", 
              RowBox[{"{", 
               RowBox[{"0.5", ",", 
                RowBox[{"1", "-", ".1"}], ",", "1"}], "}"}]}], "]"}], ",", 
            RowBox[{"Text", "[", 
             RowBox[{"\"\<8\>\"", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"0", "+", ".1"}], ",", ".5", ",", "1"}], "}"}]}], 
             "]"}], ",", 
            RowBox[{"Text", "[", 
             RowBox[{"\"\<9\>\"", ",", 
              RowBox[{"{", 
               RowBox[{"0", ",", 
                RowBox[{"0", "-", ".1"}], ",", ".5"}], "}"}]}], "]"}], ",", 
            RowBox[{"Text", "[", 
             RowBox[{"\"\<10\>\"", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"1", "+", ".1"}], ",", "0", ",", 
                RowBox[{".5", "+", ".1"}]}], "}"}]}], "]"}], ",", 
            RowBox[{"Text", "[", 
             RowBox[{"\"\<11\>\"", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"1", "+", ".1"}], ",", "1", ",", ".5"}], "}"}]}], 
             "]"}], ",", 
            RowBox[{"Text", "[", 
             RowBox[{"\"\<12\>\"", ",", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"0", "+", ".1"}], ",", 
                RowBox[{"1", "+", ".1"}], ",", ".5"}], "}"}]}], "]"}]}], 
           "\[IndentingNewLine]", "}"}], "\[IndentingNewLine]", "]"}], ",", 
         RowBox[{"Boxed", "\[Rule]", "False"}], ",", 
         RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}]], "PackageInput"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0131 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0256265 1.10306 -3.37729e-017 1.10306 [
[ 0 0 0 0 ]
[ 1 1.0131 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.0131 L
0 1.0131 L
closepath
clip
newpath
0 g
.5 Mabswid
[ ] 0 setdash
.4348 .55031 m
.42288 .96256 L
s
.4348 .55031 m
.17005 .27725 L
s
.85726 .41258 m
.4348 .55031 L
s
.85726 .41258 m
.90467 .84347 L
s
.64183 .08903 m
.85726 .41258 L
s
.42288 .96256 m
.11478 .72393 L
s
.90467 .84347 m
.42288 .96256 L
s
.17005 .27725 m
.11478 .72393 L
s
.17005 .27725 m
.64183 .08903 L
s
.66185 .55336 m
.90467 .84347 L
s
.64183 .08903 m
.66185 .55336 L
s
.11478 .72393 m
.66185 .55336 L
s
1 0 0 r
gsave
.13879 .24502 -66 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(1) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.66891 .02869 -66 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(2) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.88528 .36919 -66 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(3) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.37254 .53946 -66 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(4) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.07753 .69508 -66 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(5) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.69443 .49757 -66 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(6) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.93811 .80542 -66 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(7) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.35232 .95327 -66 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 1 r
gsave
.36632 .15217 -66 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(1) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.80724 .24638 -66 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(2) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.61671 .45838 -66 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(3) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.35363 .40914 -66 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(4) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.39557 .59325 -66 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(5) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.82805 .66638 -66 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(6) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.62933 .88336 -66 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(7) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.32893 .84046 -66 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.11041 .45355 -66 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(9) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.7105 .32952 -69 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(10) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.92874 .59938 -69 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(11) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.49447 .75383 -69 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(12) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{284.25, 287.938},
 ImageMargins->{{43, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],
 ImageRangeCache->{{{0, 283.25}, {286.938, 0}} -> {0.0231912, -4.59227, \
0.00320089, 0.00320089}}]
}, Open  ]],

Cell["\<\
Red = Vertex, Blue = Edge

The vertices data structure layout is:{vertex-8, vertex-7, vertex-6, \
vertex-5, vertex-4, vertex-3, vertex-2, vertex-1}
 vertex-X = 1 if inside
 vertex-X = 0 if outside
There are 256 possible combinations.
The CubeIndex number is based on this 8 bits binary number:
 Converting this 8 bit binary data structure to a decimal number will result \
in the cubeIndex number.
{0,0,0,0,0,0,0,0}=>CubeIndex 0
{0,0,0,0,0,0,0,1}=>CubeIndex 1
{0,0,0,0,0,0,1,0}=>CubeIndex 2
...
{1,1,1,1,1,1,1,1}=>CubeIndex 255
 With this CubeIndex number the program knows where to place the triangles \
and surface points.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["basicMarchingCubePatterns", "Subsection"],

Cell["\<\
There are 2^8=256 possible combinations of cube vertices beining inside/out \
side and thus 256 ways to draw a surface in the cube.
However, by rotating only 15 unique basic cubes with the surfaces (triangles) \
inside, the other 241 cubes can be constructed.
These originally 15 basic cubes are found by Lorensen and Cline (1987).
To avoid problems this set of 15 cubes is extended to 23 by Shoeb (1998).

The first part of each entry is the vertex data structure layout:
The vertices data structure layout is:{vertex-8, vertex-7, vertex-6, \
vertex-5, vertex-4, vertex-3, vertex-2, vertex-1}
 vertex-X = 1 if inside
 vertex-X = 0 if outside
 The second part is a list of triangles. Each triange is defind by three \
numbers. The numbers are edges of the cube.  The vertices of the triangle are \
located on the listed cube edges.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"basicMarchingCubePatterns", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
         "0"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
         "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"1", ",", "4", ",", "9"}], "}"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "1", ",", 
         "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2", ",", "4", ",", "9"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "9", ",", "10"}], "}"}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0", ",", "0", ",", "1", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
         "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "4", ",", "9"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"5", ",", "6", ",", "10"}], "}"}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0", ",", "0", ",", "0", ",", "0", ",", "1", ",", "1", ",", "1", ",", 
         "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"10", ",", "11", ",", "12"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "10", ",", "4"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "10", ",", "12"}], "}"}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0", ",", "0", ",", "0", ",", "0", ",", "1", ",", "1", ",", "1", ",", 
         "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"10", ",", "11", ",", "12"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"9", ",", "10", ",", "12"}], "}"}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0", ",", "0", ",", "0", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
         "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"10", ",", "11", ",", "12"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "10", ",", "4"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "10", ",", "12"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"5", ",", "9", ",", "8"}], "}"}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "1", ",", "0", ",", "1", ",", "0", ",", "0", ",", "1", ",", "0", ",", 
         "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "4", ",", "9"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"5", ",", "6", ",", "10"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "11", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"7", ",", "8", ",", "12"}], "}"}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "1", ",", "0", ",", "0", ",", "0", ",", "1", ",", "1", ",", "0", ",", 
         "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"7", ",", "8", ",", "9"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "7", ",", "9"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "11", ",", "7"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "11"}], "}"}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "1", ",", "0", ",", "0", ",", "0", ",", "1", ",", "1", ",", "1", ",", 
         "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "8", ",", "4"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "8", ",", "10"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"8", ",", "10", ",", "11"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"7", ",", "8", ",", "11"}], "}"}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0", ",", "1", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
         "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "4", ",", "9"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"6", ",", "7", ",", "11"}], "}"}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0", ",", "1", ",", "0", ",", "0", ",", "0", ",", "0", ",", "1", ",", 
         "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"2", ",", "4", ",", "9"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "9", ",", "10"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"6", ",", "7", ",", "11"}], "}"}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0", ",", "1", ",", "0", ",", "1", ",", "0", ",", "0", ",", "1", ",", 
         "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "10", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"6", ",", "7", ",", "11"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"5", ",", "9", ",", "8"}], "}"}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0", ",", "1", ",", "0", ",", "1", ",", "0", ",", "1", ",", "0", ",", 
         "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "4", ",", "8"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "8", ",", "5"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "7", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "6", ",", "7"}], "}"}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "0", ",", "1", ",", "0", ",", "0", ",", "1", ",", "1", ",", "0", ",", 
         "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "12", ",", "9"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "6", ",", "12"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "6"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"6", ",", "7", ",", "12"}], "}"}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "1", ",", "0", ",", "0", ",", "0", ",", "1", ",", "1", ",", "1", ",", 
         "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"8", ",", "9", ",", "10"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"8", ",", "10", ",", "11"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"7", ",", "8", ",", "11"}], "}"}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "1", ",", "1", ",", "0", ",", "0", ",", "1", ",", "0", ",", "1", ",", 
         "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"6", ",", "8", ",", "9"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"3", ",", "6", ",", "9"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"3", ",", "11", ",", "6"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"3", ",", "9", ",", "10"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "3", ",", "10"}], "}"}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "1", ",", "1", ",", "0", ",", "0", ",", "1", ",", "1", ",", "1", ",", 
         "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"6", ",", "8", ",", "10"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"8", ",", "9", ",", "10"}], "}"}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "1", ",", "0", ",", "1", ",", "0", ",", "1", ",", "1", ",", "0", ",", 
         "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "8", ",", "9"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "7", ",", "8"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "2", ",", "7"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "11", ",", "7"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"5", ",", "6", ",", "10"}], "}"}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "1", ",", "0", ",", "1", ",", "0", ",", "1", ",", "1", ",", "1", ",", 
         "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"7", ",", "8", ",", "9"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"7", ",", "9", ",", "11"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"5", ",", "11", ",", "9"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"5", ",", "6", ",", "11"}], "}"}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "1", ",", "1", ",", "1", ",", "0", ",", "1", ",", "0", ",", "1", ",", 
         "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"5", ",", "8", ",", "9"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "3", ",", "11"}], "}"}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "1", ",", "1", ",", "1", ",", "0", ",", "1", ",", "1", ",", "1", ",", 
         "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"5", ",", "8", ",", "9"}], "}"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", 
         "1"}], "}"}], ",", 
       RowBox[{"{", "}"}]}], "}"}]}], "\[IndentingNewLine]", "}"}]}], 
  ";"}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["rotations", "Subsection"],

Cell["\<\
The rotation given by the Euler angles phi,theta ,and psi can be decomposed \
into a sequence of three successive rotations. The first by angle phi about \
the z axis, the second by angle theta about the x axis, and the third about \
the z axis (again) by angle psi. The angle theta is restricted to the range 0 \
to \[Pi].
For each of the 6 cube faces there are 4 possible rotations giving a total of \
24:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rotations", "=", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "bottom", ",", "top", ",", "front", ",", "left", ",", "back", ",", 
       "right"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"bottom", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}], "\[Pi]"}], ",", "0", ",", "0"}], 
          "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Pi]", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"3", "/", "2"}], ")"}], "\[Pi]"}], ",", "0", ",", "0"}], 
          "}"}]}], "}"}]}], " ", ";", "\[IndentingNewLine]", 
      RowBox[{"top", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "\[Pi]", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}], "\[Pi]"}], ",", "\[Pi]", ",", 
           "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Pi]", ",", "\[Pi]", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"3", "/", "2"}], ")"}], "\[Pi]"}], ",", "\[Pi]", ",", 
           "0"}], "}"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"front", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}], "\[Pi]"}], ",", "0"}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}], "\[Pi]"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}], "\[Pi]"}], ",", "0"}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{"\[Pi]", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}], "\[Pi]"}], ",", "0"}], "}"}], 
         ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"3", "/", "2"}], ")"}], "\[Pi]"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}], "\[Pi]"}], ",", "0"}], "}"}]}], 
        "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"left", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}], "\[Pi]"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}], "\[Pi]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}], "\[Pi]"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}], "\[Pi]"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}], "\[Pi]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Pi]", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}], "\[Pi]"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}], "\[Pi]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"3", "/", "2"}], ")"}], "\[Pi]"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}], "\[Pi]"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}], "\[Pi]"}]}], "}"}]}], "}"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"back", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}], "\[Pi]"}], ",", "\[Pi]"}], "}"}],
          ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}], "\[Pi]"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}], "\[Pi]"}], ",", "\[Pi]"}], "}"}],
          ",", 
         RowBox[{"{", 
          RowBox[{"\[Pi]", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}], "\[Pi]"}], ",", "\[Pi]"}], "}"}],
          ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"3", "/", "2"}], ")"}], "\[Pi]"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}], "\[Pi]"}], ",", "\[Pi]"}], 
          "}"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"right", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}], "\[Pi]"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"3", "/", "2"}], ")"}], "\[Pi]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}], "\[Pi]"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}], "\[Pi]"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"3", "/", "2"}], ")"}], "\[Pi]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Pi]", ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}], "\[Pi]"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"3", "/", "2"}], ")"}], "\[Pi]"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"3", "/", "2"}], ")"}], "\[Pi]"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"1", "/", "2"}], ")"}], "\[Pi]"}], ",", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"3", "/", "2"}], ")"}], "\[Pi]"}]}], "}"}]}], "}"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"Flatten", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
         "top", ",", "bottom", ",", "front", ",", "left", ",", "back", ",", 
          "right"}], "}"}], ",", "1"}], "]"}]}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["getVertexCoordinate", "Subsection"],

Cell["\<\
Given a vertex number it returns its vertex coordinate (used by \
findAllRotations)\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"getVertexCoordinate", "[", "vertexNumber_Integer", "]"}], ":=", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "coordVertices", "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"debug", " ", "stuff"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"vertexNumber", "<", "1"}], ",", " ", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"StyleForm", "[", 
           RowBox[{"\"\<->Error: getVertexCoordinate <1\>\"", ",", 
            RowBox[{"FontColor", "\[Rule]", 
             RowBox[{"RGBColor", "[", 
              RowBox[{"1", ",", "0", ",", "0"}], "]"}]}]}], "]"}], "]"}], ";", 
         RowBox[{"Abort", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"vertexNumber", ">", "8"}], ",", " ", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"StyleForm", "[", 
           RowBox[{"\"\<->Error: getVertexCoordinate >8\>\"", ",", 
            RowBox[{"FontColor", "\[Rule]", 
             RowBox[{"RGBColor", "[", 
              RowBox[{"1", ",", "0", ",", "0"}], "]"}]}]}], "]"}], "]"}], ";", 
         RowBox[{"Abort", "[", "]"}]}]}], "]"}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{"Vertices", ":", " ", "1"}], ",", "    ", "2", ",", 
        "         ", "3", ",", "          ", "4", ",", "           ", "5", 
        ",", "         ", "6", ",", "       ", "7", ",", "         ", "8"}], 
       " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", 
           RowBox[{"-", "1"}], ",", 
           RowBox[{"-", "1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{"-", "1"}], ",", 
           RowBox[{"-", "1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", 
           RowBox[{"-", "1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "1", ",", 
           RowBox[{"-", "1"}]}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", 
           RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", 
           RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "1"}], ",", "1", ",", "1"}], "}"}]}], "}"}], "[", 
       RowBox[{"[", "vertexNumber", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
    "]"}]}], ";"}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["getVertexNumber", "Subsection"],

Cell["\<\
Given a vertex coordinate {x,y,z} it returns its vertex number (used by \
getEdgeNumber for findAllRotations)\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"getVertexNumber", "[", "vertexCoordinate_List", "]"}], ":=", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", "coordVertices", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"Vertex", ":", "           ", 
      RowBox[{
      "1", "             ", "2", "          ", "3", "           ", "4", "          ",
        "5", "          ", "6", "        ", "7", "          ", "8"}]}], 
     "    ", "*)"}], "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"coordVertices", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", 
          RowBox[{"-", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", 
          RowBox[{"-", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", 
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", 
          RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1"}], ",", "1", ",", "1"}], "}"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Position", "[", 
       RowBox[{"coordVertices", ",", "vertexCoordinate"}], "]"}], "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "1"}], "]"}], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["getVertexCoordinates", "Subsection"],

Cell["\<\
Given an edge number it returns its vertex numbers {vertex number, vertex \
number}  \
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"getVertexCoordinates", "[", "edgeNumber_Integer", "]"}], ":=", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "vertexNumbers", "}"}], ",", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"debug", " ", "stuff"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"\[Not]", 
         RowBox[{"(", 
          RowBox[{"1", "\[LessEqual]", "edgeNumber", "\[LessEqual]", "12"}], 
          ")"}]}], ",", " ", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"StyleForm", "[", 
           RowBox[{
           "\"\<->Error: getVertexCoordinates \[Not](1\[LessEqual]edgeNumber\
\[LessEqual]12)\>\"", ",", 
            RowBox[{"FontColor", "\[Rule]", 
             RowBox[{"RGBColor", "[", 
              RowBox[{"1", ",", "0", ",", "0"}], "]"}]}]}], "]"}], "]"}], ";", 
         RowBox[{"Abort", "[", "]"}]}]}], "\[IndentingNewLine]", "]"}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{"Edge", ":", "           ", 
        RowBox[{
        "1", "      ", "2", "      ", "3", "      ", "4", "      ", "5", "      ",
          "6", "       ", "7", "      ", "8", "      ", "9", "      ", "10", "     ",
          "11", "      ", "12"}]}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"vertexNumbers", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"3", ",", "4"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"5", ",", "6"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"6", ",", "7"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"7", ",", "8"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"8", ",", "5"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "5"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "6"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"3", ",", "7"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "8"}], "}"}]}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"getVertexCoordinate", "[", 
         RowBox[{"vertexNumbers", "[", 
          RowBox[{"[", 
           RowBox[{"edgeNumber", ",", "1"}], "]"}], "]"}], "]"}], ",", 
        RowBox[{"getVertexCoordinate", "[", 
         RowBox[{"vertexNumbers", "[", 
          RowBox[{"[", 
           RowBox[{"edgeNumber", ",", "2"}], "]"}], "]"}], "]"}]}], "}"}]}]}],
     "]"}]}], ";"}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["getEdgeNumber", "Subsection"],

Cell["\<\
Given two vertex coordinates {vertex coordinate {x1,y1,z1}, vertex coordinate \
{x2,y2,z2}}it returns its edge number connecting the vertices (used by \
findAllRotations)\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"getEdgeNumber", "[", "edgeCoordinates_List", "]"}], ":=", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"vertexNumbers", ",", "a", ",", "b"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"Edge", ":", "           ", 
       RowBox[{
       "1", "      ", "2", "      ", "3", "      ", "4", "      ", "5", "      ",
         "6", "       ", "7", "      ", "8", "      ", "9", "      ", "10", "     ",
         "11", "      ", "12"}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"vertexNumbers", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"1", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "3"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"3", ",", "4"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"5", ",", "6"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"6", ",", "7"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"7", ",", "8"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"8", ",", "5"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "5"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"2", ",", "6"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"3", ",", "7"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"4", ",", "8"}], "}"}]}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"a", "=", 
       RowBox[{"getVertexNumber", "[", 
        RowBox[{"edgeCoordinates", "[", 
         RowBox[{"[", "1", "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"b", "=", 
       RowBox[{"getVertexNumber", "[", 
        RowBox[{"edgeCoordinates", "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Flatten", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Position", "[", 
           RowBox[{"vertexNumbers", ",", 
            RowBox[{"{", 
             RowBox[{"a", ",", "b"}], "}"}]}], "]"}], ",", 
          RowBox[{"Position", "[", 
           RowBox[{"vertexNumbers", ",", 
            RowBox[{"{", 
             RowBox[{"b", ",", "a"}], "}"}]}], "]"}]}], "}"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  ";"}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["findAllRotations", "Subsection"],

Cell["\<\
given the vertices and the triangles \
{{0,1,0,0,0,0,1,1},{{2,4,9},{2,9,10},{6,7,11}}} it returns a list of all \
posible rotations:
{ {{0,1,0,0,0,0,1,1},{{2,4,9},{2,9,10},{6,7,11}}}, ... }
findAllRotations[{{1,0,1,0,1,1,0,1},{{1,8,9},{1,7,8},{1,2,7},{2,7,11},{5,6,10}\
}}]\
\>", "Text"],

Cell["(* check out function: memberQ *)", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"findAllRotations", "[", 
    RowBox[{"{", 
     RowBox[{"vertices_List", ",", "triangles_List"}], "}"}], "]"}], ":=", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "pointsInside", ",", "pointsOutside", ",", "edgeCoords", ",", 
       "rotatedCoordinates", ",", "phi", ",", "theta", ",", "psi", ",", "r", 
       ",", "newPointsInside", ",", "newPointsOutside", ",", "newEdgeCoords", 
       ",", "newVertices", ",", "newTriangles", ",", "coordinate", ",", "i", 
       ",", "allRotatedVerticesAndTriangleList"}], "}"}], ",", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "replace", " ", "vertex", " ", "numbers", " ", "from", " ", "vertices", 
       " ", "with", " ", "coordinates"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"pointsInside", "=", 
       RowBox[{"MapIndexed", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"#1", "\[Equal]", "1"}], ",", 
             RowBox[{"getVertexCoordinate", "[", 
              RowBox[{"9", "-", 
               RowBox[{"#2", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], " ", "]"}], ",", 
             RowBox[{"{", "}"}]}], "]"}], ")"}], "&"}], ",", "vertices"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"pointsInside", "=", 
       RowBox[{"Select", "[", 
        RowBox[{"pointsInside", ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"#", "\[NotEqual]", 
            RowBox[{"{", "}"}]}], ")"}], "&"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"pointsOutside", "=", 
       RowBox[{"MapIndexed", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"#1", "\[Equal]", "0"}], ",", 
             RowBox[{"getVertexCoordinate", "[", 
              RowBox[{"9", "-", 
               RowBox[{"#2", "[", 
                RowBox[{"[", "1", "]"}], "]"}]}], " ", "]"}], ",", 
             RowBox[{"{", "}"}]}], "]"}], ")"}], "&"}], ",", "vertices"}], 
        "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"pointsOutside", "=", 
       RowBox[{"Select", "[", 
        RowBox[{"pointsOutside", ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"#", "\[NotEqual]", 
            RowBox[{"{", "}"}]}], ")"}], "&"}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "replace", " ", "each", " ", "edges", " ", "from", " ", "triangles", 
        " ", "with", " ", "2", " ", "vertex", " ", "coordinates"}], " ", 
       "*)"}], "\[IndentingNewLine]", 
      RowBox[{"edgeCoords", "=", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"getVertexCoordinates", "[", "#", "]"}], ")"}], "&"}], 
             ",", "#"}], "]"}], ")"}], "&"}], ",", "triangles"}], "]"}]}], 
      ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{"\"\<pointsInside: \>\"", "<>", 
          RowBox[{"ToString", "[", "pointsInside", "]"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<pointsOutside: \>\"", "<>", 
          RowBox[{"ToString", "[", "pointsOutside", "]"}]}], "]"}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<edgeCoords: \>\"", "<>", 
          RowBox[{"ToString", "[", "edgeCoords", "]"}]}], "]"}], ";"}], 
       "\[IndentingNewLine]", "*)"}], "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "rotate", " ", "all", " ", "the", " ", "coordinates", " ", "with", " ",
         "the", " ", "aid", " ", "of", " ", "\"\<rotations\>\"", " ", 
        "defined", " ", "else", " ", "where", " ", "outside", " ", "this", 
        " ", "function"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"rotatedCoordinates", "=", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"phi", "=", 
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"theta", "=", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"psi", "=", 
             RowBox[{"#", "[", 
              RowBox[{"[", "3", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"r", "=", 
             RowBox[{"RotationMatrix3D", "[", 
              RowBox[{"phi", ",", "theta", ",", "psi"}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"newPointsInside", "=", 
             RowBox[{"Map", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"Dot", "[", 
                  RowBox[{"r", ",", " ", "#"}], "]"}], ")"}], "&"}], ",", 
               "pointsInside"}], "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"newPointsOutside", "=", 
             RowBox[{"Map", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"Dot", "[", 
                  RowBox[{"r", ",", " ", "#"}], "]"}], ")"}], "&"}], ",", 
               "pointsOutside"}], "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"newEdgeCoords", "=", 
             RowBox[{"Map", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"Dot", "[", 
                  RowBox[{"r", ",", " ", "#"}], "]"}], ")"}], "&"}], ",", 
               "edgeCoords", ",", 
               RowBox[{"{", "3", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"(*", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"Print", "[", 
               RowBox[{"\"\<newPointsInside: \>\"", "<>", 
                RowBox[{"ToString", "[", "newPointsInside", "]"}]}], "]"}], 
              ";", "\[IndentingNewLine]", 
              RowBox[{"Print", "[", 
               RowBox[{"\"\<newPointsOutside: \>\"", "<>", 
                RowBox[{"ToString", "[", "newPointsOutside", "]"}]}], "]"}], 
              ";", "\[IndentingNewLine]", 
              RowBox[{"Print", "[", 
               RowBox[{"\"\<newEdgeCoords: \>\"", "<>", 
                RowBox[{"ToString", "[", "newEdgeCoords", "]"}]}], "]"}], 
              ";"}], "\[IndentingNewLine]", "*)"}], "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{
             "newPointsInside", ",", "newPointsOutside", ",", 
              "newEdgeCoords"}], "}"}]}], "\[IndentingNewLine]", ")"}], "&"}],
          ",", "\[IndentingNewLine]", "rotations"}], "\[IndentingNewLine]", 
        "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(*", " ", 
       RowBox[{
       "convert", " ", "coordinates", " ", "back", " ", "to", " ", "a", " ", 
        "vertex", " ", "list", " ", "and", " ", "a", " ", "triangle", " ", 
        "list"}], " ", "*)"}], "\[IndentingNewLine]", 
      RowBox[{"allRotatedVerticesAndTriangleList", "=", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"(", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"newPointsInside", "=", 
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"newPointsOutside", "=", 
             RowBox[{"#", "[", 
              RowBox[{"[", "2", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"newEdgeCoords", "=", 
             RowBox[{"#", "[", 
              RowBox[{"[", "3", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"(*", " ", 
             RowBox[{"the", " ", "vertices"}], " ", "*)"}], 
            "\[IndentingNewLine]", 
            RowBox[{"newVertices", "=", 
             RowBox[{"Table", "[", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{
                RowBox[{"coordinate", "=", 
                 RowBox[{"getVertexCoordinate", "[", "i", "]"}]}], ";", 
                "\[IndentingNewLine]", 
                RowBox[{"(*", " ", 
                 RowBox[{"check", " ", "out", " ", 
                  RowBox[{"function", ":", " ", "memberQ"}]}], " ", "*)"}], 
                "\[IndentingNewLine]", 
                RowBox[{"If", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"Length", "[", 
                    RowBox[{"Select", "[", 
                    RowBox[{"newPointsInside", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"#", "\[Equal]", "coordinate"}], ")"}], "&"}]}], 
                    "]"}], "]"}], "\[Equal]", "1"}], ",", 
                  "\[IndentingNewLine]", "1", ",", "\[IndentingNewLine]", 
                  RowBox[{"If", "[", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"Length", "[", 
                    RowBox[{"Select", "[", 
                    RowBox[{"newPointsOutside", ",", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"#", "\[Equal]", "coordinate"}], ")"}], "&"}]}], 
                    "]"}], "]"}], "\[Equal]", "1"}], ",", 
                    "\[IndentingNewLine]", "0", ",", "\[IndentingNewLine]", 
                    RowBox[{"(*", " ", 
                    RowBox[{"debug", " ", "stuff"}], " ", "*)"}], 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"Print", "[", 
                    RowBox[{"StyleForm", "[", 
                    RowBox[{"\"\<->Error: findAllRotations\>\"", ",", 
                    RowBox[{"FontColor", "\[Rule]", 
                    RowBox[{"RGBColor", "[", 
                    RowBox[{"1", ",", "0", ",", "0"}], "]"}]}]}], "]"}], 
                    "]"}], ";", 
                    RowBox[{"Abort", "[", "]"}], ";"}]}], 
                   "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
                 "]"}]}], ",", "\[IndentingNewLine]", 
               RowBox[{"{", 
                RowBox[{"i", ",", "8", ",", "1", ",", 
                 RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";", 
            "\[IndentingNewLine]", 
            RowBox[{"(*", " ", 
             RowBox[{"the", " ", "triangles"}], " ", "*)"}], 
            "\[IndentingNewLine]", 
            RowBox[{"newTriangles", "=", 
             RowBox[{"Map", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"getEdgeNumber", "[", "#", "]"}], ")"}], "&"}], ",", 
               "newEdgeCoords", ",", 
               RowBox[{"{", "2", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
            RowBox[{"{", 
             RowBox[{"newVertices", ",", "newTriangles"}], "}"}]}], 
           "\[IndentingNewLine]", ")"}], "&"}], ",", "\[IndentingNewLine]", 
         "rotatedCoordinates"}], "\[IndentingNewLine]", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Union", "[", 
       RowBox[{"allRotatedVerticesAndTriangleList", ",", 
        RowBox[{"SameTest", "\[Rule]", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"#1", "[", 
              RowBox[{"[", "1", "]"}], "]"}], "===", 
             RowBox[{"#2", "[", 
              RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "&"}], ")"}]}]}], 
       "]"}]}]}], "\[IndentingNewLine]", "]"}]}], ";"}]], "PackageInput"],

Cell["", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["plotMarchingCube", "Subsection"],

Cell["\<\
Plots the cube with the defined vertices and triangles.
The red dots at the vertices indicate that they are inside, the black ones \
the vertices outside.
The edge intercept is set half way the vertices.
Example: plotMarchingCube[{{1,0,1,0,1,1,0,1},{{1,8,9},{1,7,8},{1,2,7},{2,7,11}\
,{5,6,10}}}] \
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"plotMarchingCube", "[", 
    RowBox[{"{", 
     RowBox[{"vertices_List", ",", "triangles_List"}], "}"}], "]"}], ":=", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "coordVertices", ",", "coordTriangles", ",", "myPoints", ",", 
       "myTriangles", ",", "liveApplet", ",", "liveFrame"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"coordVertices", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "1", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "0", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "1", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"coordTriangles", "=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0.5", ",", "0", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "0.5", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0.5", ",", "1", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0.5", ",", "0"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0.5", ",", "0", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "0.5", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0.5", ",", "1", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0.5", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0", ",", "0.5"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "0", ",", "0.5"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "1", ",", "0.5"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "1", ",", "0.5"}], "}"}]}], "}"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"myPoints", "=", 
       RowBox[{"Graphics3D", "[", 
        RowBox[{"MapThread", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"#1", "\[Equal]", "0"}], ",", "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"RGBColor", "[", 
                 RowBox[{"0", ",", "0", ",", "0"}], "]"}], ",", 
                RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
                RowBox[{"Point", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"#2", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                   RowBox[{"#2", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", 
                   RowBox[{"#2", "[", 
                    RowBox[{"[", "3", "]"}], "]"}]}], "}"}], "]"}]}], "}"}], 
              ",", "\[IndentingNewLine]", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"RGBColor", "[", 
                 RowBox[{"1", ",", "0", ",", "0"}], "]"}], ",", 
                RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
                RowBox[{"Point", "[", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"#2", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                   RowBox[{"#2", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", 
                   RowBox[{"#2", "[", 
                    RowBox[{"[", "3", "]"}], "]"}]}], "}"}], "]"}]}], "}"}]}],
              "\[IndentingNewLine]", "]"}], ")"}], "&"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", 
           RowBox[{"vertices", ",", "coordVertices"}], "}"}]}], "]"}], 
        "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
      "\[IndentingNewLine]", 
      RowBox[{"myTriangles", "=", 
       RowBox[{"Graphics3D", "[", 
        RowBox[{"Map", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"Polygon", "[", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"coordTriangles", "[", 
                RowBox[{"[", " ", 
                 RowBox[{"#", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], " ", "]"}], "]"}], ",", 
               RowBox[{"coordTriangles", "[", 
                RowBox[{"[", " ", 
                 RowBox[{"#", "[", 
                  RowBox[{"[", "2", "]"}], "]"}], " ", "]"}], "]"}], ",", 
               RowBox[{"coordTriangles", "[", 
                RowBox[{"[", " ", 
                 RowBox[{"#", "[", 
                  RowBox[{"[", "3", "]"}], "]"}], " ", "]"}], "]"}]}], "}"}], 
             "]"}], ")"}], "&"}], ",", "\[IndentingNewLine]", "triangles"}], 
         "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", "]"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"myPoints", ",", "myTriangles"}], "}"}], ",", 
        RowBox[{"BoxRatios", "\[Rule]", "Automatic"}], ",", 
        RowBox[{"Boxed", "\[Rule]", "True"}], ",", 
        RowBox[{"Axes", "\[Rule]", "True"}], ",", 
        RowBox[{"AxesLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\""}], 
          "}"}]}]}], "]"}], ";"}]}], "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "If", " ", "there", " ", "is", " ", "the", " ", "java", " ", "live", 
       " ", "applet", " ", "installed"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"liveApplet", "=", 
       RowBox[{"JavaNew", "[", "\"\<Live\>\"", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"liveFrame", "=", 
       RowBox[{"JavaNew", "[", 
        RowBox[{
        "\"\<com.wolfram.jlink.MathAppletFrame\>\"", ",", "liveApplet", ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\"\<INPUT=\>\"", "<>", 
            RowBox[{"ToString", "[", 
             RowBox[{"InputForm", "[", 
              RowBox[{"N", "[", "\[IndentingNewLine]", 
               RowBox[{"Show", "[", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{"myPoints", ",", "myTriangles"}], "}"}], ",", 
                 RowBox[{"BoxRatios", "\[Rule]", "Automatic"}], ",", 
                 RowBox[{"Boxed", "\[Rule]", "True"}], ",", 
                 RowBox[{"Axes", "\[Rule]", "True"}], ",", 
                 RowBox[{"AxesLabel", "\[Rule]", 
                  RowBox[{"{", 
                   RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\""}], 
                   "}"}]}]}], "]"}], "\[IndentingNewLine]", "]"}], "]"}], 
             "]"}]}], ",", "\"\<WIDTH=600\>\"", ",", "\"\<HEIGHT=600\>\""}], 
          "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", "*)"}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["triangleTable", "Subsection"],

Cell["\<\
Calculate all possible rotations of all basicMarchingCubePatterns. This is \
done with the findAllRotations function.
Transform the 8 digits of each Vertex to calculate the CubeIndex number and \
place this number infront, followed by the vertex digits and triangles.
Then Sort the table accoriding to the CubeIndex number and extract the \
triangles.

Now the table contains a list of triangles for each possible cube, the \
listindex matches the CubeIndex number.
If one wants the triangles for cubeIndex 5 then triangleTable[[5]] returns \
the list of triangles.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"triangleTable", "=", 
   RowBox[{
    RowBox[{"Sort", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Map", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"FromDigits", "[", 
            RowBox[{
             RowBox[{"#", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", "2"}], "]"}], ",", 
           RowBox[{"#", "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", 
           RowBox[{"#", "[", 
            RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "&"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Flatten", "[", 
         RowBox[{
          RowBox[{"Map", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"findAllRotations", "[", "#", "]"}], ")"}], "&"}], ",", 
            "basicMarchingCubePatterns"}], "]"}], ",", "1"}], "]"}]}], 
       "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"#1", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "<", 
         RowBox[{"#2", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "&"}]}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "3"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Dimensions", "[", "triangleTable", "]"}], 
   "*)"}]}]}], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["edgeTable", "Subsection"],

Cell["\<\
Contains a list of edges (for every CubeIndex number one) that need to be \
interpolated to find the more accurate possition of the surface.
If one wants the edges that need to be interpolated for cubeIndex 5 then \
edgeTable[[5]] returns the list of edges.
triangleTable contains all the edges on which a vertice of the triangles are \
located. The dubble listed edges are removed with the union.\
\>", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"edgeTable", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"Union", "[", 
        RowBox[{"Flatten", "[", "#", "]"}], "]"}], ")"}], "&"}], ",", 
     "triangleTable"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"Dimensions", "[", "edgeTable", "]"}], "*)"}]}]}], "PackageInput"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Internal marching cube functions (for the user functions)", "Subtitle",
 Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["MCinterpolationC", "Subsection"],

Cell["\<\
Calculates the position of isolevel between vertex1 with value1 and vertex2 \
with value2.
MCinterpolationC[0.5,{1,2,3},{1,2,4},0.4,0.6]\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MCinterpolationC", "=", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"isolevel", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"vertex1", ",", "_Integer", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"vertex2", ",", "_Integer", ",", "1"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"value1", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"value2", ",", "_Real"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Module", "[", 
      RowBox[{
       RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"debug", " ", "stuff"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"isolevel", "<", "value1"}], ")"}], " ", "&&", " ", 
            RowBox[{"(", 
             RowBox[{"isolevel", "<", "value2"}], ")"}]}], ")"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Print", "[", 
            RowBox[{"StyleForm", "[", 
             RowBox[{"\"\<->Error: MCinterpolationC\>\"", ",", 
              RowBox[{"FontColor", "\[Rule]", 
               RowBox[{"RGBColor", "[", 
                RowBox[{"1", ",", "0", ",", "0"}], "]"}]}]}], "]"}], "]"}], 
           ";", "\[IndentingNewLine]", 
           RowBox[{"Print", "[", 
            RowBox[{"StyleForm", "[", 
             RowBox[{
              RowBox[{"\"\<->       Vertex1:\>\"", "<>", 
               RowBox[{"ToString", "[", "vertex1", "]"}], "<>", 
               "\"\< Vertex2:\>\"", "<>", 
               RowBox[{"ToString", "[", "vertex2", "]"}]}], ",", 
              RowBox[{"FontColor", "\[Rule]", 
               RowBox[{"RGBColor", "[", 
                RowBox[{"1", ",", "0", ",", "0"}], "]"}]}]}], "]"}], "]"}], 
           ";", "\[IndentingNewLine]", 
           RowBox[{"Abort", "[", "]"}]}]}], "\[IndentingNewLine]", "]"}], ";",
         "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"isolevel", ">", "value1"}], ")"}], " ", "&&", " ", 
            RowBox[{"(", 
             RowBox[{"isolevel", ">", "value2"}], ")"}]}], ")"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Print", "[", 
            RowBox[{"StyleForm", "[", 
             RowBox[{"\"\<->Error: MCinterpolationC\>\"", ",", 
              RowBox[{"FontColor", "\[Rule]", 
               RowBox[{"RGBColor", "[", 
                RowBox[{"1", ",", "0", ",", "0"}], "]"}]}]}], "]"}], "]"}], 
           ";", "\[IndentingNewLine]", 
           RowBox[{"Print", "[", 
            RowBox[{"StyleForm", "[", 
             RowBox[{
              RowBox[{"\"\<->       Vertex1:\>\"", "<>", 
               RowBox[{"ToString", "[", "vertex1", "]"}], "<>", 
               "\"\< Vertex2:\>\"", "<>", 
               RowBox[{"ToString", "[", "vertex2", "]"}]}], ",", 
              RowBox[{"FontColor", "\[Rule]", 
               RowBox[{"RGBColor", "[", 
                RowBox[{"1", ",", "0", ",", "0"}], "]"}]}]}], "]"}], "]"}], 
           ";", "\[IndentingNewLine]", 
           RowBox[{"Abort", "[", "]"}]}]}], "\[IndentingNewLine]", "]"}], ";",
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"tune", " ", "if", " ", "you", " ", "want"}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Abs", "[", 
            RowBox[{"isolevel", "-", "value1"}], "]"}], "<", "0.00001"}], ",",
           "vertex1", ",", "\[IndentingNewLine]", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Abs", "[", 
              RowBox[{"isolevel", "-", "value2"}], "]"}], "<", "0.00001"}], 
            ",", "vertex2", ",", "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{
               RowBox[{"Abs", "[", 
                RowBox[{"value1", "-", "value2"}], "]"}], "<", "0.00001"}], 
              ",", "vertex1", ",", "\[IndentingNewLine]", 
              RowBox[{"N", "[", 
               RowBox[{"vertex1", " ", "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"vertex2", "-", "vertex1"}], ")"}], 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{"isolevel", "-", "value1"}], ")"}], "/", 
                   RowBox[{"(", 
                    RowBox[{"value2", "-", "value1"}], ")"}]}], ")"}]}]}], 
               "]"}]}], "\[IndentingNewLine]", "]"}]}], "]"}]}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}]}], "]"}]}], ";"}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MCgetInterceptionCoordinateC", "Subsection"],

Cell["\<\
This funcion returns the estimated interception coordinate of a edge \
(edgeNumber) of a cube ({x,y,z}) with the surface.
edge number must be 1,2,3,4,5,6,7,8,9,10,11 or 12.
MCgetInterceptionCoordinateC[edgeNumber_, \
isolevel_,vertexCoordinates_,vertexValues_]\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MCgetInterceptionCoordinateC", "=", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"edgeNumber", ",", "_Integer"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"isolevel", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"vertexCoordinates", ",", " ", "_Integer", ",", "2"}], "}"}], 
       ",", 
       RowBox[{"{", 
        RowBox[{"vertexValues", ",", "_Real", ",", "1"}], "}"}]}], "}"}], ",",
      "\[IndentingNewLine]", 
     RowBox[{"Module", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "vertex1", ",", "vertex2", ",", "vertexCoordinate1", ",", 
         "vertexCoordinate2", ",", "vertexValue1", ",", "vertexValue2", ",", 
         "coordinateIntercept"}], "}"}], ",", "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", " ", 
        RowBox[{"debug", " ", "stuff"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"\[Not]", 
           RowBox[{"(", 
            RowBox[{"1", "\[LessEqual]", "edgeNumber", "\[LessEqual]", "12"}],
             ")"}]}], ",", " ", 
          RowBox[{
           RowBox[{"Print", "[", 
            RowBox[{"StyleForm", "[", 
             RowBox[{
             "\"\<->Error: MCgetInterceptionCoordinateC \
\[Not](1\[LessEqual]edgeNumber\[LessEqual]12)\>\"", ",", 
              RowBox[{"FontColor", "\[Rule]", 
               RowBox[{"RGBColor", "[", 
                RowBox[{"1", ",", "0", ",", "0"}], "]"}]}]}], "]"}], "]"}], 
           ";", 
           RowBox[{"Abort", "[", "]"}]}]}], "\[IndentingNewLine]", "]"}], ";",
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "Find", " ", "the", " ", "vertex", " ", "numbers", " ", "connected", 
          " ", "with", " ", "the", " ", "edge"}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"(*", "      ", 
         RowBox[{"Edge", ":", "      ", 
          RowBox[{
          "1", "      ", "2", "      ", "3", "       ", "4", "      ", "5", "      ",
            "6", "      ", "7", "      ", "8", "      ", "9", "      ", "10", 
           "     ", "11", "     ", "12"}]}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"vertex1", ",", "vertex2"}], "}"}], "=", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"1", ",", "2"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"2", ",", "3"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"3", ",", "4"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"4", ",", "1"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"5", ",", "6"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"6", ",", "7"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"7", ",", "8"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"8", ",", "5"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"1", ",", "5"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"2", ",", "6"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"3", ",", "7"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"4", ",", "8"}], "}"}]}], "}"}], "[", 
          RowBox[{"[", "edgeNumber", "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "Find", " ", "the", " ", "vertex", " ", "coordinates", " ", 
          "connected", " ", "with", " ", "the", " ", "edge"}], " ", "*)"}], 
        "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"Mind", " ", "the", " ", "vertex", " ", 
          RowBox[{"order", ":", " ", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "8", ",", "7", ",", "6", ",", "5", ",", "4", ",", "3", ",", "2", 
              ",", "1"}], "}"}], " ", "in", " ", "vertexCoordinates"}]}]}], 
         " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"vertexCoordinate1", "=", 
         RowBox[{"vertexCoordinates", "[", 
          RowBox[{"[", 
           RowBox[{"9", "-", "vertex1"}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"vertexCoordinate2", "=", 
         RowBox[{"vertexCoordinates", "[", 
          RowBox[{"[", 
           RowBox[{"9", "-", "vertex2"}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{
         "Find", " ", "the", " ", "values", " ", "at", " ", "the", " ", 
          "vertex", " ", "coordinates", " ", "connected", " ", "with", " ", 
          "the", " ", "edge"}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"Mind", " ", "the", " ", "vertex", " ", 
          RowBox[{"order", ":", " ", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "8", ",", "7", ",", "6", ",", "5", ",", "4", ",", "3", ",", "2", 
              ",", "1"}], "}"}], " ", "in", " ", "vertexValues"}]}]}], "*)"}],
         "\[IndentingNewLine]", 
        RowBox[{"vertexValue1", "=", 
         RowBox[{"vertexValues", "[", 
          RowBox[{"[", 
           RowBox[{"9", "-", "vertex1"}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"vertexValue2", "=", 
         RowBox[{"vertexValues", "[", 
          RowBox[{"[", 
           RowBox[{"9", "-", "vertex2"}], "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"(*", " ", 
         RowBox[{"debug", " ", "stuff"}], " ", "*)"}], "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"isolevel", "<", "vertexValue1"}], ")"}], " ", "&&", " ", 
            RowBox[{"(", 
             RowBox[{"isolevel", "<", "vertexValue2"}], ")"}]}], ")"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Print", "[", 
            RowBox[{"StyleForm", "[", 
             RowBox[{"\"\<->Error: MCgetInterceptionCoordinateC\>\"", ",", 
              RowBox[{"FontColor", "\[Rule]", 
               RowBox[{"RGBColor", "[", 
                RowBox[{"1", ",", "0", ",", "0"}], "]"}]}]}], "]"}], "]"}], 
           ";", 
           RowBox[{"Print", "[", 
            RowBox[{"StyleForm", "[", 
             RowBox[{
              RowBox[{"\"\<         Cube\>\"", "<>", 
               RowBox[{"ToString", "[", "cube", "]"}], "<>", 
               "\"\< edgenr:\>\"", "<>", 
               RowBox[{"ToString", "[", "edgeNumber", "]"}], "<>", 
               "\"\< Vertex1:\>\"", "<>", 
               RowBox[{"ToString", "[", "vertexCoordinate1", "]"}], "<>", 
               "\"\< Vertex2:\>\"", "<>", 
               RowBox[{"ToString", "[", "vertexCoordinate2", "]"}]}], ",", 
              RowBox[{"FontColor", "\[Rule]", 
               RowBox[{"RGBColor", "[", 
                RowBox[{"1", ",", "0", ",", "0"}], "]"}]}]}], "]"}], "]"}], 
           ";", "\[IndentingNewLine]", 
           RowBox[{"Abort", "[", "]"}]}]}], "\[IndentingNewLine]", "]"}], ";",
         "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"isolevel", ">", "vertexValue1"}], ")"}], " ", "&&", " ", 
            RowBox[{"(", 
             RowBox[{"isolevel", ">", "vertexValue2"}], ")"}]}], ")"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Print", "[", 
            RowBox[{"StyleForm", "[", 
             RowBox[{"\"\<->Error: MCgetInterceptionCoordinateC\>\"", ",", 
              RowBox[{"FontColor", "\[Rule]", 
               RowBox[{"RGBColor", "[", 
                RowBox[{"1", ",", "0", ",", "0"}], "]"}]}]}], "]"}], "]"}], 
           ";", 
           RowBox[{"Print", "[", 
            RowBox[{"StyleForm", "[", 
             RowBox[{
              RowBox[{"\"\<         Cube\>\"", "<>", 
               RowBox[{"ToString", "[", "cube", "]"}], "<>", 
               "\"\< edgenr:\>\"", "<>", 
               RowBox[{"ToString", "[", "edgeNumber", "]"}], "<>", 
               "\"\< Vertex1:\>\"", "<>", 
               RowBox[{"ToString", "[", "vertexCoordinate1", "]"}], "<>", 
               "\"\< Vertex2:\>\"", "<>", 
               RowBox[{"ToString", "[", "vertexCoordinate2", "]"}]}], ",", 
              RowBox[{"FontColor", "\[Rule]", 
               RowBox[{"RGBColor", "[", 
                RowBox[{"1", ",", "0", ",", "0"}], "]"}]}]}], "]"}], "]"}], 
           ";", "\[IndentingNewLine]", 
           RowBox[{"Abort", "[", "]"}]}]}], "\[IndentingNewLine]", "]"}], ";",
         "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"coordinateIntercept", "=", 
         RowBox[{"MCinterpolationC", "[", "\[IndentingNewLine]", 
          RowBox[{
          "isolevel", ",", "vertexCoordinate1", ",", "vertexCoordinate2", ",",
            "vertexValue1", ",", "vertexValue2"}], "\[IndentingNewLine]", 
          "]"}]}]}]}], "\[IndentingNewLine]", "]"}]}], "]"}]}], 
  ";"}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MCtriangleTable", "Subsection"],

Cell["This funcion returns the entry from the edgeTable.  ", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MCtriangleTable", "[", "cubeIndex_Integer", "]"}], ":=", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"triangleTable", "[", 
      RowBox[{"[", 
       RowBox[{"cubeIndex", "+", "1"}], "]"}], "]"}]}], "\[IndentingNewLine]",
     "]"}]}], ";"}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MCedgeTable", "Subsection"],

Cell["This funcion returns the entry from the edgeTable.  ", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MCedgeTable", "[", "cubeIndex_Integer", "]"}], ":=", 
   RowBox[{"Module", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"edgeTable", "[", 
      RowBox[{"[", 
       RowBox[{"cubeIndex", "+", "1"}], "]"}], "]"}]}], "\[IndentingNewLine]",
     "]"}]}], ";"}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MCfindSurfaceInCubeA", "Subsection"],

Cell["\<\
This funcion returns a list of estimated coordinates and a list of polygons. \
it is used by MCfindSurfaceInCubes en MCfindSurfaceInCube\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MCfindSurfaceInCubeA", "[", 
   RowBox[{"vertexCoordinates_", ",", "vertexValues_", ",", "isolevel_"}], 
   "]"}], ":=", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
     "cubeIndex", ",", "edgesInterceptingSurface", ",", 
      "interceptionCoordinate", ",", "edgeToCoordinateTable", ",", 
      "interceptionCoordinates", ",", "triangleVerticesOnEdges", ",", 
      "polygons"}], " ", "}"}], ",", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"(*", " ", 
     RowBox[{"calculate", " ", "the", " ", "cubeIndex"}], " ", "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"cubeIndex", "=", " ", 
      RowBox[{"MCcubeIndexC", "[", 
       RowBox[{"isolevel", ",", "vertexValues"}], "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "get", " ", "the", " ", "edges", " ", "that", " ", "intercept", " ", 
       "the", " ", "surface"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"edgesInterceptingSurface", "=", 
      RowBox[{"MCedgeTable", "[", "cubeIndex", "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"Build", " ", "a", " ", "lookup", " ", 
        RowBox[{"table", ":", " ", 
         RowBox[{"given", " ", "a", " ", "edge", " ", "number"}]}]}], ",", 
       " ", 
       RowBox[{
        RowBox[{
        "it", " ", "returns", " ", "the", " ", "interception", " ", 
         "coordinate", " ", "of", " ", "the", " ", "edge", " ", "with", " ", 
         "the", " ", "iso"}], "-", "surface"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"edgeToCoordinateTable", "=", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"{", "}"}], ",", 
        RowBox[{"{", "12", "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"interceptionCoordinates", "=", 
      RowBox[{"Map", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"(", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"interceptionCoordinate", "=", 
            RowBox[{"MCgetInterceptionCoordinateC", "[", 
             RowBox[{
             "#", ",", "isolevel", ",", "vertexCoordinates", ",", 
              "vertexValues"}], "]"}]}], ";", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{"edgeToCoordinateTable", "[", 
             RowBox[{"[", "#", "]"}], "]"}], "=", "interceptionCoordinate"}], 
           ";", "\[IndentingNewLine]", "interceptionCoordinate"}], 
          "\[IndentingNewLine]", ")"}], "&"}], ",", "\[IndentingNewLine]", 
        "edgesInterceptingSurface"}], "\[IndentingNewLine]", "]"}]}], ";", 
     "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{
       "for", " ", "edges", " ", "and", " ", "polygons", " ", "only"}], ";"}],
       " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "get", " ", "the", " ", "edges", " ", "on", " ", "which", " ", "the", 
       " ", "vertices", " ", "of", " ", "the", " ", "triangles", " ", "are"}],
       " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"triangleVerticesOnEdges", "=", 
      RowBox[{"MCtriangleTable", "[", "cubeIndex", "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
      "use", " ", "this", " ", "to", " ", "find", " ", "the", " ", 
       "coordinates", " ", "of", " ", "the", " ", "triangle", " ", 
       "vertices"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{"polygons", "=", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"Polygon", "[", 
           RowBox[{"Map", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"(", " ", 
               RowBox[{"edgeToCoordinateTable", "[", 
                RowBox[{"[", "#", "]"}], "]"}], ")"}], "&"}], ",", " ", "#"}],
             "]"}], "]"}], ")"}], "&"}], ",", "triangleVerticesOnEdges"}], 
       "]"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"interceptionCoordinates", ",", "polygons"}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "PackageInput"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["User functions", "Subtitle",
 Background->RGBColor[0, 1, 1]],

Cell[CellGroupData[{

Cell["MCfindSurfaceInCubes", "Subsection"],

Cell["\<\
This funcion returns a list of estimated coordinates {{ex,ey,ez},...} and a \
list of polygons on the surface inside the cubes {{x,y,z},...}.
{estimated coordinates List, polygons List}
Cubes must contian a surface.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MCfindSurfaceInCubes", "[", 
   RowBox[{"cubes_", ",", "isolevel_", ",", "data_"}], "]"}], ":=", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "x", ",", "y", ",", "z", ",", "vertexCoordinates", ",", "vertexValues"}],
      "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Transpose", "[", "\[IndentingNewLine]", 
     RowBox[{"Map", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"(", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"x", ",", "y", ",", "z"}], "}"}], "=", "#"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"vertexCoordinates", "=", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{"x", ",", 
               RowBox[{"y", "+", "1"}], ",", 
               RowBox[{"z", "+", "1"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"x", "+", "1"}], ",", 
               RowBox[{"y", "+", "1"}], ",", 
               RowBox[{"z", "+", "1"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"x", "+", "1"}], ",", "y", ",", 
               RowBox[{"z", "+", "1"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", "y", ",", 
               RowBox[{"z", "+", "1"}]}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", 
               RowBox[{"y", "+", "1"}], ",", "z"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"x", "+", "1"}], ",", 
               RowBox[{"y", "+", "1"}], ",", "z"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{
               RowBox[{"x", "+", "1"}], ",", "y", ",", "z"}], "}"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "}"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"vertexValues", "=", 
           RowBox[{"Extract", "[", 
            RowBox[{"data", ",", 
             RowBox[{"Map", "[", 
              RowBox[{
               RowBox[{
                RowBox[{"Reverse", "[", "#", "]"}], "&"}], ",", 
               "vertexCoordinates"}], "]"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"MCfindSurfaceInCubeA", "[", 
           RowBox[{
           "vertexCoordinates", ",", "vertexValues", ",", "isolevel"}], 
           "]"}]}], "\[IndentingNewLine]", ")"}], "&"}], ",", 
       "\[IndentingNewLine]", "cubes"}], "]"}], "\[IndentingNewLine]", 
     "]"}]}], "\[IndentingNewLine]", "]"}]}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MCfindSurfaceInCube", "Subsection"],

Cell["\<\
This funcion returns a list of estimated coordinates {{ex,ey,ez},...} and a \
list of polygons on the surface inside the cube {x,y,z}.
{estimated coordinates List, polygons List}
Cube must contian a surface.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MCfindSurfaceInCube", "[", 
   RowBox[{"cube_", ",", "isolevel_", ",", "data_"}], "]"}], ":=", 
  RowBox[{"Module", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"{", " ", 
     RowBox[{
     "x", ",", "y", ",", "z", ",", "vertexCoordinates", ",", "vertexValues"}],
      "}"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "y", ",", "z"}], "}"}], "=", "cube"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"vertexCoordinates", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"y", "+", "1"}], ",", 
          RowBox[{"z", "+", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x", "+", "1"}], ",", 
          RowBox[{"y", "+", "1"}], ",", 
          RowBox[{"z", "+", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x", "+", "1"}], ",", "y", ",", 
          RowBox[{"z", "+", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "y", ",", 
          RowBox[{"z", "+", "1"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", 
          RowBox[{"y", "+", "1"}], ",", "z"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x", "+", "1"}], ",", 
          RowBox[{"y", "+", "1"}], ",", "z"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"x", "+", "1"}], ",", "y", ",", "z"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"vertexValues", "=", 
      RowBox[{"Extract", "[", 
       RowBox[{"data", ",", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Reverse", "[", "#", "]"}], "&"}], ",", 
          "vertexCoordinates"}], "]"}]}], "]"}]}], ";", "\[IndentingNewLine]",
      "\[IndentingNewLine]", 
     RowBox[{"MCfindSurfaceInCubeA", "[", 
      RowBox[{"vertexCoordinates", ",", "vertexValues", ",", "isolevel"}], 
      "]"}]}]}], "\[IndentingNewLine]", "]"}]}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["MCcubeIndexC", "Subsection"],

Cell["\<\
Calculates the cubeindex of the cube {x,y,z} given the isolevel and the \
vertexValues {8,7,6,5,4,3,2,1}
returns: 0, if all verticeValues are <isolevel; (inside)
\t255, if all verticeValues are >= isolevel; (outside)
\t 1-254 otherwise; (surface)
example: MCcubeIndexC[0.5,{0,0,0,0,0,0,0,1}]\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"MCcubeIndexC", "=", 
   RowBox[{"Compile", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"isolevel", ",", "_Real"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"vertexValues", ",", "_Real", ",", "1"}], "}"}]}], "}"}], ",",
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{"debug", " ", "stuff"}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "vertexValues", "]"}], " ", "\[NotEqual]", 
         " ", "8"}], ",", " ", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{"StyleForm", "[", 
           RowBox[{"\"\<->Error: MCcubeIndexC\>\"", ",", 
            RowBox[{"FontColor", "\[Rule]", 
             RowBox[{"RGBColor", "[", 
              RowBox[{"1", ",", "0", ",", "0"}], "]"}]}]}], "]"}], "]"}], ";", 
         RowBox[{"Abort", "[", "]"}]}]}], "\[IndentingNewLine]", "]"}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"(", 
       RowBox[{"Plus", "@@", 
        RowBox[{"MapIndexed", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"If", "[", 
             RowBox[{
              RowBox[{"#1", "<", "isolevel"}], ",", "0", ",", 
              RowBox[{"2", "^", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"#2", "[", 
                  RowBox[{"[", "1", "]"}], "]"}], "-", "1"}], ")"}]}]}], 
             "]"}], ")"}], "&"}], ",", 
          RowBox[{"Reverse", "[", "vertexValues", "]"}]}], "]"}]}], ")"}]}]}],
     "\[IndentingNewLine]", "]"}]}], ";"}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["End", "Section",
 CellFrame->{{0, 0}, {0, 2}}],

Cell[BoxData[
 RowBox[{"End", "[", "]"}]], "PackageInput"],

Cell[BoxData[
 RowBox[{"EndPackage", "[", "]"}]], "PackageInput"]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowToolbars->"EditBar",
WindowSize->{1351, 950},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Magnification->2,
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (November 10, 2008)",
StyleDefinitions->"PackageNotebook.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 62, 1, 224, "Title"],
Cell[632, 25, 402, 10, 111, "PackageInput"],
Cell[1037, 37, 564, 17, 358, "Text"],
Cell[CellGroupData[{
Cell[1626, 58, 55, 1, 116, "Section"],
Cell[1684, 61, 126, 3, 80, "PackageInput"]
}, Closed]],
Cell[CellGroupData[{
Cell[1847, 69, 61, 1, 72, "Section"],
Cell[1911, 72, 176, 4, 80, "PackageInput"]
}, Closed]],
Cell[CellGroupData[{
Cell[2124, 81, 72, 1, 72, "Section"],
Cell[2199, 84, 1503, 30, 711, "PackageInput"]
}, Closed]],
Cell[CellGroupData[{
Cell[3739, 119, 38, 0, 72, "Subsubtitle"],
Cell[3780, 121, 1623, 34, 741, "PackageInput"],
Cell[5406, 157, 808, 15, 322, "Text"],
Cell[CellGroupData[{
Cell[6239, 176, 69, 1, 116, "Section"],
Cell[6311, 179, 113, 3, 80, "PackageInput"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[6473, 188, 109, 1, 124, "Subtitle"],
Cell[CellGroupData[{
Cell[6607, 193, 29, 0, 84, "Subsection"],
Cell[6639, 195, 41, 0, 52, "Text"],
Cell[6683, 197, 25, 0, 52, "Text"],
Cell[6711, 199, 29, 0, 52, "Text"],
Cell[6743, 201, 25, 0, 52, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6805, 206, 34, 0, 84, "Subsection"],
Cell[6842, 208, 75, 0, 52, "Text"],
Cell[CellGroupData[{
Cell[6942, 212, 8046, 196, 711, "PackageInput"],
Cell[14991, 410, 31515, 1113, 592, 27095, 1037, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[46521, 1526, 648, 18, 442, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47206, 1549, 47, 0, 84, "Subsection"],
Cell[47256, 1551, 855, 16, 382, "Text"],
Cell[48114, 1569, 11401, 334, 861, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[59552, 1908, 31, 0, 84, "Subsection"],
Cell[59586, 1910, 431, 8, 142, "Text"],
Cell[60020, 1920, 6843, 204, 471, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[66900, 2129, 41, 0, 84, "Subsection"],
Cell[66944, 2131, 107, 3, 52, "Text"],
Cell[67054, 2136, 2863, 72, 531, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[69954, 2213, 37, 0, 84, "Subsection"],
Cell[69994, 2215, 133, 3, 52, "Text"],
Cell[70130, 2220, 1824, 50, 291, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[71991, 2275, 42, 0, 84, "Subsection"],
Cell[72036, 2277, 109, 3, 52, "Text"],
Cell[72148, 2282, 2835, 72, 501, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[75020, 2359, 35, 0, 84, "Subsection"],
Cell[75058, 2361, 194, 4, 82, "Text"],
Cell[75255, 2367, 2490, 65, 381, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[77782, 2437, 38, 0, 84, "Subsection"],
Cell[77823, 2439, 297, 7, 112, "Text"],
Cell[78123, 2448, 49, 0, 52, "Text"],
Cell[78175, 2450, 11894, 268, 2121, "PackageInput"],
Cell[90072, 2720, 16, 0, 52, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[90125, 2725, 38, 0, 84, "Subsection"],
Cell[90166, 2727, 321, 7, 142, "Text"],
Cell[90490, 2736, 7429, 175, 1131, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[97956, 2916, 35, 0, 84, "Subsection"],
Cell[97994, 2918, 589, 12, 232, "Text"],
Cell[98586, 2932, 1437, 41, 261, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[100060, 2978, 31, 0, 84, "Subsection"],
Cell[100094, 2980, 421, 7, 172, "Text"],
Cell[100518, 2989, 394, 12, 111, "PackageInput"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[100961, 3007, 109, 1, 124, "Subtitle"],
Cell[CellGroupData[{
Cell[101095, 3012, 38, 0, 84, "Subsection"],
Cell[101136, 3014, 160, 4, 82, "Text"],
Cell[101299, 3020, 4970, 117, 891, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[106306, 3142, 50, 0, 84, "Subsection"],
Cell[106359, 3144, 284, 6, 112, "Text"],
Cell[106646, 3152, 9304, 214, 1671, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[115987, 3371, 37, 0, 84, "Subsection"],
Cell[116027, 3373, 68, 0, 52, "Text"],
Cell[116098, 3375, 394, 10, 171, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[116529, 3390, 33, 0, 84, "Subsection"],
Cell[116565, 3392, 68, 0, 52, "Text"],
Cell[116636, 3394, 386, 10, 171, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[117059, 3409, 42, 0, 84, "Subsection"],
Cell[117104, 3411, 160, 3, 82, "Text"],
Cell[117267, 3416, 4257, 98, 1041, "PackageInput"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[121573, 3520, 66, 1, 124, "Subtitle"],
Cell[CellGroupData[{
Cell[121664, 3525, 42, 0, 84, "Subsection"],
Cell[121709, 3527, 239, 5, 142, "Text"],
Cell[121951, 3534, 2664, 66, 471, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[124652, 3605, 41, 0, 84, "Subsection"],
Cell[124696, 3607, 231, 5, 112, "Text"],
Cell[124930, 3614, 2153, 58, 824, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[127120, 3677, 34, 0, 188, "Subsection"],
Cell[127157, 3679, 315, 7, 436, "Text"],
Cell[127475, 3688, 1725, 45, 824, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[129237, 3738, 52, 1, 276, "Section"],
Cell[129292, 3741, 58, 1, 184, "PackageInput"],
Cell[129353, 3744, 65, 1, 184, "PackageInput"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

