(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    105250,       2499]
NotebookOptionsPosition[     55309,       1411]
NotebookOutlinePosition[    102201,       2401]
CellTagsIndexPosition[    102158,       2398]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Version Compatibility Package", "Title"],

Cell["\<\
Markus van Almsick, Technische Universiteit Eindhoven
\[Copyright]2009\
\>", "Subsubtitle"],

Cell[CellGroupData[{

Cell["Prefix", "Section"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "TimeSamp", " ", "for", " ", "Package", " ", "Version", " ", "Control"}], 
   " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Unprotect", "[", "TimeStamp", "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"TimeStamp", "::", "usage"}], "=", 
     "\"\<TimeStamp[context] should be set to a Date[]-List indicating the \
version of the corresponding package.\>\""}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
     "TimeStamp", "[", "\"\<MathVisionTools`VersionCompatibility`\>\"", "]"}],
      " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{"2009", ",", "10", ",", "28", ",", "17", ",", "12", ",", "0"}], 
      "}"}]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Protect", "[", "TimeStamp", "]"}], ";"}]}]}]], "PackageInput"],

Cell["\<\
The preamble of the package containing all kinds of remarks about authorship, \
contence, and copyright.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Name", ":", " ", "MathVisionTools`VersionCompatibility"}]}], " ",
    "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"Authors", ":", " ", 
      RowBox[{"Markus", " ", "van", " ", "Almsick"}]}]}], ",", " ", 
    RowBox[{"Technische", " ", "Universiteit", " ", "Eindhoven"}]}], 
   StyleBox[" ",
    FontColor->RGBColor[1, 0, 1]], "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Email", " ", 
     RowBox[{"address", ":", " ", 
      RowBox[{"m", ".", "v", ".", 
       RowBox[{"almsick", "@", "tue"}], ".", "nl"}]}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Context", ":", " ", "MathVisionTools`VersionCompatibility`"}]}], 
   " ", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Package", " ", 
     RowBox[{"Version", ":", " ", "1.2"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Mathematica", " ", 
     RowBox[{"Version", ":", " ", 
      RowBox[{"5", " ", "or", " ", "later"}]}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"Copyright", ":", " ", 
      RowBox[{"Copyright", " ", "2008"}]}]}], ",", " ", 
    RowBox[{"Technische", " ", "Universiteit", " ", "Eindhoven"}]}], " ", 
   "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Title", ":", " ", 
     RowBox[{"Version", " ", "Compatibility"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Summary", ":", " ", 
     RowBox[{
     "Implement", " ", "new", " ", "System`", " ", "functions", " ", "for", 
      " ", "older", " ", "Mathematica", " ", 
      RowBox[{"versions", "."}]}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Keywords", ":", " ", "Version"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Requirements", ":", " ", "None"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Source", ":", " ", "None"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{":", 
     RowBox[{"History", ":", " ", 
      RowBox[{
      "Version", " ", "1.0", " ", "by", " ", "Markus", " ", "van", " ", 
       "Almsick"}]}]}], ",", " ", 
    RowBox[{"September", " ", "2008"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Limitations", ":"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"Discussion", ":"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{":", 
    RowBox[{"To", " ", 
     RowBox[{"do", ":"}]}]}], " ", "*)"}]}]], "PackageInput",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Begin Package", "Section"],

Cell["\<\
Declaring the package and unlocking all symbols defined in the code.\
\>", "Text"],

Cell[BoxData[" "], "Input"],

Cell[BoxData[
 RowBox[{"BeginPackage", "[", "\"\<MathVisionTools`VersionCompatibility`\>\"",
   "]"}]], "PackageInput",
 InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Online Help and Options", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Context", "[", "\"\<Interleaving\>\"", "]"}], "=!=", 
      "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Unprotect", "[", "Interleaving", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Interleaving", "::", "usage"}], " ", "=", " ", 
       "\"\<Interleaving is an option for Image and related functions that \
specifies whether data corresponding to different channels in an object such \
as an image should be interleaved.\>\""}]}]}], "\[IndentingNewLine]", "]"}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Context", "[", "\"\<ImageData\>\"", "]"}], "=!=", 
      "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Unprotect", "[", "ImageData", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ImageData", "::", "usage"}], " ", "=", " ", 
       "\"\<ImageData[\\!\\(\\*StyleBox[\\\"image\\\", \\\"TI\\\"]\\)] gives \
the array of pixel values in \\!\\(\\*StyleBox[\\\"image\\\", \\\"TI\\\"]\\). \
ImageData[\\!\\(\\*StyleBox[\\\"image\\\", \\\"TI\\\"]\\), \\!\\(\\*StyleBox[\
\\\"\\\\\\\"\\<\\!\\(\\*StyleBox[\\\\\\\"type\\\\\\\", \\\\\\\"TI\\\\\\\"]\\)\
\\>\\\\\\\"\\\",\\nShowStringCharacters->True]\\)] gives the array of pixel \
values converted to the specified type.\>\""}]}]}], "\[IndentingNewLine]", 
    "]"}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Context", "[", "\"\<Accumulate\>\"", "]"}], "=!=", 
      "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Unprotect", "[", "Accumulate", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Accumulate", "::", "usage"}], "=", 
       "\"\<\\!\\(\\*RowBox[{\\\"Accumulate\\\", \\\"[\\\", StyleBox[\\\"list\
\\\", \\\"TI\\\"], \\\"]\\\"}]\\) gives a list of the successive accumulated \
totals of elements in \\!\\(\\*StyleBox[\\\"list\\\", \\\"TI\\\"]\\). \
\>\""}]}]}], "\[IndentingNewLine]", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Context", "[", "\"\<Differences\>\"", "]"}], "=!=", 
      "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Unprotect", "[", "Differences", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Differences", "::", "usage"}], "=", 
       "\"\<\\!\\(\\*RowBox[{\\\"Differences\\\", \\\"[\\\", \
StyleBox[\\\"list\\\", \\\"TI\\\"], \\\"]\\\"}]\\) gives the successive \
differences of elements in \\!\\(\\*StyleBox[\\\"list\\\", \\\"TI\\\"]\\). \
\\n\\!\\(\\*RowBox[{\\\"Differences\\\", \\\"[\\\", RowBox[{StyleBox[\\\"list\
\\\", \\\"TI\\\"], \\\",\\\", StyleBox[\\\"n\\\", \\\"TI\\\"]}], \
\\\"]\\\"}]\\) gives the \\!\\(\\*StyleBox[\\\"n\\\", \
\\\"TI\\\"]\\)\\!\\(\\*SuperscriptBox[\\\"\[Null]\\\", \\\"th\\\"]\\) \
differences of \\!\\(\\*StyleBox[\\\"list\\\", \\\"TI\\\"]\\). \>\""}]}]}], 
    "\[IndentingNewLine]", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Context", "[", "\"\<Riffle\>\"", "]"}], "=!=", 
      "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Unprotect", "[", "Riffle", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Riffle", "::", "usage"}], "=", 
       "\"\<\\!\\(\\*RowBox[{\\\"Riffle\\\", \\\"[\\\", RowBox[{RowBox[{\\\"{\
\\\", RowBox[{SubscriptBox[StyleBox[\\\"e\\\", \\\"TI\\\"], \
StyleBox[\\\"1\\\", \\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"e\\\", \
\\\"TI\\\"], StyleBox[\\\"2\\\", \\\"TR\\\"]], \\\",\\\", StyleBox[\\\"\
\[Ellipsis]\\\", \\\"TR\\\"]}], \\\"}\\\"}], \\\",\\\", StyleBox[\\\"x\\\", \
\\\"TI\\\"]}], \\\"]\\\"}]\\) gives \\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{SubscriptBox[StyleBox[\\\"e\\\", \\\"TI\\\"], StyleBox[\\\"1\\\", \
\\\"TR\\\"]], \\\",\\\", StyleBox[\\\"x\\\", \\\"TI\\\"], \\\",\\\", \
SubscriptBox[StyleBox[\\\"e\\\", \\\"TI\\\"], StyleBox[\\\"2\\\", \
\\\"TR\\\"]], \\\",\\\", StyleBox[\\\"x\\\", \\\"TI\\\"], \\\",\\\", \
StyleBox[\\\"\[Ellipsis]\\\", \\\"TR\\\"]}], \\\"}\\\"}]\\). \
\\n\\!\\(\\*RowBox[{\\\"Riffle\\\", \\\"[\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{SubscriptBox[StyleBox[\\\"e\\\", \\\"TI\\\"], StyleBox[\\\"1\\\", \
\\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"e\\\", \\\"TI\\\"], \
StyleBox[\\\"2\\\", \\\"TR\\\"]], \\\",\\\", StyleBox[\\\"\[Ellipsis]\\\", \\\
\"TR\\\"]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"1\\\", \
\\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], \
StyleBox[\\\"2\\\", \\\"TR\\\"]], \\\",\\\", StyleBox[\\\"\[Ellipsis]\\\", \\\
\"TR\\\"]}], \\\"}\\\"}]}], \\\"]\\\"}]\\) gives \\!\\(\\*RowBox[{\\\"{\\\", \
RowBox[{SubscriptBox[StyleBox[\\\"e\\\", \\\"TI\\\"], StyleBox[\\\"1\\\", \
\\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], \
StyleBox[\\\"1\\\", \\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"e\\\", \
\\\"TI\\\"], StyleBox[\\\"2\\\", \\\"TR\\\"]], \\\",\\\", \
SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"2\\\", \
\\\"TR\\\"]], \\\",\\\", StyleBox[\\\"\[Ellipsis]\\\", \\\"TR\\\"]}], \\\"}\\\
\"}]\\).  \>\""}]}]}], "\[IndentingNewLine]", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Context", "[", "\"\<TakeWhile\>\"", "]"}], "=!=", 
      "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Unprotect", "[", "TakeWhile", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"TakeWhile", "::", "usage"}], "=", 
       "\"\<\\!\\(\\*RowBox[{\\\"TakeWhile\\\", \\\"[\\\", \
RowBox[{StyleBox[\\\"list\\\", \\\"TI\\\"], \\\",\\\", StyleBox[\\\"crit\\\", \
\\\"TI\\\"]}], \\\"]\\\"}]\\) gives elements \
\\!\\(\\*SubscriptBox[StyleBox[\\\"e\\\", \\\"TI\\\"], StyleBox[\\\"i\\\", \\\
\"TI\\\"]]\\) from the beginning of \\!\\(\\*StyleBox[\\\"list\\\", \
\\\"TI\\\"]\\), continuing so long as \\!\\(\\*RowBox[{StyleBox[\\\"crit\\\", \
\\\"TI\\\"], \\\"[\\\", SubscriptBox[StyleBox[\\\"e\\\", \\\"TI\\\"], \
StyleBox[\\\"i\\\", \\\"TI\\\"]], \\\"]\\\"}]\\) is True.\>\""}]}]}], 
    "\[IndentingNewLine]", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Context", "[", "\"\<LengthWhile\>\"", "]"}], "=!=", 
      "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Unprotect", "[", "LengthWhile", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"LengthWhile", "::", "usage"}], "=", 
       "\"\<\\!\\(\\*RowBox[{\\\"LengthWhile\\\", \\\"[\\\", \
RowBox[{StyleBox[\\\"list\\\", \\\"TI\\\"], \\\",\\\", StyleBox[\\\"crit\\\", \
\\\"TI\\\"]}], \\\"]\\\"}]\\) gives the number of continuous elements \
\\!\\(\\*SubscriptBox[StyleBox[\\\"e\\\", \\\"TI\\\"], StyleBox[\\\"i\\\", \\\
\"TI\\\"]]\\) starting at the beginning of \\!\\(\\*StyleBox[\\\"list\\\", \\\
\"TI\\\"]\\) for which \\!\\(\\*RowBox[{StyleBox[\\\"crit\\\", \\\"TI\\\"], \
\\\"[\\\", SubscriptBox[StyleBox[\\\"e\\\", \\\"TI\\\"], StyleBox[\\\"i\\\", \
\\\"TI\\\"]], \\\"]\\\"}]\\) is True.\>\""}]}]}], "\[IndentingNewLine]", 
    "]"}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"  ", 
  RowBox[{
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Context", "[", "\"\<Commonest\>\"", "]"}], "=!=", 
      "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Unprotect", "[", "Commonest", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Commonest", "::", "usage"}], "=", 
       "\"\<\\!\\(\\*RowBox[{\\\"Commonest\\\", \\\"[\\\", \
StyleBox[\\\"list\\\", \\\"TI\\\"], \\\"]\\\"}]\\) gives a list of the \
elements that are the most common in \\!\\(\\*StyleBox[\\\"list\\\", \\\"TI\\\
\"]\\).\\n\\!\\(\\*RowBox[{\\\"Commonest\\\", \\\"[\\\", \
RowBox[{StyleBox[\\\"list\\\", \\\"TI\\\"], \\\",\\\", StyleBox[\\\"n\\\", \\\
\"TI\\\"]}], \\\"]\\\"}]\\) gives a list of the \\!\\(\\*StyleBox[\\\"n\\\", \
\\\"TI\\\"]\\) most common elements in \\!\\(\\*StyleBox[\\\"list\\\", \\\"TI\
\\\"]\\).\>\""}]}]}], "\[IndentingNewLine]", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"  ", 
  RowBox[{
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Context", "[", "\"\<ArrayFlatten\>\"", "]"}], "=!=", 
      "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Unprotect", "[", "ArrayFlatten", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ArrayFlatten", "::", "usage"}], "=", 
       "\"\<\\!\\(\\*RowBox[{\\\"ArrayFlatten\\\", \\\"[\\\", RowBox[{\\\"{\\\
\", RowBox[{RowBox[{\\\"{\\\", RowBox[{SubscriptBox[StyleBox[\\\"m\\\", \
\\\"TI\\\"], StyleBox[\\\"11\\\", \\\"TR\\\"]], \\\",\\\", \
SubscriptBox[StyleBox[\\\"m\\\", \\\"TI\\\"], StyleBox[\\\"12\\\", \
\\\"TR\\\"]], \\\",\\\", StyleBox[\\\"\[Ellipsis]\\\", \\\"TR\\\"]}], \\\"}\\\
\"}], \\\",\\\", RowBox[{\\\"{\\\", RowBox[{SubscriptBox[StyleBox[\\\"m\\\", \
\\\"TI\\\"], StyleBox[\\\"21\\\", \\\"TR\\\"]], \\\",\\\", \
SubscriptBox[StyleBox[\\\"m\\\", \\\"TI\\\"], StyleBox[\\\"22\\\", \
\\\"TR\\\"]], \\\",\\\", StyleBox[\\\"\[Ellipsis]\\\", \\\"TR\\\"]}], \\\"}\\\
\"}], \\\",\\\", StyleBox[\\\"\[Ellipsis]\\\", \\\"TR\\\"]}], \\\"}\\\"}], \\\
\"]\\\"}]\\) creates a single flattened matrix from a matrix of matrices \
\\!\\(\\*SubscriptBox[\\\"m\\\", RowBox[{\\\"i\\\", \
\\\"\[InvisibleSpace]\\\", \\\"j\\\"}]]\\). \>\""}]}]}], 
    "\[IndentingNewLine]", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Context", "[", "\"\<ConstantArray\>\"", "]"}], "=!=", 
      "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Unprotect", "[", "ConstantArray", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ConstantArray", "::", "usage"}], "=", 
       "\"\<\\!\\(\\*RowBox[{\\\\\\\"ConstantArray\\\\\\\", \
\\\\\\\"[\\\\\\\", RowBox[{StyleBox[\\\\\\\"c\\\\\\\", \\\\\\\"TI\\\\\\\"], \
\\\\\\\",\\\\\\\", StyleBox[\\\\\\\"n\\\\\\\", \\\\\\\"TI\\\\\\\"]}], \
\\\\\\\"]\\\\\\\"}]\\) generates a list of \
\\!\\(\\*StyleBox[\\\\\\\"n\\\\\\\", \\\\\\\"TI\\\\\\\"]\\) copies of the \
element \\!\\(\\*StyleBox[\\\\\\\"c\\\\\\\", \
\\\\\\\"TI\\\\\\\"]\\).\\\\n\\!\\(\\*RowBox[{\\\\\\\"ConstantArray\\\\\\\", \
\\\\\\\"[\\\\\\\", RowBox[{StyleBox[\\\\\\\"c\\\\\\\", \\\\\\\"TI\\\\\\\"], \
\\\\\\\",\\\\\\\", RowBox[{\\\\\\\"{\\\\\\\", \
RowBox[{SubscriptBox[StyleBox[\\\\\\\"n\\\\\\\", \\\\\\\"TI\\\\\\\"], \
StyleBox[\\\\\\\"1\\\\\\\", \\\\\\\"TR\\\\\\\"]], \\\\\\\",\\\\\\\", \
SubscriptBox[StyleBox[\\\\\\\"n\\\\\\\", \\\\\\\"TI\\\\\\\"], StyleBox[\\\\\\\
\"2\\\\\\\", \\\\\\\"TR\\\\\\\"]], \\\\\\\",\\\\\\\", StyleBox[\\\\\\\"\
\[Ellipsis]\\\\\\\", \\\\\\\"TR\\\\\\\"]}], \\\\\\\"}\\\\\\\"}]}], \
\\\\\\\"]\\\\\\\"}]\\) generates an \\!\\(\\*RowBox[{SubscriptBox[StyleBox[\\\
\\\\\"n\\\\\\\", \\\\\\\"TI\\\\\\\"], StyleBox[\\\\\\\"1\\\\\\\", \
\\\\\\\"TR\\\\\\\"]], \\\\\\\"\[Cross]\\\\\\\", \
SubscriptBox[StyleBox[\\\\\\\"n\\\\\\\", \\\\\\\"TI\\\\\\\"], StyleBox[\\\\\\\
\"2\\\\\\\", \\\\\\\"TR\\\\\\\"]], \\\\\\\"\[Cross]\\\\\\\", \
StyleBox[\\\\\\\"\[Ellipsis]\\\\\\\", \\\\\\\"TR\\\\\\\"]}]\\) array of \
nested lists containing copies of the element \\!\\(\\*StyleBox[\\\\\\\"c\\\\\
\\\", \\\\\\\"TI\\\\\\\"]\\).\>\""}]}]}], "\[IndentingNewLine]", "]"}], ";"}],
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"  ", 
  RowBox[{
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Context", "[", "\"\<RandomInteger\>\"", "]"}], "=!=", 
      "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Unprotect", "[", "RandomInteger", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"RandomInteger", "::", "usage"}], "=", 
       "\"\<\\!\\(\\*RowBox[{\\\"RandomInteger\\\", \\\"[\\\", \
RowBox[{\\\"{\\\", RowBox[{SubscriptBox[StyleBox[\\\"i\\\", \\\"TI\\\"], \
StyleBox[\\\"min\\\", \\\"TI\\\"]], \\\",\\\", \
SubscriptBox[StyleBox[\\\"i\\\", \\\"TI\\\"], StyleBox[\\\"max\\\", \
\\\"TI\\\"]]}], \\\"}\\\"}], \\\"]\\\"}]\\) gives a pseudorandom integer in \
the range \\!\\(\\*RowBox[{\\\"{\\\", RowBox[{SubscriptBox[\\\"i\\\", \\\"min\
\\\"], \\\",\\\", \\\"\[Ellipsis]\\\", \\\",\\\", SubscriptBox[\\\"i\\\", \
\\\"max\\\"]}], \\\"}\\\"}]\\). \\n\\!\\(\\*RowBox[{\\\"RandomInteger\\\", \\\
\"[\\\", SubscriptBox[StyleBox[\\\"i\\\", \\\"TI\\\"], StyleBox[\\\"max\\\", \
\\\"TI\\\"]], \\\"]\\\"}]\\) gives a pseudorandom integer in the range \\!\\(\
\\*RowBox[{\\\"{\\\", RowBox[{\\\"0\\\", \\\",\\\", \\\"\[Ellipsis]\\\", \
\\\",\\\", SubscriptBox[\\\"i\\\", \\\"max\\\"]}], \\\"}\\\"}]\\). \
\\n\\!\\(\\*RowBox[{\\\"RandomInteger\\\", \\\"[\\\", \\\"]\\\"}]\\) \
pseudorandomly gives 0 or 1. \\n\\!\\(\\*RowBox[{\\\"RandomInteger\\\", \\\"[\
\\\", RowBox[{StyleBox[\\\"range\\\", \\\"TI\\\"], \\\",\\\", \
StyleBox[\\\"n\\\", \\\"TI\\\"]}], \\\"]\\\"}]\\) gives a list of \
\\!\\(\\*StyleBox[\\\"n\\\", \\\"TI\\\"]\\) pseudorandom integers. \
\\n\\!\\(\\*RowBox[{\\\"RandomInteger\\\", \\\"[\\\", \
RowBox[{StyleBox[\\\"range\\\", \\\"TI\\\"], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{SubscriptBox[StyleBox[\\\"n\\\", \\\"TI\\\"], StyleBox[\\\"1\\\", \
\\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"n\\\", \\\"TI\\\"], \
StyleBox[\\\"2\\\", \\\"TR\\\"]], \\\",\\\", StyleBox[\\\"\[Ellipsis]\\\", \\\
\"TR\\\"]}], \\\"}\\\"}]}], \\\"]\\\"}]\\) gives an \
\\!\\(\\*RowBox[{SubscriptBox[\\\"n\\\", \\\"1\\\"], \\\"\[Cross]\\\", \
SubscriptBox[\\\"n\\\", \\\"2\\\"], \\\"\[Cross]\\\", \\\"\[Ellipsis]\\\", \\\
\" \\\"}]\\) array of pseudorandom integers. \>\""}]}]}], 
    "\[IndentingNewLine]", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Context", "[", "\"\<RandomChoice\>\"", "]"}], "=!=", 
      "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Unprotect", "[", "RandomChoice", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"RandomChoice", "::", "usage"}], "=", 
       "\"\<\\!\\(\\*RowBox[{\\\"RandomChoice\\\", \\\"[\\\", RowBox[{\\\"{\\\
\", RowBox[{SubscriptBox[StyleBox[\\\"e\\\", \\\"TI\\\"], StyleBox[\\\"1\\\", \
\\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"e\\\", \\\"TI\\\"], \
StyleBox[\\\"2\\\", \\\"TR\\\"]], \\\",\\\", StyleBox[\\\"\[Ellipsis]\\\", \\\
\"TR\\\"]}], \\\"}\\\"}], \\\"]\\\"}]\\) gives a pseudorandom choice of one \
of the \\!\\(\\*SubscriptBox[StyleBox[\\\"e\\\", \\\"TI\\\"], \
StyleBox[\\\"i\\\", \\\"TI\\\"]]\\). \
\\n\\!\\(\\*RowBox[{\\\"RandomChoice\\\", \\\"[\\\", \
RowBox[{StyleBox[\\\"list\\\", \\\"TI\\\"], \\\",\\\", StyleBox[\\\"n\\\", \\\
\"TI\\\"]}], \\\"]\\\"}]\\) gives a list of \\!\\(\\*StyleBox[\\\"n\\\", \
\\\"TI\\\"]\\) pseudorandom choices. \
\\n\\!\\(\\*RowBox[{\\\"RandomChoice\\\", \\\"[\\\", \
RowBox[{StyleBox[\\\"list\\\", \\\"TI\\\"], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{SubscriptBox[StyleBox[\\\"n\\\", \\\"TI\\\"], StyleBox[\\\"1\\\", \
\\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"n\\\", \\\"TI\\\"], \
StyleBox[\\\"2\\\", \\\"TR\\\"]], \\\",\\\", StyleBox[\\\"\[Ellipsis]\\\", \\\
\"TR\\\"]}], \\\"}\\\"}]}], \\\"]\\\"}]\\) gives an \
\\!\\(\\*RowBox[{SubscriptBox[StyleBox[\\\"n\\\", \\\"TI\\\"], StyleBox[\\\"1\
\\\", \\\"TR\\\"]], \\\"\[Cross]\\\", SubscriptBox[StyleBox[\\\"n\\\", \\\"TI\
\\\"], StyleBox[\\\"2\\\", \\\"TR\\\"]], \\\"\[Cross]\\\", \
\\\"\[Ellipsis]\\\", \\\" \\\"}]\\) array of pseudorandom choices. \
\>\""}]}]}], "\[IndentingNewLine]", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"  ", 
  RowBox[{
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Context", "[", "\"\<RandomReal\>\"", "]"}], "=!=", 
      "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Unprotect", "[", "RandomReal", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"RandomReal", "::", "usage"}], "=", 
       "\"\<\\!\\(\\*RowBox[{\\\"RandomReal\\\", \\\"[\\\", \\\"]\\\"}]\\) \
gives a pseudorandom real number in the range 0 to 1. \
\\n\\!\\(\\*RowBox[{\\\"RandomReal\\\", \\\"[\\\", RowBox[{\\\"{\\\", \
RowBox[{SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"min\\\", \
\\\"TI\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], \
StyleBox[\\\"max\\\", \\\"TI\\\"]]}], \\\"}\\\"}], \\\"]\\\"}]\\) gives a \
pseudorandom real number in the range \
\\!\\(\\*SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"min\\\", \
\\\"TI\\\"]]\\) to \\!\\(\\*SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], \
StyleBox[\\\"max\\\", \\\"TI\\\"]]\\). \
\\n\\!\\(\\*RowBox[{\\\"RandomReal\\\", \\\"[\\\", \
SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"max\\\", \
\\\"TI\\\"]], \\\"]\\\"}]\\) gives a pseudorandom real number in the range 0 \
to \\!\\(\\*SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], \
StyleBox[\\\"max\\\", \\\"TI\\\"]]\\). \
\\n\\!\\(\\*RowBox[{\\\"RandomReal\\\", \\\"[\\\", RowBox[{StyleBox[\\\"range\
\\\", \\\"TI\\\"], \\\",\\\", StyleBox[\\\"n\\\", \\\"TI\\\"]}], \
\\\"]\\\"}]\\) gives a list of \\!\\(\\*StyleBox[\\\"n\\\", \\\"TI\\\"]\\) \
pseudorandom reals. \\n\\!\\(\\*RowBox[{\\\"RandomReal\\\", \\\"[\\\", \
RowBox[{StyleBox[\\\"range\\\", \\\"TI\\\"], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{SubscriptBox[StyleBox[\\\"n\\\", \\\"TI\\\"], StyleBox[\\\"1\\\", \
\\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"n\\\", \\\"TI\\\"], \
StyleBox[\\\"2\\\", \\\"TR\\\"]], \\\",\\\", StyleBox[\\\"\[Ellipsis]\\\", \\\
\"TR\\\"]}], \\\"}\\\"}]}], \\\"]\\\"}]\\) gives an \
\\!\\(\\*RowBox[{SubscriptBox[\\\"n\\\", \\\"1\\\"], \\\"\[Cross]\\\", \
SubscriptBox[\\\"n\\\", \\\"2\\\"], \\\"\[Cross]\\\", \\\"\[Ellipsis]\\\", \\\
\" \\\"}]\\) array of pseudorandom reals. \>\""}]}]}], "\[IndentingNewLine]", 
    "]"}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Context", "[", "\"\<SortBy\>\"", "]"}], "=!=", 
      "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Unprotect", "[", "SortBy", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"SortBy", "::", "usage"}], "=", 
       "\"\<\\!\\(\\*RowBox[{\\\"SortBy\\\", \\\"[\\\", \
RowBox[{StyleBox[\\\"list\\\", \\\"TI\\\"], \\\",\\\", StyleBox[\\\"f\\\", \\\
\"TI\\\"]}], \\\"]\\\"}]\\) sorts the elements of \
\\!\\(\\*StyleBox[\\\"list\\\", \\\"TI\\\"]\\) in the order defined by \
applying \\!\\(\\*StyleBox[\\\"f\\\", \\\"TI\\\"]\\) to each of them. \>\""}],
       ";"}]}], "\[IndentingNewLine]", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Context", "[", "\"\<Diagonal\>\"", "]"}], "=!=", 
      "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Unprotect", "[", "Diagonal", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Diagonal", "::", "usage"}], "=", 
       "\"\<\\!\\(\\*RowBox[{\\\"Diagonal\\\", \\\"[\\\", StyleBox[\\\"m\\\", \
\\\"TI\\\"], \\\"]\\\"}]\\) gives the list of elements on the leading \
diagonal of the matrix \\!\\(\\*StyleBox[\\\"m\\\", \
\\\"TI\\\"]\\).\\n\\!\\(\\*RowBox[{\\\"Diagonal\\\", \\\"[\\\", \
RowBox[{StyleBox[\\\"m\\\", \\\"TI\\\"], \\\",\\\", StyleBox[\\\"k\\\", \
\\\"TI\\\"]}], \\\"]\\\"}]\\) gives the elements on the \
\\!\\(\\*StyleBox[\\\"k\\\", \
\\\"TI\\\"]\\)\\!\\(\\*SuperscriptBox[\\\"\[Null]\\\", \\\"th\\\"]\\) \
diagonal of \\!\\(\\*StyleBox[\\\"m\\\", \\\"TI\\\"]\\).\>\""}]}]}], 
    "\[IndentingNewLine]", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Context", "[", "\"\<Piecewise\>\"", "]"}], "=!=", 
      "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Unprotect", "[", "Piecewise", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Piecewise", "::", "usage"}], "=", 
       "\"\<\\!\\(\\*RowBox[{\\\"Piecewise\\\", \\\"[\\\", RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", RowBox[{SubscriptBox[StyleBox[\\\"val\\\", \
\\\"TI\\\"], StyleBox[\\\"1\\\", \\\"TR\\\"]], \\\",\\\", \
SubscriptBox[StyleBox[\\\"cond\\\", \\\"TI\\\"], StyleBox[\\\"1\\\", \\\"TR\\\
\"]]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{SubscriptBox[StyleBox[\\\"val\\\", \\\"TI\\\"], StyleBox[\\\"2\\\", \
\\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"cond\\\", \\\"TI\\\"], \
StyleBox[\\\"2\\\", \\\"TR\\\"]]}], \\\"}\\\"}], \\\",\\\", StyleBox[\\\"\
\[Ellipsis]\\\", \\\"TR\\\"]}], \\\"}\\\"}], \\\"]\\\"}]\\) represents a \
piecewise function with values \\!\\(\\*SubscriptBox[StyleBox[\\\"val\\\", \\\
\"TI\\\"], StyleBox[\\\"i\\\", \\\"TI\\\"]]\\) in the regions defined by the \
conditions \\!\\(\\*SubscriptBox[StyleBox[\\\"cond\\\", \\\"TI\\\"], \
StyleBox[\\\"i\\\", \\\"TI\\\"]]\\). \\n\\!\\(\\*RowBox[{\\\"Piecewise\\\", \
\\\"[\\\", RowBox[{RowBox[{\\\"{\\\", RowBox[{RowBox[{\\\"{\\\", \
RowBox[{SubscriptBox[StyleBox[\\\"val\\\", \\\"TI\\\"], StyleBox[\\\"1\\\", \
\\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"cond\\\", \\\"TI\\\"], \
StyleBox[\\\"1\\\", \\\"TR\\\"]]}], \\\"}\\\"}], \\\",\\\", StyleBox[\\\"\
\[Ellipsis]\\\", \\\"TR\\\"]}], \\\"}\\\"}], \\\",\\\", StyleBox[\\\"val\\\", \
\\\"TI\\\"]}], \\\"]\\\"}]\\) uses default value \
\\!\\(\\*StyleBox[\\\"val\\\", \\\"TI\\\"]\\) if none of the \
\\!\\(\\*SubscriptBox[StyleBox[\\\"cond\\\", \\\"TI\\\"], StyleBox[\\\"i\\\", \
\\\"TI\\\"]]\\) apply. The default for \\!\\(\\*StyleBox[\\\"val\\\", \
\\\"TI\\\"]\\) is 0. \>\""}]}]}], "\[IndentingNewLine]", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Context", "[", "\"\<Pick\>\"", "]"}], "=!=", 
      "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Unprotect", "[", "Pick", "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Pick", "::", "usage"}], "=", 
       "\"\<\\!\\(\\*RowBox[{\\\"Pick\\\", \\\"[\\\", \
RowBox[{StyleBox[\\\"list\\\", \\\"TI\\\"], \\\",\\\", StyleBox[\\\"sel\\\", \
\\\"TI\\\"]}], \\\"]\\\"}]\\) picks out those elements of \
\\!\\(\\*StyleBox[\\\"list\\\", \\\"TI\\\"]\\) for which the corresponding \
element of \\!\\(\\*StyleBox[\\\"sel\\\", \\\"TI\\\"]\\) is True. \
\\n\\!\\(\\*RowBox[{\\\"Pick\\\", \\\"[\\\", RowBox[{StyleBox[\\\"list\\\", \
\\\"TI\\\"], \\\",\\\", StyleBox[\\\"sel\\\", \\\"TI\\\"], \\\",\\\", \
StyleBox[\\\"patt\\\", \\\"TI\\\"]}], \\\"]\\\"}]\\) picks out those elements \
of \\!\\(\\*StyleBox[\\\"list\\\", \\\"TI\\\"]\\) for which the corresponding \
element of \\!\\(\\*StyleBox[\\\"sel\\\", \\\"TI\\\"]\\) matches \
\\!\\(\\*StyleBox[\\\"patt\\\", \\\"TI\\\"]\\). \>\""}]}]}], 
    "\[IndentingNewLine]", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{" ", 
  RowBox[{
   RowBox[{"If", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Context", "[", "\"\<FilterRules\>\"", "]"}], "=!=", 
      "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Unprotect", "[", "FilterRules", "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"FilterRules", "::", "usage"}], "=", 
       "\"\<\\!\\(\\*RowBox[{\\\"FilterRules\\\", \\\"[\\\", \
RowBox[{StyleBox[\\\"rules\\\", \\\"TI\\\"], \\\",\\\", \
StyleBox[\\\"patt\\\", \\\"TI\\\"]}], \\\"]\\\"}]\\) filters the list \
\\!\\(\\*StyleBox[\\\"rules\\\", \\\"TI\\\"]\\) by picking out only those \
rules whose left-hand sides match \\!\\(\\*StyleBox[\\\"patt\\\", \\\"TI\\\"]\
\\).\\n\\!\\(\\*RowBox[{\\\"FilterRules\\\", \\\"[\\\", \
RowBox[{StyleBox[\\\"rules\\\", \\\"TI\\\"], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{SubscriptBox[StyleBox[\\\"patt\\\", \\\"TI\\\"], StyleBox[\\\"1\\\", \
\\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"patt\\\", \\\"TI\\\"], \
StyleBox[\\\"2\\\", \\\"TR\\\"]], \\\",\\\", StyleBox[\\\"\[Ellipsis]\\\", \\\
\"TR\\\"]}], \\\"}\\\"}]}], \\\"]\\\"}]\\) picks out rules whose left-hand \
sides match any of the \\!\\(\\*SubscriptBox[StyleBox[\\\"patt\\\", \
\\\"TI\\\"], StyleBox[\\\"i\\\", \\\"TI\\\"]]\\).\>\""}]}]}], 
    "\[IndentingNewLine]", "]"}], ";"}]}]}], "PackageInput"]
}, Closed]],

Cell[CellGroupData[{

Cell["Package Code", "Section"],

Cell[BoxData[
 RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}]], "PackageInput"],

Cell[CellGroupData[{

Cell["ImageData", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Context", "[", "\"\<ImageData\>\"", "]"}], "=!=", 
     "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Options", "[", "ImageData", "]"}], " ", "=", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"DataReversed", "\[Rule]", "False"}], ",", 
        RowBox[{"Interleaving", "\[Rule]", "True"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ImageData", "[", 
       RowBox[{
        RowBox[{"Graphics", "[", 
         RowBox[{
          RowBox[{"Raster", "[", 
           RowBox[{"data_List", ",", "_", ",", "range_List", ",", 
            RowBox[{"ColorFunction", " ", "\[Rule]", " ", 
             RowBox[{"GrayLevel", "|", "RGBColor"}]}]}], "]"}], ",", "___"}], 
         "]"}], ",", 
        RowBox[{"opts___", "?", "OptionQ"}]}], "]"}], " ", ":=", 
      "\[IndentingNewLine]", 
      RowBox[{"Module", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"reverseQ", "=", 
           RowBox[{
            RowBox[{"DataReversed", "/.", 
             RowBox[{"{", "opts", "}"}]}], "/.", 
            RowBox[{"Options", "[", "ImageData", "]"}]}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"interleaveQ", "=", 
           RowBox[{
            RowBox[{"Interleaving", "/.", 
             RowBox[{"{", "opts", "}"}]}], "/.", 
            RowBox[{"Options", "[", "ImageData", "]"}]}]}]}], "}"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Not", "[", "interleaveQ", "]"}], " ", "\[And]", " ", 
             RowBox[{
              RowBox[{"TensorRank", "[", "data", "]"}], "===", "3"}]}], ",", 
            RowBox[{"Transpose", "[", 
             RowBox[{"#", ",", 
              RowBox[{"{", 
               RowBox[{"2", ",", "3", ",", "1"}], "}"}]}], "]"}], ",", "#", 
            ",", "#"}], "]"}], "&"}], "[", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{"reverseQ", ",", "data", ",", 
            RowBox[{"Reverse", "[", "data", "]"}]}], "]"}], "/", 
          RowBox[{"N", "[", 
           RowBox[{"-", 
            RowBox[{"Subtract", "@@", "range"}]}], "]"}]}], "]"}]}], 
       "\[IndentingNewLine]", "]"}]}]}]}], "\[IndentingNewLine]", "]"}], 
  ";"}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Accumulate", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Context", "[", "\"\<Accumulate\>\"", "]"}], "=!=", 
     "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Accumulate", "[", "l_List", "]"}], " ", ":=", " ", 
     RowBox[{"Rest", "[", 
      RowBox[{"FoldList", "[", 
       RowBox[{"Plus", ",", "0", ",", "l"}], "]"}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}], ";"}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Differences", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Context", "[", "\"\<Differences\>\"", "]"}], "=!=", 
     "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Differences", "[", "l_List", "]"}], " ", ":=", " ", 
      RowBox[{"-", 
       RowBox[{"Apply", "[", 
        RowBox[{"Subtract", ",", 
         RowBox[{"Partition", "[", 
          RowBox[{"l", ",", "2", ",", "1"}], "]"}], ",", 
         RowBox[{"{", "1", "}"}]}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Differences", "[", 
       RowBox[{"l_List", ",", 
        RowBox[{"n_Integer", "?", "Positive"}]}], "]"}], ":=", " ", 
      RowBox[{"Nest", "[", 
       RowBox[{"Differences", ",", "l", ",", "n"}], "]"}]}]}]}], 
   "\[IndentingNewLine]", "]"}], ";"}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Riffle", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Context", "[", "\"\<Riffle\>\"", "]"}], "=!=", 
     "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Riffle", "[", 
       RowBox[{"l_List", ",", "elems_List"}], "]"}], " ", ":=", " ", 
      RowBox[{"Most", "[", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"l", ",", 
           RowBox[{"PadRight", "[", 
            RowBox[{"elems", ",", 
             RowBox[{"{", 
              RowBox[{"Length", "[", "l", "]"}], "}"}], ",", "elems"}], 
            "]"}]}], "}"}], "]"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Riffle", "[", 
       RowBox[{"l_List", ",", "elem_"}], "]"}], " ", ":=", " ", 
      RowBox[{"Most", "[", 
       RowBox[{"Flatten", "[", 
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"l", ",", 
           RowBox[{"Table", "[", 
            RowBox[{"elem", ",", 
             RowBox[{"{", 
              RowBox[{"Length", "[", "l", "]"}], "}"}]}], "]"}]}], "}"}], 
         "]"}], "]"}], "]"}]}]}]}], "\[IndentingNewLine]", "]"}], 
  ";"}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TakeWhile", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Context", "[", "\"\<TakeWhile\>\"", "]"}], "=!=", 
     "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"TakeWhile", "[", 
      RowBox[{"l_List", ",", "crit_"}], "]"}], ":=", 
     RowBox[{"Take", "[", 
      RowBox[{"l", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{"#", "===", 
            RowBox[{"{", "}"}]}], ",", "All", ",", 
           RowBox[{
            RowBox[{"#", "\[LeftDoubleBracket]", 
             RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "-", "1"}]}],
           "]"}], "&"}], "[", 
        RowBox[{"Position", "[", 
         RowBox[{"l", ",", 
          RowBox[{"Except", "[", 
           RowBox[{"_", "?", 
            RowBox[{"(", "crit", ")"}]}], "]"}], ",", "1", ",", "1", ",", 
          RowBox[{"Heads", "\[Rule]", " ", "False"}]}], "]"}], "]"}]}], 
      "]"}]}]}], "\[IndentingNewLine]", "]"}], ";"}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["LengthWhile", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Context", "[", "\"\<LengthWhile\>\"", "]"}], "=!=", 
     "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"LengthWhile", "[", 
      RowBox[{"l_List", ",", "crit_"}], "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"#", "===", 
          RowBox[{"{", "}"}]}], ",", 
         RowBox[{"Length", "[", "l", "]"}], ",", 
         RowBox[{
          RowBox[{"#", "\[LeftDoubleBracket]", 
           RowBox[{"1", ",", "1"}], "\[RightDoubleBracket]"}], "-", "1"}]}], 
        "]"}], "&"}], "[", 
      RowBox[{"Position", "[", 
       RowBox[{"l", ",", 
        RowBox[{"Except", "[", 
         RowBox[{"_", "?", 
          RowBox[{"(", "crit", ")"}]}], "]"}], ",", "1", ",", "1", ",", 
        RowBox[{"Heads", "\[Rule]", " ", "False"}]}], "]"}], "]"}]}]}], 
   "\[IndentingNewLine]", "]"}], ";"}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Commonest", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Context", "[", "\"\<Commonest\>\"", "]"}], "=!=", 
     "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Commonest", "[", 
      RowBox[{"l_List", ",", 
       RowBox[{"n_Integer:", "3"}]}], "]"}], ":=", 
     RowBox[{"Module", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"splits", " ", "=", " ", 
          RowBox[{"Split", "[", 
           RowBox[{"Sort", "[", "l", "]"}], "]"}]}], ",", "ords", ",", "f"}], 
        "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"f", "[", "y_", "]"}], ":=", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"f", "[", "y", "]"}], "=", 
            RowBox[{"Sequence", "[", "]"}]}], ";", "y"}], ")"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{"ords", "=", 
         RowBox[{"Take", "[", 
          RowBox[{
           RowBox[{"Ordering", "[", 
            RowBox[{"Map", "[", 
             RowBox[{"Length", ",", "splits"}], "]"}], "]"}], ",", 
           RowBox[{"-", 
            RowBox[{"Min", "[", 
             RowBox[{
              RowBox[{"Max", "[", 
               RowBox[{
                RowBox[{
                 RowBox[{"Length", "[", "splits", "]"}], "-", "1"}], ",", 
                "1"}], "]"}], ",", "n"}], "]"}]}]}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"Replace", "[", 
           RowBox[{
            RowBox[{"Map", "[", 
             RowBox[{"f", ",", "l"}], "]"}], ",", 
            RowBox[{"Dispatch", "[", 
             RowBox[{"Append", "[", 
              RowBox[{
               RowBox[{"Thread", "[", 
                RowBox[{"#", "\[Rule]", "#"}], "]"}], ",", 
               RowBox[{"_", "\[RuleDelayed]", 
                RowBox[{"Sequence", "[", "]"}]}]}], "]"}], "]"}], ",", 
            RowBox[{"{", "1", "}"}]}], "]"}], "&"}], "[", 
         RowBox[{"splits", "\[LeftDoubleBracket]", 
          RowBox[{"ords", ",", "1"}], "\[RightDoubleBracket]"}], "]"}]}]}], 
      "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", "]"}], 
  ";"}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ArrayFlatten", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Context", "[", "\"\<ArrayFlatten\>\"", "]"}], "=!=", 
     "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ArrayFlatten", "[", 
      RowBox[{"submat_List", "/;", 
       RowBox[{
        RowBox[{"TensorRank", "[", "submat", "]"}], "\[GreaterEqual]", 
        "4"}]}], "]"}], ":=", "\[IndentingNewLine]", 
     RowBox[{"Flatten", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Map", "[", "\[IndentingNewLine]", 
        RowBox[{"Flatten", ",", "\[IndentingNewLine]", 
         RowBox[{"Transpose", "[", 
          RowBox[{"submat", ",", 
           RowBox[{"{", 
            RowBox[{"1", ",", "3", ",", "2", ",", "4"}], "}"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"{", "2", "}"}]}], "\[IndentingNewLine]", "]"}], ",", 
       "\[IndentingNewLine]", "1"}], "\[IndentingNewLine]", "]"}]}]}], 
   "\[IndentingNewLine]", "]"}], ";"}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ConstantArray", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Context", "[", "\"\<ConstantArray\>\"", "]"}], "=!=", 
     "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ConstantArray", "[", 
      RowBox[{"c_", ",", "dims_"}], "]"}], ":=", 
     RowBox[{"Array", "[", 
      RowBox[{
       RowBox[{"c", "&"}], ",", "dims"}], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}], ";"}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RandomInteger", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Context", "[", "\"\<RandomInteger\>\"", "]"}], "=!=", 
     "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"RandomInteger", "[", "]"}], " ", ":=", " ", 
      RowBox[{"Random", "[", "Integer", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"RandomInteger", "[", "rng_", "]"}], " ", ":=", " ", 
      RowBox[{"Random", "[", 
       RowBox[{"Integer", ",", "rng"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"RandomInteger", "[", 
       RowBox[{"rng_", ",", "dims_"}], "]"}], " ", ":=", " ", 
      RowBox[{"Array", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Random", "[", 
          RowBox[{"Integer", ",", "rng"}], "]"}], "&"}], ",", "dims"}], 
       "]"}]}]}]}], "\[IndentingNewLine]", "]"}], ";"}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RandomChoice", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Context", "[", "\"\<RandomChoice\>\"", "]"}], "=!=", 
     "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"RandomChoice", "[", "smpl_List", "]"}], " ", ":=", " ", 
      RowBox[{"Part", "[", 
       RowBox[{"smpl", ",", 
        RowBox[{"Random", "[", 
         RowBox[{"Integer", ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", 
            RowBox[{"Length", "[", "smpl", "]"}]}], "}"}]}], "]"}]}], "]"}]}],
      ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"RandomChoice", "[", 
       RowBox[{"smpl_List", ",", "dims_"}], "]"}], " ", ":=", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Part", "[", 
          RowBox[{"smpl", ",", "#"}], "]"}], "&"}], ",", 
        RowBox[{"Array", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Random", "[", 
            RowBox[{"Integer", ",", 
             RowBox[{"{", 
              RowBox[{"1", ",", 
               RowBox[{"Length", "[", "smpl", "]"}]}], "}"}]}], "]"}], "&"}], 
          ",", "dims"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"-", "1"}], "}"}]}], "]"}]}]}]}], "\[IndentingNewLine]", 
   "]"}], ";"}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["RandomReal", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Context", "[", "\"\<RandomReal\>\"", "]"}], "=!=", 
     "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"RandomReal", "[", "]"}], " ", ":=", " ", 
      RowBox[{"Random", "[", "Real", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"RandomReal", "[", "rng_", "]"}], " ", ":=", " ", 
      RowBox[{"Random", "[", 
       RowBox[{"Real", ",", "rng"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"RandomReal", "[", 
       RowBox[{"rng_", ",", "dims_"}], "]"}], " ", ":=", " ", 
      RowBox[{"Array", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Random", "[", 
          RowBox[{"Real", ",", "rng"}], "]"}], "&"}], ",", "dims"}], 
       "]"}]}]}]}], "\[IndentingNewLine]", "]"}], ";"}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SortBy", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Context", "[", "\"\<SortBy\>\"", "]"}], "=!=", 
     "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"SortBy", "[", 
      RowBox[{"l_List", ",", 
       RowBox[{"f", ":", 
        RowBox[{"(", 
         RowBox[{"_Symbol", "|", "_Function"}], ")"}]}]}], "]"}], ":=", " ", 
     RowBox[{
      RowBox[{"Sort", "[", 
       RowBox[{"Map", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"f", "[", "#", "]"}], ",", "#"}], "}"}], "&"}], ",", 
         "l"}], "]"}], "]"}], "\[LeftDoubleBracket]", 
      RowBox[{"All", ",", "1"}], "\[RightDoubleBracket]"}]}]}], 
   "\[IndentingNewLine]", "]"}], ";"}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Diagonal", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Context", "[", "\"\<Diagonal\>\"", "]"}], "=!=", 
     "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Diagonal", "[", 
       RowBox[{"mat_", "?", "MatrixQ"}], "]"}], " ", ":=", " ", 
      RowBox[{"Transpose", "[", 
       RowBox[{
        RowBox[{"PadRight", "[", 
         RowBox[{"mat", ",", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{"#", ",", "#"}], "}"}], "&"}], "[", 
           RowBox[{"Min", "[", 
            RowBox[{"Dimensions", "[", "mat", "]"}], "]"}], "]"}]}], "]"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1"}], "}"}]}], "]"}]}], ";", 
     RowBox[{
      RowBox[{"Diagonal", "[", 
       RowBox[{
        RowBox[{"mat_", "?", "MatrixQ"}], ",", "0"}], "]"}], " ", ":=", " ", 
      RowBox[{"Transpose", "[", 
       RowBox[{
        RowBox[{"PadRight", "[", 
         RowBox[{"mat", ",", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{"#", ",", "#"}], "}"}], "&"}], "[", 
           RowBox[{"Min", "[", 
            RowBox[{"Dimensions", "[", "mat", "]"}], "]"}], "]"}]}], "]"}], 
        ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "1"}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Diagonal", "[", 
       RowBox[{
        RowBox[{"mat_", "?", "MatrixQ"}], ",", 
        RowBox[{"n_Integer", "?", "Positive"}]}], "]"}], " ", ":=", " ", 
      RowBox[{"Diagonal", "[", 
       RowBox[{"Drop", "[", 
        RowBox[{"mat", ",", "0", ",", "n"}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Diagonal", "[", 
       RowBox[{
        RowBox[{"mat_", "?", "MatrixQ"}], ",", 
        RowBox[{"n_Integer", "?", "Negative"}]}], "]"}], " ", ":=", " ", 
      RowBox[{"Diagonal", "[", 
       RowBox[{"Drop", "[", 
        RowBox[{"mat", ",", 
         RowBox[{"-", "n"}]}], "]"}], "]"}]}]}]}], "\[IndentingNewLine]", 
   "]"}], ";"}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Piecewise", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Context", "[", "\"\<Piecewise\>\"", "]"}], "=!=", 
     "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Piecewise", "[", "def_List", "]"}], ":=", 
      RowBox[{"Apply", "[", 
       RowBox[{"Which", ",", 
        RowBox[{"Flatten", "[", 
         RowBox[{"Map", "[", 
          RowBox[{"Reverse", ",", "def"}], "]"}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Piecewise", "[", 
       RowBox[{"def_List", ",", "val_"}], "]"}], ":=", 
      RowBox[{"Apply", "[", 
       RowBox[{"Which", ",", 
        RowBox[{"Flatten", "[", 
         RowBox[{"Append", "[", 
          RowBox[{
           RowBox[{"Map", "[", 
            RowBox[{"Reverse", ",", "def"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"True", ",", "val"}], "}"}]}], "]"}], "]"}]}], 
       "]"}]}]}]}], "\[IndentingNewLine]", "]"}], ";"}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pick", "Subsection"],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Context", "[", "\"\<Pick\>\"", "]"}], "=!=", 
     "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"Pick", "[", 
       RowBox[{"data_List", ",", "sel_List", ",", "patt_"}], "]"}], ":=", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Part", "[", 
          RowBox[{"data", ",", "#"}], "]"}], "&"}], ",", 
        RowBox[{"Flatten", "[", 
         RowBox[{"Position", "[", 
          RowBox[{"sel", ",", "patt", ",", 
           RowBox[{"{", "1", "}"}]}], "]"}], "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Pick", "[", 
       RowBox[{"data_List", ",", "sel_List"}], "]"}], ":=", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Part", "[", 
          RowBox[{"data", ",", "#"}], "]"}], "&"}], ",", 
        RowBox[{"Flatten", "[", 
         RowBox[{"Position", "[", 
          RowBox[{"sel", ",", "True", ",", 
           RowBox[{"{", "1", "}"}]}], "]"}], "]"}]}], "]"}]}]}]}], 
   "\[IndentingNewLine]", "]"}], ";"}]], "PackageInput"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FilterRules", "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"FilterRules", "[", 
    RowBox[{
     RowBox[{"opts", ":", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"_Rule", "|", "_RuleDelayed"}], ")"}], "..."}], "}"}]}], ",",
      "pat_"}], "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"Cases", "[", 
     RowBox[{"opts", ",", "pat"}], "]"}], "/;", " ", 
    RowBox[{
     RowBox[{"Head", "[", "pat", "]"}], "\[NotEqual]", "List"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FilterRules", "[", 
   RowBox[{
    RowBox[{"opts", ":", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"_Rule", "|", "_RuleDelayed"}], ")"}], "..."}], "}"}]}], ",", 
    "pats_List"}], "]"}], ":=", " ", 
  RowBox[{"Cases", "[", 
   RowBox[{"opts", ",", 
    RowBox[{"Alternatives", "@@", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"#", "\[Rule]", " ", "_"}], ")"}], "&"}], ",", "pats"}], 
      "]"}]}]}], "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Context", "[", "\"\<FilterRules\>\"", "]"}], "=!=", 
     "\"\<System`\>\""}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"FilterRules", "[", 
       RowBox[{"rules_List", ",", "symbs_List"}], "]"}], ":=", 
      "\[IndentingNewLine]", 
      RowBox[{"Flatten", "[", " ", 
       RowBox[{
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"FilterRules", "[", 
            RowBox[{"rules", ",", "#"}], "]"}], "&"}], ",", "symbs"}], "]"}], 
        ",", "1"}], "]"}]}], ";", 
     RowBox[{
      RowBox[{"FilterRules", "[", 
       RowBox[{"rules_List", ",", 
        RowBox[{"symb", ":", 
         RowBox[{"(", 
          RowBox[{"_Symbol", "|", 
           RowBox[{"Except", "[", "_Symbol", "]"}]}], ")"}]}]}], "]"}], ":=", 
      "\[IndentingNewLine]", " ", 
      RowBox[{"Extract", "[", 
       RowBox[{"rules", ",", 
        RowBox[{"Position", "[", 
         RowBox[{
          RowBox[{"Map", "[", 
           RowBox[{"First", ",", "rules"}], "]"}], ",", "symb", ",", 
          RowBox[{"{", "1", "}"}], ",", 
          RowBox[{"Heads", "\[Rule]", "False"}]}], "]"}]}], "]"}]}], ";", 
     RowBox[{
      RowBox[{"FilterRules", "[", 
       RowBox[{"rules_List", ",", 
        RowBox[{"symb", ":", "_String"}]}], "]"}], ":=", 
      "\[IndentingNewLine]", " ", 
      RowBox[{"Extract", "[", 
       RowBox[{"rules", ",", 
        RowBox[{"Position", "[", 
         RowBox[{
          RowBox[{"Map", "[", 
           RowBox[{"First", ",", "rules"}], "]"}], ",", 
          RowBox[{"Symbol", "[", "symb", "]"}], ",", 
          RowBox[{"{", "1", "}"}], ",", 
          RowBox[{"Heads", "\[Rule]", "False"}]}], "]"}]}], "]"}]}]}]}], 
   "\[IndentingNewLine]", "]"}], ";"}]], "PackageInput"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Closing Package", "Section"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"End", "[", "]"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetAttributes", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "Interleaving", ",", "ImageData", ",", "Accumulate", ",", "Differences", 
      ",", "Riffle", ",", "TakeWhile", ",", "LengthWhile", ",", "Commonest", 
      ",", "ArrayFlatten", ",", "ConstantArray", ",", "RandomInteger", ",", 
      "RandomChoice", ",", "RandomReal", ",", "SortBy", ",", "Diagonal", ",", 
      "Piecewise", ",", "Pick", ",", "FilterRules"}], "}"}], ",", 
    RowBox[{"{", "Protected", "}"}]}], "\[IndentingNewLine]", "]"}], 
  ";"}]}], "PackageInput"],

Cell[BoxData[
 RowBox[{"EndPackage", "[", "]"}]], "PackageInput",
 InitializationCell->True]
}, Closed]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
WindowSize->{1076, 940},
WindowMargins->{{25, Automatic}, {Automatic, 0}},
ShowSelection->True,
Magnification->1.5,
FrontEndVersion->"7.0 for Mac OS X x86 (32-bit) (November 10, 2008)",
StyleDefinitions->Notebook[{
   Cell[
    CellGroupData[{
      Cell["Style Definitions", "Subtitle"], 
      Cell[
      "Modify the definitions below to change the default appearance of all \
cells in a given style.  Make modifications to any definition using commands \
in the Format menu.", "Text"], 
      Cell[
       CellGroupData[{
         Cell["Style Environment Names", "Section"], 
         Cell[
          StyleData[All, "Working"], PageWidth -> WindowWidth, 
          CellLabelMargins -> {{12, Inherited}, {Inherited, Inherited}}, 
          ScriptMinSize -> 9], 
         Cell[
          StyleData[All, "Presentation"], PageWidth -> WindowWidth, 
          CellLabelMargins -> {{24, Inherited}, {Inherited, Inherited}}, 
          ScriptMinSize -> 12], 
         Cell[
          StyleData[All, "Condensed"], PageWidth -> WindowWidth, 
          CellLabelMargins -> {{8, Inherited}, {Inherited, Inherited}}, 
          ScriptMinSize -> 8], 
         Cell[
          StyleData[All, "Printout"], PageWidth -> PaperWidth, 
          CellLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          ScriptMinSize -> 5, 
          PrivateFontOptions -> {"FontType" -> "Outline"}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Notebook Options", "Section"], 
         Cell[
         "The options defined for the style below will be used at the \
Notebook level.", "Text"], 
         Cell[
          StyleData["Notebook"], PageHeaders -> {{
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"], None, 
             Cell[
              TextData[{
                ValueBox["FileName"]}], "Header"]}, {
             Cell[
              TextData[{
                ValueBox["FileName"]}], "Header"], None, 
             Cell[
              TextData[{
                CounterBox["Page"]}], "PageNumber"]}}, CellFrameLabelMargins -> 
          6, StyleMenuListing -> None]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headings", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Title"], CellMargins -> {{12, Inherited}, {20, 40}}, 
             CellGroupingRules -> {"TitleGrouping", 0}, PageBreakBelow -> 
             False, DefaultNewInlineCellStyle -> "None", 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", Inherited}, 
             LineSpacing -> {1, 11}, LanguageCategory -> "NaturalLanguage", 
             CounterIncrements -> "Title", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}, {"Subtitle", 0}, {"Subsubtitle", 0}}, FontFamily -> 
             "Helvetica", FontSize -> 36, FontWeight -> "Bold"], 
            Cell[
             StyleData["Title", "Presentation"], 
             CellMargins -> {{24, 10}, {20, 40}}, LineSpacing -> {1, 0}, 
             FontSize -> 44], 
            Cell[
             StyleData["Title", "Condensed"], 
             CellMargins -> {{8, 10}, {4, 8}}, FontSize -> 20], 
            Cell[
             StyleData["Title", "Printout"], 
             CellMargins -> {{2, 10}, {12, 30}}, FontSize -> 24]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subtitle"], 
             CellMargins -> {{12, Inherited}, {20, 15}}, 
             CellGroupingRules -> {"TitleGrouping", 10}, PageBreakBelow -> 
             False, DefaultNewInlineCellStyle -> "None", 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", Inherited}, 
             LanguageCategory -> "NaturalLanguage", CounterIncrements -> 
             "Subtitle", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}, {"Subsubtitle", 0}}, FontFamily -> "Helvetica", 
             FontSize -> 24], 
            Cell[
             StyleData["Subtitle", "Presentation"], 
             CellMargins -> {{24, 10}, {20, 20}}, LineSpacing -> {1, 0}, 
             FontSize -> 36], 
            Cell[
             StyleData["Subtitle", "Condensed"], 
             CellMargins -> {{8, 10}, {4, 4}}, FontSize -> 14], 
            Cell[
             StyleData["Subtitle", "Printout"], 
             CellMargins -> {{2, 10}, {12, 8}}, FontSize -> 18]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubtitle"], 
             CellMargins -> {{12, Inherited}, {20, 15}}, 
             CellGroupingRules -> {"TitleGrouping", 20}, PageBreakBelow -> 
             False, DefaultNewInlineCellStyle -> "None", 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", Inherited}, 
             LanguageCategory -> "NaturalLanguage", CounterIncrements -> 
             "Subsubtitle", 
             CounterAssignments -> {{"Section", 0}, {"Equation", 0}, {
               "Figure", 0}}, FontFamily -> "Helvetica", FontSize -> 14, 
             FontSlant -> "Italic"], 
            Cell[
             StyleData["Subsubtitle", "Presentation"], 
             CellMargins -> {{24, 10}, {20, 20}}, LineSpacing -> {1, 0}, 
             FontSize -> 24], 
            Cell[
             StyleData["Subsubtitle", "Condensed"], 
             CellMargins -> {{8, 10}, {8, 8}}, FontSize -> 12], 
            Cell[
             StyleData["Subsubtitle", "Printout"], 
             CellMargins -> {{2, 10}, {12, 8}}, FontSize -> 14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Section"], CellDingbat -> "\[FilledSquare]", 
             CellMargins -> {{25, Inherited}, {8, 24}}, 
             CellGroupingRules -> {"SectionGrouping", 30}, PageBreakBelow -> 
             False, DefaultNewInlineCellStyle -> "None", 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", Inherited}, 
             LineSpacing -> {1, 7}, LanguageCategory -> "NaturalLanguage", 
             CounterIncrements -> "Section", 
             CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}}, 
             FontFamily -> "Helvetica", FontSize -> 16, FontWeight -> "Bold"], 
            Cell[
             StyleData["Section", "Presentation"], 
             CellMargins -> {{40, 10}, {11, 32}}, LineSpacing -> {1, 0}, 
             FontSize -> 24], 
            Cell[
             StyleData["Section", "Condensed"], 
             CellMargins -> {{18, Inherited}, {6, 12}}, FontSize -> 12], 
            Cell[
             StyleData["Section", "Printout"], 
             CellMargins -> {{13, 0}, {7, 22}}, FontSize -> 14]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsection"], CellDingbat -> "\[FilledSmallSquare]", 
             CellMargins -> {{22, Inherited}, {8, 20}}, 
             CellGroupingRules -> {"SectionGrouping", 40}, PageBreakBelow -> 
             False, DefaultNewInlineCellStyle -> "None", 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", Inherited}, 
             LanguageCategory -> "NaturalLanguage", CounterIncrements -> 
             "Subsection", CounterAssignments -> {{"Subsubsection", 0}}, 
             FontFamily -> "Times", FontSize -> 14, FontWeight -> "Bold"], 
            Cell[
             StyleData["Subsection", "Presentation"], 
             CellMargins -> {{36, 10}, {11, 32}}, LineSpacing -> {1, 0}, 
             FontSize -> 22], 
            Cell[
             StyleData["Subsection", "Condensed"], 
             CellMargins -> {{16, Inherited}, {6, 12}}, FontSize -> 12], 
            Cell[
             StyleData["Subsection", "Printout"], 
             CellMargins -> {{9, 0}, {7, 22}}, FontSize -> 12]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Subsubsection"], CellDingbat -> 
             "\[FilledSmallSquare]", 
             CellMargins -> {{22, Inherited}, {8, 18}}, 
             CellGroupingRules -> {"SectionGrouping", 50}, PageBreakBelow -> 
             False, DefaultNewInlineCellStyle -> "None", 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", Inherited}, 
             LanguageCategory -> "NaturalLanguage", CounterIncrements -> 
             "Subsubsection", FontFamily -> "Times", FontWeight -> "Bold"], 
            Cell[
             StyleData["Subsubsection", "Presentation"], 
             CellMargins -> {{34, 10}, {11, 26}}, LineSpacing -> {1, 0}, 
             FontSize -> 18], 
            Cell[
             StyleData["Subsubsection", "Condensed"], 
             CellMargins -> {{17, Inherited}, {6, 12}}, FontSize -> 10], 
            Cell[
             StyleData["Subsubsection", "Printout"], 
             CellMargins -> {{9, 0}, {7, 14}}, FontSize -> 11]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Body Text", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Text"], CellMargins -> {{12, 10}, {7, 7}}, 
             InputAutoReplacements -> {"TeX" -> StyleBox[
                 RowBox[{"T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "LaTeX" -> StyleBox[
                 RowBox[{"L", 
                   StyleBox[
                    AdjustmentBox[
                    "A", BoxMargins -> {{-0.36, -0.1}, {0, 0}}, 
                    BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
                   AdjustmentBox[
                   "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
                    BoxBaselineShift -> 0.5], "X"}]], "mma" -> "Mathematica", 
               "Mma" -> "Mathematica", "MMA" -> "Mathematica", Inherited}, 
             Hyphenation -> True, LineSpacing -> {1, 3}, CounterIncrements -> 
             "Text"], 
            Cell[
             StyleData["Text", "Presentation"], 
             CellMargins -> {{24, 10}, {10, 10}}, LineSpacing -> {1, 5}, 
             FontSize -> 16], 
            Cell[
             StyleData["Text", "Condensed"], CellMargins -> {{8, 10}, {6, 6}},
              LineSpacing -> {1, 1}, FontSize -> 11], 
            Cell[
             StyleData["Text", "Printout"], CellMargins -> {{2, 2}, {6, 6}}, 
             TextJustification -> 0.5, FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SmallText"], CellMargins -> {{12, 10}, {6, 6}}, 
             DefaultNewInlineCellStyle -> "None", Hyphenation -> True, 
             LineSpacing -> {1, 3}, LanguageCategory -> "NaturalLanguage", 
             CounterIncrements -> "SmallText", FontFamily -> "Helvetica", 
             FontSize -> 9], 
            Cell[
             StyleData["SmallText", "Presentation"], 
             CellMargins -> {{24, 10}, {8, 8}}, LineSpacing -> {1, 5}, 
             FontSize -> 12], 
            Cell[
             StyleData["SmallText", "Condensed"], 
             CellMargins -> {{8, 10}, {5, 5}}, LineSpacing -> {1, 2}, 
             FontSize -> 9], 
            Cell[
             StyleData["SmallText", "Printout"], 
             CellMargins -> {{2, 2}, {5, 5}}, TextJustification -> 0.5, 
             FontSize -> 7]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Input/Output", "Section"], 
         Cell[
         "The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). ", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Input"], CellMargins -> {{45, 10}, {5, 7}}, 
             Evaluatable -> True, CellGroupingRules -> "InputGrouping", 
             CellHorizontalScrolling -> True, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, DefaultFormatType -> 
             DefaultInputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, 
             AutoItalicWords -> {}, LanguageCategory -> "Mathematica", 
             FormatType -> InputForm, ShowStringCharacters -> True, 
             NumberMarks -> True, LinebreakAdjustments -> {0.85, 2, 10, 0, 1},
              CounterIncrements -> "Input", FontWeight -> "Bold"], 
            Cell[
             StyleData["Input", "Presentation"], 
             CellMargins -> {{72, Inherited}, {8, 10}}, LineSpacing -> {1, 0},
              FontSize -> 16], 
            Cell[
             StyleData["Input", "Condensed"], 
             CellMargins -> {{40, 10}, {2, 3}}, FontSize -> 11], 
            Cell[
             StyleData["Input", "Printout"], CellMargins -> {{39, 0}, {4, 6}},
              LinebreakAdjustments -> {0.85, 2, 10, 1, 1}, FontSize -> 9]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["PackageInput"], CellMargins -> {{45, 10}, {5, 7}}, 
             Evaluatable -> True, CellGroupingRules -> "InputGrouping", 
             CellHorizontalScrolling -> True, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, InitializationCell -> True, 
             DefaultFormatType -> DefaultInputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, 
             AutoItalicWords -> {}, LanguageCategory -> "Mathematica", 
             FormatType -> InputForm, ShowStringCharacters -> True, 
             NumberMarks -> True, LinebreakAdjustments -> {0.85, 2, 10, 0, 1},
              CounterIncrements -> "Input", FontWeight -> "Bold", Background -> 
             RGBColor[0.500008, 1, 0.566644]], 
            Cell[
             StyleData["PackageInput", "Presentation"], 
             CellMargins -> {{72, Inherited}, {8, 10}}, LineSpacing -> {1, 0},
              FontSize -> 16], 
            Cell[
             StyleData["PackageInput", "Condensed"], 
             CellMargins -> {{40, 10}, {2, 3}}, FontSize -> 11], 
            Cell[
             StyleData["PackageInput", "Printout"], 
             CellMargins -> {{39, 0}, {4, 6}}, 
             LinebreakAdjustments -> {0.85, 2, 10, 1, 1}, FontSize -> 9, 
             Background -> GrayLevel[1]]}, Closed]], 
         Cell[
          StyleData["InputOnly"], Evaluatable -> True, CellGroupingRules -> 
          "InputGrouping", CellHorizontalScrolling -> True, DefaultFormatType -> 
          DefaultInputFormatType, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, LanguageCategory -> "Mathematica", 
          FormatType -> InputForm, ShowStringCharacters -> True, NumberMarks -> 
          True, LinebreakAdjustments -> {0.85, 2, 10, 0, 1}, 
          CounterIncrements -> "Input", StyleMenuListing -> None, FontWeight -> 
          "Bold"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Output"], CellMargins -> {{47, 10}, {7, 5}}, 
             CellEditDuplicate -> True, CellGroupingRules -> "OutputGrouping",
              CellHorizontalScrolling -> True, PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, DefaultFormatType -> 
             DefaultOutputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, 
             AutoItalicWords -> {}, LanguageCategory -> None, FormatType -> 
             InputForm, CounterIncrements -> "Output"], 
            Cell[
             StyleData["Output", "Presentation"], 
             CellMargins -> {{72, Inherited}, {10, 8}}, LineSpacing -> {1, 0},
              FontSize -> 16], 
            Cell[
             StyleData["Output", "Condensed"], 
             CellMargins -> {{41, Inherited}, {3, 2}}, FontSize -> 11], 
            Cell[
             StyleData["Output", "Printout"], 
             CellMargins -> {{39, 0}, {6, 4}}, FontSize -> 9]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Message"], 
             CellMargins -> {{45, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "OutputGrouping", PageBreakWithin -> False, 
             GroupPageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             DefaultFormatType -> DefaultOutputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, 
             AutoItalicWords -> {}, LanguageCategory -> None, FormatType -> 
             InputForm, CounterIncrements -> "Message", StyleMenuListing -> 
             None, FontSize -> 11, FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["Message", "Presentation"], 
             CellMargins -> {{72, Inherited}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 0}, FontSize -> 16], 
            Cell[
             StyleData["Message", "Condensed"], 
             CellMargins -> {{41, Inherited}, {Inherited, Inherited}}, 
             FontSize -> 11], 
            Cell[
             StyleData["Message", "Printout"], 
             CellMargins -> {{39, Inherited}, {Inherited, Inherited}}, 
             FontSize -> 7, FontColor -> GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Print"], 
             CellMargins -> {{45, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "OutputGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GroupPageBreakWithin -> False, 
             GeneratedCell -> True, CellAutoOverwrite -> True, ShowCellLabel -> 
             False, DefaultFormatType -> DefaultOutputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, 
             AutoItalicWords -> {}, LanguageCategory -> None, FormatType -> 
             InputForm, CounterIncrements -> "Print", StyleMenuListing -> 
             None], 
            Cell[
             StyleData["Print", "Presentation"], 
             CellMargins -> {{72, Inherited}, {Inherited, Inherited}}, 
             LineSpacing -> {1, 0}, FontSize -> 16], 
            Cell[
             StyleData["Print", "Condensed"], 
             CellMargins -> {{41, Inherited}, {Inherited, Inherited}}, 
             FontSize -> 11], 
            Cell[
             StyleData["Print", "Printout"], 
             CellMargins -> {{39, Inherited}, {Inherited, Inherited}}, 
             FontSize -> 8]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Graphics"], 
             CellMargins -> {{4, Inherited}, {Inherited, Inherited}}, 
             CellGroupingRules -> "GraphicsGrouping", CellHorizontalScrolling -> 
             True, PageBreakWithin -> False, GeneratedCell -> True, 
             CellAutoOverwrite -> True, ShowCellLabel -> False, 
             DefaultFormatType -> DefaultOutputFormatType, LanguageCategory -> 
             None, FormatType -> InputForm, CounterIncrements -> "Graphics", 
             ImageMargins -> {{43, Inherited}, {Inherited, 0}}, 
             StyleMenuListing -> None, FontFamily -> "Courier", FontSize -> 
             10], 
            Cell[
             StyleData["Graphics", "Presentation"], 
             ImageMargins -> {{62, Inherited}, {Inherited, 0}}], 
            Cell[
             StyleData["Graphics", "Condensed"], 
             ImageMargins -> {{38, Inherited}, {Inherited, 0}}, Magnification -> 
             0.6], 
            Cell[
             StyleData["Graphics", "Printout"], 
             ImageMargins -> {{30, Inherited}, {Inherited, 0}}, Magnification -> 
             0.8]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["CellLabel"], LanguageCategory -> None, 
             StyleMenuListing -> None, FontFamily -> "Helvetica", FontSize -> 
             9, FontColor -> RGBColor[0, 0, 1]], 
            Cell[
             StyleData["CellLabel", "Presentation"], FontSize -> 12], 
            Cell[
             StyleData["CellLabel", "Condensed"], FontSize -> 9], 
            Cell[
             StyleData["CellLabel", "Printout"], FontFamily -> "Courier", 
             FontSize -> 8, FontSlant -> "Italic", FontColor -> 
             GrayLevel[0]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Inline Formatting", "Section"], 
         Cell[
         "These styles are for modifying individual words or letters in a \
cell exclusive of the cell tag.", "Text"], 
         Cell[
          StyleData["RM"], StyleMenuListing -> None, FontWeight -> "Plain", 
          FontSlant -> "Plain"], 
         Cell[
          StyleData["BF"], StyleMenuListing -> None, FontWeight -> "Bold"], 
         Cell[
          StyleData["IT"], StyleMenuListing -> None, FontSlant -> "Italic"], 
         Cell[
          StyleData["TR"], StyleMenuListing -> None, FontFamily -> "Times", 
          FontWeight -> "Plain", FontSlant -> "Plain"], 
         Cell[
          StyleData["TI"], StyleMenuListing -> None, FontFamily -> "Times", 
          FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["TB"], StyleMenuListing -> None, FontFamily -> "Times", 
          FontWeight -> "Bold", FontSlant -> "Plain"], 
         Cell[
          StyleData["TBI"], StyleMenuListing -> None, FontFamily -> "Times", 
          FontWeight -> "Bold", FontSlant -> "Italic"], 
         Cell[
          StyleData["MR"], 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           StyleMenuListing -> None, FontFamily -> "Courier", FontWeight -> 
          "Plain", FontSlant -> "Plain"], 
         Cell[
          StyleData["MO"], 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           StyleMenuListing -> None, FontFamily -> "Courier", FontWeight -> 
          "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["MB"], 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           StyleMenuListing -> None, FontFamily -> "Courier", FontWeight -> 
          "Bold", FontSlant -> "Plain"], 
         Cell[
          StyleData["MBO"], 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           StyleMenuListing -> None, FontFamily -> "Courier", FontWeight -> 
          "Bold", FontSlant -> "Italic"], 
         Cell[
          StyleData["SR"], StyleMenuListing -> None, FontFamily -> 
          "Helvetica", FontWeight -> "Plain", FontSlant -> "Plain"], 
         Cell[
          StyleData["SO"], StyleMenuListing -> None, FontFamily -> 
          "Helvetica", FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["SB"], StyleMenuListing -> None, FontFamily -> 
          "Helvetica", FontWeight -> "Bold", FontSlant -> "Plain"], 
         Cell[
          StyleData["SBO"], StyleMenuListing -> None, FontFamily -> 
          "Helvetica", FontWeight -> "Bold", FontSlant -> "Italic"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["SO10"], StyleMenuListing -> None, FontFamily -> 
             "Helvetica", FontSize -> 10, FontWeight -> "Plain", FontSlant -> 
             "Italic"], 
            Cell[
             StyleData["SO10", "Printout"], StyleMenuListing -> None, 
             FontFamily -> "Helvetica", FontSize -> 7, FontWeight -> "Plain", 
             FontSlant -> "Italic"], 
            Cell[
             StyleData["SO10", "EnhancedPrintout"], StyleMenuListing -> None, 
             FontFamily -> "Futura", FontSize -> 7, FontWeight -> "Plain", 
             FontSlant -> "Italic"]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Formulas and Programming", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["InlineFormula"], CellMargins -> {{10, 4}, {0, 8}}, 
             CellHorizontalScrolling -> True, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Formula", ScriptLevel -> 1, SingleLetterItalics -> True], 
            Cell[
             StyleData["InlineFormula", "Presentation"], 
             CellMargins -> {{24, 10}, {10, 10}}, LineSpacing -> {1, 5}, 
             FontSize -> 16], 
            Cell[
             StyleData["InlineFormula", "Condensed"], 
             CellMargins -> {{8, 10}, {6, 6}}, LineSpacing -> {1, 1}, 
             FontSize -> 11], 
            Cell[
             StyleData["InlineFormula", "Printout"], 
             CellMargins -> {{2, 0}, {6, 6}}, FontSize -> 10]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["DisplayFormula"], 
             CellMargins -> {{42, Inherited}, {Inherited, Inherited}}, 
             CellHorizontalScrolling -> True, DefaultFormatType -> 
             DefaultInputFormatType, 
             HyphenationOptions -> {
              "HyphenationCharacter" -> "\[Continuation]"}, LanguageCategory -> 
             "Formula", ScriptLevel -> 0, SingleLetterItalics -> True, 
             UnderoverscriptBoxOptions -> {LimitsPositioning -> True}], 
            Cell[
             StyleData["DisplayFormula", "Presentation"], 
             LineSpacing -> {1, 5}, FontSize -> 16], 
            Cell[
             StyleData["DisplayFormula", "Condensed"], LineSpacing -> {1, 1}, 
             FontSize -> 11], 
            Cell[
             StyleData["DisplayFormula", "Printout"], FontSize -> 10]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Program"], CellFrame -> {{0, 0}, {0.5, 0.5}}, 
             CellMargins -> {{10, 4}, {0, 8}}, CellHorizontalScrolling -> 
             True, Hyphenation -> False, LanguageCategory -> "Formula", 
             ScriptLevel -> 1, FontFamily -> "Courier"], 
            Cell[
             StyleData["Program", "Presentation"], 
             CellMargins -> {{24, 10}, {10, 10}}, LineSpacing -> {1, 5}, 
             FontSize -> 16], 
            Cell[
             StyleData["Program", "Condensed"], 
             CellMargins -> {{8, 10}, {6, 6}}, LineSpacing -> {1, 1}, 
             FontSize -> 11], 
            Cell[
             StyleData["Program", "Printout"], 
             CellMargins -> {{2, 0}, {6, 6}}, FontSize -> 9]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Outline Styles", "Section"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Outline1"], CellMargins -> {{12, 10}, {7, 7}}, 
             CellGroupingRules -> {"SectionGrouping", 50}, 
             ParagraphIndent -> -38, CounterIncrements -> "Outline1", 
             FontSize -> 18, FontWeight -> "Bold", 
             CounterBoxOptions -> {CounterFunction :> CapitalRomanNumeral}], 
            Cell[
             StyleData["Outline1", "Printout"], 
             CounterBoxOptions -> {CounterFunction :> CapitalRomanNumeral}]}, 
           Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Outline2"], CellMargins -> {{59, 10}, {7, 7}}, 
             CellGroupingRules -> {"SectionGrouping", 60}, 
             ParagraphIndent -> -27, CounterIncrements -> "Outline2", 
             FontSize -> 15, FontWeight -> "Bold", 
             CounterBoxOptions -> {CounterFunction :> (Part[
                 CharacterRange["A", "Z"], #]& )}], 
            Cell[
             StyleData["Outline2", "Printout"], 
             CounterBoxOptions -> {CounterFunction :> (Part[
                 CharacterRange["A", "Z"], #]& )}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Outline3"], CellMargins -> {{108, 10}, {7, 7}}, 
             CellGroupingRules -> {"SectionGrouping", 70}, 
             ParagraphIndent -> -21, CounterIncrements -> "Outline3", 
             FontSize -> 12, 
             CounterBoxOptions -> {CounterFunction :> Identity}], 
            Cell[
             StyleData["Outline3", "Printout"], 
             CounterBoxOptions -> {CounterFunction :> Identity}]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Outline4"], CellMargins -> {{158, 10}, {7, 7}}, 
             CellGroupingRules -> {"SectionGrouping", 80}, 
             ParagraphIndent -> -18, CounterIncrements -> "Outline4", 
             FontSize -> 10, CounterBoxOptions -> {CounterFunction :> (Part[
                 CharacterRange["a", "z"], #]& )}], 
            Cell[
             StyleData["Outline4", "Printout"]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Hyperlink Styles", "Section"], 
         Cell[
         "The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Hyperlink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`NotebookLocate[#2]}]& ), ButtonNote -> 
               ButtonData}], 
            Cell[
             StyleData["Hyperlink", "Presentation"], FontSize -> 16], 
            Cell[
             StyleData["Hyperlink", "Condensed"], FontSize -> 11], 
            Cell[
             StyleData["Hyperlink", "Printout"], FontSize -> 10, 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
         "The following styles are for linking automatically to the on-line \
help system.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["MainBookLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["MainBook", #]}]& )}], 
            Cell[
             StyleData["MainBookLink", "Presentation"], FontSize -> 16], 
            Cell[
             StyleData["MainBookLink", "Condensed"], FontSize -> 11], 
            Cell[
             StyleData["MainBookLink", "Printout"], FontSize -> 10, 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["AddOnsLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontFamily -> "Courier", 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["AddOns", #]}]& )}], 
            Cell[
             StyleData["AddOnsLink", "Presentation"], FontSize -> 16], 
            Cell[
             StyleData["AddOnsLink", "Condensed"], FontSize -> 11], 
            Cell[
             StyleData["AddOnsLink", "Printout"], FontSize -> 10, 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["RefGuideLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, FontFamily -> "Courier", 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["RefGuide", #]}]& )}], 
            Cell[
             StyleData["RefGuideLink", "Presentation"], FontSize -> 16], 
            Cell[
             StyleData["RefGuideLink", "Condensed"], FontSize -> 11], 
            Cell[
             StyleData["RefGuideLink", "Printout"], FontSize -> 10, 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["GettingStartedLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["GettingStarted", #]}]& )}], 
            Cell[
             StyleData["GettingStartedLink", "Presentation"], FontSize -> 16], 
            Cell[
             StyleData["GettingStartedLink", "Condensed"], FontSize -> 11], 
            Cell[
             StyleData["GettingStartedLink", "Printout"], FontSize -> 10, 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["OtherInformationLink"], StyleMenuListing -> None, 
             ButtonStyleMenuListing -> Automatic, 
             FontVariations -> {"Underline" -> True}, FontColor -> 
             RGBColor[0, 0, 1], 
             ButtonBoxOptions -> {
              Active -> True, Appearance -> {Automatic, None}, 
               ButtonFunction :> (FrontEndExecute[{
                  FrontEnd`HelpBrowserLookup["OtherInformation", #]}]& )}], 
            Cell[
             StyleData["OtherInformationLink", "Presentation"], FontSize -> 
             16], 
            Cell[
             StyleData["OtherInformationLink", "Condensed"], FontSize -> 11], 
            
            Cell[
             StyleData["OtherInformationLink", "Printout"], FontSize -> 10, 
             FontVariations -> {"Underline" -> False}, FontColor -> 
             GrayLevel[0]]}, Closed]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Styles for Headers and Footers", "Section"], 
         Cell[
          StyleData["Header"], CellMargins -> {{0, 0}, {4, 1}}, 
          DefaultNewInlineCellStyle -> "None", LanguageCategory -> 
          "NaturalLanguage", StyleMenuListing -> None, FontSize -> 10, 
          FontSlant -> "Italic"], 
         Cell[
          StyleData["Footer"], CellMargins -> {{0, 0}, {0, 4}}, 
          DefaultNewInlineCellStyle -> "None", LanguageCategory -> 
          "NaturalLanguage", StyleMenuListing -> None, FontSize -> 9, 
          FontSlant -> "Italic"], 
         Cell[
          StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
          StyleMenuListing -> None, FontFamily -> "Times", FontSize -> 10]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["Palette Styles", "Section"], 
         Cell[
         "The cells below define styles that define standard ButtonFunctions, \
for use in palette buttons.", "Text"], 
         Cell[
          StyleData["Paste"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, After]}]& )}], 
         Cell[
          StyleData["Evaluate"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               SelectionEvaluate[
                FrontEnd`InputNotebook[], All]}]& )}], 
         Cell[
          StyleData["EvaluateCell"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               FrontEnd`SelectionMove[
                FrontEnd`InputNotebook[], All, Cell, 1], 
               FrontEnd`SelectionEvaluateCreateCell[
                FrontEnd`InputNotebook[], All]}]& )}], 
         Cell[
          StyleData["CopyEvaluate"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`SelectionCreateCell[
                FrontEnd`InputNotebook[], All], 
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               FrontEnd`SelectionEvaluate[
                FrontEnd`InputNotebook[], All]}]& )}], 
         Cell[
          StyleData["CopyEvaluateCell"], StyleMenuListing -> None, 
          ButtonStyleMenuListing -> Automatic, 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               FrontEnd`SelectionCreateCell[
                FrontEnd`InputNotebook[], All], 
               FrontEnd`NotebookApply[
                FrontEnd`InputNotebook[], #, All], 
               FrontEnd`SelectionEvaluateCreateCell[
                FrontEnd`InputNotebook[], All]}]& )}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Placeholder Styles", "Section"], 
         Cell[
         "The cells below define styles useful for making placeholder objects \
in palette templates.", "Text"], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["Placeholder"], Placeholder -> True, StyleMenuListing -> 
             None, FontSlant -> "Italic", FontColor -> 
             RGBColor[0.890623, 0.864698, 0.384756], 
             TagBoxOptions -> {
              Editable -> False, Selectable -> False, StripWrapperBoxes -> 
               False}], 
            Cell[
             StyleData["Placeholder", "Presentation"]], 
            Cell[
             StyleData["Placeholder", "Condensed"]], 
            Cell[
             StyleData["Placeholder", "Printout"]]}, Closed]], 
         Cell[
          CellGroupData[{
            Cell[
             StyleData["PrimaryPlaceholder"], StyleMenuListing -> None, 
             DrawHighlighted -> True, FontSlant -> "Italic", Background -> 
             RGBColor[0.912505, 0.891798, 0.507774], 
             TagBoxOptions -> {
              Editable -> False, Selectable -> False, StripWrapperBoxes -> 
               False}], 
            Cell[
             StyleData["PrimaryPlaceholder", "Presentation"]], 
            Cell[
             StyleData["PrimaryPlaceholder", "Condensed"]], 
            Cell[
             StyleData["PrimaryPlaceholder", "Printout"]]}, Closed]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell["FormatType Styles", "Section"], 
         Cell[
         "The cells below define styles that are mixed in with the styles of \
most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.", "Text"], 
         Cell[
          StyleData["CellExpression"], PageWidth -> Infinity, 
          CellMargins -> {{6, Inherited}, {Inherited, Inherited}}, 
          ShowCellLabel -> False, ShowSpecialCharacters -> False, 
          AllowInlineCells -> False, Hyphenation -> False, 
          AutoItalicWords -> {}, StyleMenuListing -> None, FontFamily -> 
          "Courier", FontSize -> 12, Background -> GrayLevel[1]], 
         Cell[
          StyleData["InputForm"], InputAutoReplacements -> {}, 
          AllowInlineCells -> False, Hyphenation -> False, StyleMenuListing -> 
          None, FontFamily -> "Courier"], 
         Cell[
          StyleData["OutputForm"], PageWidth -> Infinity, TextAlignment -> 
          Left, LineSpacing -> {0.6, 1}, StyleMenuListing -> None, FontFamily -> 
          "Courier"], 
         Cell[
          StyleData["StandardForm"], 
          InputAutoReplacements -> {
           "->" -> "\[Rule]", ":>" -> "\[RuleDelayed]", "<=" -> 
            "\[LessEqual]", ">=" -> "\[GreaterEqual]", "!=" -> "\[NotEqual]", 
            "==" -> "\[Equal]", Inherited}, LineSpacing -> {1.25, 0}, 
          StyleMenuListing -> None, FontFamily -> "Courier"], 
         Cell[
          StyleData["TraditionalForm"], 
          InputAutoReplacements -> {
           "->" -> "\[Rule]", ":>" -> "\[RuleDelayed]", "<=" -> 
            "\[LessEqual]", ">=" -> "\[GreaterEqual]", "!=" -> "\[NotEqual]", 
            "==" -> "\[Equal]", Inherited}, LineSpacing -> {1.25, 0}, 
          SingleLetterItalics -> True, TraditionalFunctionNotation -> True, 
          DelimiterMatching -> None, StyleMenuListing -> None], 
         Cell[
         "The style defined below is mixed in to any cell that is in an \
inline cell within another.", "Text"], 
         Cell[
          StyleData["InlineCell"], LanguageCategory -> "Formula", ScriptLevel -> 
          1, StyleMenuListing -> None], 
         Cell[
          StyleData["InlineCellEditing"], StyleMenuListing -> None, 
          Background -> RGBColor[1, 0.749996, 0.8]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell["Automatic Styles", "Section"], 
         Cell[
         "The cells below define styles that are used to affect the display \
of certain types of objects in typeset expressions.  For example, \
\"UnmatchedBracket\" style defines how unmatched bracket, curly bracket, and \
parenthesis characters are displayed (typically by coloring them to make them \
stand out).", "Text"], 
         Cell[
          StyleData["UnmatchedBracket"], StyleMenuListing -> None, FontColor -> 
          RGBColor[0.760006, 0.330007, 0.8]]}, Closed]]}, Open]]}, Visible -> 
  False, FrontEndVersion -> 
  "7.0 for Mac OS X x86 (32-bit) (November 10, 2008)", StyleDefinitions -> 
  "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 46, 0, 144, "Title"],
Cell[616, 24, 101, 3, 96, "Subsubtitle"],
Cell[CellGroupData[{
Cell[742, 31, 25, 0, 72, "Section"],
Cell[770, 33, 962, 25, 436, "PackageInput"],
Cell[1735, 60, 128, 3, 58, "Text"],
Cell[1866, 65, 3263, 90, 1126, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[5166, 160, 32, 0, 40, "Section"],
Cell[5201, 162, 92, 2, 87, "Text"],
Cell[5296, 166, 27, 0, 81, "Input"],
Cell[5326, 168, 146, 3, 135, "PackageInput",
 InitializationCell->True]
}, Closed]],
Cell[CellGroupData[{
Cell[5509, 176, 42, 0, 40, "Section"],
Cell[5554, 178, 25461, 480, 10717, "PackageInput"]
}, Closed]],
Cell[CellGroupData[{
Cell[31052, 663, 31, 0, 40, "Section"],
Cell[31086, 665, 81, 1, 90, "PackageInput"],
Cell[CellGroupData[{
Cell[31192, 670, 31, 0, 94, "Subsection"],
Cell[31226, 672, 2480, 64, 508, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33743, 741, 32, 0, 94, "Subsection"],
Cell[33778, 743, 473, 12, 196, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[34288, 760, 33, 0, 94, "Subsection"],
Cell[34324, 762, 864, 22, 232, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[35225, 789, 28, 0, 94, "Subsection"],
Cell[35256, 791, 1255, 34, 267, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36548, 830, 31, 0, 94, "Subsection"],
Cell[36582, 832, 1054, 28, 267, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[37673, 865, 33, 0, 94, "Subsection"],
Cell[37709, 867, 1000, 27, 400, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38746, 899, 31, 0, 141, "Subsection"],
Cell[38780, 901, 2271, 60, 609, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41088, 966, 34, 0, 141, "Subsection"],
Cell[41125, 968, 1025, 24, 708, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42187, 997, 35, 0, 141, "Subsection"],
Cell[42225, 999, 470, 13, 294, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42732, 1017, 35, 0, 141, "Subsection"],
Cell[42770, 1019, 928, 23, 400, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43735, 1047, 34, 0, 141, "Subsection"],
Cell[43772, 1049, 1321, 37, 400, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[45130, 1091, 32, 0, 141, "Subsection"],
Cell[45165, 1093, 907, 23, 400, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[46109, 1121, 28, 0, 94, "Subsection"],
Cell[46140, 1123, 808, 23, 294, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[46985, 1151, 30, 0, 94, "Subsection"],
Cell[47018, 1153, 2107, 60, 373, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[49162, 1218, 31, 0, 94, "Subsection"],
Cell[49196, 1220, 1027, 28, 267, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[50260, 1253, 26, 0, 94, "Subsection"],
Cell[50289, 1255, 1186, 33, 267, "PackageInput"]
}, Open  ]],
Cell[CellGroupData[{
Cell[51512, 1293, 33, 0, 94, "Subsection"],
Cell[51548, 1295, 1020, 34, 163, "Input"],
Cell[52571, 1331, 1863, 50, 372, "PackageInput"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[54483, 1387, 34, 0, 40, "Section"],
Cell[54520, 1389, 666, 14, 298, "PackageInput"],
Cell[55189, 1405, 92, 2, 90, "PackageInput",
 InitializationCell->True]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
